(function(){const t=document.createElement("link").relList;if(t&&t.supports&&t.supports("modulepreload"))return;for(const l of document.querySelectorAll('link[rel="modulepreload"]'))a(l);new MutationObserver(l=>{for(const s of l)if(s.type==="childList")for(const o of s.addedNodes)o.tagName==="LINK"&&o.rel==="modulepreload"&&a(o)}).observe(document,{childList:!0,subtree:!0});function n(l){const s={};return l.integrity&&(s.integrity=l.integrity),l.referrerPolicy&&(s.referrerPolicy=l.referrerPolicy),l.crossOrigin==="use-credentials"?s.credentials="include":l.crossOrigin==="anonymous"?s.credentials="omit":s.credentials="same-origin",s}function a(l){if(l.ep)return;l.ep=!0;const s=n(l);fetch(l.href,s)}})();function zc(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}var fh={exports:{}},Yu={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var x4;function yv(){if(x4)return Yu;x4=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.fragment");function n(a,l,s){var o=null;if(s!==void 0&&(o=""+s),l.key!==void 0&&(o=""+l.key),"key"in l){s={};for(var d in l)d!=="key"&&(s[d]=l[d])}else s=l;return l=s.ref,{$$typeof:e,type:a,key:o,ref:l!==void 0?l:null,props:s}}return Yu.Fragment=t,Yu.jsx=n,Yu.jsxs=n,Yu}var k4;function vv(){return k4||(k4=1,fh.exports=yv()),fh.exports}var gt=vv(),hh={exports:{}},ct={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var N4;function Tv(){if(N4)return ct;N4=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),a=Symbol.for("react.strict_mode"),l=Symbol.for("react.profiler"),s=Symbol.for("react.consumer"),o=Symbol.for("react.context"),d=Symbol.for("react.forward_ref"),f=Symbol.for("react.suspense"),h=Symbol.for("react.memo"),p=Symbol.for("react.lazy"),E=Symbol.iterator;function T(A){return A===null||typeof A!="object"?null:(A=E&&A[E]||A["@@iterator"],typeof A=="function"?A:null)}var v={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},x=Object.assign,N={};function D(A,te,ue){this.props=A,this.context=te,this.refs=N,this.updater=ue||v}D.prototype.isReactComponent={},D.prototype.setState=function(A,te){if(typeof A!="object"&&typeof A!="function"&&A!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,A,te,"setState")},D.prototype.forceUpdate=function(A){this.updater.enqueueForceUpdate(this,A,"forceUpdate")};function C(){}C.prototype=D.prototype;function I(A,te,ue){this.props=A,this.context=te,this.refs=N,this.updater=ue||v}var F=I.prototype=new C;F.constructor=I,x(F,D.prototype),F.isPureReactComponent=!0;var J=Array.isArray,K={H:null,A:null,T:null,S:null,V:null},U=Object.prototype.hasOwnProperty;function le(A,te,ue,R,De,Ge){return ue=Ge.ref,{$$typeof:e,type:A,key:te,ref:ue!==void 0?ue:null,props:Ge}}function ae(A,te){return le(A.type,te,void 0,void 0,void 0,A.props)}function se(A){return typeof A=="object"&&A!==null&&A.$$typeof===e}function G(A){var te={"=":"=0",":":"=2"};return"$"+A.replace(/[=:]/g,function(ue){return te[ue]})}var ge=/\/+/g;function ce(A,te){return typeof A=="object"&&A!==null&&A.key!=null?G(""+A.key):te.toString(36)}function Se(){}function fe(A){switch(A.status){case"fulfilled":return A.value;case"rejected":throw A.reason;default:switch(typeof A.status=="string"?A.then(Se,Se):(A.status="pending",A.then(function(te){A.status==="pending"&&(A.status="fulfilled",A.value=te)},function(te){A.status==="pending"&&(A.status="rejected",A.reason=te)})),A.status){case"fulfilled":return A.value;case"rejected":throw A.reason}}throw A}function ye(A,te,ue,R,De){var Ge=typeof A;(Ge==="undefined"||Ge==="boolean")&&(A=null);var Le=!1;if(A===null)Le=!0;else switch(Ge){case"bigint":case"string":case"number":Le=!0;break;case"object":switch(A.$$typeof){case e:case t:Le=!0;break;case p:return Le=A._init,ye(Le(A._payload),te,ue,R,De)}}if(Le)return De=De(A),Le=R===""?"."+ce(A,0):R,J(De)?(ue="",Le!=null&&(ue=Le.replace(ge,"$&/")+"/"),ye(De,te,ue,"",function(Wt){return Wt})):De!=null&&(se(De)&&(De=ae(De,ue+(De.key==null||A&&A.key===De.key?"":(""+De.key).replace(ge,"$&/")+"/")+Le)),te.push(De)),1;Le=0;var kt=R===""?".":R+":";if(J(A))for(var it=0;it<A.length;it++)R=A[it],Ge=kt+ce(R,it),Le+=ye(R,te,ue,Ge,De);else if(it=T(A),typeof it=="function")for(A=it.call(A),it=0;!(R=A.next()).done;)R=R.value,Ge=kt+ce(R,it++),Le+=ye(R,te,ue,Ge,De);else if(Ge==="object"){if(typeof A.then=="function")return ye(fe(A),te,ue,R,De);throw te=String(A),Error("Objects are not valid as a React child (found: "+(te==="[object Object]"?"object with keys {"+Object.keys(A).join(", ")+"}":te)+"). If you meant to render a collection of children, use an array instead.")}return Le}function X(A,te,ue){if(A==null)return A;var R=[],De=0;return ye(A,R,"","",function(Ge){return te.call(ue,Ge,De++)}),R}function oe(A){if(A._status===-1){var te=A._result;te=te(),te.then(function(ue){(A._status===0||A._status===-1)&&(A._status=1,A._result=ue)},function(ue){(A._status===0||A._status===-1)&&(A._status=2,A._result=ue)}),A._status===-1&&(A._status=0,A._result=te)}if(A._status===1)return A._result.default;throw A._result}var be=typeof reportError=="function"?reportError:function(A){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var te=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof A=="object"&&A!==null&&typeof A.message=="string"?String(A.message):String(A),error:A});if(!window.dispatchEvent(te))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",A);return}console.error(A)};function ze(){}return ct.Children={map:X,forEach:function(A,te,ue){X(A,function(){te.apply(this,arguments)},ue)},count:function(A){var te=0;return X(A,function(){te++}),te},toArray:function(A){return X(A,function(te){return te})||[]},only:function(A){if(!se(A))throw Error("React.Children.only expected to receive a single React element child.");return A}},ct.Component=D,ct.Fragment=n,ct.Profiler=l,ct.PureComponent=I,ct.StrictMode=a,ct.Suspense=f,ct.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=K,ct.__COMPILER_RUNTIME={__proto__:null,c:function(A){return K.H.useMemoCache(A)}},ct.cache=function(A){return function(){return A.apply(null,arguments)}},ct.cloneElement=function(A,te,ue){if(A==null)throw Error("The argument must be a React element, but you passed "+A+".");var R=x({},A.props),De=A.key,Ge=void 0;if(te!=null)for(Le in te.ref!==void 0&&(Ge=void 0),te.key!==void 0&&(De=""+te.key),te)!U.call(te,Le)||Le==="key"||Le==="__self"||Le==="__source"||Le==="ref"&&te.ref===void 0||(R[Le]=te[Le]);var Le=arguments.length-2;if(Le===1)R.children=ue;else if(1<Le){for(var kt=Array(Le),it=0;it<Le;it++)kt[it]=arguments[it+2];R.children=kt}return le(A.type,De,void 0,void 0,Ge,R)},ct.createContext=function(A){return A={$$typeof:o,_currentValue:A,_currentValue2:A,_threadCount:0,Provider:null,Consumer:null},A.Provider=A,A.Consumer={$$typeof:s,_context:A},A},ct.createElement=function(A,te,ue){var R,De={},Ge=null;if(te!=null)for(R in te.key!==void 0&&(Ge=""+te.key),te)U.call(te,R)&&R!=="key"&&R!=="__self"&&R!=="__source"&&(De[R]=te[R]);var Le=arguments.length-2;if(Le===1)De.children=ue;else if(1<Le){for(var kt=Array(Le),it=0;it<Le;it++)kt[it]=arguments[it+2];De.children=kt}if(A&&A.defaultProps)for(R in Le=A.defaultProps,Le)De[R]===void 0&&(De[R]=Le[R]);return le(A,Ge,void 0,void 0,null,De)},ct.createRef=function(){return{current:null}},ct.forwardRef=function(A){return{$$typeof:d,render:A}},ct.isValidElement=se,ct.lazy=function(A){return{$$typeof:p,_payload:{_status:-1,_result:A},_init:oe}},ct.memo=function(A,te){return{$$typeof:h,type:A,compare:te===void 0?null:te}},ct.startTransition=function(A){var te=K.T,ue={};K.T=ue;try{var R=A(),De=K.S;De!==null&&De(ue,R),typeof R=="object"&&R!==null&&typeof R.then=="function"&&R.then(ze,be)}catch(Ge){be(Ge)}finally{K.T=te}},ct.unstable_useCacheRefresh=function(){return K.H.useCacheRefresh()},ct.use=function(A){return K.H.use(A)},ct.useActionState=function(A,te,ue){return K.H.useActionState(A,te,ue)},ct.useCallback=function(A,te){return K.H.useCallback(A,te)},ct.useContext=function(A){return K.H.useContext(A)},ct.useDebugValue=function(){},ct.useDeferredValue=function(A,te){return K.H.useDeferredValue(A,te)},ct.useEffect=function(A,te,ue){var R=K.H;if(typeof ue=="function")throw Error("useEffect CRUD overload is not enabled in this build of React.");return R.useEffect(A,te)},ct.useId=function(){return K.H.useId()},ct.useImperativeHandle=function(A,te,ue){return K.H.useImperativeHandle(A,te,ue)},ct.useInsertionEffect=function(A,te){return K.H.useInsertionEffect(A,te)},ct.useLayoutEffect=function(A,te){return K.H.useLayoutEffect(A,te)},ct.useMemo=function(A,te){return K.H.useMemo(A,te)},ct.useOptimistic=function(A,te){return K.H.useOptimistic(A,te)},ct.useReducer=function(A,te,ue){return K.H.useReducer(A,te,ue)},ct.useRef=function(A){return K.H.useRef(A)},ct.useState=function(A){return K.H.useState(A)},ct.useSyncExternalStore=function(A,te,ue){return K.H.useSyncExternalStore(A,te,ue)},ct.useTransition=function(){return K.H.useTransition()},ct.version="19.1.0",ct}var w4;function Hc(){return w4||(w4=1,hh.exports=Tv()),hh.exports}var Qe=Hc();const he=zc(Qe);var mh={exports:{}},Gu={},ph={exports:{}},gh={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var C4;function _v(){return C4||(C4=1,function(e){function t(X,oe){var be=X.length;X.push(oe);e:for(;0<be;){var ze=be-1>>>1,A=X[ze];if(0<l(A,oe))X[ze]=oe,X[be]=A,be=ze;else break e}}function n(X){return X.length===0?null:X[0]}function a(X){if(X.length===0)return null;var oe=X[0],be=X.pop();if(be!==oe){X[0]=be;e:for(var ze=0,A=X.length,te=A>>>1;ze<te;){var ue=2*(ze+1)-1,R=X[ue],De=ue+1,Ge=X[De];if(0>l(R,be))De<A&&0>l(Ge,R)?(X[ze]=Ge,X[De]=be,ze=De):(X[ze]=R,X[ue]=be,ze=ue);else if(De<A&&0>l(Ge,be))X[ze]=Ge,X[De]=be,ze=De;else break e}}return oe}function l(X,oe){var be=X.sortIndex-oe.sortIndex;return be!==0?be:X.id-oe.id}if(e.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var s=performance;e.unstable_now=function(){return s.now()}}else{var o=Date,d=o.now();e.unstable_now=function(){return o.now()-d}}var f=[],h=[],p=1,E=null,T=3,v=!1,x=!1,N=!1,D=!1,C=typeof setTimeout=="function"?setTimeout:null,I=typeof clearTimeout=="function"?clearTimeout:null,F=typeof setImmediate<"u"?setImmediate:null;function J(X){for(var oe=n(h);oe!==null;){if(oe.callback===null)a(h);else if(oe.startTime<=X)a(h),oe.sortIndex=oe.expirationTime,t(f,oe);else break;oe=n(h)}}function K(X){if(N=!1,J(X),!x)if(n(f)!==null)x=!0,U||(U=!0,ce());else{var oe=n(h);oe!==null&&ye(K,oe.startTime-X)}}var U=!1,le=-1,ae=5,se=-1;function G(){return D?!0:!(e.unstable_now()-se<ae)}function ge(){if(D=!1,U){var X=e.unstable_now();se=X;var oe=!0;try{e:{x=!1,N&&(N=!1,I(le),le=-1),v=!0;var be=T;try{t:{for(J(X),E=n(f);E!==null&&!(E.expirationTime>X&&G());){var ze=E.callback;if(typeof ze=="function"){E.callback=null,T=E.priorityLevel;var A=ze(E.expirationTime<=X);if(X=e.unstable_now(),typeof A=="function"){E.callback=A,J(X),oe=!0;break t}E===n(f)&&a(f),J(X)}else a(f);E=n(f)}if(E!==null)oe=!0;else{var te=n(h);te!==null&&ye(K,te.startTime-X),oe=!1}}break e}finally{E=null,T=be,v=!1}oe=void 0}}finally{oe?ce():U=!1}}}var ce;if(typeof F=="function")ce=function(){F(ge)};else if(typeof MessageChannel<"u"){var Se=new MessageChannel,fe=Se.port2;Se.port1.onmessage=ge,ce=function(){fe.postMessage(null)}}else ce=function(){C(ge,0)};function ye(X,oe){le=C(function(){X(e.unstable_now())},oe)}e.unstable_IdlePriority=5,e.unstable_ImmediatePriority=1,e.unstable_LowPriority=4,e.unstable_NormalPriority=3,e.unstable_Profiling=null,e.unstable_UserBlockingPriority=2,e.unstable_cancelCallback=function(X){X.callback=null},e.unstable_forceFrameRate=function(X){0>X||125<X?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):ae=0<X?Math.floor(1e3/X):5},e.unstable_getCurrentPriorityLevel=function(){return T},e.unstable_next=function(X){switch(T){case 1:case 2:case 3:var oe=3;break;default:oe=T}var be=T;T=oe;try{return X()}finally{T=be}},e.unstable_requestPaint=function(){D=!0},e.unstable_runWithPriority=function(X,oe){switch(X){case 1:case 2:case 3:case 4:case 5:break;default:X=3}var be=T;T=X;try{return oe()}finally{T=be}},e.unstable_scheduleCallback=function(X,oe,be){var ze=e.unstable_now();switch(typeof be=="object"&&be!==null?(be=be.delay,be=typeof be=="number"&&0<be?ze+be:ze):be=ze,X){case 1:var A=-1;break;case 2:A=250;break;case 5:A=1073741823;break;case 4:A=1e4;break;default:A=5e3}return A=be+A,X={id:p++,callback:oe,priorityLevel:X,startTime:be,expirationTime:A,sortIndex:-1},be>ze?(X.sortIndex=be,t(h,X),n(f)===null&&X===n(h)&&(N?(I(le),le=-1):N=!0,ye(K,be-ze))):(X.sortIndex=A,t(f,X),x||v||(x=!0,U||(U=!0,ce()))),X},e.unstable_shouldYield=G,e.unstable_wrapCallback=function(X){var oe=T;return function(){var be=T;T=oe;try{return X.apply(this,arguments)}finally{T=be}}}}(gh)),gh}var O4;function Sv(){return O4||(O4=1,ph.exports=_v()),ph.exports}var bh={exports:{}},Xn={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var R4;function Av(){if(R4)return Xn;R4=1;var e=Hc();function t(f){var h="https://react.dev/errors/"+f;if(1<arguments.length){h+="?args[]="+encodeURIComponent(arguments[1]);for(var p=2;p<arguments.length;p++)h+="&args[]="+encodeURIComponent(arguments[p])}return"Minified React error #"+f+"; visit "+h+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function n(){}var a={d:{f:n,r:function(){throw Error(t(522))},D:n,C:n,L:n,m:n,X:n,S:n,M:n},p:0,findDOMNode:null},l=Symbol.for("react.portal");function s(f,h,p){var E=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:l,key:E==null?null:""+E,children:f,containerInfo:h,implementation:p}}var o=e.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function d(f,h){if(f==="font")return"";if(typeof h=="string")return h==="use-credentials"?h:""}return Xn.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=a,Xn.createPortal=function(f,h){var p=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!h||h.nodeType!==1&&h.nodeType!==9&&h.nodeType!==11)throw Error(t(299));return s(f,h,null,p)},Xn.flushSync=function(f){var h=o.T,p=a.p;try{if(o.T=null,a.p=2,f)return f()}finally{o.T=h,a.p=p,a.d.f()}},Xn.preconnect=function(f,h){typeof f=="string"&&(h?(h=h.crossOrigin,h=typeof h=="string"?h==="use-credentials"?h:"":void 0):h=null,a.d.C(f,h))},Xn.prefetchDNS=function(f){typeof f=="string"&&a.d.D(f)},Xn.preinit=function(f,h){if(typeof f=="string"&&h&&typeof h.as=="string"){var p=h.as,E=d(p,h.crossOrigin),T=typeof h.integrity=="string"?h.integrity:void 0,v=typeof h.fetchPriority=="string"?h.fetchPriority:void 0;p==="style"?a.d.S(f,typeof h.precedence=="string"?h.precedence:void 0,{crossOrigin:E,integrity:T,fetchPriority:v}):p==="script"&&a.d.X(f,{crossOrigin:E,integrity:T,fetchPriority:v,nonce:typeof h.nonce=="string"?h.nonce:void 0})}},Xn.preinitModule=function(f,h){if(typeof f=="string")if(typeof h=="object"&&h!==null){if(h.as==null||h.as==="script"){var p=d(h.as,h.crossOrigin);a.d.M(f,{crossOrigin:p,integrity:typeof h.integrity=="string"?h.integrity:void 0,nonce:typeof h.nonce=="string"?h.nonce:void 0})}}else h==null&&a.d.M(f)},Xn.preload=function(f,h){if(typeof f=="string"&&typeof h=="object"&&h!==null&&typeof h.as=="string"){var p=h.as,E=d(p,h.crossOrigin);a.d.L(f,p,{crossOrigin:E,integrity:typeof h.integrity=="string"?h.integrity:void 0,nonce:typeof h.nonce=="string"?h.nonce:void 0,type:typeof h.type=="string"?h.type:void 0,fetchPriority:typeof h.fetchPriority=="string"?h.fetchPriority:void 0,referrerPolicy:typeof h.referrerPolicy=="string"?h.referrerPolicy:void 0,imageSrcSet:typeof h.imageSrcSet=="string"?h.imageSrcSet:void 0,imageSizes:typeof h.imageSizes=="string"?h.imageSizes:void 0,media:typeof h.media=="string"?h.media:void 0})}},Xn.preloadModule=function(f,h){if(typeof f=="string")if(h){var p=d(h.as,h.crossOrigin);a.d.m(f,{as:typeof h.as=="string"&&h.as!=="script"?h.as:void 0,crossOrigin:p,integrity:typeof h.integrity=="string"?h.integrity:void 0})}else a.d.m(f)},Xn.requestFormReset=function(f){a.d.r(f)},Xn.unstable_batchedUpdates=function(f,h){return f(h)},Xn.useFormState=function(f,h,p){return o.H.useFormState(f,h,p)},Xn.useFormStatus=function(){return o.H.useHostTransitionStatus()},Xn.version="19.1.0",Xn}var M4;function g6(){if(M4)return bh.exports;M4=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),bh.exports=Av(),bh.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var D4;function xv(){if(D4)return Gu;D4=1;var e=Sv(),t=Hc(),n=g6();function a(r){var i="https://react.dev/errors/"+r;if(1<arguments.length){i+="?args[]="+encodeURIComponent(arguments[1]);for(var u=2;u<arguments.length;u++)i+="&args[]="+encodeURIComponent(arguments[u])}return"Minified React error #"+r+"; visit "+i+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function l(r){return!(!r||r.nodeType!==1&&r.nodeType!==9&&r.nodeType!==11)}function s(r){var i=r,u=r;if(r.alternate)for(;i.return;)i=i.return;else{r=i;do i=r,(i.flags&4098)!==0&&(u=i.return),r=i.return;while(r)}return i.tag===3?u:null}function o(r){if(r.tag===13){var i=r.memoizedState;if(i===null&&(r=r.alternate,r!==null&&(i=r.memoizedState)),i!==null)return i.dehydrated}return null}function d(r){if(s(r)!==r)throw Error(a(188))}function f(r){var i=r.alternate;if(!i){if(i=s(r),i===null)throw Error(a(188));return i!==r?null:r}for(var u=r,c=i;;){var m=u.return;if(m===null)break;var g=m.alternate;if(g===null){if(c=m.return,c!==null){u=c;continue}break}if(m.child===g.child){for(g=m.child;g;){if(g===u)return d(m),r;if(g===c)return d(m),i;g=g.sibling}throw Error(a(188))}if(u.return!==c.return)u=m,c=g;else{for(var S=!1,w=m.child;w;){if(w===u){S=!0,u=m,c=g;break}if(w===c){S=!0,c=m,u=g;break}w=w.sibling}if(!S){for(w=g.child;w;){if(w===u){S=!0,u=g,c=m;break}if(w===c){S=!0,c=g,u=m;break}w=w.sibling}if(!S)throw Error(a(189))}}if(u.alternate!==c)throw Error(a(190))}if(u.tag!==3)throw Error(a(188));return u.stateNode.current===u?r:i}function h(r){var i=r.tag;if(i===5||i===26||i===27||i===6)return r;for(r=r.child;r!==null;){if(i=h(r),i!==null)return i;r=r.sibling}return null}var p=Object.assign,E=Symbol.for("react.element"),T=Symbol.for("react.transitional.element"),v=Symbol.for("react.portal"),x=Symbol.for("react.fragment"),N=Symbol.for("react.strict_mode"),D=Symbol.for("react.profiler"),C=Symbol.for("react.provider"),I=Symbol.for("react.consumer"),F=Symbol.for("react.context"),J=Symbol.for("react.forward_ref"),K=Symbol.for("react.suspense"),U=Symbol.for("react.suspense_list"),le=Symbol.for("react.memo"),ae=Symbol.for("react.lazy"),se=Symbol.for("react.activity"),G=Symbol.for("react.memo_cache_sentinel"),ge=Symbol.iterator;function ce(r){return r===null||typeof r!="object"?null:(r=ge&&r[ge]||r["@@iterator"],typeof r=="function"?r:null)}var Se=Symbol.for("react.client.reference");function fe(r){if(r==null)return null;if(typeof r=="function")return r.$$typeof===Se?null:r.displayName||r.name||null;if(typeof r=="string")return r;switch(r){case x:return"Fragment";case D:return"Profiler";case N:return"StrictMode";case K:return"Suspense";case U:return"SuspenseList";case se:return"Activity"}if(typeof r=="object")switch(r.$$typeof){case v:return"Portal";case F:return(r.displayName||"Context")+".Provider";case I:return(r._context.displayName||"Context")+".Consumer";case J:var i=r.render;return r=r.displayName,r||(r=i.displayName||i.name||"",r=r!==""?"ForwardRef("+r+")":"ForwardRef"),r;case le:return i=r.displayName||null,i!==null?i:fe(r.type)||"Memo";case ae:i=r._payload,r=r._init;try{return fe(r(i))}catch{}}return null}var ye=Array.isArray,X=t.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,oe=n.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,be={pending:!1,data:null,method:null,action:null},ze=[],A=-1;function te(r){return{current:r}}function ue(r){0>A||(r.current=ze[A],ze[A]=null,A--)}function R(r,i){A++,ze[A]=r.current,r.current=i}var De=te(null),Ge=te(null),Le=te(null),kt=te(null);function it(r,i){switch(R(Le,i),R(Ge,r),R(De,null),i.nodeType){case 9:case 11:r=(r=i.documentElement)&&(r=r.namespaceURI)?J2(r):0;break;default:if(r=i.tagName,i=i.namespaceURI)i=J2(i),r=e4(i,r);else switch(r){case"svg":r=1;break;case"math":r=2;break;default:r=0}}ue(De),R(De,r)}function Wt(){ue(De),ue(Ge),ue(Le)}function Pt(r){r.memoizedState!==null&&R(kt,r);var i=De.current,u=e4(i,r.type);i!==u&&(R(Ge,r),R(De,u))}function In(r){Ge.current===r&&(ue(De),ue(Ge)),kt.current===r&&(ue(kt),Uu._currentValue=be)}var zr=Object.prototype.hasOwnProperty,vt=e.unstable_scheduleCallback,ht=e.unstable_cancelCallback,Ut=e.unstable_shouldYield,Ve=e.unstable_requestPaint,At=e.unstable_now,an=e.unstable_getCurrentPriorityLevel,wt=e.unstable_ImmediatePriority,Zt=e.unstable_UserBlockingPriority,Ln=e.unstable_NormalPriority,di=e.unstable_LowPriority,pa=e.unstable_IdlePriority,cr=e.log,Cn=e.unstable_setDisableYieldValue,re=null,Te=null;function Ke(r){if(typeof cr=="function"&&Cn(r),Te&&typeof Te.setStrictMode=="function")try{Te.setStrictMode(re,r)}catch{}}var $e=Math.clz32?Math.clz32:aa,Rt=Math.log,Zn=Math.LN2;function aa(r){return r>>>=0,r===0?32:31-(Rt(r)/Zn|0)|0}var Vn=256,Sr=4194304;function Jn(r){var i=r&42;if(i!==0)return i;switch(r&-r){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return r&4194048;case 4194304:case 8388608:case 16777216:case 33554432:return r&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return r}}function Tn(r,i,u){var c=r.pendingLanes;if(c===0)return 0;var m=0,g=r.suspendedLanes,S=r.pingedLanes;r=r.warmLanes;var w=c&134217727;return w!==0?(c=w&~g,c!==0?m=Jn(c):(S&=w,S!==0?m=Jn(S):u||(u=w&~r,u!==0&&(m=Jn(u))))):(w=c&~g,w!==0?m=Jn(w):S!==0?m=Jn(S):u||(u=c&~r,u!==0&&(m=Jn(u)))),m===0?0:i!==0&&i!==m&&(i&g)===0&&(g=m&-m,u=i&-i,g>=u||g===32&&(u&4194048)!==0)?i:m}function dr(r,i){return(r.pendingLanes&~(r.suspendedLanes&~r.pingedLanes)&i)===0}function er(r,i){switch(r){case 1:case 2:case 4:case 8:case 64:return i+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return i+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function Gs(){var r=Vn;return Vn<<=1,(Vn&4194048)===0&&(Vn=256),r}function Vs(){var r=Sr;return Sr<<=1,(Sr&62914560)===0&&(Sr=4194304),r}function Ks(r){for(var i=[],u=0;31>u;u++)i.push(r);return i}function fi(r,i){r.pendingLanes|=i,i!==268435456&&(r.suspendedLanes=0,r.pingedLanes=0,r.warmLanes=0)}function hi(r,i,u,c,m,g){var S=r.pendingLanes;r.pendingLanes=u,r.suspendedLanes=0,r.pingedLanes=0,r.warmLanes=0,r.expiredLanes&=u,r.entangledLanes&=u,r.errorRecoveryDisabledLanes&=u,r.shellSuspendCounter=0;var w=r.entanglements,H=r.expirationTimes,Q=r.hiddenUpdates;for(u=S&~u;0<u;){var de=31-$e(u),Ee=1<<de;w[de]=0,H[de]=-1;var ee=Q[de];if(ee!==null)for(Q[de]=null,de=0;de<ee.length;de++){var ne=ee[de];ne!==null&&(ne.lane&=-536870913)}u&=~Ee}c!==0&&q(r,c,0),g!==0&&m===0&&r.tag!==0&&(r.suspendedLanes|=g&~(S&~i))}function q(r,i,u){r.pendingLanes|=i,r.suspendedLanes&=~i;var c=31-$e(i);r.entangledLanes|=i,r.entanglements[c]=r.entanglements[c]|1073741824|u&4194090}function me(r,i){var u=r.entangledLanes|=i;for(r=r.entanglements;u;){var c=31-$e(u),m=1<<c;m&i|r[c]&i&&(r[c]|=i),u&=~m}}function Me(r){switch(r){case 2:r=1;break;case 8:r=4;break;case 32:r=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:r=128;break;case 268435456:r=134217728;break;default:r=0}return r}function nt(r){return r&=-r,2<r?8<r?(r&134217727)!==0?32:268435456:8:2}function Jt(){var r=oe.p;return r!==0?r:(r=window.event,r===void 0?32:y4(r.type))}function ln(r,i){var u=oe.p;try{return oe.p=r,i()}finally{oe.p=u}}var Pe=Math.random().toString(36).slice(2),Re="__reactFiber$"+Pe,qe="__reactProps$"+Pe,Qt="__reactContainer$"+Pe,en="__reactEvents$"+Pe,nl="__reactListeners$"+Pe,js="__reactHandles$"+Pe,Pl="__reactResources$"+Pe,rl="__reactMarker$"+Pe;function al(r){delete r[Re],delete r[qe],delete r[en],delete r[nl],delete r[js]}function mi(r){var i=r[Re];if(i)return i;for(var u=r.parentNode;u;){if(i=u[Qt]||u[Re]){if(u=i.alternate,i.child!==null||u!==null&&u.child!==null)for(r=a4(r);r!==null;){if(u=r[Re])return u;r=a4(r)}return i}r=u,u=r.parentNode}return null}function pi(r){if(r=r[Re]||r[Qt]){var i=r.tag;if(i===5||i===6||i===13||i===26||i===27||i===3)return r}return null}function il(r){var i=r.tag;if(i===5||i===26||i===27||i===6)return r.stateNode;throw Error(a(33))}function La(r){var i=r[Pl];return i||(i=r[Pl]={hoistableStyles:new Map,hoistableScripts:new Map}),i}function sn(r){r[rl]=!0}var Lo=new Set,Bo={};function Ba(r,i){tr(r,i),tr(r+"Capture",i)}function tr(r,i){for(Bo[r]=i,r=0;r<i.length;r++)Lo.add(i[r])}var Po=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),Xs={},Uo={};function fd(r){return zr.call(Uo,r)?!0:zr.call(Xs,r)?!1:Po.test(r)?Uo[r]=!0:(Xs[r]=!0,!1)}function Ul(r,i,u){if(fd(i))if(u===null)r.removeAttribute(i);else{switch(typeof u){case"undefined":case"function":case"symbol":r.removeAttribute(i);return;case"boolean":var c=i.toLowerCase().slice(0,5);if(c!=="data-"&&c!=="aria-"){r.removeAttribute(i);return}}r.setAttribute(i,""+u)}}function Pa(r,i,u){if(u===null)r.removeAttribute(i);else{switch(typeof u){case"undefined":case"function":case"symbol":case"boolean":r.removeAttribute(i);return}r.setAttribute(i,""+u)}}function ia(r,i,u,c){if(c===null)r.removeAttribute(u);else{switch(typeof c){case"undefined":case"function":case"symbol":case"boolean":r.removeAttribute(u);return}r.setAttributeNS(i,u,""+c)}}var Ne,je;function ut(r){if(Ne===void 0)try{throw Error()}catch(u){var i=u.stack.trim().match(/\n( *(at )?)/);Ne=i&&i[1]||"",je=-1<u.stack.indexOf(`
    at`)?" (<anonymous>)":-1<u.stack.indexOf("@")?"@unknown:0:0":""}return`
`+Ne+r+je}var Dt=!1;function un(r,i){if(!r||Dt)return"";Dt=!0;var u=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var c={DetermineComponentFrameRoot:function(){try{if(i){var Ee=function(){throw Error()};if(Object.defineProperty(Ee.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(Ee,[])}catch(ne){var ee=ne}Reflect.construct(r,[],Ee)}else{try{Ee.call()}catch(ne){ee=ne}r.call(Ee.prototype)}}else{try{throw Error()}catch(ne){ee=ne}(Ee=r())&&typeof Ee.catch=="function"&&Ee.catch(function(){})}}catch(ne){if(ne&&ee&&typeof ne.stack=="string")return[ne.stack,ee.stack]}return[null,null]}};c.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var m=Object.getOwnPropertyDescriptor(c.DetermineComponentFrameRoot,"name");m&&m.configurable&&Object.defineProperty(c.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var g=c.DetermineComponentFrameRoot(),S=g[0],w=g[1];if(S&&w){var H=S.split(`
`),Q=w.split(`
`);for(m=c=0;c<H.length&&!H[c].includes("DetermineComponentFrameRoot");)c++;for(;m<Q.length&&!Q[m].includes("DetermineComponentFrameRoot");)m++;if(c===H.length||m===Q.length)for(c=H.length-1,m=Q.length-1;1<=c&&0<=m&&H[c]!==Q[m];)m--;for(;1<=c&&0<=m;c--,m--)if(H[c]!==Q[m]){if(c!==1||m!==1)do if(c--,m--,0>m||H[c]!==Q[m]){var de=`
`+H[c].replace(" at new "," at ");return r.displayName&&de.includes("<anonymous>")&&(de=de.replace("<anonymous>",r.displayName)),de}while(1<=c&&0<=m);break}}}finally{Dt=!1,Error.prepareStackTrace=u}return(u=r?r.displayName||r.name:"")?ut(u):""}function Ar(r){switch(r.tag){case 26:case 27:case 5:return ut(r.type);case 16:return ut("Lazy");case 13:return ut("Suspense");case 19:return ut("SuspenseList");case 0:case 15:return un(r.type,!1);case 11:return un(r.type.render,!1);case 1:return un(r.type,!0);case 31:return ut("Activity");default:return""}}function la(r){try{var i="";do i+=Ar(r),r=r.return;while(r);return i}catch(u){return`
Error generating stack: `+u.message+`
`+u.stack}}function Fn(r){switch(typeof r){case"bigint":case"boolean":case"number":case"string":case"undefined":return r;case"object":return r;default:return""}}function Kn(r){var i=r.type;return(r=r.nodeName)&&r.toLowerCase()==="input"&&(i==="checkbox"||i==="radio")}function Hr(r){var i=Kn(r)?"checked":"value",u=Object.getOwnPropertyDescriptor(r.constructor.prototype,i),c=""+r[i];if(!r.hasOwnProperty(i)&&typeof u<"u"&&typeof u.get=="function"&&typeof u.set=="function"){var m=u.get,g=u.set;return Object.defineProperty(r,i,{configurable:!0,get:function(){return m.call(this)},set:function(S){c=""+S,g.call(this,S)}}),Object.defineProperty(r,i,{enumerable:u.enumerable}),{getValue:function(){return c},setValue:function(S){c=""+S},stopTracking:function(){r._valueTracker=null,delete r[i]}}}}function ll(r){r._valueTracker||(r._valueTracker=Hr(r))}function $s(r){if(!r)return!1;var i=r._valueTracker;if(!i)return!0;var u=i.getValue(),c="";return r&&(c=Kn(r)?r.checked?"true":"false":r.value),r=c,r!==u?(i.setValue(r),!0):!1}function sl(r){if(r=r||(typeof document<"u"?document:void 0),typeof r>"u")return null;try{return r.activeElement||r.body}catch{return r.body}}var hd=/[\n"\\]/g;function fr(r){return r.replace(hd,function(i){return"\\"+i.charCodeAt(0).toString(16)+" "})}function Ws(r,i,u,c,m,g,S,w){r.name="",S!=null&&typeof S!="function"&&typeof S!="symbol"&&typeof S!="boolean"?r.type=S:r.removeAttribute("type"),i!=null?S==="number"?(i===0&&r.value===""||r.value!=i)&&(r.value=""+Fn(i)):r.value!==""+Fn(i)&&(r.value=""+Fn(i)):S!=="submit"&&S!=="reset"||r.removeAttribute("value"),i!=null?gi(r,S,Fn(i)):u!=null?gi(r,S,Fn(u)):c!=null&&r.removeAttribute("value"),m==null&&g!=null&&(r.defaultChecked=!!g),m!=null&&(r.checked=m&&typeof m!="function"&&typeof m!="symbol"),w!=null&&typeof w!="function"&&typeof w!="symbol"&&typeof w!="boolean"?r.name=""+Fn(w):r.removeAttribute("name")}function zo(r,i,u,c,m,g,S,w){if(g!=null&&typeof g!="function"&&typeof g!="symbol"&&typeof g!="boolean"&&(r.type=g),i!=null||u!=null){if(!(g!=="submit"&&g!=="reset"||i!=null))return;u=u!=null?""+Fn(u):"",i=i!=null?""+Fn(i):u,w||i===r.value||(r.value=i),r.defaultValue=i}c=c??m,c=typeof c!="function"&&typeof c!="symbol"&&!!c,r.checked=w?r.checked:!!c,r.defaultChecked=!!c,S!=null&&typeof S!="function"&&typeof S!="symbol"&&typeof S!="boolean"&&(r.name=S)}function gi(r,i,u){i==="number"&&sl(r.ownerDocument)===r||r.defaultValue===""+u||(r.defaultValue=""+u)}function Ua(r,i,u,c){if(r=r.options,i){i={};for(var m=0;m<u.length;m++)i["$"+u[m]]=!0;for(u=0;u<r.length;u++)m=i.hasOwnProperty("$"+r[u].value),r[u].selected!==m&&(r[u].selected=m),m&&c&&(r[u].defaultSelected=!0)}else{for(u=""+Fn(u),i=null,m=0;m<r.length;m++){if(r[m].value===u){r[m].selected=!0,c&&(r[m].defaultSelected=!0);return}i!==null||r[m].disabled||(i=r[m])}i!==null&&(i.selected=!0)}}function xr(r,i,u){if(i!=null&&(i=""+Fn(i),i!==r.value&&(r.value=i),u==null)){r.defaultValue!==i&&(r.defaultValue=i);return}r.defaultValue=u!=null?""+Fn(u):""}function Ho(r,i,u,c){if(i==null){if(c!=null){if(u!=null)throw Error(a(92));if(ye(c)){if(1<c.length)throw Error(a(93));c=c[0]}u=c}u==null&&(u=""),i=u}u=Fn(i),r.defaultValue=u,c=r.textContent,c===u&&c!==""&&c!==null&&(r.value=c)}function ga(r,i){if(i){var u=r.firstChild;if(u&&u===r.lastChild&&u.nodeType===3){u.nodeValue=i;return}}r.textContent=i}var st=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function Qs(r,i,u){var c=i.indexOf("--")===0;u==null||typeof u=="boolean"||u===""?c?r.setProperty(i,""):i==="float"?r.cssFloat="":r[i]="":c?r.setProperty(i,u):typeof u!="number"||u===0||st.has(i)?i==="float"?r.cssFloat=u:r[i]=(""+u).trim():r[i]=u+"px"}function _n(r,i,u){if(i!=null&&typeof i!="object")throw Error(a(62));if(r=r.style,u!=null){for(var c in u)!u.hasOwnProperty(c)||i!=null&&i.hasOwnProperty(c)||(c.indexOf("--")===0?r.setProperty(c,""):c==="float"?r.cssFloat="":r[c]="");for(var m in i)c=i[m],i.hasOwnProperty(m)&&u[m]!==c&&Qs(r,m,c)}else for(var g in i)i.hasOwnProperty(g)&&Qs(r,g,i[g])}function It(r){if(r.indexOf("-")===-1)return!1;switch(r){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var zl=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),za=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function bi(r){return za.test(""+r)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":r}var ul=null;function Ie(r){return r=r.target||r.srcElement||window,r.correspondingUseElement&&(r=r.correspondingUseElement),r.nodeType===3?r.parentNode:r}var He=null,lt=null;function Ct(r){var i=pi(r);if(i&&(r=i.stateNode)){var u=r[qe]||null;e:switch(r=i.stateNode,i.type){case"input":if(Ws(r,u.value,u.defaultValue,u.defaultValue,u.checked,u.defaultChecked,u.type,u.name),i=u.name,u.type==="radio"&&i!=null){for(u=r;u.parentNode;)u=u.parentNode;for(u=u.querySelectorAll('input[name="'+fr(""+i)+'"][type="radio"]'),i=0;i<u.length;i++){var c=u[i];if(c!==r&&c.form===r.form){var m=c[qe]||null;if(!m)throw Error(a(90));Ws(c,m.value,m.defaultValue,m.defaultValue,m.checked,m.defaultChecked,m.type,m.name)}}for(i=0;i<u.length;i++)c=u[i],c.form===r.form&&$s(c)}break e;case"textarea":xr(r,u.value,u.defaultValue);break e;case"select":i=u.value,i!=null&&Ua(r,!!u.multiple,i,!1)}}}var Sn=!1;function Fr(r,i,u){if(Sn)return r(i,u);Sn=!0;try{var c=r(i);return c}finally{if(Sn=!1,(He!==null||lt!==null)&&(x0(),He&&(i=He,r=lt,lt=He=null,Ct(i),r)))for(i=0;i<r.length;i++)Ct(r[i])}}function ol(r,i){var u=r.stateNode;if(u===null)return null;var c=u[qe]||null;if(c===null)return null;u=c[i];e:switch(i){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(c=!c.disabled)||(r=r.type,c=!(r==="button"||r==="input"||r==="select"||r==="textarea")),r=!c;break e;default:r=!1}if(r)return null;if(u&&typeof u!="function")throw Error(a(231,i,typeof u));return u}var sa=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),md=!1;if(sa)try{var Zs={};Object.defineProperty(Zs,"passive",{get:function(){md=!0}}),window.addEventListener("test",Zs,Zs),window.removeEventListener("test",Zs,Zs)}catch{md=!1}var Ei=null,pd=null,Fo=null;function rp(){if(Fo)return Fo;var r,i=pd,u=i.length,c,m="value"in Ei?Ei.value:Ei.textContent,g=m.length;for(r=0;r<u&&i[r]===m[r];r++);var S=u-r;for(c=1;c<=S&&i[u-c]===m[g-c];c++);return Fo=m.slice(r,1<c?1-c:void 0)}function qo(r){var i=r.keyCode;return"charCode"in r?(r=r.charCode,r===0&&i===13&&(r=13)):r=i,r===10&&(r=13),32<=r||r===13?r:0}function Yo(){return!0}function ap(){return!1}function hr(r){function i(u,c,m,g,S){this._reactName=u,this._targetInst=m,this.type=c,this.nativeEvent=g,this.target=S,this.currentTarget=null;for(var w in r)r.hasOwnProperty(w)&&(u=r[w],this[w]=u?u(g):g[w]);return this.isDefaultPrevented=(g.defaultPrevented!=null?g.defaultPrevented:g.returnValue===!1)?Yo:ap,this.isPropagationStopped=ap,this}return p(i.prototype,{preventDefault:function(){this.defaultPrevented=!0;var u=this.nativeEvent;u&&(u.preventDefault?u.preventDefault():typeof u.returnValue!="unknown"&&(u.returnValue=!1),this.isDefaultPrevented=Yo)},stopPropagation:function(){var u=this.nativeEvent;u&&(u.stopPropagation?u.stopPropagation():typeof u.cancelBubble!="unknown"&&(u.cancelBubble=!0),this.isPropagationStopped=Yo)},persist:function(){},isPersistent:Yo}),i}var cl={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(r){return r.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Go=hr(cl),Js=p({},cl,{view:0,detail:0}),y8=hr(Js),gd,bd,eu,Vo=p({},Js,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:yd,button:0,buttons:0,relatedTarget:function(r){return r.relatedTarget===void 0?r.fromElement===r.srcElement?r.toElement:r.fromElement:r.relatedTarget},movementX:function(r){return"movementX"in r?r.movementX:(r!==eu&&(eu&&r.type==="mousemove"?(gd=r.screenX-eu.screenX,bd=r.screenY-eu.screenY):bd=gd=0,eu=r),gd)},movementY:function(r){return"movementY"in r?r.movementY:bd}}),ip=hr(Vo),v8=p({},Vo,{dataTransfer:0}),T8=hr(v8),_8=p({},Js,{relatedTarget:0}),Ed=hr(_8),S8=p({},cl,{animationName:0,elapsedTime:0,pseudoElement:0}),A8=hr(S8),x8=p({},cl,{clipboardData:function(r){return"clipboardData"in r?r.clipboardData:window.clipboardData}}),k8=hr(x8),N8=p({},cl,{data:0}),lp=hr(N8),w8={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},C8={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},O8={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function R8(r){var i=this.nativeEvent;return i.getModifierState?i.getModifierState(r):(r=O8[r])?!!i[r]:!1}function yd(){return R8}var M8=p({},Js,{key:function(r){if(r.key){var i=w8[r.key]||r.key;if(i!=="Unidentified")return i}return r.type==="keypress"?(r=qo(r),r===13?"Enter":String.fromCharCode(r)):r.type==="keydown"||r.type==="keyup"?C8[r.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:yd,charCode:function(r){return r.type==="keypress"?qo(r):0},keyCode:function(r){return r.type==="keydown"||r.type==="keyup"?r.keyCode:0},which:function(r){return r.type==="keypress"?qo(r):r.type==="keydown"||r.type==="keyup"?r.keyCode:0}}),D8=hr(M8),I8=p({},Vo,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),sp=hr(I8),L8=p({},Js,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:yd}),B8=hr(L8),P8=p({},cl,{propertyName:0,elapsedTime:0,pseudoElement:0}),U8=hr(P8),z8=p({},Vo,{deltaX:function(r){return"deltaX"in r?r.deltaX:"wheelDeltaX"in r?-r.wheelDeltaX:0},deltaY:function(r){return"deltaY"in r?r.deltaY:"wheelDeltaY"in r?-r.wheelDeltaY:"wheelDelta"in r?-r.wheelDelta:0},deltaZ:0,deltaMode:0}),H8=hr(z8),F8=p({},cl,{newState:0,oldState:0}),q8=hr(F8),Y8=[9,13,27,32],vd=sa&&"CompositionEvent"in window,tu=null;sa&&"documentMode"in document&&(tu=document.documentMode);var G8=sa&&"TextEvent"in window&&!tu,up=sa&&(!vd||tu&&8<tu&&11>=tu),op=" ",cp=!1;function dp(r,i){switch(r){case"keyup":return Y8.indexOf(i.keyCode)!==-1;case"keydown":return i.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function fp(r){return r=r.detail,typeof r=="object"&&"data"in r?r.data:null}var Hl=!1;function V8(r,i){switch(r){case"compositionend":return fp(i);case"keypress":return i.which!==32?null:(cp=!0,op);case"textInput":return r=i.data,r===op&&cp?null:r;default:return null}}function K8(r,i){if(Hl)return r==="compositionend"||!vd&&dp(r,i)?(r=rp(),Fo=pd=Ei=null,Hl=!1,r):null;switch(r){case"paste":return null;case"keypress":if(!(i.ctrlKey||i.altKey||i.metaKey)||i.ctrlKey&&i.altKey){if(i.char&&1<i.char.length)return i.char;if(i.which)return String.fromCharCode(i.which)}return null;case"compositionend":return up&&i.locale!=="ko"?null:i.data;default:return null}}var j8={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function hp(r){var i=r&&r.nodeName&&r.nodeName.toLowerCase();return i==="input"?!!j8[r.type]:i==="textarea"}function mp(r,i,u,c){He?lt?lt.push(c):lt=[c]:He=c,i=R0(i,"onChange"),0<i.length&&(u=new Go("onChange","change",null,u,c),r.push({event:u,listeners:i}))}var nu=null,ru=null;function X8(r){X2(r,0)}function Ko(r){var i=il(r);if($s(i))return r}function pp(r,i){if(r==="change")return i}var gp=!1;if(sa){var Td;if(sa){var _d="oninput"in document;if(!_d){var bp=document.createElement("div");bp.setAttribute("oninput","return;"),_d=typeof bp.oninput=="function"}Td=_d}else Td=!1;gp=Td&&(!document.documentMode||9<document.documentMode)}function Ep(){nu&&(nu.detachEvent("onpropertychange",yp),ru=nu=null)}function yp(r){if(r.propertyName==="value"&&Ko(ru)){var i=[];mp(i,ru,r,Ie(r)),Fr(X8,i)}}function $8(r,i,u){r==="focusin"?(Ep(),nu=i,ru=u,nu.attachEvent("onpropertychange",yp)):r==="focusout"&&Ep()}function W8(r){if(r==="selectionchange"||r==="keyup"||r==="keydown")return Ko(ru)}function Q8(r,i){if(r==="click")return Ko(i)}function Z8(r,i){if(r==="input"||r==="change")return Ko(i)}function J8(r,i){return r===i&&(r!==0||1/r===1/i)||r!==r&&i!==i}var kr=typeof Object.is=="function"?Object.is:J8;function au(r,i){if(kr(r,i))return!0;if(typeof r!="object"||r===null||typeof i!="object"||i===null)return!1;var u=Object.keys(r),c=Object.keys(i);if(u.length!==c.length)return!1;for(c=0;c<u.length;c++){var m=u[c];if(!zr.call(i,m)||!kr(r[m],i[m]))return!1}return!0}function vp(r){for(;r&&r.firstChild;)r=r.firstChild;return r}function Tp(r,i){var u=vp(r);r=0;for(var c;u;){if(u.nodeType===3){if(c=r+u.textContent.length,r<=i&&c>=i)return{node:u,offset:i-r};r=c}e:{for(;u;){if(u.nextSibling){u=u.nextSibling;break e}u=u.parentNode}u=void 0}u=vp(u)}}function _p(r,i){return r&&i?r===i?!0:r&&r.nodeType===3?!1:i&&i.nodeType===3?_p(r,i.parentNode):"contains"in r?r.contains(i):r.compareDocumentPosition?!!(r.compareDocumentPosition(i)&16):!1:!1}function Sp(r){r=r!=null&&r.ownerDocument!=null&&r.ownerDocument.defaultView!=null?r.ownerDocument.defaultView:window;for(var i=sl(r.document);i instanceof r.HTMLIFrameElement;){try{var u=typeof i.contentWindow.location.href=="string"}catch{u=!1}if(u)r=i.contentWindow;else break;i=sl(r.document)}return i}function Sd(r){var i=r&&r.nodeName&&r.nodeName.toLowerCase();return i&&(i==="input"&&(r.type==="text"||r.type==="search"||r.type==="tel"||r.type==="url"||r.type==="password")||i==="textarea"||r.contentEditable==="true")}var ey=sa&&"documentMode"in document&&11>=document.documentMode,Fl=null,Ad=null,iu=null,xd=!1;function Ap(r,i,u){var c=u.window===u?u.document:u.nodeType===9?u:u.ownerDocument;xd||Fl==null||Fl!==sl(c)||(c=Fl,"selectionStart"in c&&Sd(c)?c={start:c.selectionStart,end:c.selectionEnd}:(c=(c.ownerDocument&&c.ownerDocument.defaultView||window).getSelection(),c={anchorNode:c.anchorNode,anchorOffset:c.anchorOffset,focusNode:c.focusNode,focusOffset:c.focusOffset}),iu&&au(iu,c)||(iu=c,c=R0(Ad,"onSelect"),0<c.length&&(i=new Go("onSelect","select",null,i,u),r.push({event:i,listeners:c}),i.target=Fl)))}function dl(r,i){var u={};return u[r.toLowerCase()]=i.toLowerCase(),u["Webkit"+r]="webkit"+i,u["Moz"+r]="moz"+i,u}var ql={animationend:dl("Animation","AnimationEnd"),animationiteration:dl("Animation","AnimationIteration"),animationstart:dl("Animation","AnimationStart"),transitionrun:dl("Transition","TransitionRun"),transitionstart:dl("Transition","TransitionStart"),transitioncancel:dl("Transition","TransitionCancel"),transitionend:dl("Transition","TransitionEnd")},kd={},xp={};sa&&(xp=document.createElement("div").style,"AnimationEvent"in window||(delete ql.animationend.animation,delete ql.animationiteration.animation,delete ql.animationstart.animation),"TransitionEvent"in window||delete ql.transitionend.transition);function fl(r){if(kd[r])return kd[r];if(!ql[r])return r;var i=ql[r],u;for(u in i)if(i.hasOwnProperty(u)&&u in xp)return kd[r]=i[u];return r}var kp=fl("animationend"),Np=fl("animationiteration"),wp=fl("animationstart"),ty=fl("transitionrun"),ny=fl("transitionstart"),ry=fl("transitioncancel"),Cp=fl("transitionend"),Op=new Map,Nd="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Nd.push("scrollEnd");function ua(r,i){Op.set(r,i),Ba(i,[r])}var Rp=new WeakMap;function qr(r,i){if(typeof r=="object"&&r!==null){var u=Rp.get(r);return u!==void 0?u:(i={value:r,source:i,stack:la(i)},Rp.set(r,i),i)}return{value:r,source:i,stack:la(i)}}var Yr=[],Yl=0,wd=0;function jo(){for(var r=Yl,i=wd=Yl=0;i<r;){var u=Yr[i];Yr[i++]=null;var c=Yr[i];Yr[i++]=null;var m=Yr[i];Yr[i++]=null;var g=Yr[i];if(Yr[i++]=null,c!==null&&m!==null){var S=c.pending;S===null?m.next=m:(m.next=S.next,S.next=m),c.pending=m}g!==0&&Mp(u,m,g)}}function Xo(r,i,u,c){Yr[Yl++]=r,Yr[Yl++]=i,Yr[Yl++]=u,Yr[Yl++]=c,wd|=c,r.lanes|=c,r=r.alternate,r!==null&&(r.lanes|=c)}function Cd(r,i,u,c){return Xo(r,i,u,c),$o(r)}function Gl(r,i){return Xo(r,null,null,i),$o(r)}function Mp(r,i,u){r.lanes|=u;var c=r.alternate;c!==null&&(c.lanes|=u);for(var m=!1,g=r.return;g!==null;)g.childLanes|=u,c=g.alternate,c!==null&&(c.childLanes|=u),g.tag===22&&(r=g.stateNode,r===null||r._visibility&1||(m=!0)),r=g,g=g.return;return r.tag===3?(g=r.stateNode,m&&i!==null&&(m=31-$e(u),r=g.hiddenUpdates,c=r[m],c===null?r[m]=[i]:c.push(i),i.lane=u|536870912),g):null}function $o(r){if(50<Ou)throw Ou=0,Bf=null,Error(a(185));for(var i=r.return;i!==null;)r=i,i=r.return;return r.tag===3?r.stateNode:null}var Vl={};function ay(r,i,u,c){this.tag=r,this.key=u,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=i,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=c,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function Nr(r,i,u,c){return new ay(r,i,u,c)}function Od(r){return r=r.prototype,!(!r||!r.isReactComponent)}function Ha(r,i){var u=r.alternate;return u===null?(u=Nr(r.tag,i,r.key,r.mode),u.elementType=r.elementType,u.type=r.type,u.stateNode=r.stateNode,u.alternate=r,r.alternate=u):(u.pendingProps=i,u.type=r.type,u.flags=0,u.subtreeFlags=0,u.deletions=null),u.flags=r.flags&65011712,u.childLanes=r.childLanes,u.lanes=r.lanes,u.child=r.child,u.memoizedProps=r.memoizedProps,u.memoizedState=r.memoizedState,u.updateQueue=r.updateQueue,i=r.dependencies,u.dependencies=i===null?null:{lanes:i.lanes,firstContext:i.firstContext},u.sibling=r.sibling,u.index=r.index,u.ref=r.ref,u.refCleanup=r.refCleanup,u}function Dp(r,i){r.flags&=65011714;var u=r.alternate;return u===null?(r.childLanes=0,r.lanes=i,r.child=null,r.subtreeFlags=0,r.memoizedProps=null,r.memoizedState=null,r.updateQueue=null,r.dependencies=null,r.stateNode=null):(r.childLanes=u.childLanes,r.lanes=u.lanes,r.child=u.child,r.subtreeFlags=0,r.deletions=null,r.memoizedProps=u.memoizedProps,r.memoizedState=u.memoizedState,r.updateQueue=u.updateQueue,r.type=u.type,i=u.dependencies,r.dependencies=i===null?null:{lanes:i.lanes,firstContext:i.firstContext}),r}function Wo(r,i,u,c,m,g){var S=0;if(c=r,typeof r=="function")Od(r)&&(S=1);else if(typeof r=="string")S=lv(r,u,De.current)?26:r==="html"||r==="head"||r==="body"?27:5;else e:switch(r){case se:return r=Nr(31,u,i,m),r.elementType=se,r.lanes=g,r;case x:return hl(u.children,m,g,i);case N:S=8,m|=24;break;case D:return r=Nr(12,u,i,m|2),r.elementType=D,r.lanes=g,r;case K:return r=Nr(13,u,i,m),r.elementType=K,r.lanes=g,r;case U:return r=Nr(19,u,i,m),r.elementType=U,r.lanes=g,r;default:if(typeof r=="object"&&r!==null)switch(r.$$typeof){case C:case F:S=10;break e;case I:S=9;break e;case J:S=11;break e;case le:S=14;break e;case ae:S=16,c=null;break e}S=29,u=Error(a(130,r===null?"null":typeof r,"")),c=null}return i=Nr(S,u,i,m),i.elementType=r,i.type=c,i.lanes=g,i}function hl(r,i,u,c){return r=Nr(7,r,c,i),r.lanes=u,r}function Rd(r,i,u){return r=Nr(6,r,null,i),r.lanes=u,r}function Md(r,i,u){return i=Nr(4,r.children!==null?r.children:[],r.key,i),i.lanes=u,i.stateNode={containerInfo:r.containerInfo,pendingChildren:null,implementation:r.implementation},i}var Kl=[],jl=0,Qo=null,Zo=0,Gr=[],Vr=0,ml=null,Fa=1,qa="";function pl(r,i){Kl[jl++]=Zo,Kl[jl++]=Qo,Qo=r,Zo=i}function Ip(r,i,u){Gr[Vr++]=Fa,Gr[Vr++]=qa,Gr[Vr++]=ml,ml=r;var c=Fa;r=qa;var m=32-$e(c)-1;c&=~(1<<m),u+=1;var g=32-$e(i)+m;if(30<g){var S=m-m%5;g=(c&(1<<S)-1).toString(32),c>>=S,m-=S,Fa=1<<32-$e(i)+m|u<<m|c,qa=g+r}else Fa=1<<g|u<<m|c,qa=r}function Dd(r){r.return!==null&&(pl(r,1),Ip(r,1,0))}function Id(r){for(;r===Qo;)Qo=Kl[--jl],Kl[jl]=null,Zo=Kl[--jl],Kl[jl]=null;for(;r===ml;)ml=Gr[--Vr],Gr[Vr]=null,qa=Gr[--Vr],Gr[Vr]=null,Fa=Gr[--Vr],Gr[Vr]=null}var nr=null,hn=null,Mt=!1,gl=null,ba=!1,Ld=Error(a(519));function bl(r){var i=Error(a(418,""));throw uu(qr(i,r)),Ld}function Lp(r){var i=r.stateNode,u=r.type,c=r.memoizedProps;switch(i[Re]=r,i[qe]=c,u){case"dialog":_t("cancel",i),_t("close",i);break;case"iframe":case"object":case"embed":_t("load",i);break;case"video":case"audio":for(u=0;u<Mu.length;u++)_t(Mu[u],i);break;case"source":_t("error",i);break;case"img":case"image":case"link":_t("error",i),_t("load",i);break;case"details":_t("toggle",i);break;case"input":_t("invalid",i),zo(i,c.value,c.defaultValue,c.checked,c.defaultChecked,c.type,c.name,!0),ll(i);break;case"select":_t("invalid",i);break;case"textarea":_t("invalid",i),Ho(i,c.value,c.defaultValue,c.children),ll(i)}u=c.children,typeof u!="string"&&typeof u!="number"&&typeof u!="bigint"||i.textContent===""+u||c.suppressHydrationWarning===!0||Z2(i.textContent,u)?(c.popover!=null&&(_t("beforetoggle",i),_t("toggle",i)),c.onScroll!=null&&_t("scroll",i),c.onScrollEnd!=null&&_t("scrollend",i),c.onClick!=null&&(i.onclick=M0),i=!0):i=!1,i||bl(r)}function Bp(r){for(nr=r.return;nr;)switch(nr.tag){case 5:case 13:ba=!1;return;case 27:case 3:ba=!0;return;default:nr=nr.return}}function lu(r){if(r!==nr)return!1;if(!Mt)return Bp(r),Mt=!0,!1;var i=r.tag,u;if((u=i!==3&&i!==27)&&((u=i===5)&&(u=r.type,u=!(u!=="form"&&u!=="button")||Zf(r.type,r.memoizedProps)),u=!u),u&&hn&&bl(r),Bp(r),i===13){if(r=r.memoizedState,r=r!==null?r.dehydrated:null,!r)throw Error(a(317));e:{for(r=r.nextSibling,i=0;r;){if(r.nodeType===8)if(u=r.data,u==="/$"){if(i===0){hn=ca(r.nextSibling);break e}i--}else u!=="$"&&u!=="$!"&&u!=="$?"||i++;r=r.nextSibling}hn=null}}else i===27?(i=hn,Ii(r.type)?(r=nh,nh=null,hn=r):hn=i):hn=nr?ca(r.stateNode.nextSibling):null;return!0}function su(){hn=nr=null,Mt=!1}function Pp(){var r=gl;return r!==null&&(gr===null?gr=r:gr.push.apply(gr,r),gl=null),r}function uu(r){gl===null?gl=[r]:gl.push(r)}var Bd=te(null),El=null,Ya=null;function yi(r,i,u){R(Bd,i._currentValue),i._currentValue=u}function Ga(r){r._currentValue=Bd.current,ue(Bd)}function Pd(r,i,u){for(;r!==null;){var c=r.alternate;if((r.childLanes&i)!==i?(r.childLanes|=i,c!==null&&(c.childLanes|=i)):c!==null&&(c.childLanes&i)!==i&&(c.childLanes|=i),r===u)break;r=r.return}}function Ud(r,i,u,c){var m=r.child;for(m!==null&&(m.return=r);m!==null;){var g=m.dependencies;if(g!==null){var S=m.child;g=g.firstContext;e:for(;g!==null;){var w=g;g=m;for(var H=0;H<i.length;H++)if(w.context===i[H]){g.lanes|=u,w=g.alternate,w!==null&&(w.lanes|=u),Pd(g.return,u,r),c||(S=null);break e}g=w.next}}else if(m.tag===18){if(S=m.return,S===null)throw Error(a(341));S.lanes|=u,g=S.alternate,g!==null&&(g.lanes|=u),Pd(S,u,r),S=null}else S=m.child;if(S!==null)S.return=m;else for(S=m;S!==null;){if(S===r){S=null;break}if(m=S.sibling,m!==null){m.return=S.return,S=m;break}S=S.return}m=S}}function ou(r,i,u,c){r=null;for(var m=i,g=!1;m!==null;){if(!g){if((m.flags&524288)!==0)g=!0;else if((m.flags&262144)!==0)break}if(m.tag===10){var S=m.alternate;if(S===null)throw Error(a(387));if(S=S.memoizedProps,S!==null){var w=m.type;kr(m.pendingProps.value,S.value)||(r!==null?r.push(w):r=[w])}}else if(m===kt.current){if(S=m.alternate,S===null)throw Error(a(387));S.memoizedState.memoizedState!==m.memoizedState.memoizedState&&(r!==null?r.push(Uu):r=[Uu])}m=m.return}r!==null&&Ud(i,r,u,c),i.flags|=262144}function Jo(r){for(r=r.firstContext;r!==null;){if(!kr(r.context._currentValue,r.memoizedValue))return!0;r=r.next}return!1}function yl(r){El=r,Ya=null,r=r.dependencies,r!==null&&(r.firstContext=null)}function jn(r){return Up(El,r)}function e0(r,i){return El===null&&yl(r),Up(r,i)}function Up(r,i){var u=i._currentValue;if(i={context:i,memoizedValue:u,next:null},Ya===null){if(r===null)throw Error(a(308));Ya=i,r.dependencies={lanes:0,firstContext:i},r.flags|=524288}else Ya=Ya.next=i;return u}var iy=typeof AbortController<"u"?AbortController:function(){var r=[],i=this.signal={aborted:!1,addEventListener:function(u,c){r.push(c)}};this.abort=function(){i.aborted=!0,r.forEach(function(u){return u()})}},ly=e.unstable_scheduleCallback,sy=e.unstable_NormalPriority,On={$$typeof:F,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function zd(){return{controller:new iy,data:new Map,refCount:0}}function cu(r){r.refCount--,r.refCount===0&&ly(sy,function(){r.controller.abort()})}var du=null,Hd=0,Xl=0,$l=null;function uy(r,i){if(du===null){var u=du=[];Hd=0,Xl=Yf(),$l={status:"pending",value:void 0,then:function(c){u.push(c)}}}return Hd++,i.then(zp,zp),i}function zp(){if(--Hd===0&&du!==null){$l!==null&&($l.status="fulfilled");var r=du;du=null,Xl=0,$l=null;for(var i=0;i<r.length;i++)(0,r[i])()}}function oy(r,i){var u=[],c={status:"pending",value:null,reason:null,then:function(m){u.push(m)}};return r.then(function(){c.status="fulfilled",c.value=i;for(var m=0;m<u.length;m++)(0,u[m])(i)},function(m){for(c.status="rejected",c.reason=m,m=0;m<u.length;m++)(0,u[m])(void 0)}),c}var Hp=X.S;X.S=function(r,i){typeof i=="object"&&i!==null&&typeof i.then=="function"&&uy(r,i),Hp!==null&&Hp(r,i)};var vl=te(null);function Fd(){var r=vl.current;return r!==null?r:Kt.pooledCache}function t0(r,i){i===null?R(vl,vl.current):R(vl,i.pool)}function Fp(){var r=Fd();return r===null?null:{parent:On._currentValue,pool:r}}var fu=Error(a(460)),qp=Error(a(474)),n0=Error(a(542)),qd={then:function(){}};function Yp(r){return r=r.status,r==="fulfilled"||r==="rejected"}function r0(){}function Gp(r,i,u){switch(u=r[u],u===void 0?r.push(i):u!==i&&(i.then(r0,r0),i=u),i.status){case"fulfilled":return i.value;case"rejected":throw r=i.reason,Kp(r),r;default:if(typeof i.status=="string")i.then(r0,r0);else{if(r=Kt,r!==null&&100<r.shellSuspendCounter)throw Error(a(482));r=i,r.status="pending",r.then(function(c){if(i.status==="pending"){var m=i;m.status="fulfilled",m.value=c}},function(c){if(i.status==="pending"){var m=i;m.status="rejected",m.reason=c}})}switch(i.status){case"fulfilled":return i.value;case"rejected":throw r=i.reason,Kp(r),r}throw hu=i,fu}}var hu=null;function Vp(){if(hu===null)throw Error(a(459));var r=hu;return hu=null,r}function Kp(r){if(r===fu||r===n0)throw Error(a(483))}var vi=!1;function Yd(r){r.updateQueue={baseState:r.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Gd(r,i){r=r.updateQueue,i.updateQueue===r&&(i.updateQueue={baseState:r.baseState,firstBaseUpdate:r.firstBaseUpdate,lastBaseUpdate:r.lastBaseUpdate,shared:r.shared,callbacks:null})}function Ti(r){return{lane:r,tag:0,payload:null,callback:null,next:null}}function _i(r,i,u){var c=r.updateQueue;if(c===null)return null;if(c=c.shared,(Lt&2)!==0){var m=c.pending;return m===null?i.next=i:(i.next=m.next,m.next=i),c.pending=i,i=$o(r),Mp(r,null,u),i}return Xo(r,c,i,u),$o(r)}function mu(r,i,u){if(i=i.updateQueue,i!==null&&(i=i.shared,(u&4194048)!==0)){var c=i.lanes;c&=r.pendingLanes,u|=c,i.lanes=u,me(r,u)}}function Vd(r,i){var u=r.updateQueue,c=r.alternate;if(c!==null&&(c=c.updateQueue,u===c)){var m=null,g=null;if(u=u.firstBaseUpdate,u!==null){do{var S={lane:u.lane,tag:u.tag,payload:u.payload,callback:null,next:null};g===null?m=g=S:g=g.next=S,u=u.next}while(u!==null);g===null?m=g=i:g=g.next=i}else m=g=i;u={baseState:c.baseState,firstBaseUpdate:m,lastBaseUpdate:g,shared:c.shared,callbacks:c.callbacks},r.updateQueue=u;return}r=u.lastBaseUpdate,r===null?u.firstBaseUpdate=i:r.next=i,u.lastBaseUpdate=i}var Kd=!1;function pu(){if(Kd){var r=$l;if(r!==null)throw r}}function gu(r,i,u,c){Kd=!1;var m=r.updateQueue;vi=!1;var g=m.firstBaseUpdate,S=m.lastBaseUpdate,w=m.shared.pending;if(w!==null){m.shared.pending=null;var H=w,Q=H.next;H.next=null,S===null?g=Q:S.next=Q,S=H;var de=r.alternate;de!==null&&(de=de.updateQueue,w=de.lastBaseUpdate,w!==S&&(w===null?de.firstBaseUpdate=Q:w.next=Q,de.lastBaseUpdate=H))}if(g!==null){var Ee=m.baseState;S=0,de=Q=H=null,w=g;do{var ee=w.lane&-536870913,ne=ee!==w.lane;if(ne?(xt&ee)===ee:(c&ee)===ee){ee!==0&&ee===Xl&&(Kd=!0),de!==null&&(de=de.next={lane:0,tag:w.tag,payload:w.payload,callback:null,next:null});e:{var rt=r,et=w;ee=i;var Ft=u;switch(et.tag){case 1:if(rt=et.payload,typeof rt=="function"){Ee=rt.call(Ft,Ee,ee);break e}Ee=rt;break e;case 3:rt.flags=rt.flags&-65537|128;case 0:if(rt=et.payload,ee=typeof rt=="function"?rt.call(Ft,Ee,ee):rt,ee==null)break e;Ee=p({},Ee,ee);break e;case 2:vi=!0}}ee=w.callback,ee!==null&&(r.flags|=64,ne&&(r.flags|=8192),ne=m.callbacks,ne===null?m.callbacks=[ee]:ne.push(ee))}else ne={lane:ee,tag:w.tag,payload:w.payload,callback:w.callback,next:null},de===null?(Q=de=ne,H=Ee):de=de.next=ne,S|=ee;if(w=w.next,w===null){if(w=m.shared.pending,w===null)break;ne=w,w=ne.next,ne.next=null,m.lastBaseUpdate=ne,m.shared.pending=null}}while(!0);de===null&&(H=Ee),m.baseState=H,m.firstBaseUpdate=Q,m.lastBaseUpdate=de,g===null&&(m.shared.lanes=0),Oi|=S,r.lanes=S,r.memoizedState=Ee}}function jp(r,i){if(typeof r!="function")throw Error(a(191,r));r.call(i)}function Xp(r,i){var u=r.callbacks;if(u!==null)for(r.callbacks=null,r=0;r<u.length;r++)jp(u[r],i)}var Wl=te(null),a0=te(0);function $p(r,i){r=Qa,R(a0,r),R(Wl,i),Qa=r|i.baseLanes}function jd(){R(a0,Qa),R(Wl,Wl.current)}function Xd(){Qa=a0.current,ue(Wl),ue(a0)}var Si=0,pt=null,zt=null,An=null,i0=!1,Ql=!1,Tl=!1,l0=0,bu=0,Zl=null,cy=0;function bn(){throw Error(a(321))}function $d(r,i){if(i===null)return!1;for(var u=0;u<i.length&&u<r.length;u++)if(!kr(r[u],i[u]))return!1;return!0}function Wd(r,i,u,c,m,g){return Si=g,pt=i,i.memoizedState=null,i.updateQueue=null,i.lanes=0,X.H=r===null||r.memoizedState===null?Mg:Dg,Tl=!1,g=u(c,m),Tl=!1,Ql&&(g=Qp(i,u,c,m)),Wp(r),g}function Wp(r){X.H=f0;var i=zt!==null&&zt.next!==null;if(Si=0,An=zt=pt=null,i0=!1,bu=0,Zl=null,i)throw Error(a(300));r===null||Bn||(r=r.dependencies,r!==null&&Jo(r)&&(Bn=!0))}function Qp(r,i,u,c){pt=r;var m=0;do{if(Ql&&(Zl=null),bu=0,Ql=!1,25<=m)throw Error(a(301));if(m+=1,An=zt=null,r.updateQueue!=null){var g=r.updateQueue;g.lastEffect=null,g.events=null,g.stores=null,g.memoCache!=null&&(g.memoCache.index=0)}X.H=by,g=i(u,c)}while(Ql);return g}function dy(){var r=X.H,i=r.useState()[0];return i=typeof i.then=="function"?Eu(i):i,r=r.useState()[0],(zt!==null?zt.memoizedState:null)!==r&&(pt.flags|=1024),i}function Qd(){var r=l0!==0;return l0=0,r}function Zd(r,i,u){i.updateQueue=r.updateQueue,i.flags&=-2053,r.lanes&=~u}function Jd(r){if(i0){for(r=r.memoizedState;r!==null;){var i=r.queue;i!==null&&(i.pending=null),r=r.next}i0=!1}Si=0,An=zt=pt=null,Ql=!1,bu=l0=0,Zl=null}function mr(){var r={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return An===null?pt.memoizedState=An=r:An=An.next=r,An}function xn(){if(zt===null){var r=pt.alternate;r=r!==null?r.memoizedState:null}else r=zt.next;var i=An===null?pt.memoizedState:An.next;if(i!==null)An=i,zt=r;else{if(r===null)throw pt.alternate===null?Error(a(467)):Error(a(310));zt=r,r={memoizedState:zt.memoizedState,baseState:zt.baseState,baseQueue:zt.baseQueue,queue:zt.queue,next:null},An===null?pt.memoizedState=An=r:An=An.next=r}return An}function ef(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Eu(r){var i=bu;return bu+=1,Zl===null&&(Zl=[]),r=Gp(Zl,r,i),i=pt,(An===null?i.memoizedState:An.next)===null&&(i=i.alternate,X.H=i===null||i.memoizedState===null?Mg:Dg),r}function s0(r){if(r!==null&&typeof r=="object"){if(typeof r.then=="function")return Eu(r);if(r.$$typeof===F)return jn(r)}throw Error(a(438,String(r)))}function tf(r){var i=null,u=pt.updateQueue;if(u!==null&&(i=u.memoCache),i==null){var c=pt.alternate;c!==null&&(c=c.updateQueue,c!==null&&(c=c.memoCache,c!=null&&(i={data:c.data.map(function(m){return m.slice()}),index:0})))}if(i==null&&(i={data:[],index:0}),u===null&&(u=ef(),pt.updateQueue=u),u.memoCache=i,u=i.data[i.index],u===void 0)for(u=i.data[i.index]=Array(r),c=0;c<r;c++)u[c]=G;return i.index++,u}function Va(r,i){return typeof i=="function"?i(r):i}function u0(r){var i=xn();return nf(i,zt,r)}function nf(r,i,u){var c=r.queue;if(c===null)throw Error(a(311));c.lastRenderedReducer=u;var m=r.baseQueue,g=c.pending;if(g!==null){if(m!==null){var S=m.next;m.next=g.next,g.next=S}i.baseQueue=m=g,c.pending=null}if(g=r.baseState,m===null)r.memoizedState=g;else{i=m.next;var w=S=null,H=null,Q=i,de=!1;do{var Ee=Q.lane&-536870913;if(Ee!==Q.lane?(xt&Ee)===Ee:(Si&Ee)===Ee){var ee=Q.revertLane;if(ee===0)H!==null&&(H=H.next={lane:0,revertLane:0,action:Q.action,hasEagerState:Q.hasEagerState,eagerState:Q.eagerState,next:null}),Ee===Xl&&(de=!0);else if((Si&ee)===ee){Q=Q.next,ee===Xl&&(de=!0);continue}else Ee={lane:0,revertLane:Q.revertLane,action:Q.action,hasEagerState:Q.hasEagerState,eagerState:Q.eagerState,next:null},H===null?(w=H=Ee,S=g):H=H.next=Ee,pt.lanes|=ee,Oi|=ee;Ee=Q.action,Tl&&u(g,Ee),g=Q.hasEagerState?Q.eagerState:u(g,Ee)}else ee={lane:Ee,revertLane:Q.revertLane,action:Q.action,hasEagerState:Q.hasEagerState,eagerState:Q.eagerState,next:null},H===null?(w=H=ee,S=g):H=H.next=ee,pt.lanes|=Ee,Oi|=Ee;Q=Q.next}while(Q!==null&&Q!==i);if(H===null?S=g:H.next=w,!kr(g,r.memoizedState)&&(Bn=!0,de&&(u=$l,u!==null)))throw u;r.memoizedState=g,r.baseState=S,r.baseQueue=H,c.lastRenderedState=g}return m===null&&(c.lanes=0),[r.memoizedState,c.dispatch]}function rf(r){var i=xn(),u=i.queue;if(u===null)throw Error(a(311));u.lastRenderedReducer=r;var c=u.dispatch,m=u.pending,g=i.memoizedState;if(m!==null){u.pending=null;var S=m=m.next;do g=r(g,S.action),S=S.next;while(S!==m);kr(g,i.memoizedState)||(Bn=!0),i.memoizedState=g,i.baseQueue===null&&(i.baseState=g),u.lastRenderedState=g}return[g,c]}function Zp(r,i,u){var c=pt,m=xn(),g=Mt;if(g){if(u===void 0)throw Error(a(407));u=u()}else u=i();var S=!kr((zt||m).memoizedState,u);S&&(m.memoizedState=u,Bn=!0),m=m.queue;var w=tg.bind(null,c,m,r);if(yu(2048,8,w,[r]),m.getSnapshot!==i||S||An!==null&&An.memoizedState.tag&1){if(c.flags|=2048,Jl(9,o0(),eg.bind(null,c,m,u,i),null),Kt===null)throw Error(a(349));g||(Si&124)!==0||Jp(c,i,u)}return u}function Jp(r,i,u){r.flags|=16384,r={getSnapshot:i,value:u},i=pt.updateQueue,i===null?(i=ef(),pt.updateQueue=i,i.stores=[r]):(u=i.stores,u===null?i.stores=[r]:u.push(r))}function eg(r,i,u,c){i.value=u,i.getSnapshot=c,ng(i)&&rg(r)}function tg(r,i,u){return u(function(){ng(i)&&rg(r)})}function ng(r){var i=r.getSnapshot;r=r.value;try{var u=i();return!kr(r,u)}catch{return!0}}function rg(r){var i=Gl(r,2);i!==null&&Mr(i,r,2)}function af(r){var i=mr();if(typeof r=="function"){var u=r;if(r=u(),Tl){Ke(!0);try{u()}finally{Ke(!1)}}}return i.memoizedState=i.baseState=r,i.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Va,lastRenderedState:r},i}function ag(r,i,u,c){return r.baseState=u,nf(r,zt,typeof c=="function"?c:Va)}function fy(r,i,u,c,m){if(d0(r))throw Error(a(485));if(r=i.action,r!==null){var g={payload:m,action:r,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(S){g.listeners.push(S)}};X.T!==null?u(!0):g.isTransition=!1,c(g),u=i.pending,u===null?(g.next=i.pending=g,ig(i,g)):(g.next=u.next,i.pending=u.next=g)}}function ig(r,i){var u=i.action,c=i.payload,m=r.state;if(i.isTransition){var g=X.T,S={};X.T=S;try{var w=u(m,c),H=X.S;H!==null&&H(S,w),lg(r,i,w)}catch(Q){lf(r,i,Q)}finally{X.T=g}}else try{g=u(m,c),lg(r,i,g)}catch(Q){lf(r,i,Q)}}function lg(r,i,u){u!==null&&typeof u=="object"&&typeof u.then=="function"?u.then(function(c){sg(r,i,c)},function(c){return lf(r,i,c)}):sg(r,i,u)}function sg(r,i,u){i.status="fulfilled",i.value=u,ug(i),r.state=u,i=r.pending,i!==null&&(u=i.next,u===i?r.pending=null:(u=u.next,i.next=u,ig(r,u)))}function lf(r,i,u){var c=r.pending;if(r.pending=null,c!==null){c=c.next;do i.status="rejected",i.reason=u,ug(i),i=i.next;while(i!==c)}r.action=null}function ug(r){r=r.listeners;for(var i=0;i<r.length;i++)(0,r[i])()}function og(r,i){return i}function cg(r,i){if(Mt){var u=Kt.formState;if(u!==null){e:{var c=pt;if(Mt){if(hn){t:{for(var m=hn,g=ba;m.nodeType!==8;){if(!g){m=null;break t}if(m=ca(m.nextSibling),m===null){m=null;break t}}g=m.data,m=g==="F!"||g==="F"?m:null}if(m){hn=ca(m.nextSibling),c=m.data==="F!";break e}}bl(c)}c=!1}c&&(i=u[0])}}return u=mr(),u.memoizedState=u.baseState=i,c={pending:null,lanes:0,dispatch:null,lastRenderedReducer:og,lastRenderedState:i},u.queue=c,u=Cg.bind(null,pt,c),c.dispatch=u,c=af(!1),g=df.bind(null,pt,!1,c.queue),c=mr(),m={state:i,dispatch:null,action:r,pending:null},c.queue=m,u=fy.bind(null,pt,m,g,u),m.dispatch=u,c.memoizedState=r,[i,u,!1]}function dg(r){var i=xn();return fg(i,zt,r)}function fg(r,i,u){if(i=nf(r,i,og)[0],r=u0(Va)[0],typeof i=="object"&&i!==null&&typeof i.then=="function")try{var c=Eu(i)}catch(S){throw S===fu?n0:S}else c=i;i=xn();var m=i.queue,g=m.dispatch;return u!==i.memoizedState&&(pt.flags|=2048,Jl(9,o0(),hy.bind(null,m,u),null)),[c,g,r]}function hy(r,i){r.action=i}function hg(r){var i=xn(),u=zt;if(u!==null)return fg(i,u,r);xn(),i=i.memoizedState,u=xn();var c=u.queue.dispatch;return u.memoizedState=r,[i,c,!1]}function Jl(r,i,u,c){return r={tag:r,create:u,deps:c,inst:i,next:null},i=pt.updateQueue,i===null&&(i=ef(),pt.updateQueue=i),u=i.lastEffect,u===null?i.lastEffect=r.next=r:(c=u.next,u.next=r,r.next=c,i.lastEffect=r),r}function o0(){return{destroy:void 0,resource:void 0}}function mg(){return xn().memoizedState}function c0(r,i,u,c){var m=mr();c=c===void 0?null:c,pt.flags|=r,m.memoizedState=Jl(1|i,o0(),u,c)}function yu(r,i,u,c){var m=xn();c=c===void 0?null:c;var g=m.memoizedState.inst;zt!==null&&c!==null&&$d(c,zt.memoizedState.deps)?m.memoizedState=Jl(i,g,u,c):(pt.flags|=r,m.memoizedState=Jl(1|i,g,u,c))}function pg(r,i){c0(8390656,8,r,i)}function gg(r,i){yu(2048,8,r,i)}function bg(r,i){return yu(4,2,r,i)}function Eg(r,i){return yu(4,4,r,i)}function yg(r,i){if(typeof i=="function"){r=r();var u=i(r);return function(){typeof u=="function"?u():i(null)}}if(i!=null)return r=r(),i.current=r,function(){i.current=null}}function vg(r,i,u){u=u!=null?u.concat([r]):null,yu(4,4,yg.bind(null,i,r),u)}function sf(){}function Tg(r,i){var u=xn();i=i===void 0?null:i;var c=u.memoizedState;return i!==null&&$d(i,c[1])?c[0]:(u.memoizedState=[r,i],r)}function _g(r,i){var u=xn();i=i===void 0?null:i;var c=u.memoizedState;if(i!==null&&$d(i,c[1]))return c[0];if(c=r(),Tl){Ke(!0);try{r()}finally{Ke(!1)}}return u.memoizedState=[c,i],c}function uf(r,i,u){return u===void 0||(Si&1073741824)!==0?r.memoizedState=i:(r.memoizedState=u,r=x2(),pt.lanes|=r,Oi|=r,u)}function Sg(r,i,u,c){return kr(u,i)?u:Wl.current!==null?(r=uf(r,u,c),kr(r,i)||(Bn=!0),r):(Si&42)===0?(Bn=!0,r.memoizedState=u):(r=x2(),pt.lanes|=r,Oi|=r,i)}function Ag(r,i,u,c,m){var g=oe.p;oe.p=g!==0&&8>g?g:8;var S=X.T,w={};X.T=w,df(r,!1,i,u);try{var H=m(),Q=X.S;if(Q!==null&&Q(w,H),H!==null&&typeof H=="object"&&typeof H.then=="function"){var de=oy(H,c);vu(r,i,de,Rr(r))}else vu(r,i,c,Rr(r))}catch(Ee){vu(r,i,{then:function(){},status:"rejected",reason:Ee},Rr())}finally{oe.p=g,X.T=S}}function my(){}function of(r,i,u,c){if(r.tag!==5)throw Error(a(476));var m=xg(r).queue;Ag(r,m,i,be,u===null?my:function(){return kg(r),u(c)})}function xg(r){var i=r.memoizedState;if(i!==null)return i;i={memoizedState:be,baseState:be,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Va,lastRenderedState:be},next:null};var u={};return i.next={memoizedState:u,baseState:u,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Va,lastRenderedState:u},next:null},r.memoizedState=i,r=r.alternate,r!==null&&(r.memoizedState=i),i}function kg(r){var i=xg(r).next.queue;vu(r,i,{},Rr())}function cf(){return jn(Uu)}function Ng(){return xn().memoizedState}function wg(){return xn().memoizedState}function py(r){for(var i=r.return;i!==null;){switch(i.tag){case 24:case 3:var u=Rr();r=Ti(u);var c=_i(i,r,u);c!==null&&(Mr(c,i,u),mu(c,i,u)),i={cache:zd()},r.payload=i;return}i=i.return}}function gy(r,i,u){var c=Rr();u={lane:c,revertLane:0,action:u,hasEagerState:!1,eagerState:null,next:null},d0(r)?Og(i,u):(u=Cd(r,i,u,c),u!==null&&(Mr(u,r,c),Rg(u,i,c)))}function Cg(r,i,u){var c=Rr();vu(r,i,u,c)}function vu(r,i,u,c){var m={lane:c,revertLane:0,action:u,hasEagerState:!1,eagerState:null,next:null};if(d0(r))Og(i,m);else{var g=r.alternate;if(r.lanes===0&&(g===null||g.lanes===0)&&(g=i.lastRenderedReducer,g!==null))try{var S=i.lastRenderedState,w=g(S,u);if(m.hasEagerState=!0,m.eagerState=w,kr(w,S))return Xo(r,i,m,0),Kt===null&&jo(),!1}catch{}finally{}if(u=Cd(r,i,m,c),u!==null)return Mr(u,r,c),Rg(u,i,c),!0}return!1}function df(r,i,u,c){if(c={lane:2,revertLane:Yf(),action:c,hasEagerState:!1,eagerState:null,next:null},d0(r)){if(i)throw Error(a(479))}else i=Cd(r,u,c,2),i!==null&&Mr(i,r,2)}function d0(r){var i=r.alternate;return r===pt||i!==null&&i===pt}function Og(r,i){Ql=i0=!0;var u=r.pending;u===null?i.next=i:(i.next=u.next,u.next=i),r.pending=i}function Rg(r,i,u){if((u&4194048)!==0){var c=i.lanes;c&=r.pendingLanes,u|=c,i.lanes=u,me(r,u)}}var f0={readContext:jn,use:s0,useCallback:bn,useContext:bn,useEffect:bn,useImperativeHandle:bn,useLayoutEffect:bn,useInsertionEffect:bn,useMemo:bn,useReducer:bn,useRef:bn,useState:bn,useDebugValue:bn,useDeferredValue:bn,useTransition:bn,useSyncExternalStore:bn,useId:bn,useHostTransitionStatus:bn,useFormState:bn,useActionState:bn,useOptimistic:bn,useMemoCache:bn,useCacheRefresh:bn},Mg={readContext:jn,use:s0,useCallback:function(r,i){return mr().memoizedState=[r,i===void 0?null:i],r},useContext:jn,useEffect:pg,useImperativeHandle:function(r,i,u){u=u!=null?u.concat([r]):null,c0(4194308,4,yg.bind(null,i,r),u)},useLayoutEffect:function(r,i){return c0(4194308,4,r,i)},useInsertionEffect:function(r,i){c0(4,2,r,i)},useMemo:function(r,i){var u=mr();i=i===void 0?null:i;var c=r();if(Tl){Ke(!0);try{r()}finally{Ke(!1)}}return u.memoizedState=[c,i],c},useReducer:function(r,i,u){var c=mr();if(u!==void 0){var m=u(i);if(Tl){Ke(!0);try{u(i)}finally{Ke(!1)}}}else m=i;return c.memoizedState=c.baseState=m,r={pending:null,lanes:0,dispatch:null,lastRenderedReducer:r,lastRenderedState:m},c.queue=r,r=r.dispatch=gy.bind(null,pt,r),[c.memoizedState,r]},useRef:function(r){var i=mr();return r={current:r},i.memoizedState=r},useState:function(r){r=af(r);var i=r.queue,u=Cg.bind(null,pt,i);return i.dispatch=u,[r.memoizedState,u]},useDebugValue:sf,useDeferredValue:function(r,i){var u=mr();return uf(u,r,i)},useTransition:function(){var r=af(!1);return r=Ag.bind(null,pt,r.queue,!0,!1),mr().memoizedState=r,[!1,r]},useSyncExternalStore:function(r,i,u){var c=pt,m=mr();if(Mt){if(u===void 0)throw Error(a(407));u=u()}else{if(u=i(),Kt===null)throw Error(a(349));(xt&124)!==0||Jp(c,i,u)}m.memoizedState=u;var g={value:u,getSnapshot:i};return m.queue=g,pg(tg.bind(null,c,g,r),[r]),c.flags|=2048,Jl(9,o0(),eg.bind(null,c,g,u,i),null),u},useId:function(){var r=mr(),i=Kt.identifierPrefix;if(Mt){var u=qa,c=Fa;u=(c&~(1<<32-$e(c)-1)).toString(32)+u,i="«"+i+"R"+u,u=l0++,0<u&&(i+="H"+u.toString(32)),i+="»"}else u=cy++,i="«"+i+"r"+u.toString(32)+"»";return r.memoizedState=i},useHostTransitionStatus:cf,useFormState:cg,useActionState:cg,useOptimistic:function(r){var i=mr();i.memoizedState=i.baseState=r;var u={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return i.queue=u,i=df.bind(null,pt,!0,u),u.dispatch=i,[r,i]},useMemoCache:tf,useCacheRefresh:function(){return mr().memoizedState=py.bind(null,pt)}},Dg={readContext:jn,use:s0,useCallback:Tg,useContext:jn,useEffect:gg,useImperativeHandle:vg,useInsertionEffect:bg,useLayoutEffect:Eg,useMemo:_g,useReducer:u0,useRef:mg,useState:function(){return u0(Va)},useDebugValue:sf,useDeferredValue:function(r,i){var u=xn();return Sg(u,zt.memoizedState,r,i)},useTransition:function(){var r=u0(Va)[0],i=xn().memoizedState;return[typeof r=="boolean"?r:Eu(r),i]},useSyncExternalStore:Zp,useId:Ng,useHostTransitionStatus:cf,useFormState:dg,useActionState:dg,useOptimistic:function(r,i){var u=xn();return ag(u,zt,r,i)},useMemoCache:tf,useCacheRefresh:wg},by={readContext:jn,use:s0,useCallback:Tg,useContext:jn,useEffect:gg,useImperativeHandle:vg,useInsertionEffect:bg,useLayoutEffect:Eg,useMemo:_g,useReducer:rf,useRef:mg,useState:function(){return rf(Va)},useDebugValue:sf,useDeferredValue:function(r,i){var u=xn();return zt===null?uf(u,r,i):Sg(u,zt.memoizedState,r,i)},useTransition:function(){var r=rf(Va)[0],i=xn().memoizedState;return[typeof r=="boolean"?r:Eu(r),i]},useSyncExternalStore:Zp,useId:Ng,useHostTransitionStatus:cf,useFormState:hg,useActionState:hg,useOptimistic:function(r,i){var u=xn();return zt!==null?ag(u,zt,r,i):(u.baseState=r,[r,u.queue.dispatch])},useMemoCache:tf,useCacheRefresh:wg},es=null,Tu=0;function h0(r){var i=Tu;return Tu+=1,es===null&&(es=[]),Gp(es,r,i)}function _u(r,i){i=i.props.ref,r.ref=i!==void 0?i:null}function m0(r,i){throw i.$$typeof===E?Error(a(525)):(r=Object.prototype.toString.call(i),Error(a(31,r==="[object Object]"?"object with keys {"+Object.keys(i).join(", ")+"}":r)))}function Ig(r){var i=r._init;return i(r._payload)}function Lg(r){function i(j,Y){if(r){var $=j.deletions;$===null?(j.deletions=[Y],j.flags|=16):$.push(Y)}}function u(j,Y){if(!r)return null;for(;Y!==null;)i(j,Y),Y=Y.sibling;return null}function c(j){for(var Y=new Map;j!==null;)j.key!==null?Y.set(j.key,j):Y.set(j.index,j),j=j.sibling;return Y}function m(j,Y){return j=Ha(j,Y),j.index=0,j.sibling=null,j}function g(j,Y,$){return j.index=$,r?($=j.alternate,$!==null?($=$.index,$<Y?(j.flags|=67108866,Y):$):(j.flags|=67108866,Y)):(j.flags|=1048576,Y)}function S(j){return r&&j.alternate===null&&(j.flags|=67108866),j}function w(j,Y,$,pe){return Y===null||Y.tag!==6?(Y=Rd($,j.mode,pe),Y.return=j,Y):(Y=m(Y,$),Y.return=j,Y)}function H(j,Y,$,pe){var Fe=$.type;return Fe===x?de(j,Y,$.props.children,pe,$.key):Y!==null&&(Y.elementType===Fe||typeof Fe=="object"&&Fe!==null&&Fe.$$typeof===ae&&Ig(Fe)===Y.type)?(Y=m(Y,$.props),_u(Y,$),Y.return=j,Y):(Y=Wo($.type,$.key,$.props,null,j.mode,pe),_u(Y,$),Y.return=j,Y)}function Q(j,Y,$,pe){return Y===null||Y.tag!==4||Y.stateNode.containerInfo!==$.containerInfo||Y.stateNode.implementation!==$.implementation?(Y=Md($,j.mode,pe),Y.return=j,Y):(Y=m(Y,$.children||[]),Y.return=j,Y)}function de(j,Y,$,pe,Fe){return Y===null||Y.tag!==7?(Y=hl($,j.mode,pe,Fe),Y.return=j,Y):(Y=m(Y,$),Y.return=j,Y)}function Ee(j,Y,$){if(typeof Y=="string"&&Y!==""||typeof Y=="number"||typeof Y=="bigint")return Y=Rd(""+Y,j.mode,$),Y.return=j,Y;if(typeof Y=="object"&&Y!==null){switch(Y.$$typeof){case T:return $=Wo(Y.type,Y.key,Y.props,null,j.mode,$),_u($,Y),$.return=j,$;case v:return Y=Md(Y,j.mode,$),Y.return=j,Y;case ae:var pe=Y._init;return Y=pe(Y._payload),Ee(j,Y,$)}if(ye(Y)||ce(Y))return Y=hl(Y,j.mode,$,null),Y.return=j,Y;if(typeof Y.then=="function")return Ee(j,h0(Y),$);if(Y.$$typeof===F)return Ee(j,e0(j,Y),$);m0(j,Y)}return null}function ee(j,Y,$,pe){var Fe=Y!==null?Y.key:null;if(typeof $=="string"&&$!==""||typeof $=="number"||typeof $=="bigint")return Fe!==null?null:w(j,Y,""+$,pe);if(typeof $=="object"&&$!==null){switch($.$$typeof){case T:return $.key===Fe?H(j,Y,$,pe):null;case v:return $.key===Fe?Q(j,Y,$,pe):null;case ae:return Fe=$._init,$=Fe($._payload),ee(j,Y,$,pe)}if(ye($)||ce($))return Fe!==null?null:de(j,Y,$,pe,null);if(typeof $.then=="function")return ee(j,Y,h0($),pe);if($.$$typeof===F)return ee(j,Y,e0(j,$),pe);m0(j,$)}return null}function ne(j,Y,$,pe,Fe){if(typeof pe=="string"&&pe!==""||typeof pe=="number"||typeof pe=="bigint")return j=j.get($)||null,w(Y,j,""+pe,Fe);if(typeof pe=="object"&&pe!==null){switch(pe.$$typeof){case T:return j=j.get(pe.key===null?$:pe.key)||null,H(Y,j,pe,Fe);case v:return j=j.get(pe.key===null?$:pe.key)||null,Q(Y,j,pe,Fe);case ae:var bt=pe._init;return pe=bt(pe._payload),ne(j,Y,$,pe,Fe)}if(ye(pe)||ce(pe))return j=j.get($)||null,de(Y,j,pe,Fe,null);if(typeof pe.then=="function")return ne(j,Y,$,h0(pe),Fe);if(pe.$$typeof===F)return ne(j,Y,$,e0(Y,pe),Fe);m0(Y,pe)}return null}function rt(j,Y,$,pe){for(var Fe=null,bt=null,Xe=Y,tt=Y=0,Un=null;Xe!==null&&tt<$.length;tt++){Xe.index>tt?(Un=Xe,Xe=null):Un=Xe.sibling;var Ot=ee(j,Xe,$[tt],pe);if(Ot===null){Xe===null&&(Xe=Un);break}r&&Xe&&Ot.alternate===null&&i(j,Xe),Y=g(Ot,Y,tt),bt===null?Fe=Ot:bt.sibling=Ot,bt=Ot,Xe=Un}if(tt===$.length)return u(j,Xe),Mt&&pl(j,tt),Fe;if(Xe===null){for(;tt<$.length;tt++)Xe=Ee(j,$[tt],pe),Xe!==null&&(Y=g(Xe,Y,tt),bt===null?Fe=Xe:bt.sibling=Xe,bt=Xe);return Mt&&pl(j,tt),Fe}for(Xe=c(Xe);tt<$.length;tt++)Un=ne(Xe,j,tt,$[tt],pe),Un!==null&&(r&&Un.alternate!==null&&Xe.delete(Un.key===null?tt:Un.key),Y=g(Un,Y,tt),bt===null?Fe=Un:bt.sibling=Un,bt=Un);return r&&Xe.forEach(function(zi){return i(j,zi)}),Mt&&pl(j,tt),Fe}function et(j,Y,$,pe){if($==null)throw Error(a(151));for(var Fe=null,bt=null,Xe=Y,tt=Y=0,Un=null,Ot=$.next();Xe!==null&&!Ot.done;tt++,Ot=$.next()){Xe.index>tt?(Un=Xe,Xe=null):Un=Xe.sibling;var zi=ee(j,Xe,Ot.value,pe);if(zi===null){Xe===null&&(Xe=Un);break}r&&Xe&&zi.alternate===null&&i(j,Xe),Y=g(zi,Y,tt),bt===null?Fe=zi:bt.sibling=zi,bt=zi,Xe=Un}if(Ot.done)return u(j,Xe),Mt&&pl(j,tt),Fe;if(Xe===null){for(;!Ot.done;tt++,Ot=$.next())Ot=Ee(j,Ot.value,pe),Ot!==null&&(Y=g(Ot,Y,tt),bt===null?Fe=Ot:bt.sibling=Ot,bt=Ot);return Mt&&pl(j,tt),Fe}for(Xe=c(Xe);!Ot.done;tt++,Ot=$.next())Ot=ne(Xe,j,tt,Ot.value,pe),Ot!==null&&(r&&Ot.alternate!==null&&Xe.delete(Ot.key===null?tt:Ot.key),Y=g(Ot,Y,tt),bt===null?Fe=Ot:bt.sibling=Ot,bt=Ot);return r&&Xe.forEach(function(Ev){return i(j,Ev)}),Mt&&pl(j,tt),Fe}function Ft(j,Y,$,pe){if(typeof $=="object"&&$!==null&&$.type===x&&$.key===null&&($=$.props.children),typeof $=="object"&&$!==null){switch($.$$typeof){case T:e:{for(var Fe=$.key;Y!==null;){if(Y.key===Fe){if(Fe=$.type,Fe===x){if(Y.tag===7){u(j,Y.sibling),pe=m(Y,$.props.children),pe.return=j,j=pe;break e}}else if(Y.elementType===Fe||typeof Fe=="object"&&Fe!==null&&Fe.$$typeof===ae&&Ig(Fe)===Y.type){u(j,Y.sibling),pe=m(Y,$.props),_u(pe,$),pe.return=j,j=pe;break e}u(j,Y);break}else i(j,Y);Y=Y.sibling}$.type===x?(pe=hl($.props.children,j.mode,pe,$.key),pe.return=j,j=pe):(pe=Wo($.type,$.key,$.props,null,j.mode,pe),_u(pe,$),pe.return=j,j=pe)}return S(j);case v:e:{for(Fe=$.key;Y!==null;){if(Y.key===Fe)if(Y.tag===4&&Y.stateNode.containerInfo===$.containerInfo&&Y.stateNode.implementation===$.implementation){u(j,Y.sibling),pe=m(Y,$.children||[]),pe.return=j,j=pe;break e}else{u(j,Y);break}else i(j,Y);Y=Y.sibling}pe=Md($,j.mode,pe),pe.return=j,j=pe}return S(j);case ae:return Fe=$._init,$=Fe($._payload),Ft(j,Y,$,pe)}if(ye($))return rt(j,Y,$,pe);if(ce($)){if(Fe=ce($),typeof Fe!="function")throw Error(a(150));return $=Fe.call($),et(j,Y,$,pe)}if(typeof $.then=="function")return Ft(j,Y,h0($),pe);if($.$$typeof===F)return Ft(j,Y,e0(j,$),pe);m0(j,$)}return typeof $=="string"&&$!==""||typeof $=="number"||typeof $=="bigint"?($=""+$,Y!==null&&Y.tag===6?(u(j,Y.sibling),pe=m(Y,$),pe.return=j,j=pe):(u(j,Y),pe=Rd($,j.mode,pe),pe.return=j,j=pe),S(j)):u(j,Y)}return function(j,Y,$,pe){try{Tu=0;var Fe=Ft(j,Y,$,pe);return es=null,Fe}catch(Xe){if(Xe===fu||Xe===n0)throw Xe;var bt=Nr(29,Xe,null,j.mode);return bt.lanes=pe,bt.return=j,bt}finally{}}}var ts=Lg(!0),Bg=Lg(!1),Kr=te(null),Ea=null;function Ai(r){var i=r.alternate;R(Rn,Rn.current&1),R(Kr,r),Ea===null&&(i===null||Wl.current!==null||i.memoizedState!==null)&&(Ea=r)}function Pg(r){if(r.tag===22){if(R(Rn,Rn.current),R(Kr,r),Ea===null){var i=r.alternate;i!==null&&i.memoizedState!==null&&(Ea=r)}}else xi()}function xi(){R(Rn,Rn.current),R(Kr,Kr.current)}function Ka(r){ue(Kr),Ea===r&&(Ea=null),ue(Rn)}var Rn=te(0);function p0(r){for(var i=r;i!==null;){if(i.tag===13){var u=i.memoizedState;if(u!==null&&(u=u.dehydrated,u===null||u.data==="$?"||th(u)))return i}else if(i.tag===19&&i.memoizedProps.revealOrder!==void 0){if((i.flags&128)!==0)return i}else if(i.child!==null){i.child.return=i,i=i.child;continue}if(i===r)break;for(;i.sibling===null;){if(i.return===null||i.return===r)return null;i=i.return}i.sibling.return=i.return,i=i.sibling}return null}function ff(r,i,u,c){i=r.memoizedState,u=u(c,i),u=u==null?i:p({},i,u),r.memoizedState=u,r.lanes===0&&(r.updateQueue.baseState=u)}var hf={enqueueSetState:function(r,i,u){r=r._reactInternals;var c=Rr(),m=Ti(c);m.payload=i,u!=null&&(m.callback=u),i=_i(r,m,c),i!==null&&(Mr(i,r,c),mu(i,r,c))},enqueueReplaceState:function(r,i,u){r=r._reactInternals;var c=Rr(),m=Ti(c);m.tag=1,m.payload=i,u!=null&&(m.callback=u),i=_i(r,m,c),i!==null&&(Mr(i,r,c),mu(i,r,c))},enqueueForceUpdate:function(r,i){r=r._reactInternals;var u=Rr(),c=Ti(u);c.tag=2,i!=null&&(c.callback=i),i=_i(r,c,u),i!==null&&(Mr(i,r,u),mu(i,r,u))}};function Ug(r,i,u,c,m,g,S){return r=r.stateNode,typeof r.shouldComponentUpdate=="function"?r.shouldComponentUpdate(c,g,S):i.prototype&&i.prototype.isPureReactComponent?!au(u,c)||!au(m,g):!0}function zg(r,i,u,c){r=i.state,typeof i.componentWillReceiveProps=="function"&&i.componentWillReceiveProps(u,c),typeof i.UNSAFE_componentWillReceiveProps=="function"&&i.UNSAFE_componentWillReceiveProps(u,c),i.state!==r&&hf.enqueueReplaceState(i,i.state,null)}function _l(r,i){var u=i;if("ref"in i){u={};for(var c in i)c!=="ref"&&(u[c]=i[c])}if(r=r.defaultProps){u===i&&(u=p({},u));for(var m in r)u[m]===void 0&&(u[m]=r[m])}return u}var g0=typeof reportError=="function"?reportError:function(r){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var i=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof r=="object"&&r!==null&&typeof r.message=="string"?String(r.message):String(r),error:r});if(!window.dispatchEvent(i))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",r);return}console.error(r)};function Hg(r){g0(r)}function Fg(r){console.error(r)}function qg(r){g0(r)}function b0(r,i){try{var u=r.onUncaughtError;u(i.value,{componentStack:i.stack})}catch(c){setTimeout(function(){throw c})}}function Yg(r,i,u){try{var c=r.onCaughtError;c(u.value,{componentStack:u.stack,errorBoundary:i.tag===1?i.stateNode:null})}catch(m){setTimeout(function(){throw m})}}function mf(r,i,u){return u=Ti(u),u.tag=3,u.payload={element:null},u.callback=function(){b0(r,i)},u}function Gg(r){return r=Ti(r),r.tag=3,r}function Vg(r,i,u,c){var m=u.type.getDerivedStateFromError;if(typeof m=="function"){var g=c.value;r.payload=function(){return m(g)},r.callback=function(){Yg(i,u,c)}}var S=u.stateNode;S!==null&&typeof S.componentDidCatch=="function"&&(r.callback=function(){Yg(i,u,c),typeof m!="function"&&(Ri===null?Ri=new Set([this]):Ri.add(this));var w=c.stack;this.componentDidCatch(c.value,{componentStack:w!==null?w:""})})}function Ey(r,i,u,c,m){if(u.flags|=32768,c!==null&&typeof c=="object"&&typeof c.then=="function"){if(i=u.alternate,i!==null&&ou(i,u,m,!0),u=Kr.current,u!==null){switch(u.tag){case 13:return Ea===null?Uf():u.alternate===null&&mn===0&&(mn=3),u.flags&=-257,u.flags|=65536,u.lanes=m,c===qd?u.flags|=16384:(i=u.updateQueue,i===null?u.updateQueue=new Set([c]):i.add(c),Hf(r,c,m)),!1;case 22:return u.flags|=65536,c===qd?u.flags|=16384:(i=u.updateQueue,i===null?(i={transitions:null,markerInstances:null,retryQueue:new Set([c])},u.updateQueue=i):(u=i.retryQueue,u===null?i.retryQueue=new Set([c]):u.add(c)),Hf(r,c,m)),!1}throw Error(a(435,u.tag))}return Hf(r,c,m),Uf(),!1}if(Mt)return i=Kr.current,i!==null?((i.flags&65536)===0&&(i.flags|=256),i.flags|=65536,i.lanes=m,c!==Ld&&(r=Error(a(422),{cause:c}),uu(qr(r,u)))):(c!==Ld&&(i=Error(a(423),{cause:c}),uu(qr(i,u))),r=r.current.alternate,r.flags|=65536,m&=-m,r.lanes|=m,c=qr(c,u),m=mf(r.stateNode,c,m),Vd(r,m),mn!==4&&(mn=2)),!1;var g=Error(a(520),{cause:c});if(g=qr(g,u),Cu===null?Cu=[g]:Cu.push(g),mn!==4&&(mn=2),i===null)return!0;c=qr(c,u),u=i;do{switch(u.tag){case 3:return u.flags|=65536,r=m&-m,u.lanes|=r,r=mf(u.stateNode,c,r),Vd(u,r),!1;case 1:if(i=u.type,g=u.stateNode,(u.flags&128)===0&&(typeof i.getDerivedStateFromError=="function"||g!==null&&typeof g.componentDidCatch=="function"&&(Ri===null||!Ri.has(g))))return u.flags|=65536,m&=-m,u.lanes|=m,m=Gg(m),Vg(m,r,u,c),Vd(u,m),!1}u=u.return}while(u!==null);return!1}var Kg=Error(a(461)),Bn=!1;function qn(r,i,u,c){i.child=r===null?Bg(i,null,u,c):ts(i,r.child,u,c)}function jg(r,i,u,c,m){u=u.render;var g=i.ref;if("ref"in c){var S={};for(var w in c)w!=="ref"&&(S[w]=c[w])}else S=c;return yl(i),c=Wd(r,i,u,S,g,m),w=Qd(),r!==null&&!Bn?(Zd(r,i,m),ja(r,i,m)):(Mt&&w&&Dd(i),i.flags|=1,qn(r,i,c,m),i.child)}function Xg(r,i,u,c,m){if(r===null){var g=u.type;return typeof g=="function"&&!Od(g)&&g.defaultProps===void 0&&u.compare===null?(i.tag=15,i.type=g,$g(r,i,g,c,m)):(r=Wo(u.type,null,c,i,i.mode,m),r.ref=i.ref,r.return=i,i.child=r)}if(g=r.child,!_f(r,m)){var S=g.memoizedProps;if(u=u.compare,u=u!==null?u:au,u(S,c)&&r.ref===i.ref)return ja(r,i,m)}return i.flags|=1,r=Ha(g,c),r.ref=i.ref,r.return=i,i.child=r}function $g(r,i,u,c,m){if(r!==null){var g=r.memoizedProps;if(au(g,c)&&r.ref===i.ref)if(Bn=!1,i.pendingProps=c=g,_f(r,m))(r.flags&131072)!==0&&(Bn=!0);else return i.lanes=r.lanes,ja(r,i,m)}return pf(r,i,u,c,m)}function Wg(r,i,u){var c=i.pendingProps,m=c.children,g=r!==null?r.memoizedState:null;if(c.mode==="hidden"){if((i.flags&128)!==0){if(c=g!==null?g.baseLanes|u:u,r!==null){for(m=i.child=r.child,g=0;m!==null;)g=g|m.lanes|m.childLanes,m=m.sibling;i.childLanes=g&~c}else i.childLanes=0,i.child=null;return Qg(r,i,c,u)}if((u&536870912)!==0)i.memoizedState={baseLanes:0,cachePool:null},r!==null&&t0(i,g!==null?g.cachePool:null),g!==null?$p(i,g):jd(),Pg(i);else return i.lanes=i.childLanes=536870912,Qg(r,i,g!==null?g.baseLanes|u:u,u)}else g!==null?(t0(i,g.cachePool),$p(i,g),xi(),i.memoizedState=null):(r!==null&&t0(i,null),jd(),xi());return qn(r,i,m,u),i.child}function Qg(r,i,u,c){var m=Fd();return m=m===null?null:{parent:On._currentValue,pool:m},i.memoizedState={baseLanes:u,cachePool:m},r!==null&&t0(i,null),jd(),Pg(i),r!==null&&ou(r,i,c,!0),null}function E0(r,i){var u=i.ref;if(u===null)r!==null&&r.ref!==null&&(i.flags|=4194816);else{if(typeof u!="function"&&typeof u!="object")throw Error(a(284));(r===null||r.ref!==u)&&(i.flags|=4194816)}}function pf(r,i,u,c,m){return yl(i),u=Wd(r,i,u,c,void 0,m),c=Qd(),r!==null&&!Bn?(Zd(r,i,m),ja(r,i,m)):(Mt&&c&&Dd(i),i.flags|=1,qn(r,i,u,m),i.child)}function Zg(r,i,u,c,m,g){return yl(i),i.updateQueue=null,u=Qp(i,c,u,m),Wp(r),c=Qd(),r!==null&&!Bn?(Zd(r,i,g),ja(r,i,g)):(Mt&&c&&Dd(i),i.flags|=1,qn(r,i,u,g),i.child)}function Jg(r,i,u,c,m){if(yl(i),i.stateNode===null){var g=Vl,S=u.contextType;typeof S=="object"&&S!==null&&(g=jn(S)),g=new u(c,g),i.memoizedState=g.state!==null&&g.state!==void 0?g.state:null,g.updater=hf,i.stateNode=g,g._reactInternals=i,g=i.stateNode,g.props=c,g.state=i.memoizedState,g.refs={},Yd(i),S=u.contextType,g.context=typeof S=="object"&&S!==null?jn(S):Vl,g.state=i.memoizedState,S=u.getDerivedStateFromProps,typeof S=="function"&&(ff(i,u,S,c),g.state=i.memoizedState),typeof u.getDerivedStateFromProps=="function"||typeof g.getSnapshotBeforeUpdate=="function"||typeof g.UNSAFE_componentWillMount!="function"&&typeof g.componentWillMount!="function"||(S=g.state,typeof g.componentWillMount=="function"&&g.componentWillMount(),typeof g.UNSAFE_componentWillMount=="function"&&g.UNSAFE_componentWillMount(),S!==g.state&&hf.enqueueReplaceState(g,g.state,null),gu(i,c,g,m),pu(),g.state=i.memoizedState),typeof g.componentDidMount=="function"&&(i.flags|=4194308),c=!0}else if(r===null){g=i.stateNode;var w=i.memoizedProps,H=_l(u,w);g.props=H;var Q=g.context,de=u.contextType;S=Vl,typeof de=="object"&&de!==null&&(S=jn(de));var Ee=u.getDerivedStateFromProps;de=typeof Ee=="function"||typeof g.getSnapshotBeforeUpdate=="function",w=i.pendingProps!==w,de||typeof g.UNSAFE_componentWillReceiveProps!="function"&&typeof g.componentWillReceiveProps!="function"||(w||Q!==S)&&zg(i,g,c,S),vi=!1;var ee=i.memoizedState;g.state=ee,gu(i,c,g,m),pu(),Q=i.memoizedState,w||ee!==Q||vi?(typeof Ee=="function"&&(ff(i,u,Ee,c),Q=i.memoizedState),(H=vi||Ug(i,u,H,c,ee,Q,S))?(de||typeof g.UNSAFE_componentWillMount!="function"&&typeof g.componentWillMount!="function"||(typeof g.componentWillMount=="function"&&g.componentWillMount(),typeof g.UNSAFE_componentWillMount=="function"&&g.UNSAFE_componentWillMount()),typeof g.componentDidMount=="function"&&(i.flags|=4194308)):(typeof g.componentDidMount=="function"&&(i.flags|=4194308),i.memoizedProps=c,i.memoizedState=Q),g.props=c,g.state=Q,g.context=S,c=H):(typeof g.componentDidMount=="function"&&(i.flags|=4194308),c=!1)}else{g=i.stateNode,Gd(r,i),S=i.memoizedProps,de=_l(u,S),g.props=de,Ee=i.pendingProps,ee=g.context,Q=u.contextType,H=Vl,typeof Q=="object"&&Q!==null&&(H=jn(Q)),w=u.getDerivedStateFromProps,(Q=typeof w=="function"||typeof g.getSnapshotBeforeUpdate=="function")||typeof g.UNSAFE_componentWillReceiveProps!="function"&&typeof g.componentWillReceiveProps!="function"||(S!==Ee||ee!==H)&&zg(i,g,c,H),vi=!1,ee=i.memoizedState,g.state=ee,gu(i,c,g,m),pu();var ne=i.memoizedState;S!==Ee||ee!==ne||vi||r!==null&&r.dependencies!==null&&Jo(r.dependencies)?(typeof w=="function"&&(ff(i,u,w,c),ne=i.memoizedState),(de=vi||Ug(i,u,de,c,ee,ne,H)||r!==null&&r.dependencies!==null&&Jo(r.dependencies))?(Q||typeof g.UNSAFE_componentWillUpdate!="function"&&typeof g.componentWillUpdate!="function"||(typeof g.componentWillUpdate=="function"&&g.componentWillUpdate(c,ne,H),typeof g.UNSAFE_componentWillUpdate=="function"&&g.UNSAFE_componentWillUpdate(c,ne,H)),typeof g.componentDidUpdate=="function"&&(i.flags|=4),typeof g.getSnapshotBeforeUpdate=="function"&&(i.flags|=1024)):(typeof g.componentDidUpdate!="function"||S===r.memoizedProps&&ee===r.memoizedState||(i.flags|=4),typeof g.getSnapshotBeforeUpdate!="function"||S===r.memoizedProps&&ee===r.memoizedState||(i.flags|=1024),i.memoizedProps=c,i.memoizedState=ne),g.props=c,g.state=ne,g.context=H,c=de):(typeof g.componentDidUpdate!="function"||S===r.memoizedProps&&ee===r.memoizedState||(i.flags|=4),typeof g.getSnapshotBeforeUpdate!="function"||S===r.memoizedProps&&ee===r.memoizedState||(i.flags|=1024),c=!1)}return g=c,E0(r,i),c=(i.flags&128)!==0,g||c?(g=i.stateNode,u=c&&typeof u.getDerivedStateFromError!="function"?null:g.render(),i.flags|=1,r!==null&&c?(i.child=ts(i,r.child,null,m),i.child=ts(i,null,u,m)):qn(r,i,u,m),i.memoizedState=g.state,r=i.child):r=ja(r,i,m),r}function e2(r,i,u,c){return su(),i.flags|=256,qn(r,i,u,c),i.child}var gf={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function bf(r){return{baseLanes:r,cachePool:Fp()}}function Ef(r,i,u){return r=r!==null?r.childLanes&~u:0,i&&(r|=jr),r}function t2(r,i,u){var c=i.pendingProps,m=!1,g=(i.flags&128)!==0,S;if((S=g)||(S=r!==null&&r.memoizedState===null?!1:(Rn.current&2)!==0),S&&(m=!0,i.flags&=-129),S=(i.flags&32)!==0,i.flags&=-33,r===null){if(Mt){if(m?Ai(i):xi(),Mt){var w=hn,H;if(H=w){e:{for(H=w,w=ba;H.nodeType!==8;){if(!w){w=null;break e}if(H=ca(H.nextSibling),H===null){w=null;break e}}w=H}w!==null?(i.memoizedState={dehydrated:w,treeContext:ml!==null?{id:Fa,overflow:qa}:null,retryLane:536870912,hydrationErrors:null},H=Nr(18,null,null,0),H.stateNode=w,H.return=i,i.child=H,nr=i,hn=null,H=!0):H=!1}H||bl(i)}if(w=i.memoizedState,w!==null&&(w=w.dehydrated,w!==null))return th(w)?i.lanes=32:i.lanes=536870912,null;Ka(i)}return w=c.children,c=c.fallback,m?(xi(),m=i.mode,w=y0({mode:"hidden",children:w},m),c=hl(c,m,u,null),w.return=i,c.return=i,w.sibling=c,i.child=w,m=i.child,m.memoizedState=bf(u),m.childLanes=Ef(r,S,u),i.memoizedState=gf,c):(Ai(i),yf(i,w))}if(H=r.memoizedState,H!==null&&(w=H.dehydrated,w!==null)){if(g)i.flags&256?(Ai(i),i.flags&=-257,i=vf(r,i,u)):i.memoizedState!==null?(xi(),i.child=r.child,i.flags|=128,i=null):(xi(),m=c.fallback,w=i.mode,c=y0({mode:"visible",children:c.children},w),m=hl(m,w,u,null),m.flags|=2,c.return=i,m.return=i,c.sibling=m,i.child=c,ts(i,r.child,null,u),c=i.child,c.memoizedState=bf(u),c.childLanes=Ef(r,S,u),i.memoizedState=gf,i=m);else if(Ai(i),th(w)){if(S=w.nextSibling&&w.nextSibling.dataset,S)var Q=S.dgst;S=Q,c=Error(a(419)),c.stack="",c.digest=S,uu({value:c,source:null,stack:null}),i=vf(r,i,u)}else if(Bn||ou(r,i,u,!1),S=(u&r.childLanes)!==0,Bn||S){if(S=Kt,S!==null&&(c=u&-u,c=(c&42)!==0?1:Me(c),c=(c&(S.suspendedLanes|u))!==0?0:c,c!==0&&c!==H.retryLane))throw H.retryLane=c,Gl(r,c),Mr(S,r,c),Kg;w.data==="$?"||Uf(),i=vf(r,i,u)}else w.data==="$?"?(i.flags|=192,i.child=r.child,i=null):(r=H.treeContext,hn=ca(w.nextSibling),nr=i,Mt=!0,gl=null,ba=!1,r!==null&&(Gr[Vr++]=Fa,Gr[Vr++]=qa,Gr[Vr++]=ml,Fa=r.id,qa=r.overflow,ml=i),i=yf(i,c.children),i.flags|=4096);return i}return m?(xi(),m=c.fallback,w=i.mode,H=r.child,Q=H.sibling,c=Ha(H,{mode:"hidden",children:c.children}),c.subtreeFlags=H.subtreeFlags&65011712,Q!==null?m=Ha(Q,m):(m=hl(m,w,u,null),m.flags|=2),m.return=i,c.return=i,c.sibling=m,i.child=c,c=m,m=i.child,w=r.child.memoizedState,w===null?w=bf(u):(H=w.cachePool,H!==null?(Q=On._currentValue,H=H.parent!==Q?{parent:Q,pool:Q}:H):H=Fp(),w={baseLanes:w.baseLanes|u,cachePool:H}),m.memoizedState=w,m.childLanes=Ef(r,S,u),i.memoizedState=gf,c):(Ai(i),u=r.child,r=u.sibling,u=Ha(u,{mode:"visible",children:c.children}),u.return=i,u.sibling=null,r!==null&&(S=i.deletions,S===null?(i.deletions=[r],i.flags|=16):S.push(r)),i.child=u,i.memoizedState=null,u)}function yf(r,i){return i=y0({mode:"visible",children:i},r.mode),i.return=r,r.child=i}function y0(r,i){return r=Nr(22,r,null,i),r.lanes=0,r.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null},r}function vf(r,i,u){return ts(i,r.child,null,u),r=yf(i,i.pendingProps.children),r.flags|=2,i.memoizedState=null,r}function n2(r,i,u){r.lanes|=i;var c=r.alternate;c!==null&&(c.lanes|=i),Pd(r.return,i,u)}function Tf(r,i,u,c,m){var g=r.memoizedState;g===null?r.memoizedState={isBackwards:i,rendering:null,renderingStartTime:0,last:c,tail:u,tailMode:m}:(g.isBackwards=i,g.rendering=null,g.renderingStartTime=0,g.last=c,g.tail=u,g.tailMode=m)}function r2(r,i,u){var c=i.pendingProps,m=c.revealOrder,g=c.tail;if(qn(r,i,c.children,u),c=Rn.current,(c&2)!==0)c=c&1|2,i.flags|=128;else{if(r!==null&&(r.flags&128)!==0)e:for(r=i.child;r!==null;){if(r.tag===13)r.memoizedState!==null&&n2(r,u,i);else if(r.tag===19)n2(r,u,i);else if(r.child!==null){r.child.return=r,r=r.child;continue}if(r===i)break e;for(;r.sibling===null;){if(r.return===null||r.return===i)break e;r=r.return}r.sibling.return=r.return,r=r.sibling}c&=1}switch(R(Rn,c),m){case"forwards":for(u=i.child,m=null;u!==null;)r=u.alternate,r!==null&&p0(r)===null&&(m=u),u=u.sibling;u=m,u===null?(m=i.child,i.child=null):(m=u.sibling,u.sibling=null),Tf(i,!1,m,u,g);break;case"backwards":for(u=null,m=i.child,i.child=null;m!==null;){if(r=m.alternate,r!==null&&p0(r)===null){i.child=m;break}r=m.sibling,m.sibling=u,u=m,m=r}Tf(i,!0,u,null,g);break;case"together":Tf(i,!1,null,null,void 0);break;default:i.memoizedState=null}return i.child}function ja(r,i,u){if(r!==null&&(i.dependencies=r.dependencies),Oi|=i.lanes,(u&i.childLanes)===0)if(r!==null){if(ou(r,i,u,!1),(u&i.childLanes)===0)return null}else return null;if(r!==null&&i.child!==r.child)throw Error(a(153));if(i.child!==null){for(r=i.child,u=Ha(r,r.pendingProps),i.child=u,u.return=i;r.sibling!==null;)r=r.sibling,u=u.sibling=Ha(r,r.pendingProps),u.return=i;u.sibling=null}return i.child}function _f(r,i){return(r.lanes&i)!==0?!0:(r=r.dependencies,!!(r!==null&&Jo(r)))}function yy(r,i,u){switch(i.tag){case 3:it(i,i.stateNode.containerInfo),yi(i,On,r.memoizedState.cache),su();break;case 27:case 5:Pt(i);break;case 4:it(i,i.stateNode.containerInfo);break;case 10:yi(i,i.type,i.memoizedProps.value);break;case 13:var c=i.memoizedState;if(c!==null)return c.dehydrated!==null?(Ai(i),i.flags|=128,null):(u&i.child.childLanes)!==0?t2(r,i,u):(Ai(i),r=ja(r,i,u),r!==null?r.sibling:null);Ai(i);break;case 19:var m=(r.flags&128)!==0;if(c=(u&i.childLanes)!==0,c||(ou(r,i,u,!1),c=(u&i.childLanes)!==0),m){if(c)return r2(r,i,u);i.flags|=128}if(m=i.memoizedState,m!==null&&(m.rendering=null,m.tail=null,m.lastEffect=null),R(Rn,Rn.current),c)break;return null;case 22:case 23:return i.lanes=0,Wg(r,i,u);case 24:yi(i,On,r.memoizedState.cache)}return ja(r,i,u)}function a2(r,i,u){if(r!==null)if(r.memoizedProps!==i.pendingProps)Bn=!0;else{if(!_f(r,u)&&(i.flags&128)===0)return Bn=!1,yy(r,i,u);Bn=(r.flags&131072)!==0}else Bn=!1,Mt&&(i.flags&1048576)!==0&&Ip(i,Zo,i.index);switch(i.lanes=0,i.tag){case 16:e:{r=i.pendingProps;var c=i.elementType,m=c._init;if(c=m(c._payload),i.type=c,typeof c=="function")Od(c)?(r=_l(c,r),i.tag=1,i=Jg(null,i,c,r,u)):(i.tag=0,i=pf(null,i,c,r,u));else{if(c!=null){if(m=c.$$typeof,m===J){i.tag=11,i=jg(null,i,c,r,u);break e}else if(m===le){i.tag=14,i=Xg(null,i,c,r,u);break e}}throw i=fe(c)||c,Error(a(306,i,""))}}return i;case 0:return pf(r,i,i.type,i.pendingProps,u);case 1:return c=i.type,m=_l(c,i.pendingProps),Jg(r,i,c,m,u);case 3:e:{if(it(i,i.stateNode.containerInfo),r===null)throw Error(a(387));c=i.pendingProps;var g=i.memoizedState;m=g.element,Gd(r,i),gu(i,c,null,u);var S=i.memoizedState;if(c=S.cache,yi(i,On,c),c!==g.cache&&Ud(i,[On],u,!0),pu(),c=S.element,g.isDehydrated)if(g={element:c,isDehydrated:!1,cache:S.cache},i.updateQueue.baseState=g,i.memoizedState=g,i.flags&256){i=e2(r,i,c,u);break e}else if(c!==m){m=qr(Error(a(424)),i),uu(m),i=e2(r,i,c,u);break e}else{switch(r=i.stateNode.containerInfo,r.nodeType){case 9:r=r.body;break;default:r=r.nodeName==="HTML"?r.ownerDocument.body:r}for(hn=ca(r.firstChild),nr=i,Mt=!0,gl=null,ba=!0,u=Bg(i,null,c,u),i.child=u;u;)u.flags=u.flags&-3|4096,u=u.sibling}else{if(su(),c===m){i=ja(r,i,u);break e}qn(r,i,c,u)}i=i.child}return i;case 26:return E0(r,i),r===null?(u=u4(i.type,null,i.pendingProps,null))?i.memoizedState=u:Mt||(u=i.type,r=i.pendingProps,c=D0(Le.current).createElement(u),c[Re]=i,c[qe]=r,Gn(c,u,r),sn(c),i.stateNode=c):i.memoizedState=u4(i.type,r.memoizedProps,i.pendingProps,r.memoizedState),null;case 27:return Pt(i),r===null&&Mt&&(c=i.stateNode=i4(i.type,i.pendingProps,Le.current),nr=i,ba=!0,m=hn,Ii(i.type)?(nh=m,hn=ca(c.firstChild)):hn=m),qn(r,i,i.pendingProps.children,u),E0(r,i),r===null&&(i.flags|=4194304),i.child;case 5:return r===null&&Mt&&((m=c=hn)&&(c=jy(c,i.type,i.pendingProps,ba),c!==null?(i.stateNode=c,nr=i,hn=ca(c.firstChild),ba=!1,m=!0):m=!1),m||bl(i)),Pt(i),m=i.type,g=i.pendingProps,S=r!==null?r.memoizedProps:null,c=g.children,Zf(m,g)?c=null:S!==null&&Zf(m,S)&&(i.flags|=32),i.memoizedState!==null&&(m=Wd(r,i,dy,null,null,u),Uu._currentValue=m),E0(r,i),qn(r,i,c,u),i.child;case 6:return r===null&&Mt&&((r=u=hn)&&(u=Xy(u,i.pendingProps,ba),u!==null?(i.stateNode=u,nr=i,hn=null,r=!0):r=!1),r||bl(i)),null;case 13:return t2(r,i,u);case 4:return it(i,i.stateNode.containerInfo),c=i.pendingProps,r===null?i.child=ts(i,null,c,u):qn(r,i,c,u),i.child;case 11:return jg(r,i,i.type,i.pendingProps,u);case 7:return qn(r,i,i.pendingProps,u),i.child;case 8:return qn(r,i,i.pendingProps.children,u),i.child;case 12:return qn(r,i,i.pendingProps.children,u),i.child;case 10:return c=i.pendingProps,yi(i,i.type,c.value),qn(r,i,c.children,u),i.child;case 9:return m=i.type._context,c=i.pendingProps.children,yl(i),m=jn(m),c=c(m),i.flags|=1,qn(r,i,c,u),i.child;case 14:return Xg(r,i,i.type,i.pendingProps,u);case 15:return $g(r,i,i.type,i.pendingProps,u);case 19:return r2(r,i,u);case 31:return c=i.pendingProps,u=i.mode,c={mode:c.mode,children:c.children},r===null?(u=y0(c,u),u.ref=i.ref,i.child=u,u.return=i,i=u):(u=Ha(r.child,c),u.ref=i.ref,i.child=u,u.return=i,i=u),i;case 22:return Wg(r,i,u);case 24:return yl(i),c=jn(On),r===null?(m=Fd(),m===null&&(m=Kt,g=zd(),m.pooledCache=g,g.refCount++,g!==null&&(m.pooledCacheLanes|=u),m=g),i.memoizedState={parent:c,cache:m},Yd(i),yi(i,On,m)):((r.lanes&u)!==0&&(Gd(r,i),gu(i,null,null,u),pu()),m=r.memoizedState,g=i.memoizedState,m.parent!==c?(m={parent:c,cache:c},i.memoizedState=m,i.lanes===0&&(i.memoizedState=i.updateQueue.baseState=m),yi(i,On,c)):(c=g.cache,yi(i,On,c),c!==m.cache&&Ud(i,[On],u,!0))),qn(r,i,i.pendingProps.children,u),i.child;case 29:throw i.pendingProps}throw Error(a(156,i.tag))}function Xa(r){r.flags|=4}function i2(r,i){if(i.type!=="stylesheet"||(i.state.loading&4)!==0)r.flags&=-16777217;else if(r.flags|=16777216,!h4(i)){if(i=Kr.current,i!==null&&((xt&4194048)===xt?Ea!==null:(xt&62914560)!==xt&&(xt&536870912)===0||i!==Ea))throw hu=qd,qp;r.flags|=8192}}function v0(r,i){i!==null&&(r.flags|=4),r.flags&16384&&(i=r.tag!==22?Vs():536870912,r.lanes|=i,is|=i)}function Su(r,i){if(!Mt)switch(r.tailMode){case"hidden":i=r.tail;for(var u=null;i!==null;)i.alternate!==null&&(u=i),i=i.sibling;u===null?r.tail=null:u.sibling=null;break;case"collapsed":u=r.tail;for(var c=null;u!==null;)u.alternate!==null&&(c=u),u=u.sibling;c===null?i||r.tail===null?r.tail=null:r.tail.sibling=null:c.sibling=null}}function on(r){var i=r.alternate!==null&&r.alternate.child===r.child,u=0,c=0;if(i)for(var m=r.child;m!==null;)u|=m.lanes|m.childLanes,c|=m.subtreeFlags&65011712,c|=m.flags&65011712,m.return=r,m=m.sibling;else for(m=r.child;m!==null;)u|=m.lanes|m.childLanes,c|=m.subtreeFlags,c|=m.flags,m.return=r,m=m.sibling;return r.subtreeFlags|=c,r.childLanes=u,i}function vy(r,i,u){var c=i.pendingProps;switch(Id(i),i.tag){case 31:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return on(i),null;case 1:return on(i),null;case 3:return u=i.stateNode,c=null,r!==null&&(c=r.memoizedState.cache),i.memoizedState.cache!==c&&(i.flags|=2048),Ga(On),Wt(),u.pendingContext&&(u.context=u.pendingContext,u.pendingContext=null),(r===null||r.child===null)&&(lu(i)?Xa(i):r===null||r.memoizedState.isDehydrated&&(i.flags&256)===0||(i.flags|=1024,Pp())),on(i),null;case 26:return u=i.memoizedState,r===null?(Xa(i),u!==null?(on(i),i2(i,u)):(on(i),i.flags&=-16777217)):u?u!==r.memoizedState?(Xa(i),on(i),i2(i,u)):(on(i),i.flags&=-16777217):(r.memoizedProps!==c&&Xa(i),on(i),i.flags&=-16777217),null;case 27:In(i),u=Le.current;var m=i.type;if(r!==null&&i.stateNode!=null)r.memoizedProps!==c&&Xa(i);else{if(!c){if(i.stateNode===null)throw Error(a(166));return on(i),null}r=De.current,lu(i)?Lp(i):(r=i4(m,c,u),i.stateNode=r,Xa(i))}return on(i),null;case 5:if(In(i),u=i.type,r!==null&&i.stateNode!=null)r.memoizedProps!==c&&Xa(i);else{if(!c){if(i.stateNode===null)throw Error(a(166));return on(i),null}if(r=De.current,lu(i))Lp(i);else{switch(m=D0(Le.current),r){case 1:r=m.createElementNS("http://www.w3.org/2000/svg",u);break;case 2:r=m.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;default:switch(u){case"svg":r=m.createElementNS("http://www.w3.org/2000/svg",u);break;case"math":r=m.createElementNS("http://www.w3.org/1998/Math/MathML",u);break;case"script":r=m.createElement("div"),r.innerHTML="<script><\/script>",r=r.removeChild(r.firstChild);break;case"select":r=typeof c.is=="string"?m.createElement("select",{is:c.is}):m.createElement("select"),c.multiple?r.multiple=!0:c.size&&(r.size=c.size);break;default:r=typeof c.is=="string"?m.createElement(u,{is:c.is}):m.createElement(u)}}r[Re]=i,r[qe]=c;e:for(m=i.child;m!==null;){if(m.tag===5||m.tag===6)r.appendChild(m.stateNode);else if(m.tag!==4&&m.tag!==27&&m.child!==null){m.child.return=m,m=m.child;continue}if(m===i)break e;for(;m.sibling===null;){if(m.return===null||m.return===i)break e;m=m.return}m.sibling.return=m.return,m=m.sibling}i.stateNode=r;e:switch(Gn(r,u,c),u){case"button":case"input":case"select":case"textarea":r=!!c.autoFocus;break e;case"img":r=!0;break e;default:r=!1}r&&Xa(i)}}return on(i),i.flags&=-16777217,null;case 6:if(r&&i.stateNode!=null)r.memoizedProps!==c&&Xa(i);else{if(typeof c!="string"&&i.stateNode===null)throw Error(a(166));if(r=Le.current,lu(i)){if(r=i.stateNode,u=i.memoizedProps,c=null,m=nr,m!==null)switch(m.tag){case 27:case 5:c=m.memoizedProps}r[Re]=i,r=!!(r.nodeValue===u||c!==null&&c.suppressHydrationWarning===!0||Z2(r.nodeValue,u)),r||bl(i)}else r=D0(r).createTextNode(c),r[Re]=i,i.stateNode=r}return on(i),null;case 13:if(c=i.memoizedState,r===null||r.memoizedState!==null&&r.memoizedState.dehydrated!==null){if(m=lu(i),c!==null&&c.dehydrated!==null){if(r===null){if(!m)throw Error(a(318));if(m=i.memoizedState,m=m!==null?m.dehydrated:null,!m)throw Error(a(317));m[Re]=i}else su(),(i.flags&128)===0&&(i.memoizedState=null),i.flags|=4;on(i),m=!1}else m=Pp(),r!==null&&r.memoizedState!==null&&(r.memoizedState.hydrationErrors=m),m=!0;if(!m)return i.flags&256?(Ka(i),i):(Ka(i),null)}if(Ka(i),(i.flags&128)!==0)return i.lanes=u,i;if(u=c!==null,r=r!==null&&r.memoizedState!==null,u){c=i.child,m=null,c.alternate!==null&&c.alternate.memoizedState!==null&&c.alternate.memoizedState.cachePool!==null&&(m=c.alternate.memoizedState.cachePool.pool);var g=null;c.memoizedState!==null&&c.memoizedState.cachePool!==null&&(g=c.memoizedState.cachePool.pool),g!==m&&(c.flags|=2048)}return u!==r&&u&&(i.child.flags|=8192),v0(i,i.updateQueue),on(i),null;case 4:return Wt(),r===null&&jf(i.stateNode.containerInfo),on(i),null;case 10:return Ga(i.type),on(i),null;case 19:if(ue(Rn),m=i.memoizedState,m===null)return on(i),null;if(c=(i.flags&128)!==0,g=m.rendering,g===null)if(c)Su(m,!1);else{if(mn!==0||r!==null&&(r.flags&128)!==0)for(r=i.child;r!==null;){if(g=p0(r),g!==null){for(i.flags|=128,Su(m,!1),r=g.updateQueue,i.updateQueue=r,v0(i,r),i.subtreeFlags=0,r=u,u=i.child;u!==null;)Dp(u,r),u=u.sibling;return R(Rn,Rn.current&1|2),i.child}r=r.sibling}m.tail!==null&&At()>S0&&(i.flags|=128,c=!0,Su(m,!1),i.lanes=4194304)}else{if(!c)if(r=p0(g),r!==null){if(i.flags|=128,c=!0,r=r.updateQueue,i.updateQueue=r,v0(i,r),Su(m,!0),m.tail===null&&m.tailMode==="hidden"&&!g.alternate&&!Mt)return on(i),null}else 2*At()-m.renderingStartTime>S0&&u!==536870912&&(i.flags|=128,c=!0,Su(m,!1),i.lanes=4194304);m.isBackwards?(g.sibling=i.child,i.child=g):(r=m.last,r!==null?r.sibling=g:i.child=g,m.last=g)}return m.tail!==null?(i=m.tail,m.rendering=i,m.tail=i.sibling,m.renderingStartTime=At(),i.sibling=null,r=Rn.current,R(Rn,c?r&1|2:r&1),i):(on(i),null);case 22:case 23:return Ka(i),Xd(),c=i.memoizedState!==null,r!==null?r.memoizedState!==null!==c&&(i.flags|=8192):c&&(i.flags|=8192),c?(u&536870912)!==0&&(i.flags&128)===0&&(on(i),i.subtreeFlags&6&&(i.flags|=8192)):on(i),u=i.updateQueue,u!==null&&v0(i,u.retryQueue),u=null,r!==null&&r.memoizedState!==null&&r.memoizedState.cachePool!==null&&(u=r.memoizedState.cachePool.pool),c=null,i.memoizedState!==null&&i.memoizedState.cachePool!==null&&(c=i.memoizedState.cachePool.pool),c!==u&&(i.flags|=2048),r!==null&&ue(vl),null;case 24:return u=null,r!==null&&(u=r.memoizedState.cache),i.memoizedState.cache!==u&&(i.flags|=2048),Ga(On),on(i),null;case 25:return null;case 30:return null}throw Error(a(156,i.tag))}function Ty(r,i){switch(Id(i),i.tag){case 1:return r=i.flags,r&65536?(i.flags=r&-65537|128,i):null;case 3:return Ga(On),Wt(),r=i.flags,(r&65536)!==0&&(r&128)===0?(i.flags=r&-65537|128,i):null;case 26:case 27:case 5:return In(i),null;case 13:if(Ka(i),r=i.memoizedState,r!==null&&r.dehydrated!==null){if(i.alternate===null)throw Error(a(340));su()}return r=i.flags,r&65536?(i.flags=r&-65537|128,i):null;case 19:return ue(Rn),null;case 4:return Wt(),null;case 10:return Ga(i.type),null;case 22:case 23:return Ka(i),Xd(),r!==null&&ue(vl),r=i.flags,r&65536?(i.flags=r&-65537|128,i):null;case 24:return Ga(On),null;case 25:return null;default:return null}}function l2(r,i){switch(Id(i),i.tag){case 3:Ga(On),Wt();break;case 26:case 27:case 5:In(i);break;case 4:Wt();break;case 13:Ka(i);break;case 19:ue(Rn);break;case 10:Ga(i.type);break;case 22:case 23:Ka(i),Xd(),r!==null&&ue(vl);break;case 24:Ga(On)}}function Au(r,i){try{var u=i.updateQueue,c=u!==null?u.lastEffect:null;if(c!==null){var m=c.next;u=m;do{if((u.tag&r)===r){c=void 0;var g=u.create,S=u.inst;c=g(),S.destroy=c}u=u.next}while(u!==m)}}catch(w){Yt(i,i.return,w)}}function ki(r,i,u){try{var c=i.updateQueue,m=c!==null?c.lastEffect:null;if(m!==null){var g=m.next;c=g;do{if((c.tag&r)===r){var S=c.inst,w=S.destroy;if(w!==void 0){S.destroy=void 0,m=i;var H=u,Q=w;try{Q()}catch(de){Yt(m,H,de)}}}c=c.next}while(c!==g)}}catch(de){Yt(i,i.return,de)}}function s2(r){var i=r.updateQueue;if(i!==null){var u=r.stateNode;try{Xp(i,u)}catch(c){Yt(r,r.return,c)}}}function u2(r,i,u){u.props=_l(r.type,r.memoizedProps),u.state=r.memoizedState;try{u.componentWillUnmount()}catch(c){Yt(r,i,c)}}function xu(r,i){try{var u=r.ref;if(u!==null){switch(r.tag){case 26:case 27:case 5:var c=r.stateNode;break;case 30:c=r.stateNode;break;default:c=r.stateNode}typeof u=="function"?r.refCleanup=u(c):u.current=c}}catch(m){Yt(r,i,m)}}function ya(r,i){var u=r.ref,c=r.refCleanup;if(u!==null)if(typeof c=="function")try{c()}catch(m){Yt(r,i,m)}finally{r.refCleanup=null,r=r.alternate,r!=null&&(r.refCleanup=null)}else if(typeof u=="function")try{u(null)}catch(m){Yt(r,i,m)}else u.current=null}function o2(r){var i=r.type,u=r.memoizedProps,c=r.stateNode;try{e:switch(i){case"button":case"input":case"select":case"textarea":u.autoFocus&&c.focus();break e;case"img":u.src?c.src=u.src:u.srcSet&&(c.srcset=u.srcSet)}}catch(m){Yt(r,r.return,m)}}function Sf(r,i,u){try{var c=r.stateNode;qy(c,r.type,u,i),c[qe]=i}catch(m){Yt(r,r.return,m)}}function c2(r){return r.tag===5||r.tag===3||r.tag===26||r.tag===27&&Ii(r.type)||r.tag===4}function Af(r){e:for(;;){for(;r.sibling===null;){if(r.return===null||c2(r.return))return null;r=r.return}for(r.sibling.return=r.return,r=r.sibling;r.tag!==5&&r.tag!==6&&r.tag!==18;){if(r.tag===27&&Ii(r.type)||r.flags&2||r.child===null||r.tag===4)continue e;r.child.return=r,r=r.child}if(!(r.flags&2))return r.stateNode}}function xf(r,i,u){var c=r.tag;if(c===5||c===6)r=r.stateNode,i?(u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u).insertBefore(r,i):(i=u.nodeType===9?u.body:u.nodeName==="HTML"?u.ownerDocument.body:u,i.appendChild(r),u=u._reactRootContainer,u!=null||i.onclick!==null||(i.onclick=M0));else if(c!==4&&(c===27&&Ii(r.type)&&(u=r.stateNode,i=null),r=r.child,r!==null))for(xf(r,i,u),r=r.sibling;r!==null;)xf(r,i,u),r=r.sibling}function T0(r,i,u){var c=r.tag;if(c===5||c===6)r=r.stateNode,i?u.insertBefore(r,i):u.appendChild(r);else if(c!==4&&(c===27&&Ii(r.type)&&(u=r.stateNode),r=r.child,r!==null))for(T0(r,i,u),r=r.sibling;r!==null;)T0(r,i,u),r=r.sibling}function d2(r){var i=r.stateNode,u=r.memoizedProps;try{for(var c=r.type,m=i.attributes;m.length;)i.removeAttributeNode(m[0]);Gn(i,c,u),i[Re]=r,i[qe]=u}catch(g){Yt(r,r.return,g)}}var $a=!1,En=!1,kf=!1,f2=typeof WeakSet=="function"?WeakSet:Set,Pn=null;function _y(r,i){if(r=r.containerInfo,Wf=z0,r=Sp(r),Sd(r)){if("selectionStart"in r)var u={start:r.selectionStart,end:r.selectionEnd};else e:{u=(u=r.ownerDocument)&&u.defaultView||window;var c=u.getSelection&&u.getSelection();if(c&&c.rangeCount!==0){u=c.anchorNode;var m=c.anchorOffset,g=c.focusNode;c=c.focusOffset;try{u.nodeType,g.nodeType}catch{u=null;break e}var S=0,w=-1,H=-1,Q=0,de=0,Ee=r,ee=null;t:for(;;){for(var ne;Ee!==u||m!==0&&Ee.nodeType!==3||(w=S+m),Ee!==g||c!==0&&Ee.nodeType!==3||(H=S+c),Ee.nodeType===3&&(S+=Ee.nodeValue.length),(ne=Ee.firstChild)!==null;)ee=Ee,Ee=ne;for(;;){if(Ee===r)break t;if(ee===u&&++Q===m&&(w=S),ee===g&&++de===c&&(H=S),(ne=Ee.nextSibling)!==null)break;Ee=ee,ee=Ee.parentNode}Ee=ne}u=w===-1||H===-1?null:{start:w,end:H}}else u=null}u=u||{start:0,end:0}}else u=null;for(Qf={focusedElem:r,selectionRange:u},z0=!1,Pn=i;Pn!==null;)if(i=Pn,r=i.child,(i.subtreeFlags&1024)!==0&&r!==null)r.return=i,Pn=r;else for(;Pn!==null;){switch(i=Pn,g=i.alternate,r=i.flags,i.tag){case 0:break;case 11:case 15:break;case 1:if((r&1024)!==0&&g!==null){r=void 0,u=i,m=g.memoizedProps,g=g.memoizedState,c=u.stateNode;try{var rt=_l(u.type,m,u.elementType===u.type);r=c.getSnapshotBeforeUpdate(rt,g),c.__reactInternalSnapshotBeforeUpdate=r}catch(et){Yt(u,u.return,et)}}break;case 3:if((r&1024)!==0){if(r=i.stateNode.containerInfo,u=r.nodeType,u===9)eh(r);else if(u===1)switch(r.nodeName){case"HEAD":case"HTML":case"BODY":eh(r);break;default:r.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((r&1024)!==0)throw Error(a(163))}if(r=i.sibling,r!==null){r.return=i.return,Pn=r;break}Pn=i.return}}function h2(r,i,u){var c=u.flags;switch(u.tag){case 0:case 11:case 15:Ni(r,u),c&4&&Au(5,u);break;case 1:if(Ni(r,u),c&4)if(r=u.stateNode,i===null)try{r.componentDidMount()}catch(S){Yt(u,u.return,S)}else{var m=_l(u.type,i.memoizedProps);i=i.memoizedState;try{r.componentDidUpdate(m,i,r.__reactInternalSnapshotBeforeUpdate)}catch(S){Yt(u,u.return,S)}}c&64&&s2(u),c&512&&xu(u,u.return);break;case 3:if(Ni(r,u),c&64&&(r=u.updateQueue,r!==null)){if(i=null,u.child!==null)switch(u.child.tag){case 27:case 5:i=u.child.stateNode;break;case 1:i=u.child.stateNode}try{Xp(r,i)}catch(S){Yt(u,u.return,S)}}break;case 27:i===null&&c&4&&d2(u);case 26:case 5:Ni(r,u),i===null&&c&4&&o2(u),c&512&&xu(u,u.return);break;case 12:Ni(r,u);break;case 13:Ni(r,u),c&4&&g2(r,u),c&64&&(r=u.memoizedState,r!==null&&(r=r.dehydrated,r!==null&&(u=Ry.bind(null,u),$y(r,u))));break;case 22:if(c=u.memoizedState!==null||$a,!c){i=i!==null&&i.memoizedState!==null||En,m=$a;var g=En;$a=c,(En=i)&&!g?wi(r,u,(u.subtreeFlags&8772)!==0):Ni(r,u),$a=m,En=g}break;case 30:break;default:Ni(r,u)}}function m2(r){var i=r.alternate;i!==null&&(r.alternate=null,m2(i)),r.child=null,r.deletions=null,r.sibling=null,r.tag===5&&(i=r.stateNode,i!==null&&al(i)),r.stateNode=null,r.return=null,r.dependencies=null,r.memoizedProps=null,r.memoizedState=null,r.pendingProps=null,r.stateNode=null,r.updateQueue=null}var tn=null,pr=!1;function Wa(r,i,u){for(u=u.child;u!==null;)p2(r,i,u),u=u.sibling}function p2(r,i,u){if(Te&&typeof Te.onCommitFiberUnmount=="function")try{Te.onCommitFiberUnmount(re,u)}catch{}switch(u.tag){case 26:En||ya(u,i),Wa(r,i,u),u.memoizedState?u.memoizedState.count--:u.stateNode&&(u=u.stateNode,u.parentNode.removeChild(u));break;case 27:En||ya(u,i);var c=tn,m=pr;Ii(u.type)&&(tn=u.stateNode,pr=!1),Wa(r,i,u),Iu(u.stateNode),tn=c,pr=m;break;case 5:En||ya(u,i);case 6:if(c=tn,m=pr,tn=null,Wa(r,i,u),tn=c,pr=m,tn!==null)if(pr)try{(tn.nodeType===9?tn.body:tn.nodeName==="HTML"?tn.ownerDocument.body:tn).removeChild(u.stateNode)}catch(g){Yt(u,i,g)}else try{tn.removeChild(u.stateNode)}catch(g){Yt(u,i,g)}break;case 18:tn!==null&&(pr?(r=tn,r4(r.nodeType===9?r.body:r.nodeName==="HTML"?r.ownerDocument.body:r,u.stateNode),qu(r)):r4(tn,u.stateNode));break;case 4:c=tn,m=pr,tn=u.stateNode.containerInfo,pr=!0,Wa(r,i,u),tn=c,pr=m;break;case 0:case 11:case 14:case 15:En||ki(2,u,i),En||ki(4,u,i),Wa(r,i,u);break;case 1:En||(ya(u,i),c=u.stateNode,typeof c.componentWillUnmount=="function"&&u2(u,i,c)),Wa(r,i,u);break;case 21:Wa(r,i,u);break;case 22:En=(c=En)||u.memoizedState!==null,Wa(r,i,u),En=c;break;default:Wa(r,i,u)}}function g2(r,i){if(i.memoizedState===null&&(r=i.alternate,r!==null&&(r=r.memoizedState,r!==null&&(r=r.dehydrated,r!==null))))try{qu(r)}catch(u){Yt(i,i.return,u)}}function Sy(r){switch(r.tag){case 13:case 19:var i=r.stateNode;return i===null&&(i=r.stateNode=new f2),i;case 22:return r=r.stateNode,i=r._retryCache,i===null&&(i=r._retryCache=new f2),i;default:throw Error(a(435,r.tag))}}function Nf(r,i){var u=Sy(r);i.forEach(function(c){var m=My.bind(null,r,c);u.has(c)||(u.add(c),c.then(m,m))})}function wr(r,i){var u=i.deletions;if(u!==null)for(var c=0;c<u.length;c++){var m=u[c],g=r,S=i,w=S;e:for(;w!==null;){switch(w.tag){case 27:if(Ii(w.type)){tn=w.stateNode,pr=!1;break e}break;case 5:tn=w.stateNode,pr=!1;break e;case 3:case 4:tn=w.stateNode.containerInfo,pr=!0;break e}w=w.return}if(tn===null)throw Error(a(160));p2(g,S,m),tn=null,pr=!1,g=m.alternate,g!==null&&(g.return=null),m.return=null}if(i.subtreeFlags&13878)for(i=i.child;i!==null;)b2(i,r),i=i.sibling}var oa=null;function b2(r,i){var u=r.alternate,c=r.flags;switch(r.tag){case 0:case 11:case 14:case 15:wr(i,r),Cr(r),c&4&&(ki(3,r,r.return),Au(3,r),ki(5,r,r.return));break;case 1:wr(i,r),Cr(r),c&512&&(En||u===null||ya(u,u.return)),c&64&&$a&&(r=r.updateQueue,r!==null&&(c=r.callbacks,c!==null&&(u=r.shared.hiddenCallbacks,r.shared.hiddenCallbacks=u===null?c:u.concat(c))));break;case 26:var m=oa;if(wr(i,r),Cr(r),c&512&&(En||u===null||ya(u,u.return)),c&4){var g=u!==null?u.memoizedState:null;if(c=r.memoizedState,u===null)if(c===null)if(r.stateNode===null){e:{c=r.type,u=r.memoizedProps,m=m.ownerDocument||m;t:switch(c){case"title":g=m.getElementsByTagName("title")[0],(!g||g[rl]||g[Re]||g.namespaceURI==="http://www.w3.org/2000/svg"||g.hasAttribute("itemprop"))&&(g=m.createElement(c),m.head.insertBefore(g,m.querySelector("head > title"))),Gn(g,c,u),g[Re]=r,sn(g),c=g;break e;case"link":var S=d4("link","href",m).get(c+(u.href||""));if(S){for(var w=0;w<S.length;w++)if(g=S[w],g.getAttribute("href")===(u.href==null||u.href===""?null:u.href)&&g.getAttribute("rel")===(u.rel==null?null:u.rel)&&g.getAttribute("title")===(u.title==null?null:u.title)&&g.getAttribute("crossorigin")===(u.crossOrigin==null?null:u.crossOrigin)){S.splice(w,1);break t}}g=m.createElement(c),Gn(g,c,u),m.head.appendChild(g);break;case"meta":if(S=d4("meta","content",m).get(c+(u.content||""))){for(w=0;w<S.length;w++)if(g=S[w],g.getAttribute("content")===(u.content==null?null:""+u.content)&&g.getAttribute("name")===(u.name==null?null:u.name)&&g.getAttribute("property")===(u.property==null?null:u.property)&&g.getAttribute("http-equiv")===(u.httpEquiv==null?null:u.httpEquiv)&&g.getAttribute("charset")===(u.charSet==null?null:u.charSet)){S.splice(w,1);break t}}g=m.createElement(c),Gn(g,c,u),m.head.appendChild(g);break;default:throw Error(a(468,c))}g[Re]=r,sn(g),c=g}r.stateNode=c}else f4(m,r.type,r.stateNode);else r.stateNode=c4(m,c,r.memoizedProps);else g!==c?(g===null?u.stateNode!==null&&(u=u.stateNode,u.parentNode.removeChild(u)):g.count--,c===null?f4(m,r.type,r.stateNode):c4(m,c,r.memoizedProps)):c===null&&r.stateNode!==null&&Sf(r,r.memoizedProps,u.memoizedProps)}break;case 27:wr(i,r),Cr(r),c&512&&(En||u===null||ya(u,u.return)),u!==null&&c&4&&Sf(r,r.memoizedProps,u.memoizedProps);break;case 5:if(wr(i,r),Cr(r),c&512&&(En||u===null||ya(u,u.return)),r.flags&32){m=r.stateNode;try{ga(m,"")}catch(ne){Yt(r,r.return,ne)}}c&4&&r.stateNode!=null&&(m=r.memoizedProps,Sf(r,m,u!==null?u.memoizedProps:m)),c&1024&&(kf=!0);break;case 6:if(wr(i,r),Cr(r),c&4){if(r.stateNode===null)throw Error(a(162));c=r.memoizedProps,u=r.stateNode;try{u.nodeValue=c}catch(ne){Yt(r,r.return,ne)}}break;case 3:if(B0=null,m=oa,oa=I0(i.containerInfo),wr(i,r),oa=m,Cr(r),c&4&&u!==null&&u.memoizedState.isDehydrated)try{qu(i.containerInfo)}catch(ne){Yt(r,r.return,ne)}kf&&(kf=!1,E2(r));break;case 4:c=oa,oa=I0(r.stateNode.containerInfo),wr(i,r),Cr(r),oa=c;break;case 12:wr(i,r),Cr(r);break;case 13:wr(i,r),Cr(r),r.child.flags&8192&&r.memoizedState!==null!=(u!==null&&u.memoizedState!==null)&&(Df=At()),c&4&&(c=r.updateQueue,c!==null&&(r.updateQueue=null,Nf(r,c)));break;case 22:m=r.memoizedState!==null;var H=u!==null&&u.memoizedState!==null,Q=$a,de=En;if($a=Q||m,En=de||H,wr(i,r),En=de,$a=Q,Cr(r),c&8192)e:for(i=r.stateNode,i._visibility=m?i._visibility&-2:i._visibility|1,m&&(u===null||H||$a||En||Sl(r)),u=null,i=r;;){if(i.tag===5||i.tag===26){if(u===null){H=u=i;try{if(g=H.stateNode,m)S=g.style,typeof S.setProperty=="function"?S.setProperty("display","none","important"):S.display="none";else{w=H.stateNode;var Ee=H.memoizedProps.style,ee=Ee!=null&&Ee.hasOwnProperty("display")?Ee.display:null;w.style.display=ee==null||typeof ee=="boolean"?"":(""+ee).trim()}}catch(ne){Yt(H,H.return,ne)}}}else if(i.tag===6){if(u===null){H=i;try{H.stateNode.nodeValue=m?"":H.memoizedProps}catch(ne){Yt(H,H.return,ne)}}}else if((i.tag!==22&&i.tag!==23||i.memoizedState===null||i===r)&&i.child!==null){i.child.return=i,i=i.child;continue}if(i===r)break e;for(;i.sibling===null;){if(i.return===null||i.return===r)break e;u===i&&(u=null),i=i.return}u===i&&(u=null),i.sibling.return=i.return,i=i.sibling}c&4&&(c=r.updateQueue,c!==null&&(u=c.retryQueue,u!==null&&(c.retryQueue=null,Nf(r,u))));break;case 19:wr(i,r),Cr(r),c&4&&(c=r.updateQueue,c!==null&&(r.updateQueue=null,Nf(r,c)));break;case 30:break;case 21:break;default:wr(i,r),Cr(r)}}function Cr(r){var i=r.flags;if(i&2){try{for(var u,c=r.return;c!==null;){if(c2(c)){u=c;break}c=c.return}if(u==null)throw Error(a(160));switch(u.tag){case 27:var m=u.stateNode,g=Af(r);T0(r,g,m);break;case 5:var S=u.stateNode;u.flags&32&&(ga(S,""),u.flags&=-33);var w=Af(r);T0(r,w,S);break;case 3:case 4:var H=u.stateNode.containerInfo,Q=Af(r);xf(r,Q,H);break;default:throw Error(a(161))}}catch(de){Yt(r,r.return,de)}r.flags&=-3}i&4096&&(r.flags&=-4097)}function E2(r){if(r.subtreeFlags&1024)for(r=r.child;r!==null;){var i=r;E2(i),i.tag===5&&i.flags&1024&&i.stateNode.reset(),r=r.sibling}}function Ni(r,i){if(i.subtreeFlags&8772)for(i=i.child;i!==null;)h2(r,i.alternate,i),i=i.sibling}function Sl(r){for(r=r.child;r!==null;){var i=r;switch(i.tag){case 0:case 11:case 14:case 15:ki(4,i,i.return),Sl(i);break;case 1:ya(i,i.return);var u=i.stateNode;typeof u.componentWillUnmount=="function"&&u2(i,i.return,u),Sl(i);break;case 27:Iu(i.stateNode);case 26:case 5:ya(i,i.return),Sl(i);break;case 22:i.memoizedState===null&&Sl(i);break;case 30:Sl(i);break;default:Sl(i)}r=r.sibling}}function wi(r,i,u){for(u=u&&(i.subtreeFlags&8772)!==0,i=i.child;i!==null;){var c=i.alternate,m=r,g=i,S=g.flags;switch(g.tag){case 0:case 11:case 15:wi(m,g,u),Au(4,g);break;case 1:if(wi(m,g,u),c=g,m=c.stateNode,typeof m.componentDidMount=="function")try{m.componentDidMount()}catch(Q){Yt(c,c.return,Q)}if(c=g,m=c.updateQueue,m!==null){var w=c.stateNode;try{var H=m.shared.hiddenCallbacks;if(H!==null)for(m.shared.hiddenCallbacks=null,m=0;m<H.length;m++)jp(H[m],w)}catch(Q){Yt(c,c.return,Q)}}u&&S&64&&s2(g),xu(g,g.return);break;case 27:d2(g);case 26:case 5:wi(m,g,u),u&&c===null&&S&4&&o2(g),xu(g,g.return);break;case 12:wi(m,g,u);break;case 13:wi(m,g,u),u&&S&4&&g2(m,g);break;case 22:g.memoizedState===null&&wi(m,g,u),xu(g,g.return);break;case 30:break;default:wi(m,g,u)}i=i.sibling}}function wf(r,i){var u=null;r!==null&&r.memoizedState!==null&&r.memoizedState.cachePool!==null&&(u=r.memoizedState.cachePool.pool),r=null,i.memoizedState!==null&&i.memoizedState.cachePool!==null&&(r=i.memoizedState.cachePool.pool),r!==u&&(r!=null&&r.refCount++,u!=null&&cu(u))}function Cf(r,i){r=null,i.alternate!==null&&(r=i.alternate.memoizedState.cache),i=i.memoizedState.cache,i!==r&&(i.refCount++,r!=null&&cu(r))}function va(r,i,u,c){if(i.subtreeFlags&10256)for(i=i.child;i!==null;)y2(r,i,u,c),i=i.sibling}function y2(r,i,u,c){var m=i.flags;switch(i.tag){case 0:case 11:case 15:va(r,i,u,c),m&2048&&Au(9,i);break;case 1:va(r,i,u,c);break;case 3:va(r,i,u,c),m&2048&&(r=null,i.alternate!==null&&(r=i.alternate.memoizedState.cache),i=i.memoizedState.cache,i!==r&&(i.refCount++,r!=null&&cu(r)));break;case 12:if(m&2048){va(r,i,u,c),r=i.stateNode;try{var g=i.memoizedProps,S=g.id,w=g.onPostCommit;typeof w=="function"&&w(S,i.alternate===null?"mount":"update",r.passiveEffectDuration,-0)}catch(H){Yt(i,i.return,H)}}else va(r,i,u,c);break;case 13:va(r,i,u,c);break;case 23:break;case 22:g=i.stateNode,S=i.alternate,i.memoizedState!==null?g._visibility&2?va(r,i,u,c):ku(r,i):g._visibility&2?va(r,i,u,c):(g._visibility|=2,ns(r,i,u,c,(i.subtreeFlags&10256)!==0)),m&2048&&wf(S,i);break;case 24:va(r,i,u,c),m&2048&&Cf(i.alternate,i);break;default:va(r,i,u,c)}}function ns(r,i,u,c,m){for(m=m&&(i.subtreeFlags&10256)!==0,i=i.child;i!==null;){var g=r,S=i,w=u,H=c,Q=S.flags;switch(S.tag){case 0:case 11:case 15:ns(g,S,w,H,m),Au(8,S);break;case 23:break;case 22:var de=S.stateNode;S.memoizedState!==null?de._visibility&2?ns(g,S,w,H,m):ku(g,S):(de._visibility|=2,ns(g,S,w,H,m)),m&&Q&2048&&wf(S.alternate,S);break;case 24:ns(g,S,w,H,m),m&&Q&2048&&Cf(S.alternate,S);break;default:ns(g,S,w,H,m)}i=i.sibling}}function ku(r,i){if(i.subtreeFlags&10256)for(i=i.child;i!==null;){var u=r,c=i,m=c.flags;switch(c.tag){case 22:ku(u,c),m&2048&&wf(c.alternate,c);break;case 24:ku(u,c),m&2048&&Cf(c.alternate,c);break;default:ku(u,c)}i=i.sibling}}var Nu=8192;function rs(r){if(r.subtreeFlags&Nu)for(r=r.child;r!==null;)v2(r),r=r.sibling}function v2(r){switch(r.tag){case 26:rs(r),r.flags&Nu&&r.memoizedState!==null&&uv(oa,r.memoizedState,r.memoizedProps);break;case 5:rs(r);break;case 3:case 4:var i=oa;oa=I0(r.stateNode.containerInfo),rs(r),oa=i;break;case 22:r.memoizedState===null&&(i=r.alternate,i!==null&&i.memoizedState!==null?(i=Nu,Nu=16777216,rs(r),Nu=i):rs(r));break;default:rs(r)}}function T2(r){var i=r.alternate;if(i!==null&&(r=i.child,r!==null)){i.child=null;do i=r.sibling,r.sibling=null,r=i;while(r!==null)}}function wu(r){var i=r.deletions;if((r.flags&16)!==0){if(i!==null)for(var u=0;u<i.length;u++){var c=i[u];Pn=c,S2(c,r)}T2(r)}if(r.subtreeFlags&10256)for(r=r.child;r!==null;)_2(r),r=r.sibling}function _2(r){switch(r.tag){case 0:case 11:case 15:wu(r),r.flags&2048&&ki(9,r,r.return);break;case 3:wu(r);break;case 12:wu(r);break;case 22:var i=r.stateNode;r.memoizedState!==null&&i._visibility&2&&(r.return===null||r.return.tag!==13)?(i._visibility&=-3,_0(r)):wu(r);break;default:wu(r)}}function _0(r){var i=r.deletions;if((r.flags&16)!==0){if(i!==null)for(var u=0;u<i.length;u++){var c=i[u];Pn=c,S2(c,r)}T2(r)}for(r=r.child;r!==null;){switch(i=r,i.tag){case 0:case 11:case 15:ki(8,i,i.return),_0(i);break;case 22:u=i.stateNode,u._visibility&2&&(u._visibility&=-3,_0(i));break;default:_0(i)}r=r.sibling}}function S2(r,i){for(;Pn!==null;){var u=Pn;switch(u.tag){case 0:case 11:case 15:ki(8,u,i);break;case 23:case 22:if(u.memoizedState!==null&&u.memoizedState.cachePool!==null){var c=u.memoizedState.cachePool.pool;c!=null&&c.refCount++}break;case 24:cu(u.memoizedState.cache)}if(c=u.child,c!==null)c.return=u,Pn=c;else e:for(u=r;Pn!==null;){c=Pn;var m=c.sibling,g=c.return;if(m2(c),c===u){Pn=null;break e}if(m!==null){m.return=g,Pn=m;break e}Pn=g}}}var Ay={getCacheForType:function(r){var i=jn(On),u=i.data.get(r);return u===void 0&&(u=r(),i.data.set(r,u)),u}},xy=typeof WeakMap=="function"?WeakMap:Map,Lt=0,Kt=null,Tt=null,xt=0,Bt=0,Or=null,Ci=!1,as=!1,Of=!1,Qa=0,mn=0,Oi=0,Al=0,Rf=0,jr=0,is=0,Cu=null,gr=null,Mf=!1,Df=0,S0=1/0,A0=null,Ri=null,Yn=0,Mi=null,ls=null,ss=0,If=0,Lf=null,A2=null,Ou=0,Bf=null;function Rr(){if((Lt&2)!==0&&xt!==0)return xt&-xt;if(X.T!==null){var r=Xl;return r!==0?r:Yf()}return Jt()}function x2(){jr===0&&(jr=(xt&536870912)===0||Mt?Gs():536870912);var r=Kr.current;return r!==null&&(r.flags|=32),jr}function Mr(r,i,u){(r===Kt&&(Bt===2||Bt===9)||r.cancelPendingCommit!==null)&&(us(r,0),Di(r,xt,jr,!1)),fi(r,u),((Lt&2)===0||r!==Kt)&&(r===Kt&&((Lt&2)===0&&(Al|=u),mn===4&&Di(r,xt,jr,!1)),Ta(r))}function k2(r,i,u){if((Lt&6)!==0)throw Error(a(327));var c=!u&&(i&124)===0&&(i&r.expiredLanes)===0||dr(r,i),m=c?wy(r,i):zf(r,i,!0),g=c;do{if(m===0){as&&!c&&Di(r,i,0,!1);break}else{if(u=r.current.alternate,g&&!ky(u)){m=zf(r,i,!1),g=!1;continue}if(m===2){if(g=i,r.errorRecoveryDisabledLanes&g)var S=0;else S=r.pendingLanes&-536870913,S=S!==0?S:S&536870912?536870912:0;if(S!==0){i=S;e:{var w=r;m=Cu;var H=w.current.memoizedState.isDehydrated;if(H&&(us(w,S).flags|=256),S=zf(w,S,!1),S!==2){if(Of&&!H){w.errorRecoveryDisabledLanes|=g,Al|=g,m=4;break e}g=gr,gr=m,g!==null&&(gr===null?gr=g:gr.push.apply(gr,g))}m=S}if(g=!1,m!==2)continue}}if(m===1){us(r,0),Di(r,i,0,!0);break}e:{switch(c=r,g=m,g){case 0:case 1:throw Error(a(345));case 4:if((i&4194048)!==i)break;case 6:Di(c,i,jr,!Ci);break e;case 2:gr=null;break;case 3:case 5:break;default:throw Error(a(329))}if((i&62914560)===i&&(m=Df+300-At(),10<m)){if(Di(c,i,jr,!Ci),Tn(c,0,!0)!==0)break e;c.timeoutHandle=t4(N2.bind(null,c,u,gr,A0,Mf,i,jr,Al,is,Ci,g,2,-0,0),m);break e}N2(c,u,gr,A0,Mf,i,jr,Al,is,Ci,g,0,-0,0)}}break}while(!0);Ta(r)}function N2(r,i,u,c,m,g,S,w,H,Q,de,Ee,ee,ne){if(r.timeoutHandle=-1,Ee=i.subtreeFlags,(Ee&8192||(Ee&16785408)===16785408)&&(Pu={stylesheets:null,count:0,unsuspend:sv},v2(i),Ee=ov(),Ee!==null)){r.cancelPendingCommit=Ee(I2.bind(null,r,i,g,u,c,m,S,w,H,de,1,ee,ne)),Di(r,g,S,!Q);return}I2(r,i,g,u,c,m,S,w,H)}function ky(r){for(var i=r;;){var u=i.tag;if((u===0||u===11||u===15)&&i.flags&16384&&(u=i.updateQueue,u!==null&&(u=u.stores,u!==null)))for(var c=0;c<u.length;c++){var m=u[c],g=m.getSnapshot;m=m.value;try{if(!kr(g(),m))return!1}catch{return!1}}if(u=i.child,i.subtreeFlags&16384&&u!==null)u.return=i,i=u;else{if(i===r)break;for(;i.sibling===null;){if(i.return===null||i.return===r)return!0;i=i.return}i.sibling.return=i.return,i=i.sibling}}return!0}function Di(r,i,u,c){i&=~Rf,i&=~Al,r.suspendedLanes|=i,r.pingedLanes&=~i,c&&(r.warmLanes|=i),c=r.expirationTimes;for(var m=i;0<m;){var g=31-$e(m),S=1<<g;c[g]=-1,m&=~S}u!==0&&q(r,u,i)}function x0(){return(Lt&6)===0?(Ru(0),!1):!0}function Pf(){if(Tt!==null){if(Bt===0)var r=Tt.return;else r=Tt,Ya=El=null,Jd(r),es=null,Tu=0,r=Tt;for(;r!==null;)l2(r.alternate,r),r=r.return;Tt=null}}function us(r,i){var u=r.timeoutHandle;u!==-1&&(r.timeoutHandle=-1,Gy(u)),u=r.cancelPendingCommit,u!==null&&(r.cancelPendingCommit=null,u()),Pf(),Kt=r,Tt=u=Ha(r.current,null),xt=i,Bt=0,Or=null,Ci=!1,as=dr(r,i),Of=!1,is=jr=Rf=Al=Oi=mn=0,gr=Cu=null,Mf=!1,(i&8)!==0&&(i|=i&32);var c=r.entangledLanes;if(c!==0)for(r=r.entanglements,c&=i;0<c;){var m=31-$e(c),g=1<<m;i|=r[m],c&=~g}return Qa=i,jo(),u}function w2(r,i){pt=null,X.H=f0,i===fu||i===n0?(i=Vp(),Bt=3):i===qp?(i=Vp(),Bt=4):Bt=i===Kg?8:i!==null&&typeof i=="object"&&typeof i.then=="function"?6:1,Or=i,Tt===null&&(mn=1,b0(r,qr(i,r.current)))}function C2(){var r=X.H;return X.H=f0,r===null?f0:r}function O2(){var r=X.A;return X.A=Ay,r}function Uf(){mn=4,Ci||(xt&4194048)!==xt&&Kr.current!==null||(as=!0),(Oi&134217727)===0&&(Al&134217727)===0||Kt===null||Di(Kt,xt,jr,!1)}function zf(r,i,u){var c=Lt;Lt|=2;var m=C2(),g=O2();(Kt!==r||xt!==i)&&(A0=null,us(r,i)),i=!1;var S=mn;e:do try{if(Bt!==0&&Tt!==null){var w=Tt,H=Or;switch(Bt){case 8:Pf(),S=6;break e;case 3:case 2:case 9:case 6:Kr.current===null&&(i=!0);var Q=Bt;if(Bt=0,Or=null,os(r,w,H,Q),u&&as){S=0;break e}break;default:Q=Bt,Bt=0,Or=null,os(r,w,H,Q)}}Ny(),S=mn;break}catch(de){w2(r,de)}while(!0);return i&&r.shellSuspendCounter++,Ya=El=null,Lt=c,X.H=m,X.A=g,Tt===null&&(Kt=null,xt=0,jo()),S}function Ny(){for(;Tt!==null;)R2(Tt)}function wy(r,i){var u=Lt;Lt|=2;var c=C2(),m=O2();Kt!==r||xt!==i?(A0=null,S0=At()+500,us(r,i)):as=dr(r,i);e:do try{if(Bt!==0&&Tt!==null){i=Tt;var g=Or;t:switch(Bt){case 1:Bt=0,Or=null,os(r,i,g,1);break;case 2:case 9:if(Yp(g)){Bt=0,Or=null,M2(i);break}i=function(){Bt!==2&&Bt!==9||Kt!==r||(Bt=7),Ta(r)},g.then(i,i);break e;case 3:Bt=7;break e;case 4:Bt=5;break e;case 7:Yp(g)?(Bt=0,Or=null,M2(i)):(Bt=0,Or=null,os(r,i,g,7));break;case 5:var S=null;switch(Tt.tag){case 26:S=Tt.memoizedState;case 5:case 27:var w=Tt;if(!S||h4(S)){Bt=0,Or=null;var H=w.sibling;if(H!==null)Tt=H;else{var Q=w.return;Q!==null?(Tt=Q,k0(Q)):Tt=null}break t}}Bt=0,Or=null,os(r,i,g,5);break;case 6:Bt=0,Or=null,os(r,i,g,6);break;case 8:Pf(),mn=6;break e;default:throw Error(a(462))}}Cy();break}catch(de){w2(r,de)}while(!0);return Ya=El=null,X.H=c,X.A=m,Lt=u,Tt!==null?0:(Kt=null,xt=0,jo(),mn)}function Cy(){for(;Tt!==null&&!Ut();)R2(Tt)}function R2(r){var i=a2(r.alternate,r,Qa);r.memoizedProps=r.pendingProps,i===null?k0(r):Tt=i}function M2(r){var i=r,u=i.alternate;switch(i.tag){case 15:case 0:i=Zg(u,i,i.pendingProps,i.type,void 0,xt);break;case 11:i=Zg(u,i,i.pendingProps,i.type.render,i.ref,xt);break;case 5:Jd(i);default:l2(u,i),i=Tt=Dp(i,Qa),i=a2(u,i,Qa)}r.memoizedProps=r.pendingProps,i===null?k0(r):Tt=i}function os(r,i,u,c){Ya=El=null,Jd(i),es=null,Tu=0;var m=i.return;try{if(Ey(r,m,i,u,xt)){mn=1,b0(r,qr(u,r.current)),Tt=null;return}}catch(g){if(m!==null)throw Tt=m,g;mn=1,b0(r,qr(u,r.current)),Tt=null;return}i.flags&32768?(Mt||c===1?r=!0:as||(xt&536870912)!==0?r=!1:(Ci=r=!0,(c===2||c===9||c===3||c===6)&&(c=Kr.current,c!==null&&c.tag===13&&(c.flags|=16384))),D2(i,r)):k0(i)}function k0(r){var i=r;do{if((i.flags&32768)!==0){D2(i,Ci);return}r=i.return;var u=vy(i.alternate,i,Qa);if(u!==null){Tt=u;return}if(i=i.sibling,i!==null){Tt=i;return}Tt=i=r}while(i!==null);mn===0&&(mn=5)}function D2(r,i){do{var u=Ty(r.alternate,r);if(u!==null){u.flags&=32767,Tt=u;return}if(u=r.return,u!==null&&(u.flags|=32768,u.subtreeFlags=0,u.deletions=null),!i&&(r=r.sibling,r!==null)){Tt=r;return}Tt=r=u}while(r!==null);mn=6,Tt=null}function I2(r,i,u,c,m,g,S,w,H){r.cancelPendingCommit=null;do N0();while(Yn!==0);if((Lt&6)!==0)throw Error(a(327));if(i!==null){if(i===r.current)throw Error(a(177));if(g=i.lanes|i.childLanes,g|=wd,hi(r,u,g,S,w,H),r===Kt&&(Tt=Kt=null,xt=0),ls=i,Mi=r,ss=u,If=g,Lf=m,A2=c,(i.subtreeFlags&10256)!==0||(i.flags&10256)!==0?(r.callbackNode=null,r.callbackPriority=0,Dy(Ln,function(){return z2(),null})):(r.callbackNode=null,r.callbackPriority=0),c=(i.flags&13878)!==0,(i.subtreeFlags&13878)!==0||c){c=X.T,X.T=null,m=oe.p,oe.p=2,S=Lt,Lt|=4;try{_y(r,i,u)}finally{Lt=S,oe.p=m,X.T=c}}Yn=1,L2(),B2(),P2()}}function L2(){if(Yn===1){Yn=0;var r=Mi,i=ls,u=(i.flags&13878)!==0;if((i.subtreeFlags&13878)!==0||u){u=X.T,X.T=null;var c=oe.p;oe.p=2;var m=Lt;Lt|=4;try{b2(i,r);var g=Qf,S=Sp(r.containerInfo),w=g.focusedElem,H=g.selectionRange;if(S!==w&&w&&w.ownerDocument&&_p(w.ownerDocument.documentElement,w)){if(H!==null&&Sd(w)){var Q=H.start,de=H.end;if(de===void 0&&(de=Q),"selectionStart"in w)w.selectionStart=Q,w.selectionEnd=Math.min(de,w.value.length);else{var Ee=w.ownerDocument||document,ee=Ee&&Ee.defaultView||window;if(ee.getSelection){var ne=ee.getSelection(),rt=w.textContent.length,et=Math.min(H.start,rt),Ft=H.end===void 0?et:Math.min(H.end,rt);!ne.extend&&et>Ft&&(S=Ft,Ft=et,et=S);var j=Tp(w,et),Y=Tp(w,Ft);if(j&&Y&&(ne.rangeCount!==1||ne.anchorNode!==j.node||ne.anchorOffset!==j.offset||ne.focusNode!==Y.node||ne.focusOffset!==Y.offset)){var $=Ee.createRange();$.setStart(j.node,j.offset),ne.removeAllRanges(),et>Ft?(ne.addRange($),ne.extend(Y.node,Y.offset)):($.setEnd(Y.node,Y.offset),ne.addRange($))}}}}for(Ee=[],ne=w;ne=ne.parentNode;)ne.nodeType===1&&Ee.push({element:ne,left:ne.scrollLeft,top:ne.scrollTop});for(typeof w.focus=="function"&&w.focus(),w=0;w<Ee.length;w++){var pe=Ee[w];pe.element.scrollLeft=pe.left,pe.element.scrollTop=pe.top}}z0=!!Wf,Qf=Wf=null}finally{Lt=m,oe.p=c,X.T=u}}r.current=i,Yn=2}}function B2(){if(Yn===2){Yn=0;var r=Mi,i=ls,u=(i.flags&8772)!==0;if((i.subtreeFlags&8772)!==0||u){u=X.T,X.T=null;var c=oe.p;oe.p=2;var m=Lt;Lt|=4;try{h2(r,i.alternate,i)}finally{Lt=m,oe.p=c,X.T=u}}Yn=3}}function P2(){if(Yn===4||Yn===3){Yn=0,Ve();var r=Mi,i=ls,u=ss,c=A2;(i.subtreeFlags&10256)!==0||(i.flags&10256)!==0?Yn=5:(Yn=0,ls=Mi=null,U2(r,r.pendingLanes));var m=r.pendingLanes;if(m===0&&(Ri=null),nt(u),i=i.stateNode,Te&&typeof Te.onCommitFiberRoot=="function")try{Te.onCommitFiberRoot(re,i,void 0,(i.current.flags&128)===128)}catch{}if(c!==null){i=X.T,m=oe.p,oe.p=2,X.T=null;try{for(var g=r.onRecoverableError,S=0;S<c.length;S++){var w=c[S];g(w.value,{componentStack:w.stack})}}finally{X.T=i,oe.p=m}}(ss&3)!==0&&N0(),Ta(r),m=r.pendingLanes,(u&4194090)!==0&&(m&42)!==0?r===Bf?Ou++:(Ou=0,Bf=r):Ou=0,Ru(0)}}function U2(r,i){(r.pooledCacheLanes&=i)===0&&(i=r.pooledCache,i!=null&&(r.pooledCache=null,cu(i)))}function N0(r){return L2(),B2(),P2(),z2()}function z2(){if(Yn!==5)return!1;var r=Mi,i=If;If=0;var u=nt(ss),c=X.T,m=oe.p;try{oe.p=32>u?32:u,X.T=null,u=Lf,Lf=null;var g=Mi,S=ss;if(Yn=0,ls=Mi=null,ss=0,(Lt&6)!==0)throw Error(a(331));var w=Lt;if(Lt|=4,_2(g.current),y2(g,g.current,S,u),Lt=w,Ru(0,!1),Te&&typeof Te.onPostCommitFiberRoot=="function")try{Te.onPostCommitFiberRoot(re,g)}catch{}return!0}finally{oe.p=m,X.T=c,U2(r,i)}}function H2(r,i,u){i=qr(u,i),i=mf(r.stateNode,i,2),r=_i(r,i,2),r!==null&&(fi(r,2),Ta(r))}function Yt(r,i,u){if(r.tag===3)H2(r,r,u);else for(;i!==null;){if(i.tag===3){H2(i,r,u);break}else if(i.tag===1){var c=i.stateNode;if(typeof i.type.getDerivedStateFromError=="function"||typeof c.componentDidCatch=="function"&&(Ri===null||!Ri.has(c))){r=qr(u,r),u=Gg(2),c=_i(i,u,2),c!==null&&(Vg(u,c,i,r),fi(c,2),Ta(c));break}}i=i.return}}function Hf(r,i,u){var c=r.pingCache;if(c===null){c=r.pingCache=new xy;var m=new Set;c.set(i,m)}else m=c.get(i),m===void 0&&(m=new Set,c.set(i,m));m.has(u)||(Of=!0,m.add(u),r=Oy.bind(null,r,i,u),i.then(r,r))}function Oy(r,i,u){var c=r.pingCache;c!==null&&c.delete(i),r.pingedLanes|=r.suspendedLanes&u,r.warmLanes&=~u,Kt===r&&(xt&u)===u&&(mn===4||mn===3&&(xt&62914560)===xt&&300>At()-Df?(Lt&2)===0&&us(r,0):Rf|=u,is===xt&&(is=0)),Ta(r)}function F2(r,i){i===0&&(i=Vs()),r=Gl(r,i),r!==null&&(fi(r,i),Ta(r))}function Ry(r){var i=r.memoizedState,u=0;i!==null&&(u=i.retryLane),F2(r,u)}function My(r,i){var u=0;switch(r.tag){case 13:var c=r.stateNode,m=r.memoizedState;m!==null&&(u=m.retryLane);break;case 19:c=r.stateNode;break;case 22:c=r.stateNode._retryCache;break;default:throw Error(a(314))}c!==null&&c.delete(i),F2(r,u)}function Dy(r,i){return vt(r,i)}var w0=null,cs=null,Ff=!1,C0=!1,qf=!1,xl=0;function Ta(r){r!==cs&&r.next===null&&(cs===null?w0=cs=r:cs=cs.next=r),C0=!0,Ff||(Ff=!0,Ly())}function Ru(r,i){if(!qf&&C0){qf=!0;do for(var u=!1,c=w0;c!==null;){if(r!==0){var m=c.pendingLanes;if(m===0)var g=0;else{var S=c.suspendedLanes,w=c.pingedLanes;g=(1<<31-$e(42|r)+1)-1,g&=m&~(S&~w),g=g&201326741?g&201326741|1:g?g|2:0}g!==0&&(u=!0,V2(c,g))}else g=xt,g=Tn(c,c===Kt?g:0,c.cancelPendingCommit!==null||c.timeoutHandle!==-1),(g&3)===0||dr(c,g)||(u=!0,V2(c,g));c=c.next}while(u);qf=!1}}function Iy(){q2()}function q2(){C0=Ff=!1;var r=0;xl!==0&&(Yy()&&(r=xl),xl=0);for(var i=At(),u=null,c=w0;c!==null;){var m=c.next,g=Y2(c,i);g===0?(c.next=null,u===null?w0=m:u.next=m,m===null&&(cs=u)):(u=c,(r!==0||(g&3)!==0)&&(C0=!0)),c=m}Ru(r)}function Y2(r,i){for(var u=r.suspendedLanes,c=r.pingedLanes,m=r.expirationTimes,g=r.pendingLanes&-62914561;0<g;){var S=31-$e(g),w=1<<S,H=m[S];H===-1?((w&u)===0||(w&c)!==0)&&(m[S]=er(w,i)):H<=i&&(r.expiredLanes|=w),g&=~w}if(i=Kt,u=xt,u=Tn(r,r===i?u:0,r.cancelPendingCommit!==null||r.timeoutHandle!==-1),c=r.callbackNode,u===0||r===i&&(Bt===2||Bt===9)||r.cancelPendingCommit!==null)return c!==null&&c!==null&&ht(c),r.callbackNode=null,r.callbackPriority=0;if((u&3)===0||dr(r,u)){if(i=u&-u,i===r.callbackPriority)return i;switch(c!==null&&ht(c),nt(u)){case 2:case 8:u=Zt;break;case 32:u=Ln;break;case 268435456:u=pa;break;default:u=Ln}return c=G2.bind(null,r),u=vt(u,c),r.callbackPriority=i,r.callbackNode=u,i}return c!==null&&c!==null&&ht(c),r.callbackPriority=2,r.callbackNode=null,2}function G2(r,i){if(Yn!==0&&Yn!==5)return r.callbackNode=null,r.callbackPriority=0,null;var u=r.callbackNode;if(N0()&&r.callbackNode!==u)return null;var c=xt;return c=Tn(r,r===Kt?c:0,r.cancelPendingCommit!==null||r.timeoutHandle!==-1),c===0?null:(k2(r,c,i),Y2(r,At()),r.callbackNode!=null&&r.callbackNode===u?G2.bind(null,r):null)}function V2(r,i){if(N0())return null;k2(r,i,!0)}function Ly(){Vy(function(){(Lt&6)!==0?vt(wt,Iy):q2()})}function Yf(){return xl===0&&(xl=Gs()),xl}function K2(r){return r==null||typeof r=="symbol"||typeof r=="boolean"?null:typeof r=="function"?r:bi(""+r)}function j2(r,i){var u=i.ownerDocument.createElement("input");return u.name=i.name,u.value=i.value,r.id&&u.setAttribute("form",r.id),i.parentNode.insertBefore(u,i),r=new FormData(r),u.parentNode.removeChild(u),r}function By(r,i,u,c,m){if(i==="submit"&&u&&u.stateNode===m){var g=K2((m[qe]||null).action),S=c.submitter;S&&(i=(i=S[qe]||null)?K2(i.formAction):S.getAttribute("formAction"),i!==null&&(g=i,S=null));var w=new Go("action","action",null,c,m);r.push({event:w,listeners:[{instance:null,listener:function(){if(c.defaultPrevented){if(xl!==0){var H=S?j2(m,S):new FormData(m);of(u,{pending:!0,data:H,method:m.method,action:g},null,H)}}else typeof g=="function"&&(w.preventDefault(),H=S?j2(m,S):new FormData(m),of(u,{pending:!0,data:H,method:m.method,action:g},g,H))},currentTarget:m}]})}}for(var Gf=0;Gf<Nd.length;Gf++){var Vf=Nd[Gf],Py=Vf.toLowerCase(),Uy=Vf[0].toUpperCase()+Vf.slice(1);ua(Py,"on"+Uy)}ua(kp,"onAnimationEnd"),ua(Np,"onAnimationIteration"),ua(wp,"onAnimationStart"),ua("dblclick","onDoubleClick"),ua("focusin","onFocus"),ua("focusout","onBlur"),ua(ty,"onTransitionRun"),ua(ny,"onTransitionStart"),ua(ry,"onTransitionCancel"),ua(Cp,"onTransitionEnd"),tr("onMouseEnter",["mouseout","mouseover"]),tr("onMouseLeave",["mouseout","mouseover"]),tr("onPointerEnter",["pointerout","pointerover"]),tr("onPointerLeave",["pointerout","pointerover"]),Ba("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Ba("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Ba("onBeforeInput",["compositionend","keypress","textInput","paste"]),Ba("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Ba("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Ba("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Mu="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),zy=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(Mu));function X2(r,i){i=(i&4)!==0;for(var u=0;u<r.length;u++){var c=r[u],m=c.event;c=c.listeners;e:{var g=void 0;if(i)for(var S=c.length-1;0<=S;S--){var w=c[S],H=w.instance,Q=w.currentTarget;if(w=w.listener,H!==g&&m.isPropagationStopped())break e;g=w,m.currentTarget=Q;try{g(m)}catch(de){g0(de)}m.currentTarget=null,g=H}else for(S=0;S<c.length;S++){if(w=c[S],H=w.instance,Q=w.currentTarget,w=w.listener,H!==g&&m.isPropagationStopped())break e;g=w,m.currentTarget=Q;try{g(m)}catch(de){g0(de)}m.currentTarget=null,g=H}}}}function _t(r,i){var u=i[en];u===void 0&&(u=i[en]=new Set);var c=r+"__bubble";u.has(c)||($2(i,r,2,!1),u.add(c))}function Kf(r,i,u){var c=0;i&&(c|=4),$2(u,r,c,i)}var O0="_reactListening"+Math.random().toString(36).slice(2);function jf(r){if(!r[O0]){r[O0]=!0,Lo.forEach(function(u){u!=="selectionchange"&&(zy.has(u)||Kf(u,!1,r),Kf(u,!0,r))});var i=r.nodeType===9?r:r.ownerDocument;i===null||i[O0]||(i[O0]=!0,Kf("selectionchange",!1,i))}}function $2(r,i,u,c){switch(y4(i)){case 2:var m=fv;break;case 8:m=hv;break;default:m=sh}u=m.bind(null,i,u,r),m=void 0,!md||i!=="touchstart"&&i!=="touchmove"&&i!=="wheel"||(m=!0),c?m!==void 0?r.addEventListener(i,u,{capture:!0,passive:m}):r.addEventListener(i,u,!0):m!==void 0?r.addEventListener(i,u,{passive:m}):r.addEventListener(i,u,!1)}function Xf(r,i,u,c,m){var g=c;if((i&1)===0&&(i&2)===0&&c!==null)e:for(;;){if(c===null)return;var S=c.tag;if(S===3||S===4){var w=c.stateNode.containerInfo;if(w===m)break;if(S===4)for(S=c.return;S!==null;){var H=S.tag;if((H===3||H===4)&&S.stateNode.containerInfo===m)return;S=S.return}for(;w!==null;){if(S=mi(w),S===null)return;if(H=S.tag,H===5||H===6||H===26||H===27){c=g=S;continue e}w=w.parentNode}}c=c.return}Fr(function(){var Q=g,de=Ie(u),Ee=[];e:{var ee=Op.get(r);if(ee!==void 0){var ne=Go,rt=r;switch(r){case"keypress":if(qo(u)===0)break e;case"keydown":case"keyup":ne=D8;break;case"focusin":rt="focus",ne=Ed;break;case"focusout":rt="blur",ne=Ed;break;case"beforeblur":case"afterblur":ne=Ed;break;case"click":if(u.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":ne=ip;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":ne=T8;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":ne=B8;break;case kp:case Np:case wp:ne=A8;break;case Cp:ne=U8;break;case"scroll":case"scrollend":ne=y8;break;case"wheel":ne=H8;break;case"copy":case"cut":case"paste":ne=k8;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":ne=sp;break;case"toggle":case"beforetoggle":ne=q8}var et=(i&4)!==0,Ft=!et&&(r==="scroll"||r==="scrollend"),j=et?ee!==null?ee+"Capture":null:ee;et=[];for(var Y=Q,$;Y!==null;){var pe=Y;if($=pe.stateNode,pe=pe.tag,pe!==5&&pe!==26&&pe!==27||$===null||j===null||(pe=ol(Y,j),pe!=null&&et.push(Du(Y,pe,$))),Ft)break;Y=Y.return}0<et.length&&(ee=new ne(ee,rt,null,u,de),Ee.push({event:ee,listeners:et}))}}if((i&7)===0){e:{if(ee=r==="mouseover"||r==="pointerover",ne=r==="mouseout"||r==="pointerout",ee&&u!==ul&&(rt=u.relatedTarget||u.fromElement)&&(mi(rt)||rt[Qt]))break e;if((ne||ee)&&(ee=de.window===de?de:(ee=de.ownerDocument)?ee.defaultView||ee.parentWindow:window,ne?(rt=u.relatedTarget||u.toElement,ne=Q,rt=rt?mi(rt):null,rt!==null&&(Ft=s(rt),et=rt.tag,rt!==Ft||et!==5&&et!==27&&et!==6)&&(rt=null)):(ne=null,rt=Q),ne!==rt)){if(et=ip,pe="onMouseLeave",j="onMouseEnter",Y="mouse",(r==="pointerout"||r==="pointerover")&&(et=sp,pe="onPointerLeave",j="onPointerEnter",Y="pointer"),Ft=ne==null?ee:il(ne),$=rt==null?ee:il(rt),ee=new et(pe,Y+"leave",ne,u,de),ee.target=Ft,ee.relatedTarget=$,pe=null,mi(de)===Q&&(et=new et(j,Y+"enter",rt,u,de),et.target=$,et.relatedTarget=Ft,pe=et),Ft=pe,ne&&rt)t:{for(et=ne,j=rt,Y=0,$=et;$;$=ds($))Y++;for($=0,pe=j;pe;pe=ds(pe))$++;for(;0<Y-$;)et=ds(et),Y--;for(;0<$-Y;)j=ds(j),$--;for(;Y--;){if(et===j||j!==null&&et===j.alternate)break t;et=ds(et),j=ds(j)}et=null}else et=null;ne!==null&&W2(Ee,ee,ne,et,!1),rt!==null&&Ft!==null&&W2(Ee,Ft,rt,et,!0)}}e:{if(ee=Q?il(Q):window,ne=ee.nodeName&&ee.nodeName.toLowerCase(),ne==="select"||ne==="input"&&ee.type==="file")var Fe=pp;else if(hp(ee))if(gp)Fe=Z8;else{Fe=W8;var bt=$8}else ne=ee.nodeName,!ne||ne.toLowerCase()!=="input"||ee.type!=="checkbox"&&ee.type!=="radio"?Q&&It(Q.elementType)&&(Fe=pp):Fe=Q8;if(Fe&&(Fe=Fe(r,Q))){mp(Ee,Fe,u,de);break e}bt&&bt(r,ee,Q),r==="focusout"&&Q&&ee.type==="number"&&Q.memoizedProps.value!=null&&gi(ee,"number",ee.value)}switch(bt=Q?il(Q):window,r){case"focusin":(hp(bt)||bt.contentEditable==="true")&&(Fl=bt,Ad=Q,iu=null);break;case"focusout":iu=Ad=Fl=null;break;case"mousedown":xd=!0;break;case"contextmenu":case"mouseup":case"dragend":xd=!1,Ap(Ee,u,de);break;case"selectionchange":if(ey)break;case"keydown":case"keyup":Ap(Ee,u,de)}var Xe;if(vd)e:{switch(r){case"compositionstart":var tt="onCompositionStart";break e;case"compositionend":tt="onCompositionEnd";break e;case"compositionupdate":tt="onCompositionUpdate";break e}tt=void 0}else Hl?dp(r,u)&&(tt="onCompositionEnd"):r==="keydown"&&u.keyCode===229&&(tt="onCompositionStart");tt&&(up&&u.locale!=="ko"&&(Hl||tt!=="onCompositionStart"?tt==="onCompositionEnd"&&Hl&&(Xe=rp()):(Ei=de,pd="value"in Ei?Ei.value:Ei.textContent,Hl=!0)),bt=R0(Q,tt),0<bt.length&&(tt=new lp(tt,r,null,u,de),Ee.push({event:tt,listeners:bt}),Xe?tt.data=Xe:(Xe=fp(u),Xe!==null&&(tt.data=Xe)))),(Xe=G8?V8(r,u):K8(r,u))&&(tt=R0(Q,"onBeforeInput"),0<tt.length&&(bt=new lp("onBeforeInput","beforeinput",null,u,de),Ee.push({event:bt,listeners:tt}),bt.data=Xe)),By(Ee,r,Q,u,de)}X2(Ee,i)})}function Du(r,i,u){return{instance:r,listener:i,currentTarget:u}}function R0(r,i){for(var u=i+"Capture",c=[];r!==null;){var m=r,g=m.stateNode;if(m=m.tag,m!==5&&m!==26&&m!==27||g===null||(m=ol(r,u),m!=null&&c.unshift(Du(r,m,g)),m=ol(r,i),m!=null&&c.push(Du(r,m,g))),r.tag===3)return c;r=r.return}return[]}function ds(r){if(r===null)return null;do r=r.return;while(r&&r.tag!==5&&r.tag!==27);return r||null}function W2(r,i,u,c,m){for(var g=i._reactName,S=[];u!==null&&u!==c;){var w=u,H=w.alternate,Q=w.stateNode;if(w=w.tag,H!==null&&H===c)break;w!==5&&w!==26&&w!==27||Q===null||(H=Q,m?(Q=ol(u,g),Q!=null&&S.unshift(Du(u,Q,H))):m||(Q=ol(u,g),Q!=null&&S.push(Du(u,Q,H)))),u=u.return}S.length!==0&&r.push({event:i,listeners:S})}var Hy=/\r\n?/g,Fy=/\u0000|\uFFFD/g;function Q2(r){return(typeof r=="string"?r:""+r).replace(Hy,`
`).replace(Fy,"")}function Z2(r,i){return i=Q2(i),Q2(r)===i}function M0(){}function Ht(r,i,u,c,m,g){switch(u){case"children":typeof c=="string"?i==="body"||i==="textarea"&&c===""||ga(r,c):(typeof c=="number"||typeof c=="bigint")&&i!=="body"&&ga(r,""+c);break;case"className":Pa(r,"class",c);break;case"tabIndex":Pa(r,"tabindex",c);break;case"dir":case"role":case"viewBox":case"width":case"height":Pa(r,u,c);break;case"style":_n(r,c,g);break;case"data":if(i!=="object"){Pa(r,"data",c);break}case"src":case"href":if(c===""&&(i!=="a"||u!=="href")){r.removeAttribute(u);break}if(c==null||typeof c=="function"||typeof c=="symbol"||typeof c=="boolean"){r.removeAttribute(u);break}c=bi(""+c),r.setAttribute(u,c);break;case"action":case"formAction":if(typeof c=="function"){r.setAttribute(u,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof g=="function"&&(u==="formAction"?(i!=="input"&&Ht(r,i,"name",m.name,m,null),Ht(r,i,"formEncType",m.formEncType,m,null),Ht(r,i,"formMethod",m.formMethod,m,null),Ht(r,i,"formTarget",m.formTarget,m,null)):(Ht(r,i,"encType",m.encType,m,null),Ht(r,i,"method",m.method,m,null),Ht(r,i,"target",m.target,m,null)));if(c==null||typeof c=="symbol"||typeof c=="boolean"){r.removeAttribute(u);break}c=bi(""+c),r.setAttribute(u,c);break;case"onClick":c!=null&&(r.onclick=M0);break;case"onScroll":c!=null&&_t("scroll",r);break;case"onScrollEnd":c!=null&&_t("scrollend",r);break;case"dangerouslySetInnerHTML":if(c!=null){if(typeof c!="object"||!("__html"in c))throw Error(a(61));if(u=c.__html,u!=null){if(m.children!=null)throw Error(a(60));r.innerHTML=u}}break;case"multiple":r.multiple=c&&typeof c!="function"&&typeof c!="symbol";break;case"muted":r.muted=c&&typeof c!="function"&&typeof c!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(c==null||typeof c=="function"||typeof c=="boolean"||typeof c=="symbol"){r.removeAttribute("xlink:href");break}u=bi(""+c),r.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",u);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":c!=null&&typeof c!="function"&&typeof c!="symbol"?r.setAttribute(u,""+c):r.removeAttribute(u);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":c&&typeof c!="function"&&typeof c!="symbol"?r.setAttribute(u,""):r.removeAttribute(u);break;case"capture":case"download":c===!0?r.setAttribute(u,""):c!==!1&&c!=null&&typeof c!="function"&&typeof c!="symbol"?r.setAttribute(u,c):r.removeAttribute(u);break;case"cols":case"rows":case"size":case"span":c!=null&&typeof c!="function"&&typeof c!="symbol"&&!isNaN(c)&&1<=c?r.setAttribute(u,c):r.removeAttribute(u);break;case"rowSpan":case"start":c==null||typeof c=="function"||typeof c=="symbol"||isNaN(c)?r.removeAttribute(u):r.setAttribute(u,c);break;case"popover":_t("beforetoggle",r),_t("toggle",r),Ul(r,"popover",c);break;case"xlinkActuate":ia(r,"http://www.w3.org/1999/xlink","xlink:actuate",c);break;case"xlinkArcrole":ia(r,"http://www.w3.org/1999/xlink","xlink:arcrole",c);break;case"xlinkRole":ia(r,"http://www.w3.org/1999/xlink","xlink:role",c);break;case"xlinkShow":ia(r,"http://www.w3.org/1999/xlink","xlink:show",c);break;case"xlinkTitle":ia(r,"http://www.w3.org/1999/xlink","xlink:title",c);break;case"xlinkType":ia(r,"http://www.w3.org/1999/xlink","xlink:type",c);break;case"xmlBase":ia(r,"http://www.w3.org/XML/1998/namespace","xml:base",c);break;case"xmlLang":ia(r,"http://www.w3.org/XML/1998/namespace","xml:lang",c);break;case"xmlSpace":ia(r,"http://www.w3.org/XML/1998/namespace","xml:space",c);break;case"is":Ul(r,"is",c);break;case"innerText":case"textContent":break;default:(!(2<u.length)||u[0]!=="o"&&u[0]!=="O"||u[1]!=="n"&&u[1]!=="N")&&(u=zl.get(u)||u,Ul(r,u,c))}}function $f(r,i,u,c,m,g){switch(u){case"style":_n(r,c,g);break;case"dangerouslySetInnerHTML":if(c!=null){if(typeof c!="object"||!("__html"in c))throw Error(a(61));if(u=c.__html,u!=null){if(m.children!=null)throw Error(a(60));r.innerHTML=u}}break;case"children":typeof c=="string"?ga(r,c):(typeof c=="number"||typeof c=="bigint")&&ga(r,""+c);break;case"onScroll":c!=null&&_t("scroll",r);break;case"onScrollEnd":c!=null&&_t("scrollend",r);break;case"onClick":c!=null&&(r.onclick=M0);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Bo.hasOwnProperty(u))e:{if(u[0]==="o"&&u[1]==="n"&&(m=u.endsWith("Capture"),i=u.slice(2,m?u.length-7:void 0),g=r[qe]||null,g=g!=null?g[u]:null,typeof g=="function"&&r.removeEventListener(i,g,m),typeof c=="function")){typeof g!="function"&&g!==null&&(u in r?r[u]=null:r.hasAttribute(u)&&r.removeAttribute(u)),r.addEventListener(i,c,m);break e}u in r?r[u]=c:c===!0?r.setAttribute(u,""):Ul(r,u,c)}}}function Gn(r,i,u){switch(i){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":_t("error",r),_t("load",r);var c=!1,m=!1,g;for(g in u)if(u.hasOwnProperty(g)){var S=u[g];if(S!=null)switch(g){case"src":c=!0;break;case"srcSet":m=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(a(137,i));default:Ht(r,i,g,S,u,null)}}m&&Ht(r,i,"srcSet",u.srcSet,u,null),c&&Ht(r,i,"src",u.src,u,null);return;case"input":_t("invalid",r);var w=g=S=m=null,H=null,Q=null;for(c in u)if(u.hasOwnProperty(c)){var de=u[c];if(de!=null)switch(c){case"name":m=de;break;case"type":S=de;break;case"checked":H=de;break;case"defaultChecked":Q=de;break;case"value":g=de;break;case"defaultValue":w=de;break;case"children":case"dangerouslySetInnerHTML":if(de!=null)throw Error(a(137,i));break;default:Ht(r,i,c,de,u,null)}}zo(r,g,w,H,Q,S,m,!1),ll(r);return;case"select":_t("invalid",r),c=S=g=null;for(m in u)if(u.hasOwnProperty(m)&&(w=u[m],w!=null))switch(m){case"value":g=w;break;case"defaultValue":S=w;break;case"multiple":c=w;default:Ht(r,i,m,w,u,null)}i=g,u=S,r.multiple=!!c,i!=null?Ua(r,!!c,i,!1):u!=null&&Ua(r,!!c,u,!0);return;case"textarea":_t("invalid",r),g=m=c=null;for(S in u)if(u.hasOwnProperty(S)&&(w=u[S],w!=null))switch(S){case"value":c=w;break;case"defaultValue":m=w;break;case"children":g=w;break;case"dangerouslySetInnerHTML":if(w!=null)throw Error(a(91));break;default:Ht(r,i,S,w,u,null)}Ho(r,c,m,g),ll(r);return;case"option":for(H in u)if(u.hasOwnProperty(H)&&(c=u[H],c!=null))switch(H){case"selected":r.selected=c&&typeof c!="function"&&typeof c!="symbol";break;default:Ht(r,i,H,c,u,null)}return;case"dialog":_t("beforetoggle",r),_t("toggle",r),_t("cancel",r),_t("close",r);break;case"iframe":case"object":_t("load",r);break;case"video":case"audio":for(c=0;c<Mu.length;c++)_t(Mu[c],r);break;case"image":_t("error",r),_t("load",r);break;case"details":_t("toggle",r);break;case"embed":case"source":case"link":_t("error",r),_t("load",r);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(Q in u)if(u.hasOwnProperty(Q)&&(c=u[Q],c!=null))switch(Q){case"children":case"dangerouslySetInnerHTML":throw Error(a(137,i));default:Ht(r,i,Q,c,u,null)}return;default:if(It(i)){for(de in u)u.hasOwnProperty(de)&&(c=u[de],c!==void 0&&$f(r,i,de,c,u,void 0));return}}for(w in u)u.hasOwnProperty(w)&&(c=u[w],c!=null&&Ht(r,i,w,c,u,null))}function qy(r,i,u,c){switch(i){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var m=null,g=null,S=null,w=null,H=null,Q=null,de=null;for(ne in u){var Ee=u[ne];if(u.hasOwnProperty(ne)&&Ee!=null)switch(ne){case"checked":break;case"value":break;case"defaultValue":H=Ee;default:c.hasOwnProperty(ne)||Ht(r,i,ne,null,c,Ee)}}for(var ee in c){var ne=c[ee];if(Ee=u[ee],c.hasOwnProperty(ee)&&(ne!=null||Ee!=null))switch(ee){case"type":g=ne;break;case"name":m=ne;break;case"checked":Q=ne;break;case"defaultChecked":de=ne;break;case"value":S=ne;break;case"defaultValue":w=ne;break;case"children":case"dangerouslySetInnerHTML":if(ne!=null)throw Error(a(137,i));break;default:ne!==Ee&&Ht(r,i,ee,ne,c,Ee)}}Ws(r,S,w,H,Q,de,g,m);return;case"select":ne=S=w=ee=null;for(g in u)if(H=u[g],u.hasOwnProperty(g)&&H!=null)switch(g){case"value":break;case"multiple":ne=H;default:c.hasOwnProperty(g)||Ht(r,i,g,null,c,H)}for(m in c)if(g=c[m],H=u[m],c.hasOwnProperty(m)&&(g!=null||H!=null))switch(m){case"value":ee=g;break;case"defaultValue":w=g;break;case"multiple":S=g;default:g!==H&&Ht(r,i,m,g,c,H)}i=w,u=S,c=ne,ee!=null?Ua(r,!!u,ee,!1):!!c!=!!u&&(i!=null?Ua(r,!!u,i,!0):Ua(r,!!u,u?[]:"",!1));return;case"textarea":ne=ee=null;for(w in u)if(m=u[w],u.hasOwnProperty(w)&&m!=null&&!c.hasOwnProperty(w))switch(w){case"value":break;case"children":break;default:Ht(r,i,w,null,c,m)}for(S in c)if(m=c[S],g=u[S],c.hasOwnProperty(S)&&(m!=null||g!=null))switch(S){case"value":ee=m;break;case"defaultValue":ne=m;break;case"children":break;case"dangerouslySetInnerHTML":if(m!=null)throw Error(a(91));break;default:m!==g&&Ht(r,i,S,m,c,g)}xr(r,ee,ne);return;case"option":for(var rt in u)if(ee=u[rt],u.hasOwnProperty(rt)&&ee!=null&&!c.hasOwnProperty(rt))switch(rt){case"selected":r.selected=!1;break;default:Ht(r,i,rt,null,c,ee)}for(H in c)if(ee=c[H],ne=u[H],c.hasOwnProperty(H)&&ee!==ne&&(ee!=null||ne!=null))switch(H){case"selected":r.selected=ee&&typeof ee!="function"&&typeof ee!="symbol";break;default:Ht(r,i,H,ee,c,ne)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var et in u)ee=u[et],u.hasOwnProperty(et)&&ee!=null&&!c.hasOwnProperty(et)&&Ht(r,i,et,null,c,ee);for(Q in c)if(ee=c[Q],ne=u[Q],c.hasOwnProperty(Q)&&ee!==ne&&(ee!=null||ne!=null))switch(Q){case"children":case"dangerouslySetInnerHTML":if(ee!=null)throw Error(a(137,i));break;default:Ht(r,i,Q,ee,c,ne)}return;default:if(It(i)){for(var Ft in u)ee=u[Ft],u.hasOwnProperty(Ft)&&ee!==void 0&&!c.hasOwnProperty(Ft)&&$f(r,i,Ft,void 0,c,ee);for(de in c)ee=c[de],ne=u[de],!c.hasOwnProperty(de)||ee===ne||ee===void 0&&ne===void 0||$f(r,i,de,ee,c,ne);return}}for(var j in u)ee=u[j],u.hasOwnProperty(j)&&ee!=null&&!c.hasOwnProperty(j)&&Ht(r,i,j,null,c,ee);for(Ee in c)ee=c[Ee],ne=u[Ee],!c.hasOwnProperty(Ee)||ee===ne||ee==null&&ne==null||Ht(r,i,Ee,ee,c,ne)}var Wf=null,Qf=null;function D0(r){return r.nodeType===9?r:r.ownerDocument}function J2(r){switch(r){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function e4(r,i){if(r===0)switch(i){case"svg":return 1;case"math":return 2;default:return 0}return r===1&&i==="foreignObject"?0:r}function Zf(r,i){return r==="textarea"||r==="noscript"||typeof i.children=="string"||typeof i.children=="number"||typeof i.children=="bigint"||typeof i.dangerouslySetInnerHTML=="object"&&i.dangerouslySetInnerHTML!==null&&i.dangerouslySetInnerHTML.__html!=null}var Jf=null;function Yy(){var r=window.event;return r&&r.type==="popstate"?r===Jf?!1:(Jf=r,!0):(Jf=null,!1)}var t4=typeof setTimeout=="function"?setTimeout:void 0,Gy=typeof clearTimeout=="function"?clearTimeout:void 0,n4=typeof Promise=="function"?Promise:void 0,Vy=typeof queueMicrotask=="function"?queueMicrotask:typeof n4<"u"?function(r){return n4.resolve(null).then(r).catch(Ky)}:t4;function Ky(r){setTimeout(function(){throw r})}function Ii(r){return r==="head"}function r4(r,i){var u=i,c=0,m=0;do{var g=u.nextSibling;if(r.removeChild(u),g&&g.nodeType===8)if(u=g.data,u==="/$"){if(0<c&&8>c){u=c;var S=r.ownerDocument;if(u&1&&Iu(S.documentElement),u&2&&Iu(S.body),u&4)for(u=S.head,Iu(u),S=u.firstChild;S;){var w=S.nextSibling,H=S.nodeName;S[rl]||H==="SCRIPT"||H==="STYLE"||H==="LINK"&&S.rel.toLowerCase()==="stylesheet"||u.removeChild(S),S=w}}if(m===0){r.removeChild(g),qu(i);return}m--}else u==="$"||u==="$?"||u==="$!"?m++:c=u.charCodeAt(0)-48;else c=0;u=g}while(u);qu(i)}function eh(r){var i=r.firstChild;for(i&&i.nodeType===10&&(i=i.nextSibling);i;){var u=i;switch(i=i.nextSibling,u.nodeName){case"HTML":case"HEAD":case"BODY":eh(u),al(u);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(u.rel.toLowerCase()==="stylesheet")continue}r.removeChild(u)}}function jy(r,i,u,c){for(;r.nodeType===1;){var m=u;if(r.nodeName.toLowerCase()!==i.toLowerCase()){if(!c&&(r.nodeName!=="INPUT"||r.type!=="hidden"))break}else if(c){if(!r[rl])switch(i){case"meta":if(!r.hasAttribute("itemprop"))break;return r;case"link":if(g=r.getAttribute("rel"),g==="stylesheet"&&r.hasAttribute("data-precedence"))break;if(g!==m.rel||r.getAttribute("href")!==(m.href==null||m.href===""?null:m.href)||r.getAttribute("crossorigin")!==(m.crossOrigin==null?null:m.crossOrigin)||r.getAttribute("title")!==(m.title==null?null:m.title))break;return r;case"style":if(r.hasAttribute("data-precedence"))break;return r;case"script":if(g=r.getAttribute("src"),(g!==(m.src==null?null:m.src)||r.getAttribute("type")!==(m.type==null?null:m.type)||r.getAttribute("crossorigin")!==(m.crossOrigin==null?null:m.crossOrigin))&&g&&r.hasAttribute("async")&&!r.hasAttribute("itemprop"))break;return r;default:return r}}else if(i==="input"&&r.type==="hidden"){var g=m.name==null?null:""+m.name;if(m.type==="hidden"&&r.getAttribute("name")===g)return r}else return r;if(r=ca(r.nextSibling),r===null)break}return null}function Xy(r,i,u){if(i==="")return null;for(;r.nodeType!==3;)if((r.nodeType!==1||r.nodeName!=="INPUT"||r.type!=="hidden")&&!u||(r=ca(r.nextSibling),r===null))return null;return r}function th(r){return r.data==="$!"||r.data==="$?"&&r.ownerDocument.readyState==="complete"}function $y(r,i){var u=r.ownerDocument;if(r.data!=="$?"||u.readyState==="complete")i();else{var c=function(){i(),u.removeEventListener("DOMContentLoaded",c)};u.addEventListener("DOMContentLoaded",c),r._reactRetry=c}}function ca(r){for(;r!=null;r=r.nextSibling){var i=r.nodeType;if(i===1||i===3)break;if(i===8){if(i=r.data,i==="$"||i==="$!"||i==="$?"||i==="F!"||i==="F")break;if(i==="/$")return null}}return r}var nh=null;function a4(r){r=r.previousSibling;for(var i=0;r;){if(r.nodeType===8){var u=r.data;if(u==="$"||u==="$!"||u==="$?"){if(i===0)return r;i--}else u==="/$"&&i++}r=r.previousSibling}return null}function i4(r,i,u){switch(i=D0(u),r){case"html":if(r=i.documentElement,!r)throw Error(a(452));return r;case"head":if(r=i.head,!r)throw Error(a(453));return r;case"body":if(r=i.body,!r)throw Error(a(454));return r;default:throw Error(a(451))}}function Iu(r){for(var i=r.attributes;i.length;)r.removeAttributeNode(i[0]);al(r)}var Xr=new Map,l4=new Set;function I0(r){return typeof r.getRootNode=="function"?r.getRootNode():r.nodeType===9?r:r.ownerDocument}var Za=oe.d;oe.d={f:Wy,r:Qy,D:Zy,C:Jy,L:ev,m:tv,X:rv,S:nv,M:av};function Wy(){var r=Za.f(),i=x0();return r||i}function Qy(r){var i=pi(r);i!==null&&i.tag===5&&i.type==="form"?kg(i):Za.r(r)}var fs=typeof document>"u"?null:document;function s4(r,i,u){var c=fs;if(c&&typeof i=="string"&&i){var m=fr(i);m='link[rel="'+r+'"][href="'+m+'"]',typeof u=="string"&&(m+='[crossorigin="'+u+'"]'),l4.has(m)||(l4.add(m),r={rel:r,crossOrigin:u,href:i},c.querySelector(m)===null&&(i=c.createElement("link"),Gn(i,"link",r),sn(i),c.head.appendChild(i)))}}function Zy(r){Za.D(r),s4("dns-prefetch",r,null)}function Jy(r,i){Za.C(r,i),s4("preconnect",r,i)}function ev(r,i,u){Za.L(r,i,u);var c=fs;if(c&&r&&i){var m='link[rel="preload"][as="'+fr(i)+'"]';i==="image"&&u&&u.imageSrcSet?(m+='[imagesrcset="'+fr(u.imageSrcSet)+'"]',typeof u.imageSizes=="string"&&(m+='[imagesizes="'+fr(u.imageSizes)+'"]')):m+='[href="'+fr(r)+'"]';var g=m;switch(i){case"style":g=hs(r);break;case"script":g=ms(r)}Xr.has(g)||(r=p({rel:"preload",href:i==="image"&&u&&u.imageSrcSet?void 0:r,as:i},u),Xr.set(g,r),c.querySelector(m)!==null||i==="style"&&c.querySelector(Lu(g))||i==="script"&&c.querySelector(Bu(g))||(i=c.createElement("link"),Gn(i,"link",r),sn(i),c.head.appendChild(i)))}}function tv(r,i){Za.m(r,i);var u=fs;if(u&&r){var c=i&&typeof i.as=="string"?i.as:"script",m='link[rel="modulepreload"][as="'+fr(c)+'"][href="'+fr(r)+'"]',g=m;switch(c){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":g=ms(r)}if(!Xr.has(g)&&(r=p({rel:"modulepreload",href:r},i),Xr.set(g,r),u.querySelector(m)===null)){switch(c){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(u.querySelector(Bu(g)))return}c=u.createElement("link"),Gn(c,"link",r),sn(c),u.head.appendChild(c)}}}function nv(r,i,u){Za.S(r,i,u);var c=fs;if(c&&r){var m=La(c).hoistableStyles,g=hs(r);i=i||"default";var S=m.get(g);if(!S){var w={loading:0,preload:null};if(S=c.querySelector(Lu(g)))w.loading=5;else{r=p({rel:"stylesheet",href:r,"data-precedence":i},u),(u=Xr.get(g))&&rh(r,u);var H=S=c.createElement("link");sn(H),Gn(H,"link",r),H._p=new Promise(function(Q,de){H.onload=Q,H.onerror=de}),H.addEventListener("load",function(){w.loading|=1}),H.addEventListener("error",function(){w.loading|=2}),w.loading|=4,L0(S,i,c)}S={type:"stylesheet",instance:S,count:1,state:w},m.set(g,S)}}}function rv(r,i){Za.X(r,i);var u=fs;if(u&&r){var c=La(u).hoistableScripts,m=ms(r),g=c.get(m);g||(g=u.querySelector(Bu(m)),g||(r=p({src:r,async:!0},i),(i=Xr.get(m))&&ah(r,i),g=u.createElement("script"),sn(g),Gn(g,"link",r),u.head.appendChild(g)),g={type:"script",instance:g,count:1,state:null},c.set(m,g))}}function av(r,i){Za.M(r,i);var u=fs;if(u&&r){var c=La(u).hoistableScripts,m=ms(r),g=c.get(m);g||(g=u.querySelector(Bu(m)),g||(r=p({src:r,async:!0,type:"module"},i),(i=Xr.get(m))&&ah(r,i),g=u.createElement("script"),sn(g),Gn(g,"link",r),u.head.appendChild(g)),g={type:"script",instance:g,count:1,state:null},c.set(m,g))}}function u4(r,i,u,c){var m=(m=Le.current)?I0(m):null;if(!m)throw Error(a(446));switch(r){case"meta":case"title":return null;case"style":return typeof u.precedence=="string"&&typeof u.href=="string"?(i=hs(u.href),u=La(m).hoistableStyles,c=u.get(i),c||(c={type:"style",instance:null,count:0,state:null},u.set(i,c)),c):{type:"void",instance:null,count:0,state:null};case"link":if(u.rel==="stylesheet"&&typeof u.href=="string"&&typeof u.precedence=="string"){r=hs(u.href);var g=La(m).hoistableStyles,S=g.get(r);if(S||(m=m.ownerDocument||m,S={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},g.set(r,S),(g=m.querySelector(Lu(r)))&&!g._p&&(S.instance=g,S.state.loading=5),Xr.has(r)||(u={rel:"preload",as:"style",href:u.href,crossOrigin:u.crossOrigin,integrity:u.integrity,media:u.media,hrefLang:u.hrefLang,referrerPolicy:u.referrerPolicy},Xr.set(r,u),g||iv(m,r,u,S.state))),i&&c===null)throw Error(a(528,""));return S}if(i&&c!==null)throw Error(a(529,""));return null;case"script":return i=u.async,u=u.src,typeof u=="string"&&i&&typeof i!="function"&&typeof i!="symbol"?(i=ms(u),u=La(m).hoistableScripts,c=u.get(i),c||(c={type:"script",instance:null,count:0,state:null},u.set(i,c)),c):{type:"void",instance:null,count:0,state:null};default:throw Error(a(444,r))}}function hs(r){return'href="'+fr(r)+'"'}function Lu(r){return'link[rel="stylesheet"]['+r+"]"}function o4(r){return p({},r,{"data-precedence":r.precedence,precedence:null})}function iv(r,i,u,c){r.querySelector('link[rel="preload"][as="style"]['+i+"]")?c.loading=1:(i=r.createElement("link"),c.preload=i,i.addEventListener("load",function(){return c.loading|=1}),i.addEventListener("error",function(){return c.loading|=2}),Gn(i,"link",u),sn(i),r.head.appendChild(i))}function ms(r){return'[src="'+fr(r)+'"]'}function Bu(r){return"script[async]"+r}function c4(r,i,u){if(i.count++,i.instance===null)switch(i.type){case"style":var c=r.querySelector('style[data-href~="'+fr(u.href)+'"]');if(c)return i.instance=c,sn(c),c;var m=p({},u,{"data-href":u.href,"data-precedence":u.precedence,href:null,precedence:null});return c=(r.ownerDocument||r).createElement("style"),sn(c),Gn(c,"style",m),L0(c,u.precedence,r),i.instance=c;case"stylesheet":m=hs(u.href);var g=r.querySelector(Lu(m));if(g)return i.state.loading|=4,i.instance=g,sn(g),g;c=o4(u),(m=Xr.get(m))&&rh(c,m),g=(r.ownerDocument||r).createElement("link"),sn(g);var S=g;return S._p=new Promise(function(w,H){S.onload=w,S.onerror=H}),Gn(g,"link",c),i.state.loading|=4,L0(g,u.precedence,r),i.instance=g;case"script":return g=ms(u.src),(m=r.querySelector(Bu(g)))?(i.instance=m,sn(m),m):(c=u,(m=Xr.get(g))&&(c=p({},u),ah(c,m)),r=r.ownerDocument||r,m=r.createElement("script"),sn(m),Gn(m,"link",c),r.head.appendChild(m),i.instance=m);case"void":return null;default:throw Error(a(443,i.type))}else i.type==="stylesheet"&&(i.state.loading&4)===0&&(c=i.instance,i.state.loading|=4,L0(c,u.precedence,r));return i.instance}function L0(r,i,u){for(var c=u.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),m=c.length?c[c.length-1]:null,g=m,S=0;S<c.length;S++){var w=c[S];if(w.dataset.precedence===i)g=w;else if(g!==m)break}g?g.parentNode.insertBefore(r,g.nextSibling):(i=u.nodeType===9?u.head:u,i.insertBefore(r,i.firstChild))}function rh(r,i){r.crossOrigin==null&&(r.crossOrigin=i.crossOrigin),r.referrerPolicy==null&&(r.referrerPolicy=i.referrerPolicy),r.title==null&&(r.title=i.title)}function ah(r,i){r.crossOrigin==null&&(r.crossOrigin=i.crossOrigin),r.referrerPolicy==null&&(r.referrerPolicy=i.referrerPolicy),r.integrity==null&&(r.integrity=i.integrity)}var B0=null;function d4(r,i,u){if(B0===null){var c=new Map,m=B0=new Map;m.set(u,c)}else m=B0,c=m.get(u),c||(c=new Map,m.set(u,c));if(c.has(r))return c;for(c.set(r,null),u=u.getElementsByTagName(r),m=0;m<u.length;m++){var g=u[m];if(!(g[rl]||g[Re]||r==="link"&&g.getAttribute("rel")==="stylesheet")&&g.namespaceURI!=="http://www.w3.org/2000/svg"){var S=g.getAttribute(i)||"";S=r+S;var w=c.get(S);w?w.push(g):c.set(S,[g])}}return c}function f4(r,i,u){r=r.ownerDocument||r,r.head.insertBefore(u,i==="title"?r.querySelector("head > title"):null)}function lv(r,i,u){if(u===1||i.itemProp!=null)return!1;switch(r){case"meta":case"title":return!0;case"style":if(typeof i.precedence!="string"||typeof i.href!="string"||i.href==="")break;return!0;case"link":if(typeof i.rel!="string"||typeof i.href!="string"||i.href===""||i.onLoad||i.onError)break;switch(i.rel){case"stylesheet":return r=i.disabled,typeof i.precedence=="string"&&r==null;default:return!0}case"script":if(i.async&&typeof i.async!="function"&&typeof i.async!="symbol"&&!i.onLoad&&!i.onError&&i.src&&typeof i.src=="string")return!0}return!1}function h4(r){return!(r.type==="stylesheet"&&(r.state.loading&3)===0)}var Pu=null;function sv(){}function uv(r,i,u){if(Pu===null)throw Error(a(475));var c=Pu;if(i.type==="stylesheet"&&(typeof u.media!="string"||matchMedia(u.media).matches!==!1)&&(i.state.loading&4)===0){if(i.instance===null){var m=hs(u.href),g=r.querySelector(Lu(m));if(g){r=g._p,r!==null&&typeof r=="object"&&typeof r.then=="function"&&(c.count++,c=P0.bind(c),r.then(c,c)),i.state.loading|=4,i.instance=g,sn(g);return}g=r.ownerDocument||r,u=o4(u),(m=Xr.get(m))&&rh(u,m),g=g.createElement("link"),sn(g);var S=g;S._p=new Promise(function(w,H){S.onload=w,S.onerror=H}),Gn(g,"link",u),i.instance=g}c.stylesheets===null&&(c.stylesheets=new Map),c.stylesheets.set(i,r),(r=i.state.preload)&&(i.state.loading&3)===0&&(c.count++,i=P0.bind(c),r.addEventListener("load",i),r.addEventListener("error",i))}}function ov(){if(Pu===null)throw Error(a(475));var r=Pu;return r.stylesheets&&r.count===0&&ih(r,r.stylesheets),0<r.count?function(i){var u=setTimeout(function(){if(r.stylesheets&&ih(r,r.stylesheets),r.unsuspend){var c=r.unsuspend;r.unsuspend=null,c()}},6e4);return r.unsuspend=i,function(){r.unsuspend=null,clearTimeout(u)}}:null}function P0(){if(this.count--,this.count===0){if(this.stylesheets)ih(this,this.stylesheets);else if(this.unsuspend){var r=this.unsuspend;this.unsuspend=null,r()}}}var U0=null;function ih(r,i){r.stylesheets=null,r.unsuspend!==null&&(r.count++,U0=new Map,i.forEach(cv,r),U0=null,P0.call(r))}function cv(r,i){if(!(i.state.loading&4)){var u=U0.get(r);if(u)var c=u.get(null);else{u=new Map,U0.set(r,u);for(var m=r.querySelectorAll("link[data-precedence],style[data-precedence]"),g=0;g<m.length;g++){var S=m[g];(S.nodeName==="LINK"||S.getAttribute("media")!=="not all")&&(u.set(S.dataset.precedence,S),c=S)}c&&u.set(null,c)}m=i.instance,S=m.getAttribute("data-precedence"),g=u.get(S)||c,g===c&&u.set(null,m),u.set(S,m),this.count++,c=P0.bind(this),m.addEventListener("load",c),m.addEventListener("error",c),g?g.parentNode.insertBefore(m,g.nextSibling):(r=r.nodeType===9?r.head:r,r.insertBefore(m,r.firstChild)),i.state.loading|=4}}var Uu={$$typeof:F,Provider:null,Consumer:null,_currentValue:be,_currentValue2:be,_threadCount:0};function dv(r,i,u,c,m,g,S,w){this.tag=1,this.containerInfo=r,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Ks(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Ks(0),this.hiddenUpdates=Ks(null),this.identifierPrefix=c,this.onUncaughtError=m,this.onCaughtError=g,this.onRecoverableError=S,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=w,this.incompleteTransitions=new Map}function m4(r,i,u,c,m,g,S,w,H,Q,de,Ee){return r=new dv(r,i,u,S,w,H,Q,Ee),i=1,g===!0&&(i|=24),g=Nr(3,null,null,i),r.current=g,g.stateNode=r,i=zd(),i.refCount++,r.pooledCache=i,i.refCount++,g.memoizedState={element:c,isDehydrated:u,cache:i},Yd(g),r}function p4(r){return r?(r=Vl,r):Vl}function g4(r,i,u,c,m,g){m=p4(m),c.context===null?c.context=m:c.pendingContext=m,c=Ti(i),c.payload={element:u},g=g===void 0?null:g,g!==null&&(c.callback=g),u=_i(r,c,i),u!==null&&(Mr(u,r,i),mu(u,r,i))}function b4(r,i){if(r=r.memoizedState,r!==null&&r.dehydrated!==null){var u=r.retryLane;r.retryLane=u!==0&&u<i?u:i}}function lh(r,i){b4(r,i),(r=r.alternate)&&b4(r,i)}function E4(r){if(r.tag===13){var i=Gl(r,67108864);i!==null&&Mr(i,r,67108864),lh(r,67108864)}}var z0=!0;function fv(r,i,u,c){var m=X.T;X.T=null;var g=oe.p;try{oe.p=2,sh(r,i,u,c)}finally{oe.p=g,X.T=m}}function hv(r,i,u,c){var m=X.T;X.T=null;var g=oe.p;try{oe.p=8,sh(r,i,u,c)}finally{oe.p=g,X.T=m}}function sh(r,i,u,c){if(z0){var m=uh(c);if(m===null)Xf(r,i,c,H0,u),v4(r,c);else if(pv(m,r,i,u,c))c.stopPropagation();else if(v4(r,c),i&4&&-1<mv.indexOf(r)){for(;m!==null;){var g=pi(m);if(g!==null)switch(g.tag){case 3:if(g=g.stateNode,g.current.memoizedState.isDehydrated){var S=Jn(g.pendingLanes);if(S!==0){var w=g;for(w.pendingLanes|=2,w.entangledLanes|=2;S;){var H=1<<31-$e(S);w.entanglements[1]|=H,S&=~H}Ta(g),(Lt&6)===0&&(S0=At()+500,Ru(0))}}break;case 13:w=Gl(g,2),w!==null&&Mr(w,g,2),x0(),lh(g,2)}if(g=uh(c),g===null&&Xf(r,i,c,H0,u),g===m)break;m=g}m!==null&&c.stopPropagation()}else Xf(r,i,c,null,u)}}function uh(r){return r=Ie(r),oh(r)}var H0=null;function oh(r){if(H0=null,r=mi(r),r!==null){var i=s(r);if(i===null)r=null;else{var u=i.tag;if(u===13){if(r=o(i),r!==null)return r;r=null}else if(u===3){if(i.stateNode.current.memoizedState.isDehydrated)return i.tag===3?i.stateNode.containerInfo:null;r=null}else i!==r&&(r=null)}}return H0=r,null}function y4(r){switch(r){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(an()){case wt:return 2;case Zt:return 8;case Ln:case di:return 32;case pa:return 268435456;default:return 32}default:return 32}}var ch=!1,Li=null,Bi=null,Pi=null,zu=new Map,Hu=new Map,Ui=[],mv="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function v4(r,i){switch(r){case"focusin":case"focusout":Li=null;break;case"dragenter":case"dragleave":Bi=null;break;case"mouseover":case"mouseout":Pi=null;break;case"pointerover":case"pointerout":zu.delete(i.pointerId);break;case"gotpointercapture":case"lostpointercapture":Hu.delete(i.pointerId)}}function Fu(r,i,u,c,m,g){return r===null||r.nativeEvent!==g?(r={blockedOn:i,domEventName:u,eventSystemFlags:c,nativeEvent:g,targetContainers:[m]},i!==null&&(i=pi(i),i!==null&&E4(i)),r):(r.eventSystemFlags|=c,i=r.targetContainers,m!==null&&i.indexOf(m)===-1&&i.push(m),r)}function pv(r,i,u,c,m){switch(i){case"focusin":return Li=Fu(Li,r,i,u,c,m),!0;case"dragenter":return Bi=Fu(Bi,r,i,u,c,m),!0;case"mouseover":return Pi=Fu(Pi,r,i,u,c,m),!0;case"pointerover":var g=m.pointerId;return zu.set(g,Fu(zu.get(g)||null,r,i,u,c,m)),!0;case"gotpointercapture":return g=m.pointerId,Hu.set(g,Fu(Hu.get(g)||null,r,i,u,c,m)),!0}return!1}function T4(r){var i=mi(r.target);if(i!==null){var u=s(i);if(u!==null){if(i=u.tag,i===13){if(i=o(u),i!==null){r.blockedOn=i,ln(r.priority,function(){if(u.tag===13){var c=Rr();c=Me(c);var m=Gl(u,c);m!==null&&Mr(m,u,c),lh(u,c)}});return}}else if(i===3&&u.stateNode.current.memoizedState.isDehydrated){r.blockedOn=u.tag===3?u.stateNode.containerInfo:null;return}}}r.blockedOn=null}function F0(r){if(r.blockedOn!==null)return!1;for(var i=r.targetContainers;0<i.length;){var u=uh(r.nativeEvent);if(u===null){u=r.nativeEvent;var c=new u.constructor(u.type,u);ul=c,u.target.dispatchEvent(c),ul=null}else return i=pi(u),i!==null&&E4(i),r.blockedOn=u,!1;i.shift()}return!0}function _4(r,i,u){F0(r)&&u.delete(i)}function gv(){ch=!1,Li!==null&&F0(Li)&&(Li=null),Bi!==null&&F0(Bi)&&(Bi=null),Pi!==null&&F0(Pi)&&(Pi=null),zu.forEach(_4),Hu.forEach(_4)}function q0(r,i){r.blockedOn===i&&(r.blockedOn=null,ch||(ch=!0,e.unstable_scheduleCallback(e.unstable_NormalPriority,gv)))}var Y0=null;function S4(r){Y0!==r&&(Y0=r,e.unstable_scheduleCallback(e.unstable_NormalPriority,function(){Y0===r&&(Y0=null);for(var i=0;i<r.length;i+=3){var u=r[i],c=r[i+1],m=r[i+2];if(typeof c!="function"){if(oh(c||u)===null)continue;break}var g=pi(u);g!==null&&(r.splice(i,3),i-=3,of(g,{pending:!0,data:m,method:u.method,action:c},c,m))}}))}function qu(r){function i(H){return q0(H,r)}Li!==null&&q0(Li,r),Bi!==null&&q0(Bi,r),Pi!==null&&q0(Pi,r),zu.forEach(i),Hu.forEach(i);for(var u=0;u<Ui.length;u++){var c=Ui[u];c.blockedOn===r&&(c.blockedOn=null)}for(;0<Ui.length&&(u=Ui[0],u.blockedOn===null);)T4(u),u.blockedOn===null&&Ui.shift();if(u=(r.ownerDocument||r).$$reactFormReplay,u!=null)for(c=0;c<u.length;c+=3){var m=u[c],g=u[c+1],S=m[qe]||null;if(typeof g=="function")S||S4(u);else if(S){var w=null;if(g&&g.hasAttribute("formAction")){if(m=g,S=g[qe]||null)w=S.formAction;else if(oh(m)!==null)continue}else w=S.action;typeof w=="function"?u[c+1]=w:(u.splice(c,3),c-=3),S4(u)}}}function dh(r){this._internalRoot=r}G0.prototype.render=dh.prototype.render=function(r){var i=this._internalRoot;if(i===null)throw Error(a(409));var u=i.current,c=Rr();g4(u,c,r,i,null,null)},G0.prototype.unmount=dh.prototype.unmount=function(){var r=this._internalRoot;if(r!==null){this._internalRoot=null;var i=r.containerInfo;g4(r.current,2,null,r,null,null),x0(),i[Qt]=null}};function G0(r){this._internalRoot=r}G0.prototype.unstable_scheduleHydration=function(r){if(r){var i=Jt();r={blockedOn:null,target:r,priority:i};for(var u=0;u<Ui.length&&i!==0&&i<Ui[u].priority;u++);Ui.splice(u,0,r),u===0&&T4(r)}};var A4=t.version;if(A4!=="19.1.0")throw Error(a(527,A4,"19.1.0"));oe.findDOMNode=function(r){var i=r._reactInternals;if(i===void 0)throw typeof r.render=="function"?Error(a(188)):(r=Object.keys(r).join(","),Error(a(268,r)));return r=f(i),r=r!==null?h(r):null,r=r===null?null:r.stateNode,r};var bv={bundleType:0,version:"19.1.0",rendererPackageName:"react-dom",currentDispatcherRef:X,reconcilerVersion:"19.1.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var V0=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!V0.isDisabled&&V0.supportsFiber)try{re=V0.inject(bv),Te=V0}catch{}}return Gu.createRoot=function(r,i){if(!l(r))throw Error(a(299));var u=!1,c="",m=Hg,g=Fg,S=qg,w=null;return i!=null&&(i.unstable_strictMode===!0&&(u=!0),i.identifierPrefix!==void 0&&(c=i.identifierPrefix),i.onUncaughtError!==void 0&&(m=i.onUncaughtError),i.onCaughtError!==void 0&&(g=i.onCaughtError),i.onRecoverableError!==void 0&&(S=i.onRecoverableError),i.unstable_transitionCallbacks!==void 0&&(w=i.unstable_transitionCallbacks)),i=m4(r,1,!1,null,null,u,c,m,g,S,w,null),r[Qt]=i.current,jf(r),new dh(i)},Gu.hydrateRoot=function(r,i,u){if(!l(r))throw Error(a(299));var c=!1,m="",g=Hg,S=Fg,w=qg,H=null,Q=null;return u!=null&&(u.unstable_strictMode===!0&&(c=!0),u.identifierPrefix!==void 0&&(m=u.identifierPrefix),u.onUncaughtError!==void 0&&(g=u.onUncaughtError),u.onCaughtError!==void 0&&(S=u.onCaughtError),u.onRecoverableError!==void 0&&(w=u.onRecoverableError),u.unstable_transitionCallbacks!==void 0&&(H=u.unstable_transitionCallbacks),u.formState!==void 0&&(Q=u.formState)),i=m4(r,1,!0,i,u??null,c,m,g,S,w,H,Q),i.context=p4(null),u=i.current,c=Rr(),c=Me(c),m=Ti(c),m.callback=null,_i(u,m,c),u=c,i.current.lanes=u,fi(i,u),Ta(i),r[Qt]=i.current,jf(r),new G0(i)},Gu.version="19.1.0",Gu}var I4;function kv(){if(I4)return mh.exports;I4=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),mh.exports=xv(),mh.exports}var Nv=kv();function L4(e){const t=[],n=String(e||"");let a=n.indexOf(","),l=0,s=!1;for(;!s;){a===-1&&(a=n.length,s=!0);const o=n.slice(l,a).trim();(o||!s)&&t.push(o),l=a+1,a=n.indexOf(",",l)}return t}function b6(e,t){const n={};return(e[e.length-1]===""?[...e,""]:e).join((n.padRight?" ":"")+","+(n.padLeft===!1?"":" ")).trim()}const wv=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,Cv=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,Ov={};function B4(e,t){return(Ov.jsx?Cv:wv).test(e)}const Rv=/[ \t\n\f\r]/g;function Mv(e){return typeof e=="object"?e.type==="text"?P4(e.value):!1:P4(e)}function P4(e){return e.replace(Rv,"")===""}let vo=class{constructor(t,n,a){this.normal=n,this.property=t,a&&(this.space=a)}};vo.prototype.normal={};vo.prototype.property={};vo.prototype.space=void 0;function E6(e,t){const n={},a={};for(const l of e)Object.assign(n,l.property),Object.assign(a,l.normal);return new vo(n,a,t)}function ho(e){return e.toLowerCase()}let vr=class{constructor(t,n){this.attribute=n,this.property=t}};vr.prototype.attribute="";vr.prototype.booleanish=!1;vr.prototype.boolean=!1;vr.prototype.commaOrSpaceSeparated=!1;vr.prototype.commaSeparated=!1;vr.prototype.defined=!1;vr.prototype.mustUseProperty=!1;vr.prototype.number=!1;vr.prototype.overloadedBoolean=!1;vr.prototype.property="";vr.prototype.spaceSeparated=!1;vr.prototype.space=void 0;let Dv=0;const dt=Ml(),kn=Ml(),y1=Ml(),we=Ml(),jt=Ml(),ks=Ml(),Dr=Ml();function Ml(){return 2**++Dv}const v1=Object.freeze(Object.defineProperty({__proto__:null,boolean:dt,booleanish:kn,commaOrSpaceSeparated:Dr,commaSeparated:ks,number:we,overloadedBoolean:y1,spaceSeparated:jt},Symbol.toStringTag,{value:"Module"})),Eh=Object.keys(v1);let lm=class extends vr{constructor(t,n,a,l){let s=-1;if(super(t,n),U4(this,"space",l),typeof a=="number")for(;++s<Eh.length;){const o=Eh[s];U4(this,Eh[s],(a&v1[o])===v1[o])}}};lm.prototype.defined=!0;function U4(e,t,n){n&&(e[t]=n)}function Is(e){const t={},n={};for(const[a,l]of Object.entries(e.properties)){const s=new lm(a,e.transform(e.attributes||{},a),l,e.space);e.mustUseProperty&&e.mustUseProperty.includes(a)&&(s.mustUseProperty=!0),t[a]=s,n[ho(a)]=a,n[ho(s.attribute)]=a}return new vo(t,n,e.space)}const y6=Is({properties:{ariaActiveDescendant:null,ariaAtomic:kn,ariaAutoComplete:null,ariaBusy:kn,ariaChecked:kn,ariaColCount:we,ariaColIndex:we,ariaColSpan:we,ariaControls:jt,ariaCurrent:null,ariaDescribedBy:jt,ariaDetails:null,ariaDisabled:kn,ariaDropEffect:jt,ariaErrorMessage:null,ariaExpanded:kn,ariaFlowTo:jt,ariaGrabbed:kn,ariaHasPopup:null,ariaHidden:kn,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:jt,ariaLevel:we,ariaLive:null,ariaModal:kn,ariaMultiLine:kn,ariaMultiSelectable:kn,ariaOrientation:null,ariaOwns:jt,ariaPlaceholder:null,ariaPosInSet:we,ariaPressed:kn,ariaReadOnly:kn,ariaRelevant:null,ariaRequired:kn,ariaRoleDescription:jt,ariaRowCount:we,ariaRowIndex:we,ariaRowSpan:we,ariaSelected:kn,ariaSetSize:we,ariaSort:null,ariaValueMax:we,ariaValueMin:we,ariaValueNow:we,ariaValueText:null,role:null},transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()}});function v6(e,t){return t in e?e[t]:t}function T6(e,t){return v6(e,t.toLowerCase())}const Iv=Is({attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:ks,acceptCharset:jt,accessKey:jt,action:null,allow:null,allowFullScreen:dt,allowPaymentRequest:dt,allowUserMedia:dt,alt:null,as:null,async:dt,autoCapitalize:null,autoComplete:jt,autoFocus:dt,autoPlay:dt,blocking:jt,capture:null,charSet:null,checked:dt,cite:null,className:jt,cols:we,colSpan:null,content:null,contentEditable:kn,controls:dt,controlsList:jt,coords:we|ks,crossOrigin:null,data:null,dateTime:null,decoding:null,default:dt,defer:dt,dir:null,dirName:null,disabled:dt,download:y1,draggable:kn,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:dt,formTarget:null,headers:jt,height:we,hidden:y1,high:we,href:null,hrefLang:null,htmlFor:jt,httpEquiv:jt,id:null,imageSizes:null,imageSrcSet:null,inert:dt,inputMode:null,integrity:null,is:null,isMap:dt,itemId:null,itemProp:jt,itemRef:jt,itemScope:dt,itemType:jt,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:dt,low:we,manifest:null,max:null,maxLength:we,media:null,method:null,min:null,minLength:we,multiple:dt,muted:dt,name:null,nonce:null,noModule:dt,noValidate:dt,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:dt,optimum:we,pattern:null,ping:jt,placeholder:null,playsInline:dt,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:dt,referrerPolicy:null,rel:jt,required:dt,reversed:dt,rows:we,rowSpan:we,sandbox:jt,scope:null,scoped:dt,seamless:dt,selected:dt,shadowRootClonable:dt,shadowRootDelegatesFocus:dt,shadowRootMode:null,shape:null,size:we,sizes:null,slot:null,span:we,spellCheck:kn,src:null,srcDoc:null,srcLang:null,srcSet:null,start:we,step:null,style:null,tabIndex:we,target:null,title:null,translate:null,type:null,typeMustMatch:dt,useMap:null,value:kn,width:we,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:jt,axis:null,background:null,bgColor:null,border:we,borderColor:null,bottomMargin:we,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:dt,declare:dt,event:null,face:null,frame:null,frameBorder:null,hSpace:we,leftMargin:we,link:null,longDesc:null,lowSrc:null,marginHeight:we,marginWidth:we,noResize:dt,noHref:dt,noShade:dt,noWrap:dt,object:null,profile:null,prompt:null,rev:null,rightMargin:we,rules:null,scheme:null,scrolling:kn,standby:null,summary:null,text:null,topMargin:we,valueType:null,version:null,vAlign:null,vLink:null,vSpace:we,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:dt,disableRemotePlayback:dt,prefix:null,property:null,results:we,security:null,unselectable:null},space:"html",transform:T6}),Lv=Is({attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},properties:{about:Dr,accentHeight:we,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:we,amplitude:we,arabicForm:null,ascent:we,attributeName:null,attributeType:null,azimuth:we,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:we,by:null,calcMode:null,capHeight:we,className:jt,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:we,diffuseConstant:we,direction:null,display:null,dur:null,divisor:we,dominantBaseline:null,download:dt,dx:null,dy:null,edgeMode:null,editable:null,elevation:we,enableBackground:null,end:null,event:null,exponent:we,externalResourcesRequired:null,fill:null,fillOpacity:we,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:ks,g2:ks,glyphName:ks,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:we,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:we,horizOriginX:we,horizOriginY:we,id:null,ideographic:we,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:we,k:we,k1:we,k2:we,k3:we,k4:we,kernelMatrix:Dr,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:we,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:we,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:we,overlineThickness:we,paintOrder:null,panose1:null,path:null,pathLength:we,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:jt,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:we,pointsAtY:we,pointsAtZ:we,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:Dr,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:Dr,rev:Dr,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:Dr,requiredFeatures:Dr,requiredFonts:Dr,requiredFormats:Dr,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:we,specularExponent:we,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:we,strikethroughThickness:we,string:null,stroke:null,strokeDashArray:Dr,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:we,strokeOpacity:we,strokeWidth:null,style:null,surfaceScale:we,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:Dr,tabIndex:we,tableValues:null,target:null,targetX:we,targetY:we,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:Dr,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:we,underlineThickness:we,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:we,values:null,vAlphabetic:we,vMathematical:we,vectorEffect:null,vHanging:we,vIdeographic:we,version:null,vertAdvY:we,vertOriginX:we,vertOriginY:we,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:we,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null},space:"svg",transform:v6}),_6=Is({properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null},space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()}}),S6=Is({attributes:{xmlnsxlink:"xmlns:xlink"},properties:{xmlnsXLink:null,xmlns:null},space:"xmlns",transform:T6}),A6=Is({properties:{xmlBase:null,xmlLang:null,xmlSpace:null},space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()}}),Bv={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},Pv=/[A-Z]/g,z4=/-[a-z]/g,Uv=/^data[-\w.:]+$/i;function sm(e,t){const n=ho(t);let a=t,l=vr;if(n in e.normal)return e.property[e.normal[n]];if(n.length>4&&n.slice(0,4)==="data"&&Uv.test(t)){if(t.charAt(4)==="-"){const s=t.slice(5).replace(z4,Hv);a="data"+s.charAt(0).toUpperCase()+s.slice(1)}else{const s=t.slice(4);if(!z4.test(s)){let o=s.replace(Pv,zv);o.charAt(0)!=="-"&&(o="-"+o),t="data"+o}}l=lm}return new l(a,t)}function zv(e){return"-"+e.toLowerCase()}function Hv(e){return e.charAt(1).toUpperCase()}const Fc=E6([y6,Iv,_6,S6,A6],"html"),Ls=E6([y6,Lv,_6,S6,A6],"svg");function H4(e){const t=String(e||"").trim();return t?t.split(/[ \t\n\r\f]+/g):[]}function x6(e){return e.join(" ").trim()}var ps={},yh,F4;function Fv(){if(F4)return yh;F4=1;var e=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,t=/\n/g,n=/^\s*/,a=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,l=/^:\s*/,s=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,o=/^[;\s]*/,d=/^\s+|\s+$/g,f=`
`,h="/",p="*",E="",T="comment",v="declaration";yh=function(N,D){if(typeof N!="string")throw new TypeError("First argument must be a string");if(!N)return[];D=D||{};var C=1,I=1;function F(Se){var fe=Se.match(t);fe&&(C+=fe.length);var ye=Se.lastIndexOf(f);I=~ye?Se.length-ye:I+Se.length}function J(){var Se={line:C,column:I};return function(fe){return fe.position=new K(Se),ae(),fe}}function K(Se){this.start=Se,this.end={line:C,column:I},this.source=D.source}K.prototype.content=N;function U(Se){var fe=new Error(D.source+":"+C+":"+I+": "+Se);if(fe.reason=Se,fe.filename=D.source,fe.line=C,fe.column=I,fe.source=N,!D.silent)throw fe}function le(Se){var fe=Se.exec(N);if(fe){var ye=fe[0];return F(ye),N=N.slice(ye.length),fe}}function ae(){le(n)}function se(Se){var fe;for(Se=Se||[];fe=G();)fe!==!1&&Se.push(fe);return Se}function G(){var Se=J();if(!(h!=N.charAt(0)||p!=N.charAt(1))){for(var fe=2;E!=N.charAt(fe)&&(p!=N.charAt(fe)||h!=N.charAt(fe+1));)++fe;if(fe+=2,E===N.charAt(fe-1))return U("End of comment missing");var ye=N.slice(2,fe-2);return I+=2,F(ye),N=N.slice(fe),I+=2,Se({type:T,comment:ye})}}function ge(){var Se=J(),fe=le(a);if(fe){if(G(),!le(l))return U("property missing ':'");var ye=le(s),X=Se({type:v,property:x(fe[0].replace(e,E)),value:ye?x(ye[0].replace(e,E)):E});return le(o),X}}function ce(){var Se=[];se(Se);for(var fe;fe=ge();)fe!==!1&&(Se.push(fe),se(Se));return Se}return ae(),ce()};function x(N){return N?N.replace(d,E):E}return yh}var q4;function qv(){if(q4)return ps;q4=1;var e=ps&&ps.__importDefault||function(a){return a&&a.__esModule?a:{default:a}};Object.defineProperty(ps,"__esModule",{value:!0}),ps.default=n;var t=e(Fv());function n(a,l){var s=null;if(!a||typeof a!="string")return s;var o=(0,t.default)(a),d=typeof l=="function";return o.forEach(function(f){if(f.type==="declaration"){var h=f.property,p=f.value;d?l(h,p,f):p&&(s=s||{},s[h]=p)}}),s}return ps}var Vu={},Y4;function Yv(){if(Y4)return Vu;Y4=1,Object.defineProperty(Vu,"__esModule",{value:!0}),Vu.camelCase=void 0;var e=/^--[a-zA-Z0-9_-]+$/,t=/-([a-z])/g,n=/^[^-]+$/,a=/^-(webkit|moz|ms|o|khtml)-/,l=/^-(ms)-/,s=function(h){return!h||n.test(h)||e.test(h)},o=function(h,p){return p.toUpperCase()},d=function(h,p){return"".concat(p,"-")},f=function(h,p){return p===void 0&&(p={}),s(h)?h:(h=h.toLowerCase(),p.reactCompat?h=h.replace(l,d):h=h.replace(a,d),h.replace(t,o))};return Vu.camelCase=f,Vu}var Ku,G4;function Gv(){if(G4)return Ku;G4=1;var e=Ku&&Ku.__importDefault||function(l){return l&&l.__esModule?l:{default:l}},t=e(qv()),n=Yv();function a(l,s){var o={};return!l||typeof l!="string"||(0,t.default)(l,function(d,f){d&&f&&(o[(0,n.camelCase)(d,s)]=f)}),o}return a.default=a,Ku=a,Ku}var Vv=Gv();const Kv=zc(Vv),qc=k6("end"),Oa=k6("start");function k6(e){return t;function t(n){const a=n&&n.position&&n.position[e]||{};if(typeof a.line=="number"&&a.line>0&&typeof a.column=="number"&&a.column>0)return{line:a.line,column:a.column,offset:typeof a.offset=="number"&&a.offset>-1?a.offset:void 0}}}function jv(e){const t=Oa(e),n=qc(e);if(t&&n)return{start:t,end:n}}function eo(e){return!e||typeof e!="object"?"":"position"in e||"type"in e?V4(e.position):"start"in e||"end"in e?V4(e):"line"in e||"column"in e?T1(e):""}function T1(e){return K4(e&&e.line)+":"+K4(e&&e.column)}function V4(e){return T1(e&&e.start)+"-"+T1(e&&e.end)}function K4(e){return e&&typeof e=="number"?e:1}class Wn extends Error{constructor(t,n,a){super(),typeof n=="string"&&(a=n,n=void 0);let l="",s={},o=!1;if(n&&("line"in n&&"column"in n?s={place:n}:"start"in n&&"end"in n?s={place:n}:"type"in n?s={ancestors:[n],place:n.position}:s={...n}),typeof t=="string"?l=t:!s.cause&&t&&(o=!0,l=t.message,s.cause=t),!s.ruleId&&!s.source&&typeof a=="string"){const f=a.indexOf(":");f===-1?s.ruleId=a:(s.source=a.slice(0,f),s.ruleId=a.slice(f+1))}if(!s.place&&s.ancestors&&s.ancestors){const f=s.ancestors[s.ancestors.length-1];f&&(s.place=f.position)}const d=s.place&&"start"in s.place?s.place.start:s.place;this.ancestors=s.ancestors||void 0,this.cause=s.cause||void 0,this.column=d?d.column:void 0,this.fatal=void 0,this.file,this.message=l,this.line=d?d.line:void 0,this.name=eo(s.place)||"1:1",this.place=s.place||void 0,this.reason=this.message,this.ruleId=s.ruleId||void 0,this.source=s.source||void 0,this.stack=o&&s.cause&&typeof s.cause.stack=="string"?s.cause.stack:"",this.actual,this.expected,this.note,this.url}}Wn.prototype.file="";Wn.prototype.name="";Wn.prototype.reason="";Wn.prototype.message="";Wn.prototype.stack="";Wn.prototype.column=void 0;Wn.prototype.line=void 0;Wn.prototype.ancestors=void 0;Wn.prototype.cause=void 0;Wn.prototype.fatal=void 0;Wn.prototype.place=void 0;Wn.prototype.ruleId=void 0;Wn.prototype.source=void 0;const um={}.hasOwnProperty,Xv=new Map,$v=/[A-Z]/g,Wv=new Set(["table","tbody","thead","tfoot","tr"]),Qv=new Set(["td","th"]),N6="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function Zv(e,t){if(!t||t.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const n=t.filePath||void 0;let a;if(t.development){if(typeof t.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");a=lT(n,t.jsxDEV)}else{if(typeof t.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof t.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");a=iT(n,t.jsx,t.jsxs)}const l={Fragment:t.Fragment,ancestors:[],components:t.components||{},create:a,elementAttributeNameCase:t.elementAttributeNameCase||"react",evaluater:t.createEvaluater?t.createEvaluater():void 0,filePath:n,ignoreInvalidStyle:t.ignoreInvalidStyle||!1,passKeys:t.passKeys!==!1,passNode:t.passNode||!1,schema:t.space==="svg"?Ls:Fc,stylePropertyNameCase:t.stylePropertyNameCase||"dom",tableCellAlignToStyle:t.tableCellAlignToStyle!==!1},s=w6(l,e,void 0);return s&&typeof s!="string"?s:l.create(e,l.Fragment,{children:s||void 0},void 0)}function w6(e,t,n){if(t.type==="element")return Jv(e,t,n);if(t.type==="mdxFlowExpression"||t.type==="mdxTextExpression")return eT(e,t);if(t.type==="mdxJsxFlowElement"||t.type==="mdxJsxTextElement")return nT(e,t,n);if(t.type==="mdxjsEsm")return tT(e,t);if(t.type==="root")return rT(e,t,n);if(t.type==="text")return aT(e,t)}function Jv(e,t,n){const a=e.schema;let l=a;t.tagName.toLowerCase()==="svg"&&a.space==="html"&&(l=Ls,e.schema=l),e.ancestors.push(t);const s=O6(e,t.tagName,!1),o=sT(e,t);let d=cm(e,t);return Wv.has(t.tagName)&&(d=d.filter(function(f){return typeof f=="string"?!Mv(f):!0})),C6(e,o,s,t),om(o,d),e.ancestors.pop(),e.schema=a,e.create(t,s,o,n)}function eT(e,t){if(t.data&&t.data.estree&&e.evaluater){const a=t.data.estree.body[0];return a.type,e.evaluater.evaluateExpression(a.expression)}mo(e,t.position)}function tT(e,t){if(t.data&&t.data.estree&&e.evaluater)return e.evaluater.evaluateProgram(t.data.estree);mo(e,t.position)}function nT(e,t,n){const a=e.schema;let l=a;t.name==="svg"&&a.space==="html"&&(l=Ls,e.schema=l),e.ancestors.push(t);const s=t.name===null?e.Fragment:O6(e,t.name,!0),o=uT(e,t),d=cm(e,t);return C6(e,o,s,t),om(o,d),e.ancestors.pop(),e.schema=a,e.create(t,s,o,n)}function rT(e,t,n){const a={};return om(a,cm(e,t)),e.create(t,e.Fragment,a,n)}function aT(e,t){return t.value}function C6(e,t,n,a){typeof n!="string"&&n!==e.Fragment&&e.passNode&&(t.node=a)}function om(e,t){if(t.length>0){const n=t.length>1?t:t[0];n&&(e.children=n)}}function iT(e,t,n){return a;function a(l,s,o,d){const h=Array.isArray(o.children)?n:t;return d?h(s,o,d):h(s,o)}}function lT(e,t){return n;function n(a,l,s,o){const d=Array.isArray(s.children),f=Oa(a);return t(l,s,o,d,{columnNumber:f?f.column-1:void 0,fileName:e,lineNumber:f?f.line:void 0},void 0)}}function sT(e,t){const n={};let a,l;for(l in t.properties)if(l!=="children"&&um.call(t.properties,l)){const s=oT(e,l,t.properties[l]);if(s){const[o,d]=s;e.tableCellAlignToStyle&&o==="align"&&typeof d=="string"&&Qv.has(t.tagName)?a=d:n[o]=d}}if(a){const s=n.style||(n.style={});s[e.stylePropertyNameCase==="css"?"text-align":"textAlign"]=a}return n}function uT(e,t){const n={};for(const a of t.attributes)if(a.type==="mdxJsxExpressionAttribute")if(a.data&&a.data.estree&&e.evaluater){const s=a.data.estree.body[0];s.type;const o=s.expression;o.type;const d=o.properties[0];d.type,Object.assign(n,e.evaluater.evaluateExpression(d.argument))}else mo(e,t.position);else{const l=a.name;let s;if(a.value&&typeof a.value=="object")if(a.value.data&&a.value.data.estree&&e.evaluater){const d=a.value.data.estree.body[0];d.type,s=e.evaluater.evaluateExpression(d.expression)}else mo(e,t.position);else s=a.value===null?!0:a.value;n[l]=s}return n}function cm(e,t){const n=[];let a=-1;const l=e.passKeys?new Map:Xv;for(;++a<t.children.length;){const s=t.children[a];let o;if(e.passKeys){const f=s.type==="element"?s.tagName:s.type==="mdxJsxFlowElement"||s.type==="mdxJsxTextElement"?s.name:void 0;if(f){const h=l.get(f)||0;o=f+"-"+h,l.set(f,h+1)}}const d=w6(e,s,o);d!==void 0&&n.push(d)}return n}function oT(e,t,n){const a=sm(e.schema,t);if(!(n==null||typeof n=="number"&&Number.isNaN(n))){if(Array.isArray(n)&&(n=a.commaSeparated?b6(n):x6(n)),a.property==="style"){let l=typeof n=="object"?n:cT(e,String(n));return e.stylePropertyNameCase==="css"&&(l=dT(l)),["style",l]}return[e.elementAttributeNameCase==="react"&&a.space?Bv[a.property]||a.property:a.attribute,n]}}function cT(e,t){try{return Kv(t,{reactCompat:!0})}catch(n){if(e.ignoreInvalidStyle)return{};const a=n,l=new Wn("Cannot parse `style` attribute",{ancestors:e.ancestors,cause:a,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw l.file=e.filePath||void 0,l.url=N6+"#cannot-parse-style-attribute",l}}function O6(e,t,n){let a;if(!n)a={type:"Literal",value:t};else if(t.includes(".")){const l=t.split(".");let s=-1,o;for(;++s<l.length;){const d=B4(l[s])?{type:"Identifier",name:l[s]}:{type:"Literal",value:l[s]};o=o?{type:"MemberExpression",object:o,property:d,computed:!!(s&&d.type==="Literal"),optional:!1}:d}a=o}else a=B4(t)&&!/^[a-z]/.test(t)?{type:"Identifier",name:t}:{type:"Literal",value:t};if(a.type==="Literal"){const l=a.value;return um.call(e.components,l)?e.components[l]:l}if(e.evaluater)return e.evaluater.evaluateExpression(a);mo(e)}function mo(e,t){const n=new Wn("Cannot handle MDX estrees without `createEvaluater`",{ancestors:e.ancestors,place:t,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw n.file=e.filePath||void 0,n.url=N6+"#cannot-handle-mdx-estrees-without-createevaluater",n}function dT(e){const t={};let n;for(n in e)um.call(e,n)&&(t[fT(n)]=e[n]);return t}function fT(e){let t=e.replace($v,hT);return t.slice(0,3)==="ms-"&&(t="-"+t),t}function hT(e){return"-"+e.toLowerCase()}const vh={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]},mT={};function dm(e,t){const n=mT,a=typeof n.includeImageAlt=="boolean"?n.includeImageAlt:!0,l=typeof n.includeHtml=="boolean"?n.includeHtml:!0;return R6(e,a,l)}function R6(e,t,n){if(pT(e)){if("value"in e)return e.type==="html"&&!n?"":e.value;if(t&&"alt"in e&&e.alt)return e.alt;if("children"in e)return j4(e.children,t,n)}return Array.isArray(e)?j4(e,t,n):""}function j4(e,t,n){const a=[];let l=-1;for(;++l<e.length;)a[l]=R6(e[l],t,n);return a.join("")}function pT(e){return!!(e&&typeof e=="object")}const X4=document.createElement("i");function fm(e){const t="&"+e+";";X4.innerHTML=t;const n=X4.textContent;return n.charCodeAt(n.length-1)===59&&e!=="semi"||n===t?!1:n}function Pr(e,t,n,a){const l=e.length;let s=0,o;if(t<0?t=-t>l?0:l+t:t=t>l?l:t,n=n>0?n:0,a.length<1e4)o=Array.from(a),o.unshift(t,n),e.splice(...o);else for(n&&e.splice(t,n);s<a.length;)o=a.slice(s,s+1e4),o.unshift(t,0),e.splice(...o),s+=1e4,t+=1e4}function $r(e,t){return e.length>0?(Pr(e,e.length,0,t),e):t}const $4={}.hasOwnProperty;function M6(e){const t={};let n=-1;for(;++n<e.length;)gT(t,e[n]);return t}function gT(e,t){let n;for(n in t){const l=($4.call(e,n)?e[n]:void 0)||(e[n]={}),s=t[n];let o;if(s)for(o in s){$4.call(l,o)||(l[o]=[]);const d=s[o];bT(l[o],Array.isArray(d)?d:d?[d]:[])}}}function bT(e,t){let n=-1;const a=[];for(;++n<t.length;)(t[n].add==="after"?e:a).push(t[n]);Pr(e,0,0,a)}function D6(e,t){const n=Number.parseInt(e,t);return n<9||n===11||n>13&&n<32||n>126&&n<160||n>55295&&n<57344||n>64975&&n<65008||(n&65535)===65535||(n&65535)===65534||n>1114111?"�":String.fromCodePoint(n)}function ha(e){return e.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const lr=el(/[A-Za-z]/),$n=el(/[\dA-Za-z]/),ET=el(/[#-'*+\--9=?A-Z^-~]/);function xc(e){return e!==null&&(e<32||e===127)}const _1=el(/\d/),yT=el(/[\dA-Fa-f]/),vT=el(/[!-/:-@[-`{-~]/);function Ye(e){return e!==null&&e<-2}function Gt(e){return e!==null&&(e<0||e===32)}function St(e){return e===-2||e===-1||e===32}const Yc=el(new RegExp("\\p{P}|\\p{S}","u")),Rl=el(/\s/);function el(e){return t;function t(n){return n!==null&&n>-1&&e.test(String.fromCharCode(n))}}function Bs(e){const t=[];let n=-1,a=0,l=0;for(;++n<e.length;){const s=e.charCodeAt(n);let o="";if(s===37&&$n(e.charCodeAt(n+1))&&$n(e.charCodeAt(n+2)))l=2;else if(s<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(s))||(o=String.fromCharCode(s));else if(s>55295&&s<57344){const d=e.charCodeAt(n+1);s<56320&&d>56319&&d<57344?(o=String.fromCharCode(s,d),l=1):o="�"}else o=String.fromCharCode(s);o&&(t.push(e.slice(a,n),encodeURIComponent(o)),a=n+l+1,o=""),l&&(n+=l,l=0)}return t.join("")+e.slice(a)}function yt(e,t,n,a){const l=a?a-1:Number.POSITIVE_INFINITY;let s=0;return o;function o(f){return St(f)?(e.enter(n),d(f)):t(f)}function d(f){return St(f)&&s++<l?(e.consume(f),d):(e.exit(n),t(f))}}const TT={tokenize:_T};function _T(e){const t=e.attempt(this.parser.constructs.contentInitial,a,l);let n;return t;function a(d){if(d===null){e.consume(d);return}return e.enter("lineEnding"),e.consume(d),e.exit("lineEnding"),yt(e,t,"linePrefix")}function l(d){return e.enter("paragraph"),s(d)}function s(d){const f=e.enter("chunkText",{contentType:"text",previous:n});return n&&(n.next=f),n=f,o(d)}function o(d){if(d===null){e.exit("chunkText"),e.exit("paragraph"),e.consume(d);return}return Ye(d)?(e.consume(d),e.exit("chunkText"),s):(e.consume(d),o)}}const ST={tokenize:AT},W4={tokenize:xT};function AT(e){const t=this,n=[];let a=0,l,s,o;return d;function d(F){if(a<n.length){const J=n[a];return t.containerState=J[1],e.attempt(J[0].continuation,f,h)(F)}return h(F)}function f(F){if(a++,t.containerState._closeFlow){t.containerState._closeFlow=void 0,l&&I();const J=t.events.length;let K=J,U;for(;K--;)if(t.events[K][0]==="exit"&&t.events[K][1].type==="chunkFlow"){U=t.events[K][1].end;break}C(a);let le=J;for(;le<t.events.length;)t.events[le][1].end={...U},le++;return Pr(t.events,K+1,0,t.events.slice(J)),t.events.length=le,h(F)}return d(F)}function h(F){if(a===n.length){if(!l)return T(F);if(l.currentConstruct&&l.currentConstruct.concrete)return x(F);t.interrupt=!!(l.currentConstruct&&!l._gfmTableDynamicInterruptHack)}return t.containerState={},e.check(W4,p,E)(F)}function p(F){return l&&I(),C(a),T(F)}function E(F){return t.parser.lazy[t.now().line]=a!==n.length,o=t.now().offset,x(F)}function T(F){return t.containerState={},e.attempt(W4,v,x)(F)}function v(F){return a++,n.push([t.currentConstruct,t.containerState]),T(F)}function x(F){if(F===null){l&&I(),C(0),e.consume(F);return}return l=l||t.parser.flow(t.now()),e.enter("chunkFlow",{_tokenizer:l,contentType:"flow",previous:s}),N(F)}function N(F){if(F===null){D(e.exit("chunkFlow"),!0),C(0),e.consume(F);return}return Ye(F)?(e.consume(F),D(e.exit("chunkFlow")),a=0,t.interrupt=void 0,d):(e.consume(F),N)}function D(F,J){const K=t.sliceStream(F);if(J&&K.push(null),F.previous=s,s&&(s.next=F),s=F,l.defineSkip(F.start),l.write(K),t.parser.lazy[F.start.line]){let U=l.events.length;for(;U--;)if(l.events[U][1].start.offset<o&&(!l.events[U][1].end||l.events[U][1].end.offset>o))return;const le=t.events.length;let ae=le,se,G;for(;ae--;)if(t.events[ae][0]==="exit"&&t.events[ae][1].type==="chunkFlow"){if(se){G=t.events[ae][1].end;break}se=!0}for(C(a),U=le;U<t.events.length;)t.events[U][1].end={...G},U++;Pr(t.events,ae+1,0,t.events.slice(le)),t.events.length=U}}function C(F){let J=n.length;for(;J-- >F;){const K=n[J];t.containerState=K[1],K[0].exit.call(t,e)}n.length=F}function I(){l.write([null]),s=void 0,l=void 0,t.containerState._closeFlow=void 0}}function xT(e,t,n){return yt(e,e.attempt(this.parser.constructs.document,t,n),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function Cs(e){if(e===null||Gt(e)||Rl(e))return 1;if(Yc(e))return 2}function Gc(e,t,n){const a=[];let l=-1;for(;++l<e.length;){const s=e[l].resolveAll;s&&!a.includes(s)&&(t=s(t,n),a.push(s))}return t}const S1={name:"attention",resolveAll:kT,tokenize:NT};function kT(e,t){let n=-1,a,l,s,o,d,f,h,p;for(;++n<e.length;)if(e[n][0]==="enter"&&e[n][1].type==="attentionSequence"&&e[n][1]._close){for(a=n;a--;)if(e[a][0]==="exit"&&e[a][1].type==="attentionSequence"&&e[a][1]._open&&t.sliceSerialize(e[a][1]).charCodeAt(0)===t.sliceSerialize(e[n][1]).charCodeAt(0)){if((e[a][1]._close||e[n][1]._open)&&(e[n][1].end.offset-e[n][1].start.offset)%3&&!((e[a][1].end.offset-e[a][1].start.offset+e[n][1].end.offset-e[n][1].start.offset)%3))continue;f=e[a][1].end.offset-e[a][1].start.offset>1&&e[n][1].end.offset-e[n][1].start.offset>1?2:1;const E={...e[a][1].end},T={...e[n][1].start};Q4(E,-f),Q4(T,f),o={type:f>1?"strongSequence":"emphasisSequence",start:E,end:{...e[a][1].end}},d={type:f>1?"strongSequence":"emphasisSequence",start:{...e[n][1].start},end:T},s={type:f>1?"strongText":"emphasisText",start:{...e[a][1].end},end:{...e[n][1].start}},l={type:f>1?"strong":"emphasis",start:{...o.start},end:{...d.end}},e[a][1].end={...o.start},e[n][1].start={...d.end},h=[],e[a][1].end.offset-e[a][1].start.offset&&(h=$r(h,[["enter",e[a][1],t],["exit",e[a][1],t]])),h=$r(h,[["enter",l,t],["enter",o,t],["exit",o,t],["enter",s,t]]),h=$r(h,Gc(t.parser.constructs.insideSpan.null,e.slice(a+1,n),t)),h=$r(h,[["exit",s,t],["enter",d,t],["exit",d,t],["exit",l,t]]),e[n][1].end.offset-e[n][1].start.offset?(p=2,h=$r(h,[["enter",e[n][1],t],["exit",e[n][1],t]])):p=0,Pr(e,a-1,n-a+3,h),n=a+h.length-p-2;break}}for(n=-1;++n<e.length;)e[n][1].type==="attentionSequence"&&(e[n][1].type="data");return e}function NT(e,t){const n=this.parser.constructs.attentionMarkers.null,a=this.previous,l=Cs(a);let s;return o;function o(f){return s=f,e.enter("attentionSequence"),d(f)}function d(f){if(f===s)return e.consume(f),d;const h=e.exit("attentionSequence"),p=Cs(f),E=!p||p===2&&l||n.includes(f),T=!l||l===2&&p||n.includes(a);return h._open=!!(s===42?E:E&&(l||!T)),h._close=!!(s===42?T:T&&(p||!E)),t(f)}}function Q4(e,t){e.column+=t,e.offset+=t,e._bufferIndex+=t}const wT={name:"autolink",tokenize:CT};function CT(e,t,n){let a=0;return l;function l(v){return e.enter("autolink"),e.enter("autolinkMarker"),e.consume(v),e.exit("autolinkMarker"),e.enter("autolinkProtocol"),s}function s(v){return lr(v)?(e.consume(v),o):v===64?n(v):h(v)}function o(v){return v===43||v===45||v===46||$n(v)?(a=1,d(v)):h(v)}function d(v){return v===58?(e.consume(v),a=0,f):(v===43||v===45||v===46||$n(v))&&a++<32?(e.consume(v),d):(a=0,h(v))}function f(v){return v===62?(e.exit("autolinkProtocol"),e.enter("autolinkMarker"),e.consume(v),e.exit("autolinkMarker"),e.exit("autolink"),t):v===null||v===32||v===60||xc(v)?n(v):(e.consume(v),f)}function h(v){return v===64?(e.consume(v),p):ET(v)?(e.consume(v),h):n(v)}function p(v){return $n(v)?E(v):n(v)}function E(v){return v===46?(e.consume(v),a=0,p):v===62?(e.exit("autolinkProtocol").type="autolinkEmail",e.enter("autolinkMarker"),e.consume(v),e.exit("autolinkMarker"),e.exit("autolink"),t):T(v)}function T(v){if((v===45||$n(v))&&a++<63){const x=v===45?T:E;return e.consume(v),x}return n(v)}}const To={partial:!0,tokenize:OT};function OT(e,t,n){return a;function a(s){return St(s)?yt(e,l,"linePrefix")(s):l(s)}function l(s){return s===null||Ye(s)?t(s):n(s)}}const I6={continuation:{tokenize:MT},exit:DT,name:"blockQuote",tokenize:RT};function RT(e,t,n){const a=this;return l;function l(o){if(o===62){const d=a.containerState;return d.open||(e.enter("blockQuote",{_container:!0}),d.open=!0),e.enter("blockQuotePrefix"),e.enter("blockQuoteMarker"),e.consume(o),e.exit("blockQuoteMarker"),s}return n(o)}function s(o){return St(o)?(e.enter("blockQuotePrefixWhitespace"),e.consume(o),e.exit("blockQuotePrefixWhitespace"),e.exit("blockQuotePrefix"),t):(e.exit("blockQuotePrefix"),t(o))}}function MT(e,t,n){const a=this;return l;function l(o){return St(o)?yt(e,s,"linePrefix",a.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(o):s(o)}function s(o){return e.attempt(I6,t,n)(o)}}function DT(e){e.exit("blockQuote")}const L6={name:"characterEscape",tokenize:IT};function IT(e,t,n){return a;function a(s){return e.enter("characterEscape"),e.enter("escapeMarker"),e.consume(s),e.exit("escapeMarker"),l}function l(s){return vT(s)?(e.enter("characterEscapeValue"),e.consume(s),e.exit("characterEscapeValue"),e.exit("characterEscape"),t):n(s)}}const B6={name:"characterReference",tokenize:LT};function LT(e,t,n){const a=this;let l=0,s,o;return d;function d(E){return e.enter("characterReference"),e.enter("characterReferenceMarker"),e.consume(E),e.exit("characterReferenceMarker"),f}function f(E){return E===35?(e.enter("characterReferenceMarkerNumeric"),e.consume(E),e.exit("characterReferenceMarkerNumeric"),h):(e.enter("characterReferenceValue"),s=31,o=$n,p(E))}function h(E){return E===88||E===120?(e.enter("characterReferenceMarkerHexadecimal"),e.consume(E),e.exit("characterReferenceMarkerHexadecimal"),e.enter("characterReferenceValue"),s=6,o=yT,p):(e.enter("characterReferenceValue"),s=7,o=_1,p(E))}function p(E){if(E===59&&l){const T=e.exit("characterReferenceValue");return o===$n&&!fm(a.sliceSerialize(T))?n(E):(e.enter("characterReferenceMarker"),e.consume(E),e.exit("characterReferenceMarker"),e.exit("characterReference"),t)}return o(E)&&l++<s?(e.consume(E),p):n(E)}}const Z4={partial:!0,tokenize:PT},J4={concrete:!0,name:"codeFenced",tokenize:BT};function BT(e,t,n){const a=this,l={partial:!0,tokenize:K};let s=0,o=0,d;return f;function f(U){return h(U)}function h(U){const le=a.events[a.events.length-1];return s=le&&le[1].type==="linePrefix"?le[2].sliceSerialize(le[1],!0).length:0,d=U,e.enter("codeFenced"),e.enter("codeFencedFence"),e.enter("codeFencedFenceSequence"),p(U)}function p(U){return U===d?(o++,e.consume(U),p):o<3?n(U):(e.exit("codeFencedFenceSequence"),St(U)?yt(e,E,"whitespace")(U):E(U))}function E(U){return U===null||Ye(U)?(e.exit("codeFencedFence"),a.interrupt?t(U):e.check(Z4,N,J)(U)):(e.enter("codeFencedFenceInfo"),e.enter("chunkString",{contentType:"string"}),T(U))}function T(U){return U===null||Ye(U)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),E(U)):St(U)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),yt(e,v,"whitespace")(U)):U===96&&U===d?n(U):(e.consume(U),T)}function v(U){return U===null||Ye(U)?E(U):(e.enter("codeFencedFenceMeta"),e.enter("chunkString",{contentType:"string"}),x(U))}function x(U){return U===null||Ye(U)?(e.exit("chunkString"),e.exit("codeFencedFenceMeta"),E(U)):U===96&&U===d?n(U):(e.consume(U),x)}function N(U){return e.attempt(l,J,D)(U)}function D(U){return e.enter("lineEnding"),e.consume(U),e.exit("lineEnding"),C}function C(U){return s>0&&St(U)?yt(e,I,"linePrefix",s+1)(U):I(U)}function I(U){return U===null||Ye(U)?e.check(Z4,N,J)(U):(e.enter("codeFlowValue"),F(U))}function F(U){return U===null||Ye(U)?(e.exit("codeFlowValue"),I(U)):(e.consume(U),F)}function J(U){return e.exit("codeFenced"),t(U)}function K(U,le,ae){let se=0;return G;function G(ye){return U.enter("lineEnding"),U.consume(ye),U.exit("lineEnding"),ge}function ge(ye){return U.enter("codeFencedFence"),St(ye)?yt(U,ce,"linePrefix",a.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(ye):ce(ye)}function ce(ye){return ye===d?(U.enter("codeFencedFenceSequence"),Se(ye)):ae(ye)}function Se(ye){return ye===d?(se++,U.consume(ye),Se):se>=o?(U.exit("codeFencedFenceSequence"),St(ye)?yt(U,fe,"whitespace")(ye):fe(ye)):ae(ye)}function fe(ye){return ye===null||Ye(ye)?(U.exit("codeFencedFence"),le(ye)):ae(ye)}}}function PT(e,t,n){const a=this;return l;function l(o){return o===null?n(o):(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),s)}function s(o){return a.parser.lazy[a.now().line]?n(o):t(o)}}const Th={name:"codeIndented",tokenize:zT},UT={partial:!0,tokenize:HT};function zT(e,t,n){const a=this;return l;function l(h){return e.enter("codeIndented"),yt(e,s,"linePrefix",5)(h)}function s(h){const p=a.events[a.events.length-1];return p&&p[1].type==="linePrefix"&&p[2].sliceSerialize(p[1],!0).length>=4?o(h):n(h)}function o(h){return h===null?f(h):Ye(h)?e.attempt(UT,o,f)(h):(e.enter("codeFlowValue"),d(h))}function d(h){return h===null||Ye(h)?(e.exit("codeFlowValue"),o(h)):(e.consume(h),d)}function f(h){return e.exit("codeIndented"),t(h)}}function HT(e,t,n){const a=this;return l;function l(o){return a.parser.lazy[a.now().line]?n(o):Ye(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),l):yt(e,s,"linePrefix",5)(o)}function s(o){const d=a.events[a.events.length-1];return d&&d[1].type==="linePrefix"&&d[2].sliceSerialize(d[1],!0).length>=4?t(o):Ye(o)?l(o):n(o)}}const FT={name:"codeText",previous:YT,resolve:qT,tokenize:GT};function qT(e){let t=e.length-4,n=3,a,l;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(a=n;++a<t;)if(e[a][1].type==="codeTextData"){e[n][1].type="codeTextPadding",e[t][1].type="codeTextPadding",n+=2,t-=2;break}}for(a=n-1,t++;++a<=t;)l===void 0?a!==t&&e[a][1].type!=="lineEnding"&&(l=a):(a===t||e[a][1].type==="lineEnding")&&(e[l][1].type="codeTextData",a!==l+2&&(e[l][1].end=e[a-1][1].end,e.splice(l+2,a-l-2),t-=a-l-2,a=l+2),l=void 0);return e}function YT(e){return e!==96||this.events[this.events.length-1][1].type==="characterEscape"}function GT(e,t,n){let a=0,l,s;return o;function o(E){return e.enter("codeText"),e.enter("codeTextSequence"),d(E)}function d(E){return E===96?(e.consume(E),a++,d):(e.exit("codeTextSequence"),f(E))}function f(E){return E===null?n(E):E===32?(e.enter("space"),e.consume(E),e.exit("space"),f):E===96?(s=e.enter("codeTextSequence"),l=0,p(E)):Ye(E)?(e.enter("lineEnding"),e.consume(E),e.exit("lineEnding"),f):(e.enter("codeTextData"),h(E))}function h(E){return E===null||E===32||E===96||Ye(E)?(e.exit("codeTextData"),f(E)):(e.consume(E),h)}function p(E){return E===96?(e.consume(E),l++,p):l===a?(e.exit("codeTextSequence"),e.exit("codeText"),t(E)):(s.type="codeTextData",h(E))}}class VT{constructor(t){this.left=t?[...t]:[],this.right=[]}get(t){if(t<0||t>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+t+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`");return t<this.left.length?this.left[t]:this.right[this.right.length-t+this.left.length-1]}get length(){return this.left.length+this.right.length}shift(){return this.setCursor(0),this.right.pop()}slice(t,n){const a=n??Number.POSITIVE_INFINITY;return a<this.left.length?this.left.slice(t,a):t>this.left.length?this.right.slice(this.right.length-a+this.left.length,this.right.length-t+this.left.length).reverse():this.left.slice(t).concat(this.right.slice(this.right.length-a+this.left.length).reverse())}splice(t,n,a){const l=n||0;this.setCursor(Math.trunc(t));const s=this.right.splice(this.right.length-l,Number.POSITIVE_INFINITY);return a&&ju(this.left,a),s.reverse()}pop(){return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(t){this.setCursor(Number.POSITIVE_INFINITY),this.left.push(t)}pushMany(t){this.setCursor(Number.POSITIVE_INFINITY),ju(this.left,t)}unshift(t){this.setCursor(0),this.right.push(t)}unshiftMany(t){this.setCursor(0),ju(this.right,t.reverse())}setCursor(t){if(!(t===this.left.length||t>this.left.length&&this.right.length===0||t<0&&this.left.length===0))if(t<this.left.length){const n=this.left.splice(t,Number.POSITIVE_INFINITY);ju(this.right,n.reverse())}else{const n=this.right.splice(this.left.length+this.right.length-t,Number.POSITIVE_INFINITY);ju(this.left,n.reverse())}}}function ju(e,t){let n=0;if(t.length<1e4)e.push(...t);else for(;n<t.length;)e.push(...t.slice(n,n+1e4)),n+=1e4}function P6(e){const t={};let n=-1,a,l,s,o,d,f,h;const p=new VT(e);for(;++n<p.length;){for(;n in t;)n=t[n];if(a=p.get(n),n&&a[1].type==="chunkFlow"&&p.get(n-1)[1].type==="listItemPrefix"&&(f=a[1]._tokenizer.events,s=0,s<f.length&&f[s][1].type==="lineEndingBlank"&&(s+=2),s<f.length&&f[s][1].type==="content"))for(;++s<f.length&&f[s][1].type!=="content";)f[s][1].type==="chunkText"&&(f[s][1]._isInFirstContentOfListItem=!0,s++);if(a[0]==="enter")a[1].contentType&&(Object.assign(t,KT(p,n)),n=t[n],h=!0);else if(a[1]._container){for(s=n,l=void 0;s--;)if(o=p.get(s),o[1].type==="lineEnding"||o[1].type==="lineEndingBlank")o[0]==="enter"&&(l&&(p.get(l)[1].type="lineEndingBlank"),o[1].type="lineEnding",l=s);else if(!(o[1].type==="linePrefix"||o[1].type==="listItemIndent"))break;l&&(a[1].end={...p.get(l)[1].start},d=p.slice(l,n),d.unshift(a),p.splice(l,n-l+1,d))}}return Pr(e,0,Number.POSITIVE_INFINITY,p.slice(0)),!h}function KT(e,t){const n=e.get(t)[1],a=e.get(t)[2];let l=t-1;const s=[];let o=n._tokenizer;o||(o=a.parser[n.contentType](n.start),n._contentTypeTextTrailing&&(o._contentTypeTextTrailing=!0));const d=o.events,f=[],h={};let p,E,T=-1,v=n,x=0,N=0;const D=[N];for(;v;){for(;e.get(++l)[1]!==v;);s.push(l),v._tokenizer||(p=a.sliceStream(v),v.next||p.push(null),E&&o.defineSkip(v.start),v._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=!0),o.write(p),v._isInFirstContentOfListItem&&(o._gfmTasklistFirstContentOfListItem=void 0)),E=v,v=v.next}for(v=n;++T<d.length;)d[T][0]==="exit"&&d[T-1][0]==="enter"&&d[T][1].type===d[T-1][1].type&&d[T][1].start.line!==d[T][1].end.line&&(N=T+1,D.push(N),v._tokenizer=void 0,v.previous=void 0,v=v.next);for(o.events=[],v?(v._tokenizer=void 0,v.previous=void 0):D.pop(),T=D.length;T--;){const C=d.slice(D[T],D[T+1]),I=s.pop();f.push([I,I+C.length-1]),e.splice(I,2,C)}for(f.reverse(),T=-1;++T<f.length;)h[x+f[T][0]]=x+f[T][1],x+=f[T][1]-f[T][0]-1;return h}const jT={resolve:$T,tokenize:WT},XT={partial:!0,tokenize:QT};function $T(e){return P6(e),e}function WT(e,t){let n;return a;function a(d){return e.enter("content"),n=e.enter("chunkContent",{contentType:"content"}),l(d)}function l(d){return d===null?s(d):Ye(d)?e.check(XT,o,s)(d):(e.consume(d),l)}function s(d){return e.exit("chunkContent"),e.exit("content"),t(d)}function o(d){return e.consume(d),e.exit("chunkContent"),n.next=e.enter("chunkContent",{contentType:"content",previous:n}),n=n.next,l}}function QT(e,t,n){const a=this;return l;function l(o){return e.exit("chunkContent"),e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),yt(e,s,"linePrefix")}function s(o){if(o===null||Ye(o))return n(o);const d=a.events[a.events.length-1];return!a.parser.constructs.disable.null.includes("codeIndented")&&d&&d[1].type==="linePrefix"&&d[2].sliceSerialize(d[1],!0).length>=4?t(o):e.interrupt(a.parser.constructs.flow,n,t)(o)}}function U6(e,t,n,a,l,s,o,d,f){const h=f||Number.POSITIVE_INFINITY;let p=0;return E;function E(C){return C===60?(e.enter(a),e.enter(l),e.enter(s),e.consume(C),e.exit(s),T):C===null||C===32||C===41||xc(C)?n(C):(e.enter(a),e.enter(o),e.enter(d),e.enter("chunkString",{contentType:"string"}),N(C))}function T(C){return C===62?(e.enter(s),e.consume(C),e.exit(s),e.exit(l),e.exit(a),t):(e.enter(d),e.enter("chunkString",{contentType:"string"}),v(C))}function v(C){return C===62?(e.exit("chunkString"),e.exit(d),T(C)):C===null||C===60||Ye(C)?n(C):(e.consume(C),C===92?x:v)}function x(C){return C===60||C===62||C===92?(e.consume(C),v):v(C)}function N(C){return!p&&(C===null||C===41||Gt(C))?(e.exit("chunkString"),e.exit(d),e.exit(o),e.exit(a),t(C)):p<h&&C===40?(e.consume(C),p++,N):C===41?(e.consume(C),p--,N):C===null||C===32||C===40||xc(C)?n(C):(e.consume(C),C===92?D:N)}function D(C){return C===40||C===41||C===92?(e.consume(C),N):N(C)}}function z6(e,t,n,a,l,s){const o=this;let d=0,f;return h;function h(v){return e.enter(a),e.enter(l),e.consume(v),e.exit(l),e.enter(s),p}function p(v){return d>999||v===null||v===91||v===93&&!f||v===94&&!d&&"_hiddenFootnoteSupport"in o.parser.constructs?n(v):v===93?(e.exit(s),e.enter(l),e.consume(v),e.exit(l),e.exit(a),t):Ye(v)?(e.enter("lineEnding"),e.consume(v),e.exit("lineEnding"),p):(e.enter("chunkString",{contentType:"string"}),E(v))}function E(v){return v===null||v===91||v===93||Ye(v)||d++>999?(e.exit("chunkString"),p(v)):(e.consume(v),f||(f=!St(v)),v===92?T:E)}function T(v){return v===91||v===92||v===93?(e.consume(v),d++,E):E(v)}}function H6(e,t,n,a,l,s){let o;return d;function d(T){return T===34||T===39||T===40?(e.enter(a),e.enter(l),e.consume(T),e.exit(l),o=T===40?41:T,f):n(T)}function f(T){return T===o?(e.enter(l),e.consume(T),e.exit(l),e.exit(a),t):(e.enter(s),h(T))}function h(T){return T===o?(e.exit(s),f(o)):T===null?n(T):Ye(T)?(e.enter("lineEnding"),e.consume(T),e.exit("lineEnding"),yt(e,h,"linePrefix")):(e.enter("chunkString",{contentType:"string"}),p(T))}function p(T){return T===o||T===null||Ye(T)?(e.exit("chunkString"),h(T)):(e.consume(T),T===92?E:p)}function E(T){return T===o||T===92?(e.consume(T),p):p(T)}}function to(e,t){let n;return a;function a(l){return Ye(l)?(e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),n=!0,a):St(l)?yt(e,a,n?"linePrefix":"lineSuffix")(l):t(l)}}const ZT={name:"definition",tokenize:e_},JT={partial:!0,tokenize:t_};function e_(e,t,n){const a=this;let l;return s;function s(v){return e.enter("definition"),o(v)}function o(v){return z6.call(a,e,d,n,"definitionLabel","definitionLabelMarker","definitionLabelString")(v)}function d(v){return l=ha(a.sliceSerialize(a.events[a.events.length-1][1]).slice(1,-1)),v===58?(e.enter("definitionMarker"),e.consume(v),e.exit("definitionMarker"),f):n(v)}function f(v){return Gt(v)?to(e,h)(v):h(v)}function h(v){return U6(e,p,n,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(v)}function p(v){return e.attempt(JT,E,E)(v)}function E(v){return St(v)?yt(e,T,"whitespace")(v):T(v)}function T(v){return v===null||Ye(v)?(e.exit("definition"),a.parser.defined.push(l),t(v)):n(v)}}function t_(e,t,n){return a;function a(d){return Gt(d)?to(e,l)(d):n(d)}function l(d){return H6(e,s,n,"definitionTitle","definitionTitleMarker","definitionTitleString")(d)}function s(d){return St(d)?yt(e,o,"whitespace")(d):o(d)}function o(d){return d===null||Ye(d)?t(d):n(d)}}const n_={name:"hardBreakEscape",tokenize:r_};function r_(e,t,n){return a;function a(s){return e.enter("hardBreakEscape"),e.consume(s),l}function l(s){return Ye(s)?(e.exit("hardBreakEscape"),t(s)):n(s)}}const a_={name:"headingAtx",resolve:i_,tokenize:l_};function i_(e,t){let n=e.length-2,a=3,l,s;return e[a][1].type==="whitespace"&&(a+=2),n-2>a&&e[n][1].type==="whitespace"&&(n-=2),e[n][1].type==="atxHeadingSequence"&&(a===n-1||n-4>a&&e[n-2][1].type==="whitespace")&&(n-=a+1===n?2:4),n>a&&(l={type:"atxHeadingText",start:e[a][1].start,end:e[n][1].end},s={type:"chunkText",start:e[a][1].start,end:e[n][1].end,contentType:"text"},Pr(e,a,n-a+1,[["enter",l,t],["enter",s,t],["exit",s,t],["exit",l,t]])),e}function l_(e,t,n){let a=0;return l;function l(p){return e.enter("atxHeading"),s(p)}function s(p){return e.enter("atxHeadingSequence"),o(p)}function o(p){return p===35&&a++<6?(e.consume(p),o):p===null||Gt(p)?(e.exit("atxHeadingSequence"),d(p)):n(p)}function d(p){return p===35?(e.enter("atxHeadingSequence"),f(p)):p===null||Ye(p)?(e.exit("atxHeading"),t(p)):St(p)?yt(e,d,"whitespace")(p):(e.enter("atxHeadingText"),h(p))}function f(p){return p===35?(e.consume(p),f):(e.exit("atxHeadingSequence"),d(p))}function h(p){return p===null||p===35||Gt(p)?(e.exit("atxHeadingText"),d(p)):(e.consume(p),h)}}const s_=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],eb=["pre","script","style","textarea"],u_={concrete:!0,name:"htmlFlow",resolveTo:d_,tokenize:f_},o_={partial:!0,tokenize:m_},c_={partial:!0,tokenize:h_};function d_(e){let t=e.length;for(;t--&&!(e[t][0]==="enter"&&e[t][1].type==="htmlFlow"););return t>1&&e[t-2][1].type==="linePrefix"&&(e[t][1].start=e[t-2][1].start,e[t+1][1].start=e[t-2][1].start,e.splice(t-2,2)),e}function f_(e,t,n){const a=this;let l,s,o,d,f;return h;function h(R){return p(R)}function p(R){return e.enter("htmlFlow"),e.enter("htmlFlowData"),e.consume(R),E}function E(R){return R===33?(e.consume(R),T):R===47?(e.consume(R),s=!0,N):R===63?(e.consume(R),l=3,a.interrupt?t:A):lr(R)?(e.consume(R),o=String.fromCharCode(R),D):n(R)}function T(R){return R===45?(e.consume(R),l=2,v):R===91?(e.consume(R),l=5,d=0,x):lr(R)?(e.consume(R),l=4,a.interrupt?t:A):n(R)}function v(R){return R===45?(e.consume(R),a.interrupt?t:A):n(R)}function x(R){const De="CDATA[";return R===De.charCodeAt(d++)?(e.consume(R),d===De.length?a.interrupt?t:ce:x):n(R)}function N(R){return lr(R)?(e.consume(R),o=String.fromCharCode(R),D):n(R)}function D(R){if(R===null||R===47||R===62||Gt(R)){const De=R===47,Ge=o.toLowerCase();return!De&&!s&&eb.includes(Ge)?(l=1,a.interrupt?t(R):ce(R)):s_.includes(o.toLowerCase())?(l=6,De?(e.consume(R),C):a.interrupt?t(R):ce(R)):(l=7,a.interrupt&&!a.parser.lazy[a.now().line]?n(R):s?I(R):F(R))}return R===45||$n(R)?(e.consume(R),o+=String.fromCharCode(R),D):n(R)}function C(R){return R===62?(e.consume(R),a.interrupt?t:ce):n(R)}function I(R){return St(R)?(e.consume(R),I):G(R)}function F(R){return R===47?(e.consume(R),G):R===58||R===95||lr(R)?(e.consume(R),J):St(R)?(e.consume(R),F):G(R)}function J(R){return R===45||R===46||R===58||R===95||$n(R)?(e.consume(R),J):K(R)}function K(R){return R===61?(e.consume(R),U):St(R)?(e.consume(R),K):F(R)}function U(R){return R===null||R===60||R===61||R===62||R===96?n(R):R===34||R===39?(e.consume(R),f=R,le):St(R)?(e.consume(R),U):ae(R)}function le(R){return R===f?(e.consume(R),f=null,se):R===null||Ye(R)?n(R):(e.consume(R),le)}function ae(R){return R===null||R===34||R===39||R===47||R===60||R===61||R===62||R===96||Gt(R)?K(R):(e.consume(R),ae)}function se(R){return R===47||R===62||St(R)?F(R):n(R)}function G(R){return R===62?(e.consume(R),ge):n(R)}function ge(R){return R===null||Ye(R)?ce(R):St(R)?(e.consume(R),ge):n(R)}function ce(R){return R===45&&l===2?(e.consume(R),X):R===60&&l===1?(e.consume(R),oe):R===62&&l===4?(e.consume(R),te):R===63&&l===3?(e.consume(R),A):R===93&&l===5?(e.consume(R),ze):Ye(R)&&(l===6||l===7)?(e.exit("htmlFlowData"),e.check(o_,ue,Se)(R)):R===null||Ye(R)?(e.exit("htmlFlowData"),Se(R)):(e.consume(R),ce)}function Se(R){return e.check(c_,fe,ue)(R)}function fe(R){return e.enter("lineEnding"),e.consume(R),e.exit("lineEnding"),ye}function ye(R){return R===null||Ye(R)?Se(R):(e.enter("htmlFlowData"),ce(R))}function X(R){return R===45?(e.consume(R),A):ce(R)}function oe(R){return R===47?(e.consume(R),o="",be):ce(R)}function be(R){if(R===62){const De=o.toLowerCase();return eb.includes(De)?(e.consume(R),te):ce(R)}return lr(R)&&o.length<8?(e.consume(R),o+=String.fromCharCode(R),be):ce(R)}function ze(R){return R===93?(e.consume(R),A):ce(R)}function A(R){return R===62?(e.consume(R),te):R===45&&l===2?(e.consume(R),A):ce(R)}function te(R){return R===null||Ye(R)?(e.exit("htmlFlowData"),ue(R)):(e.consume(R),te)}function ue(R){return e.exit("htmlFlow"),t(R)}}function h_(e,t,n){const a=this;return l;function l(o){return Ye(o)?(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),s):n(o)}function s(o){return a.parser.lazy[a.now().line]?n(o):t(o)}}function m_(e,t,n){return a;function a(l){return e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),e.attempt(To,t,n)}}const p_={name:"htmlText",tokenize:g_};function g_(e,t,n){const a=this;let l,s,o;return d;function d(A){return e.enter("htmlText"),e.enter("htmlTextData"),e.consume(A),f}function f(A){return A===33?(e.consume(A),h):A===47?(e.consume(A),K):A===63?(e.consume(A),F):lr(A)?(e.consume(A),ae):n(A)}function h(A){return A===45?(e.consume(A),p):A===91?(e.consume(A),s=0,x):lr(A)?(e.consume(A),I):n(A)}function p(A){return A===45?(e.consume(A),v):n(A)}function E(A){return A===null?n(A):A===45?(e.consume(A),T):Ye(A)?(o=E,oe(A)):(e.consume(A),E)}function T(A){return A===45?(e.consume(A),v):E(A)}function v(A){return A===62?X(A):A===45?T(A):E(A)}function x(A){const te="CDATA[";return A===te.charCodeAt(s++)?(e.consume(A),s===te.length?N:x):n(A)}function N(A){return A===null?n(A):A===93?(e.consume(A),D):Ye(A)?(o=N,oe(A)):(e.consume(A),N)}function D(A){return A===93?(e.consume(A),C):N(A)}function C(A){return A===62?X(A):A===93?(e.consume(A),C):N(A)}function I(A){return A===null||A===62?X(A):Ye(A)?(o=I,oe(A)):(e.consume(A),I)}function F(A){return A===null?n(A):A===63?(e.consume(A),J):Ye(A)?(o=F,oe(A)):(e.consume(A),F)}function J(A){return A===62?X(A):F(A)}function K(A){return lr(A)?(e.consume(A),U):n(A)}function U(A){return A===45||$n(A)?(e.consume(A),U):le(A)}function le(A){return Ye(A)?(o=le,oe(A)):St(A)?(e.consume(A),le):X(A)}function ae(A){return A===45||$n(A)?(e.consume(A),ae):A===47||A===62||Gt(A)?se(A):n(A)}function se(A){return A===47?(e.consume(A),X):A===58||A===95||lr(A)?(e.consume(A),G):Ye(A)?(o=se,oe(A)):St(A)?(e.consume(A),se):X(A)}function G(A){return A===45||A===46||A===58||A===95||$n(A)?(e.consume(A),G):ge(A)}function ge(A){return A===61?(e.consume(A),ce):Ye(A)?(o=ge,oe(A)):St(A)?(e.consume(A),ge):se(A)}function ce(A){return A===null||A===60||A===61||A===62||A===96?n(A):A===34||A===39?(e.consume(A),l=A,Se):Ye(A)?(o=ce,oe(A)):St(A)?(e.consume(A),ce):(e.consume(A),fe)}function Se(A){return A===l?(e.consume(A),l=void 0,ye):A===null?n(A):Ye(A)?(o=Se,oe(A)):(e.consume(A),Se)}function fe(A){return A===null||A===34||A===39||A===60||A===61||A===96?n(A):A===47||A===62||Gt(A)?se(A):(e.consume(A),fe)}function ye(A){return A===47||A===62||Gt(A)?se(A):n(A)}function X(A){return A===62?(e.consume(A),e.exit("htmlTextData"),e.exit("htmlText"),t):n(A)}function oe(A){return e.exit("htmlTextData"),e.enter("lineEnding"),e.consume(A),e.exit("lineEnding"),be}function be(A){return St(A)?yt(e,ze,"linePrefix",a.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(A):ze(A)}function ze(A){return e.enter("htmlTextData"),o(A)}}const hm={name:"labelEnd",resolveAll:v_,resolveTo:T_,tokenize:__},b_={tokenize:S_},E_={tokenize:A_},y_={tokenize:x_};function v_(e){let t=-1;const n=[];for(;++t<e.length;){const a=e[t][1];if(n.push(e[t]),a.type==="labelImage"||a.type==="labelLink"||a.type==="labelEnd"){const l=a.type==="labelImage"?4:2;a.type="data",t+=l}}return e.length!==n.length&&Pr(e,0,e.length,n),e}function T_(e,t){let n=e.length,a=0,l,s,o,d;for(;n--;)if(l=e[n][1],s){if(l.type==="link"||l.type==="labelLink"&&l._inactive)break;e[n][0]==="enter"&&l.type==="labelLink"&&(l._inactive=!0)}else if(o){if(e[n][0]==="enter"&&(l.type==="labelImage"||l.type==="labelLink")&&!l._balanced&&(s=n,l.type!=="labelLink")){a=2;break}}else l.type==="labelEnd"&&(o=n);const f={type:e[s][1].type==="labelLink"?"link":"image",start:{...e[s][1].start},end:{...e[e.length-1][1].end}},h={type:"label",start:{...e[s][1].start},end:{...e[o][1].end}},p={type:"labelText",start:{...e[s+a+2][1].end},end:{...e[o-2][1].start}};return d=[["enter",f,t],["enter",h,t]],d=$r(d,e.slice(s+1,s+a+3)),d=$r(d,[["enter",p,t]]),d=$r(d,Gc(t.parser.constructs.insideSpan.null,e.slice(s+a+4,o-3),t)),d=$r(d,[["exit",p,t],e[o-2],e[o-1],["exit",h,t]]),d=$r(d,e.slice(o+1)),d=$r(d,[["exit",f,t]]),Pr(e,s,e.length,d),e}function __(e,t,n){const a=this;let l=a.events.length,s,o;for(;l--;)if((a.events[l][1].type==="labelImage"||a.events[l][1].type==="labelLink")&&!a.events[l][1]._balanced){s=a.events[l][1];break}return d;function d(T){return s?s._inactive?E(T):(o=a.parser.defined.includes(ha(a.sliceSerialize({start:s.end,end:a.now()}))),e.enter("labelEnd"),e.enter("labelMarker"),e.consume(T),e.exit("labelMarker"),e.exit("labelEnd"),f):n(T)}function f(T){return T===40?e.attempt(b_,p,o?p:E)(T):T===91?e.attempt(E_,p,o?h:E)(T):o?p(T):E(T)}function h(T){return e.attempt(y_,p,E)(T)}function p(T){return t(T)}function E(T){return s._balanced=!0,n(T)}}function S_(e,t,n){return a;function a(E){return e.enter("resource"),e.enter("resourceMarker"),e.consume(E),e.exit("resourceMarker"),l}function l(E){return Gt(E)?to(e,s)(E):s(E)}function s(E){return E===41?p(E):U6(e,o,d,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(E)}function o(E){return Gt(E)?to(e,f)(E):p(E)}function d(E){return n(E)}function f(E){return E===34||E===39||E===40?H6(e,h,n,"resourceTitle","resourceTitleMarker","resourceTitleString")(E):p(E)}function h(E){return Gt(E)?to(e,p)(E):p(E)}function p(E){return E===41?(e.enter("resourceMarker"),e.consume(E),e.exit("resourceMarker"),e.exit("resource"),t):n(E)}}function A_(e,t,n){const a=this;return l;function l(d){return z6.call(a,e,s,o,"reference","referenceMarker","referenceString")(d)}function s(d){return a.parser.defined.includes(ha(a.sliceSerialize(a.events[a.events.length-1][1]).slice(1,-1)))?t(d):n(d)}function o(d){return n(d)}}function x_(e,t,n){return a;function a(s){return e.enter("reference"),e.enter("referenceMarker"),e.consume(s),e.exit("referenceMarker"),l}function l(s){return s===93?(e.enter("referenceMarker"),e.consume(s),e.exit("referenceMarker"),e.exit("reference"),t):n(s)}}const k_={name:"labelStartImage",resolveAll:hm.resolveAll,tokenize:N_};function N_(e,t,n){const a=this;return l;function l(d){return e.enter("labelImage"),e.enter("labelImageMarker"),e.consume(d),e.exit("labelImageMarker"),s}function s(d){return d===91?(e.enter("labelMarker"),e.consume(d),e.exit("labelMarker"),e.exit("labelImage"),o):n(d)}function o(d){return d===94&&"_hiddenFootnoteSupport"in a.parser.constructs?n(d):t(d)}}const w_={name:"labelStartLink",resolveAll:hm.resolveAll,tokenize:C_};function C_(e,t,n){const a=this;return l;function l(o){return e.enter("labelLink"),e.enter("labelMarker"),e.consume(o),e.exit("labelMarker"),e.exit("labelLink"),s}function s(o){return o===94&&"_hiddenFootnoteSupport"in a.parser.constructs?n(o):t(o)}}const _h={name:"lineEnding",tokenize:O_};function O_(e,t){return n;function n(a){return e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),yt(e,t,"linePrefix")}}const Ec={name:"thematicBreak",tokenize:R_};function R_(e,t,n){let a=0,l;return s;function s(h){return e.enter("thematicBreak"),o(h)}function o(h){return l=h,d(h)}function d(h){return h===l?(e.enter("thematicBreakSequence"),f(h)):a>=3&&(h===null||Ye(h))?(e.exit("thematicBreak"),t(h)):n(h)}function f(h){return h===l?(e.consume(h),a++,f):(e.exit("thematicBreakSequence"),St(h)?yt(e,d,"whitespace")(h):d(h))}}const Er={continuation:{tokenize:L_},exit:P_,name:"list",tokenize:I_},M_={partial:!0,tokenize:U_},D_={partial:!0,tokenize:B_};function I_(e,t,n){const a=this,l=a.events[a.events.length-1];let s=l&&l[1].type==="linePrefix"?l[2].sliceSerialize(l[1],!0).length:0,o=0;return d;function d(v){const x=a.containerState.type||(v===42||v===43||v===45?"listUnordered":"listOrdered");if(x==="listUnordered"?!a.containerState.marker||v===a.containerState.marker:_1(v)){if(a.containerState.type||(a.containerState.type=x,e.enter(x,{_container:!0})),x==="listUnordered")return e.enter("listItemPrefix"),v===42||v===45?e.check(Ec,n,h)(v):h(v);if(!a.interrupt||v===49)return e.enter("listItemPrefix"),e.enter("listItemValue"),f(v)}return n(v)}function f(v){return _1(v)&&++o<10?(e.consume(v),f):(!a.interrupt||o<2)&&(a.containerState.marker?v===a.containerState.marker:v===41||v===46)?(e.exit("listItemValue"),h(v)):n(v)}function h(v){return e.enter("listItemMarker"),e.consume(v),e.exit("listItemMarker"),a.containerState.marker=a.containerState.marker||v,e.check(To,a.interrupt?n:p,e.attempt(M_,T,E))}function p(v){return a.containerState.initialBlankLine=!0,s++,T(v)}function E(v){return St(v)?(e.enter("listItemPrefixWhitespace"),e.consume(v),e.exit("listItemPrefixWhitespace"),T):n(v)}function T(v){return a.containerState.size=s+a.sliceSerialize(e.exit("listItemPrefix"),!0).length,t(v)}}function L_(e,t,n){const a=this;return a.containerState._closeFlow=void 0,e.check(To,l,s);function l(d){return a.containerState.furtherBlankLines=a.containerState.furtherBlankLines||a.containerState.initialBlankLine,yt(e,t,"listItemIndent",a.containerState.size+1)(d)}function s(d){return a.containerState.furtherBlankLines||!St(d)?(a.containerState.furtherBlankLines=void 0,a.containerState.initialBlankLine=void 0,o(d)):(a.containerState.furtherBlankLines=void 0,a.containerState.initialBlankLine=void 0,e.attempt(D_,t,o)(d))}function o(d){return a.containerState._closeFlow=!0,a.interrupt=void 0,yt(e,e.attempt(Er,t,n),"linePrefix",a.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(d)}}function B_(e,t,n){const a=this;return yt(e,l,"listItemIndent",a.containerState.size+1);function l(s){const o=a.events[a.events.length-1];return o&&o[1].type==="listItemIndent"&&o[2].sliceSerialize(o[1],!0).length===a.containerState.size?t(s):n(s)}}function P_(e){e.exit(this.containerState.type)}function U_(e,t,n){const a=this;return yt(e,l,"listItemPrefixWhitespace",a.parser.constructs.disable.null.includes("codeIndented")?void 0:5);function l(s){const o=a.events[a.events.length-1];return!St(s)&&o&&o[1].type==="listItemPrefixWhitespace"?t(s):n(s)}}const tb={name:"setextUnderline",resolveTo:z_,tokenize:H_};function z_(e,t){let n=e.length,a,l,s;for(;n--;)if(e[n][0]==="enter"){if(e[n][1].type==="content"){a=n;break}e[n][1].type==="paragraph"&&(l=n)}else e[n][1].type==="content"&&e.splice(n,1),!s&&e[n][1].type==="definition"&&(s=n);const o={type:"setextHeading",start:{...e[a][1].start},end:{...e[e.length-1][1].end}};return e[l][1].type="setextHeadingText",s?(e.splice(l,0,["enter",o,t]),e.splice(s+1,0,["exit",e[a][1],t]),e[a][1].end={...e[s][1].end}):e[a][1]=o,e.push(["exit",o,t]),e}function H_(e,t,n){const a=this;let l;return s;function s(h){let p=a.events.length,E;for(;p--;)if(a.events[p][1].type!=="lineEnding"&&a.events[p][1].type!=="linePrefix"&&a.events[p][1].type!=="content"){E=a.events[p][1].type==="paragraph";break}return!a.parser.lazy[a.now().line]&&(a.interrupt||E)?(e.enter("setextHeadingLine"),l=h,o(h)):n(h)}function o(h){return e.enter("setextHeadingLineSequence"),d(h)}function d(h){return h===l?(e.consume(h),d):(e.exit("setextHeadingLineSequence"),St(h)?yt(e,f,"lineSuffix")(h):f(h))}function f(h){return h===null||Ye(h)?(e.exit("setextHeadingLine"),t(h)):n(h)}}const F_={tokenize:q_};function q_(e){const t=this,n=e.attempt(To,a,e.attempt(this.parser.constructs.flowInitial,l,yt(e,e.attempt(this.parser.constructs.flow,l,e.attempt(jT,l)),"linePrefix")));return n;function a(s){if(s===null){e.consume(s);return}return e.enter("lineEndingBlank"),e.consume(s),e.exit("lineEndingBlank"),t.currentConstruct=void 0,n}function l(s){if(s===null){e.consume(s);return}return e.enter("lineEnding"),e.consume(s),e.exit("lineEnding"),t.currentConstruct=void 0,n}}const Y_={resolveAll:q6()},G_=F6("string"),V_=F6("text");function F6(e){return{resolveAll:q6(e==="text"?K_:void 0),tokenize:t};function t(n){const a=this,l=this.parser.constructs[e],s=n.attempt(l,o,d);return o;function o(p){return h(p)?s(p):d(p)}function d(p){if(p===null){n.consume(p);return}return n.enter("data"),n.consume(p),f}function f(p){return h(p)?(n.exit("data"),s(p)):(n.consume(p),f)}function h(p){if(p===null)return!0;const E=l[p];let T=-1;if(E)for(;++T<E.length;){const v=E[T];if(!v.previous||v.previous.call(a,a.previous))return!0}return!1}}}function q6(e){return t;function t(n,a){let l=-1,s;for(;++l<=n.length;)s===void 0?n[l]&&n[l][1].type==="data"&&(s=l,l++):(!n[l]||n[l][1].type!=="data")&&(l!==s+2&&(n[s][1].end=n[l-1][1].end,n.splice(s+2,l-s-2),l=s+2),s=void 0);return e?e(n,a):n}}function K_(e,t){let n=0;for(;++n<=e.length;)if((n===e.length||e[n][1].type==="lineEnding")&&e[n-1][1].type==="data"){const a=e[n-1][1],l=t.sliceStream(a);let s=l.length,o=-1,d=0,f;for(;s--;){const h=l[s];if(typeof h=="string"){for(o=h.length;h.charCodeAt(o-1)===32;)d++,o--;if(o)break;o=-1}else if(h===-2)f=!0,d++;else if(h!==-1){s++;break}}if(t._contentTypeTextTrailing&&n===e.length&&(d=0),d){const h={type:n===e.length||f||d<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:s?o:a.start._bufferIndex+o,_index:a.start._index+s,line:a.end.line,column:a.end.column-d,offset:a.end.offset-d},end:{...a.end}};a.end={...h.start},a.start.offset===a.end.offset?Object.assign(a,h):(e.splice(n,0,["enter",h,t],["exit",h,t]),n+=2)}n++}return e}const j_={42:Er,43:Er,45:Er,48:Er,49:Er,50:Er,51:Er,52:Er,53:Er,54:Er,55:Er,56:Er,57:Er,62:I6},X_={91:ZT},$_={[-2]:Th,[-1]:Th,32:Th},W_={35:a_,42:Ec,45:[tb,Ec],60:u_,61:tb,95:Ec,96:J4,126:J4},Q_={38:B6,92:L6},Z_={[-5]:_h,[-4]:_h,[-3]:_h,33:k_,38:B6,42:S1,60:[wT,p_],91:w_,92:[n_,L6],93:hm,95:S1,96:FT},J_={null:[S1,Y_]},e9={null:[42,95]},t9={null:[]},n9=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:e9,contentInitial:X_,disable:t9,document:j_,flow:W_,flowInitial:$_,insideSpan:J_,string:Q_,text:Z_},Symbol.toStringTag,{value:"Module"}));function r9(e,t,n){let a={_bufferIndex:-1,_index:0,line:n&&n.line||1,column:n&&n.column||1,offset:n&&n.offset||0};const l={},s=[];let o=[],d=[];const f={attempt:le(K),check:le(U),consume:I,enter:F,exit:J,interrupt:le(U,{interrupt:!0})},h={code:null,containerState:{},defineSkip:N,events:[],now:x,parser:e,previous:null,sliceSerialize:T,sliceStream:v,write:E};let p=t.tokenize.call(h,f);return t.resolveAll&&s.push(t),h;function E(ge){return o=$r(o,ge),D(),o[o.length-1]!==null?[]:(ae(t,0),h.events=Gc(s,h.events,h),h.events)}function T(ge,ce){return i9(v(ge),ce)}function v(ge){return a9(o,ge)}function x(){const{_bufferIndex:ge,_index:ce,line:Se,column:fe,offset:ye}=a;return{_bufferIndex:ge,_index:ce,line:Se,column:fe,offset:ye}}function N(ge){l[ge.line]=ge.column,G()}function D(){let ge;for(;a._index<o.length;){const ce=o[a._index];if(typeof ce=="string")for(ge=a._index,a._bufferIndex<0&&(a._bufferIndex=0);a._index===ge&&a._bufferIndex<ce.length;)C(ce.charCodeAt(a._bufferIndex));else C(ce)}}function C(ge){p=p(ge)}function I(ge){Ye(ge)?(a.line++,a.column=1,a.offset+=ge===-3?2:1,G()):ge!==-1&&(a.column++,a.offset++),a._bufferIndex<0?a._index++:(a._bufferIndex++,a._bufferIndex===o[a._index].length&&(a._bufferIndex=-1,a._index++)),h.previous=ge}function F(ge,ce){const Se=ce||{};return Se.type=ge,Se.start=x(),h.events.push(["enter",Se,h]),d.push(Se),Se}function J(ge){const ce=d.pop();return ce.end=x(),h.events.push(["exit",ce,h]),ce}function K(ge,ce){ae(ge,ce.from)}function U(ge,ce){ce.restore()}function le(ge,ce){return Se;function Se(fe,ye,X){let oe,be,ze,A;return Array.isArray(fe)?ue(fe):"tokenize"in fe?ue([fe]):te(fe);function te(Le){return kt;function kt(it){const Wt=it!==null&&Le[it],Pt=it!==null&&Le.null,In=[...Array.isArray(Wt)?Wt:Wt?[Wt]:[],...Array.isArray(Pt)?Pt:Pt?[Pt]:[]];return ue(In)(it)}}function ue(Le){return oe=Le,be=0,Le.length===0?X:R(Le[be])}function R(Le){return kt;function kt(it){return A=se(),ze=Le,Le.partial||(h.currentConstruct=Le),Le.name&&h.parser.constructs.disable.null.includes(Le.name)?Ge():Le.tokenize.call(ce?Object.assign(Object.create(h),ce):h,f,De,Ge)(it)}}function De(Le){return ge(ze,A),ye}function Ge(Le){return A.restore(),++be<oe.length?R(oe[be]):X}}}function ae(ge,ce){ge.resolveAll&&!s.includes(ge)&&s.push(ge),ge.resolve&&Pr(h.events,ce,h.events.length-ce,ge.resolve(h.events.slice(ce),h)),ge.resolveTo&&(h.events=ge.resolveTo(h.events,h))}function se(){const ge=x(),ce=h.previous,Se=h.currentConstruct,fe=h.events.length,ye=Array.from(d);return{from:fe,restore:X};function X(){a=ge,h.previous=ce,h.currentConstruct=Se,h.events.length=fe,d=ye,G()}}function G(){a.line in l&&a.column<2&&(a.column=l[a.line],a.offset+=l[a.line]-1)}}function a9(e,t){const n=t.start._index,a=t.start._bufferIndex,l=t.end._index,s=t.end._bufferIndex;let o;if(n===l)o=[e[n].slice(a,s)];else{if(o=e.slice(n,l),a>-1){const d=o[0];typeof d=="string"?o[0]=d.slice(a):o.shift()}s>0&&o.push(e[l].slice(0,s))}return o}function i9(e,t){let n=-1;const a=[];let l;for(;++n<e.length;){const s=e[n];let o;if(typeof s=="string")o=s;else switch(s){case-5:{o="\r";break}case-4:{o=`
`;break}case-3:{o=`\r
`;break}case-2:{o=t?" ":"	";break}case-1:{if(!t&&l)continue;o=" ";break}default:o=String.fromCharCode(s)}l=s===-2,a.push(o)}return a.join("")}function l9(e){const a={constructs:M6([n9,...(e||{}).extensions||[]]),content:l(TT),defined:[],document:l(ST),flow:l(F_),lazy:{},string:l(G_),text:l(V_)};return a;function l(s){return o;function o(d){return r9(a,s,d)}}}function s9(e){for(;!P6(e););return e}const nb=/[\0\t\n\r]/g;function u9(){let e=1,t="",n=!0,a;return l;function l(s,o,d){const f=[];let h,p,E,T,v;for(s=t+(typeof s=="string"?s.toString():new TextDecoder(o||void 0).decode(s)),E=0,t="",n&&(s.charCodeAt(0)===65279&&E++,n=void 0);E<s.length;){if(nb.lastIndex=E,h=nb.exec(s),T=h&&h.index!==void 0?h.index:s.length,v=s.charCodeAt(T),!h){t=s.slice(E);break}if(v===10&&E===T&&a)f.push(-3),a=void 0;else switch(a&&(f.push(-5),a=void 0),E<T&&(f.push(s.slice(E,T)),e+=T-E),v){case 0:{f.push(65533),e++;break}case 9:{for(p=Math.ceil(e/4)*4,f.push(-2);e++<p;)f.push(-1);break}case 10:{f.push(-4),e=1;break}default:a=!0,e=1}E=T+1}return d&&(a&&f.push(-5),t&&f.push(t),f.push(null)),f}}const o9=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function c9(e){return e.replace(o9,d9)}function d9(e,t,n){if(t)return t;if(n.charCodeAt(0)===35){const l=n.charCodeAt(1),s=l===120||l===88;return D6(n.slice(s?2:1),s?16:10)}return fm(n)||e}const Y6={}.hasOwnProperty;function f9(e,t,n){return typeof t!="string"&&(n=t,t=void 0),h9(n)(s9(l9(n).document().write(u9()(e,t,!0))))}function h9(e){const t={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:s(wt),autolinkProtocol:se,autolinkEmail:se,atxHeading:s(Ut),blockQuote:s(Pt),characterEscape:se,characterReference:se,codeFenced:s(In),codeFencedFenceInfo:o,codeFencedFenceMeta:o,codeIndented:s(In,o),codeText:s(zr,o),codeTextData:se,data:se,codeFlowValue:se,definition:s(vt),definitionDestinationString:o,definitionLabelString:o,definitionTitleString:o,emphasis:s(ht),hardBreakEscape:s(Ve),hardBreakTrailing:s(Ve),htmlFlow:s(At,o),htmlFlowData:se,htmlText:s(At,o),htmlTextData:se,image:s(an),label:o,link:s(wt),listItem:s(Ln),listItemValue:T,listOrdered:s(Zt,E),listUnordered:s(Zt),paragraph:s(di),reference:R,referenceString:o,resourceDestinationString:o,resourceTitleString:o,setextHeading:s(Ut),strong:s(pa),thematicBreak:s(Cn)},exit:{atxHeading:f(),atxHeadingSequence:K,autolink:f(),autolinkEmail:Wt,autolinkProtocol:it,blockQuote:f(),characterEscapeValue:G,characterReferenceMarkerHexadecimal:Ge,characterReferenceMarkerNumeric:Ge,characterReferenceValue:Le,characterReference:kt,codeFenced:f(D),codeFencedFence:N,codeFencedFenceInfo:v,codeFencedFenceMeta:x,codeFlowValue:G,codeIndented:f(C),codeText:f(ye),codeTextData:G,data:G,definition:f(),definitionDestinationString:J,definitionLabelString:I,definitionTitleString:F,emphasis:f(),hardBreakEscape:f(ce),hardBreakTrailing:f(ce),htmlFlow:f(Se),htmlFlowData:G,htmlText:f(fe),htmlTextData:G,image:f(oe),label:ze,labelText:be,lineEnding:ge,link:f(X),listItem:f(),listOrdered:f(),listUnordered:f(),paragraph:f(),referenceString:De,resourceDestinationString:A,resourceTitleString:te,resource:ue,setextHeading:f(ae),setextHeadingLineSequence:le,setextHeadingText:U,strong:f(),thematicBreak:f()}};G6(t,(e||{}).mdastExtensions||[]);const n={};return a;function a(re){let Te={type:"root",children:[]};const Ke={stack:[Te],tokenStack:[],config:t,enter:d,exit:h,buffer:o,resume:p,data:n},$e=[];let Rt=-1;for(;++Rt<re.length;)if(re[Rt][1].type==="listOrdered"||re[Rt][1].type==="listUnordered")if(re[Rt][0]==="enter")$e.push(Rt);else{const Zn=$e.pop();Rt=l(re,Zn,Rt)}for(Rt=-1;++Rt<re.length;){const Zn=t[re[Rt][0]];Y6.call(Zn,re[Rt][1].type)&&Zn[re[Rt][1].type].call(Object.assign({sliceSerialize:re[Rt][2].sliceSerialize},Ke),re[Rt][1])}if(Ke.tokenStack.length>0){const Zn=Ke.tokenStack[Ke.tokenStack.length-1];(Zn[1]||rb).call(Ke,void 0,Zn[0])}for(Te.position={start:Hi(re.length>0?re[0][1].start:{line:1,column:1,offset:0}),end:Hi(re.length>0?re[re.length-2][1].end:{line:1,column:1,offset:0})},Rt=-1;++Rt<t.transforms.length;)Te=t.transforms[Rt](Te)||Te;return Te}function l(re,Te,Ke){let $e=Te-1,Rt=-1,Zn=!1,aa,Vn,Sr,Jn;for(;++$e<=Ke;){const Tn=re[$e];switch(Tn[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{Tn[0]==="enter"?Rt++:Rt--,Jn=void 0;break}case"lineEndingBlank":{Tn[0]==="enter"&&(aa&&!Jn&&!Rt&&!Sr&&(Sr=$e),Jn=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:Jn=void 0}if(!Rt&&Tn[0]==="enter"&&Tn[1].type==="listItemPrefix"||Rt===-1&&Tn[0]==="exit"&&(Tn[1].type==="listUnordered"||Tn[1].type==="listOrdered")){if(aa){let dr=$e;for(Vn=void 0;dr--;){const er=re[dr];if(er[1].type==="lineEnding"||er[1].type==="lineEndingBlank"){if(er[0]==="exit")continue;Vn&&(re[Vn][1].type="lineEndingBlank",Zn=!0),er[1].type="lineEnding",Vn=dr}else if(!(er[1].type==="linePrefix"||er[1].type==="blockQuotePrefix"||er[1].type==="blockQuotePrefixWhitespace"||er[1].type==="blockQuoteMarker"||er[1].type==="listItemIndent"))break}Sr&&(!Vn||Sr<Vn)&&(aa._spread=!0),aa.end=Object.assign({},Vn?re[Vn][1].start:Tn[1].end),re.splice(Vn||$e,0,["exit",aa,Tn[2]]),$e++,Ke++}if(Tn[1].type==="listItemPrefix"){const dr={type:"listItem",_spread:!1,start:Object.assign({},Tn[1].start),end:void 0};aa=dr,re.splice($e,0,["enter",dr,Tn[2]]),$e++,Ke++,Sr=void 0,Jn=!0}}}return re[Te][1]._spread=Zn,Ke}function s(re,Te){return Ke;function Ke($e){d.call(this,re($e),$e),Te&&Te.call(this,$e)}}function o(){this.stack.push({type:"fragment",children:[]})}function d(re,Te,Ke){this.stack[this.stack.length-1].children.push(re),this.stack.push(re),this.tokenStack.push([Te,Ke||void 0]),re.position={start:Hi(Te.start),end:void 0}}function f(re){return Te;function Te(Ke){re&&re.call(this,Ke),h.call(this,Ke)}}function h(re,Te){const Ke=this.stack.pop(),$e=this.tokenStack.pop();if($e)$e[0].type!==re.type&&(Te?Te.call(this,re,$e[0]):($e[1]||rb).call(this,re,$e[0]));else throw new Error("Cannot close `"+re.type+"` ("+eo({start:re.start,end:re.end})+"): it’s not open");Ke.position.end=Hi(re.end)}function p(){return dm(this.stack.pop())}function E(){this.data.expectingFirstListItemValue=!0}function T(re){if(this.data.expectingFirstListItemValue){const Te=this.stack[this.stack.length-2];Te.start=Number.parseInt(this.sliceSerialize(re),10),this.data.expectingFirstListItemValue=void 0}}function v(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.lang=re}function x(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.meta=re}function N(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function D(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.value=re.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function C(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.value=re.replace(/(\r?\n|\r)$/g,"")}function I(re){const Te=this.resume(),Ke=this.stack[this.stack.length-1];Ke.label=Te,Ke.identifier=ha(this.sliceSerialize(re)).toLowerCase()}function F(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.title=re}function J(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.url=re}function K(re){const Te=this.stack[this.stack.length-1];if(!Te.depth){const Ke=this.sliceSerialize(re).length;Te.depth=Ke}}function U(){this.data.setextHeadingSlurpLineEnding=!0}function le(re){const Te=this.stack[this.stack.length-1];Te.depth=this.sliceSerialize(re).codePointAt(0)===61?1:2}function ae(){this.data.setextHeadingSlurpLineEnding=void 0}function se(re){const Ke=this.stack[this.stack.length-1].children;let $e=Ke[Ke.length-1];(!$e||$e.type!=="text")&&($e=cr(),$e.position={start:Hi(re.start),end:void 0},Ke.push($e)),this.stack.push($e)}function G(re){const Te=this.stack.pop();Te.value+=this.sliceSerialize(re),Te.position.end=Hi(re.end)}function ge(re){const Te=this.stack[this.stack.length-1];if(this.data.atHardBreak){const Ke=Te.children[Te.children.length-1];Ke.position.end=Hi(re.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&t.canContainEols.includes(Te.type)&&(se.call(this,re),G.call(this,re))}function ce(){this.data.atHardBreak=!0}function Se(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.value=re}function fe(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.value=re}function ye(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.value=re}function X(){const re=this.stack[this.stack.length-1];if(this.data.inReference){const Te=this.data.referenceType||"shortcut";re.type+="Reference",re.referenceType=Te,delete re.url,delete re.title}else delete re.identifier,delete re.label;this.data.referenceType=void 0}function oe(){const re=this.stack[this.stack.length-1];if(this.data.inReference){const Te=this.data.referenceType||"shortcut";re.type+="Reference",re.referenceType=Te,delete re.url,delete re.title}else delete re.identifier,delete re.label;this.data.referenceType=void 0}function be(re){const Te=this.sliceSerialize(re),Ke=this.stack[this.stack.length-2];Ke.label=c9(Te),Ke.identifier=ha(Te).toLowerCase()}function ze(){const re=this.stack[this.stack.length-1],Te=this.resume(),Ke=this.stack[this.stack.length-1];if(this.data.inReference=!0,Ke.type==="link"){const $e=re.children;Ke.children=$e}else Ke.alt=Te}function A(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.url=re}function te(){const re=this.resume(),Te=this.stack[this.stack.length-1];Te.title=re}function ue(){this.data.inReference=void 0}function R(){this.data.referenceType="collapsed"}function De(re){const Te=this.resume(),Ke=this.stack[this.stack.length-1];Ke.label=Te,Ke.identifier=ha(this.sliceSerialize(re)).toLowerCase(),this.data.referenceType="full"}function Ge(re){this.data.characterReferenceType=re.type}function Le(re){const Te=this.sliceSerialize(re),Ke=this.data.characterReferenceType;let $e;Ke?($e=D6(Te,Ke==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):$e=fm(Te);const Rt=this.stack[this.stack.length-1];Rt.value+=$e}function kt(re){const Te=this.stack.pop();Te.position.end=Hi(re.end)}function it(re){G.call(this,re);const Te=this.stack[this.stack.length-1];Te.url=this.sliceSerialize(re)}function Wt(re){G.call(this,re);const Te=this.stack[this.stack.length-1];Te.url="mailto:"+this.sliceSerialize(re)}function Pt(){return{type:"blockquote",children:[]}}function In(){return{type:"code",lang:null,meta:null,value:""}}function zr(){return{type:"inlineCode",value:""}}function vt(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function ht(){return{type:"emphasis",children:[]}}function Ut(){return{type:"heading",depth:0,children:[]}}function Ve(){return{type:"break"}}function At(){return{type:"html",value:""}}function an(){return{type:"image",title:null,url:"",alt:null}}function wt(){return{type:"link",title:null,url:"",children:[]}}function Zt(re){return{type:"list",ordered:re.type==="listOrdered",start:null,spread:re._spread,children:[]}}function Ln(re){return{type:"listItem",spread:re._spread,checked:null,children:[]}}function di(){return{type:"paragraph",children:[]}}function pa(){return{type:"strong",children:[]}}function cr(){return{type:"text",value:""}}function Cn(){return{type:"thematicBreak"}}}function Hi(e){return{line:e.line,column:e.column,offset:e.offset}}function G6(e,t){let n=-1;for(;++n<t.length;){const a=t[n];Array.isArray(a)?G6(e,a):m9(e,a)}}function m9(e,t){let n;for(n in t)if(Y6.call(t,n))switch(n){case"canContainEols":{const a=t[n];a&&e[n].push(...a);break}case"transforms":{const a=t[n];a&&e[n].push(...a);break}case"enter":case"exit":{const a=t[n];a&&Object.assign(e[n],a);break}}}function rb(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+eo({start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+eo({start:t.start,end:t.end})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+eo({start:t.start,end:t.end})+") is still open")}function p9(e){const t=this;t.parser=n;function n(a){return f9(a,{...t.data("settings"),...e,extensions:t.data("micromarkExtensions")||[],mdastExtensions:t.data("fromMarkdownExtensions")||[]})}}function g9(e,t){const n={type:"element",tagName:"blockquote",properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,n),e.applyData(t,n)}function b9(e,t){const n={type:"element",tagName:"br",properties:{},children:[]};return e.patch(t,n),[e.applyData(t,n),{type:"text",value:`
`}]}function E9(e,t){const n=t.value?t.value+`
`:"",a={};t.lang&&(a.className=["language-"+t.lang]);let l={type:"element",tagName:"code",properties:a,children:[{type:"text",value:n}]};return t.meta&&(l.data={meta:t.meta}),e.patch(t,l),l=e.applyData(t,l),l={type:"element",tagName:"pre",properties:{},children:[l]},e.patch(t,l),l}function y9(e,t){const n={type:"element",tagName:"del",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function v9(e,t){const n={type:"element",tagName:"em",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function T9(e,t){const n=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",a=String(t.identifier).toUpperCase(),l=Bs(a.toLowerCase()),s=e.footnoteOrder.indexOf(a);let o,d=e.footnoteCounts.get(a);d===void 0?(d=0,e.footnoteOrder.push(a),o=e.footnoteOrder.length):o=s+1,d+=1,e.footnoteCounts.set(a,d);const f={type:"element",tagName:"a",properties:{href:"#"+n+"fn-"+l,id:n+"fnref-"+l+(d>1?"-"+d:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(o)}]};e.patch(t,f);const h={type:"element",tagName:"sup",properties:{},children:[f]};return e.patch(t,h),e.applyData(t,h)}function _9(e,t){const n={type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function S9(e,t){if(e.options.allowDangerousHtml){const n={type:"raw",value:t.value};return e.patch(t,n),e.applyData(t,n)}}function V6(e,t){const n=t.referenceType;let a="]";if(n==="collapsed"?a+="[]":n==="full"&&(a+="["+(t.label||t.identifier)+"]"),t.type==="imageReference")return[{type:"text",value:"!["+t.alt+a}];const l=e.all(t),s=l[0];s&&s.type==="text"?s.value="["+s.value:l.unshift({type:"text",value:"["});const o=l[l.length-1];return o&&o.type==="text"?o.value+=a:l.push({type:"text",value:a}),l}function A9(e,t){const n=String(t.identifier).toUpperCase(),a=e.definitionById.get(n);if(!a)return V6(e,t);const l={src:Bs(a.url||""),alt:t.alt};a.title!==null&&a.title!==void 0&&(l.title=a.title);const s={type:"element",tagName:"img",properties:l,children:[]};return e.patch(t,s),e.applyData(t,s)}function x9(e,t){const n={src:Bs(t.url)};t.alt!==null&&t.alt!==void 0&&(n.alt=t.alt),t.title!==null&&t.title!==void 0&&(n.title=t.title);const a={type:"element",tagName:"img",properties:n,children:[]};return e.patch(t,a),e.applyData(t,a)}function k9(e,t){const n={type:"text",value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,n);const a={type:"element",tagName:"code",properties:{},children:[n]};return e.patch(t,a),e.applyData(t,a)}function N9(e,t){const n=String(t.identifier).toUpperCase(),a=e.definitionById.get(n);if(!a)return V6(e,t);const l={href:Bs(a.url||"")};a.title!==null&&a.title!==void 0&&(l.title=a.title);const s={type:"element",tagName:"a",properties:l,children:e.all(t)};return e.patch(t,s),e.applyData(t,s)}function w9(e,t){const n={href:Bs(t.url)};t.title!==null&&t.title!==void 0&&(n.title=t.title);const a={type:"element",tagName:"a",properties:n,children:e.all(t)};return e.patch(t,a),e.applyData(t,a)}function C9(e,t,n){const a=e.all(t),l=n?O9(n):K6(t),s={},o=[];if(typeof t.checked=="boolean"){const p=a[0];let E;p&&p.type==="element"&&p.tagName==="p"?E=p:(E={type:"element",tagName:"p",properties:{},children:[]},a.unshift(E)),E.children.length>0&&E.children.unshift({type:"text",value:" "}),E.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:t.checked,disabled:!0},children:[]}),s.className=["task-list-item"]}let d=-1;for(;++d<a.length;){const p=a[d];(l||d!==0||p.type!=="element"||p.tagName!=="p")&&o.push({type:"text",value:`
`}),p.type==="element"&&p.tagName==="p"&&!l?o.push(...p.children):o.push(p)}const f=a[a.length-1];f&&(l||f.type!=="element"||f.tagName!=="p")&&o.push({type:"text",value:`
`});const h={type:"element",tagName:"li",properties:s,children:o};return e.patch(t,h),e.applyData(t,h)}function O9(e){let t=!1;if(e.type==="list"){t=e.spread||!1;const n=e.children;let a=-1;for(;!t&&++a<n.length;)t=K6(n[a])}return t}function K6(e){const t=e.spread;return t??e.children.length>1}function R9(e,t){const n={},a=e.all(t);let l=-1;for(typeof t.start=="number"&&t.start!==1&&(n.start=t.start);++l<a.length;){const o=a[l];if(o.type==="element"&&o.tagName==="li"&&o.properties&&Array.isArray(o.properties.className)&&o.properties.className.includes("task-list-item")){n.className=["contains-task-list"];break}}const s={type:"element",tagName:t.ordered?"ol":"ul",properties:n,children:e.wrap(a,!0)};return e.patch(t,s),e.applyData(t,s)}function M9(e,t){const n={type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function D9(e,t){const n={type:"root",children:e.wrap(e.all(t))};return e.patch(t,n),e.applyData(t,n)}function I9(e,t){const n={type:"element",tagName:"strong",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function L9(e,t){const n=e.all(t),a=n.shift(),l=[];if(a){const o={type:"element",tagName:"thead",properties:{},children:e.wrap([a],!0)};e.patch(t.children[0],o),l.push(o)}if(n.length>0){const o={type:"element",tagName:"tbody",properties:{},children:e.wrap(n,!0)},d=Oa(t.children[1]),f=qc(t.children[t.children.length-1]);d&&f&&(o.position={start:d,end:f}),l.push(o)}const s={type:"element",tagName:"table",properties:{},children:e.wrap(l,!0)};return e.patch(t,s),e.applyData(t,s)}function B9(e,t,n){const a=n?n.children:void 0,s=(a?a.indexOf(t):1)===0?"th":"td",o=n&&n.type==="table"?n.align:void 0,d=o?o.length:t.children.length;let f=-1;const h=[];for(;++f<d;){const E=t.children[f],T={},v=o?o[f]:void 0;v&&(T.align=v);let x={type:"element",tagName:s,properties:T,children:[]};E&&(x.children=e.all(E),e.patch(E,x),x=e.applyData(E,x)),h.push(x)}const p={type:"element",tagName:"tr",properties:{},children:e.wrap(h,!0)};return e.patch(t,p),e.applyData(t,p)}function P9(e,t){const n={type:"element",tagName:"td",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}const ab=9,ib=32;function U9(e){const t=String(e),n=/\r?\n|\r/g;let a=n.exec(t),l=0;const s=[];for(;a;)s.push(lb(t.slice(l,a.index),l>0,!0),a[0]),l=a.index+a[0].length,a=n.exec(t);return s.push(lb(t.slice(l),l>0,!1)),s.join("")}function lb(e,t,n){let a=0,l=e.length;if(t){let s=e.codePointAt(a);for(;s===ab||s===ib;)a++,s=e.codePointAt(a)}if(n){let s=e.codePointAt(l-1);for(;s===ab||s===ib;)l--,s=e.codePointAt(l-1)}return l>a?e.slice(a,l):""}function z9(e,t){const n={type:"text",value:U9(String(t.value))};return e.patch(t,n),e.applyData(t,n)}function H9(e,t){const n={type:"element",tagName:"hr",properties:{},children:[]};return e.patch(t,n),e.applyData(t,n)}const F9={blockquote:g9,break:b9,code:E9,delete:y9,emphasis:v9,footnoteReference:T9,heading:_9,html:S9,imageReference:A9,image:x9,inlineCode:k9,linkReference:N9,link:w9,listItem:C9,list:R9,paragraph:M9,root:D9,strong:I9,table:L9,tableCell:P9,tableRow:B9,text:z9,thematicBreak:H9,toml:K0,yaml:K0,definition:K0,footnoteDefinition:K0};function K0(){}const j6=-1,Vc=0,no=1,kc=2,mm=3,pm=4,gm=5,bm=6,X6=7,$6=8,sb=typeof self=="object"?self:globalThis,q9=(e,t)=>{const n=(l,s)=>(e.set(s,l),l),a=l=>{if(e.has(l))return e.get(l);const[s,o]=t[l];switch(s){case Vc:case j6:return n(o,l);case no:{const d=n([],l);for(const f of o)d.push(a(f));return d}case kc:{const d=n({},l);for(const[f,h]of o)d[a(f)]=a(h);return d}case mm:return n(new Date(o),l);case pm:{const{source:d,flags:f}=o;return n(new RegExp(d,f),l)}case gm:{const d=n(new Map,l);for(const[f,h]of o)d.set(a(f),a(h));return d}case bm:{const d=n(new Set,l);for(const f of o)d.add(a(f));return d}case X6:{const{name:d,message:f}=o;return n(new sb[d](f),l)}case $6:return n(BigInt(o),l);case"BigInt":return n(Object(BigInt(o)),l);case"ArrayBuffer":return n(new Uint8Array(o).buffer,o);case"DataView":{const{buffer:d}=new Uint8Array(o);return n(new DataView(d),o)}}return n(new sb[s](o),l)};return a},ub=e=>q9(new Map,e)(0),gs="",{toString:Y9}={},{keys:G9}=Object,Xu=e=>{const t=typeof e;if(t!=="object"||!e)return[Vc,t];const n=Y9.call(e).slice(8,-1);switch(n){case"Array":return[no,gs];case"Object":return[kc,gs];case"Date":return[mm,gs];case"RegExp":return[pm,gs];case"Map":return[gm,gs];case"Set":return[bm,gs];case"DataView":return[no,n]}return n.includes("Array")?[no,n]:n.includes("Error")?[X6,n]:[kc,n]},j0=([e,t])=>e===Vc&&(t==="function"||t==="symbol"),V9=(e,t,n,a)=>{const l=(o,d)=>{const f=a.push(o)-1;return n.set(d,f),f},s=o=>{if(n.has(o))return n.get(o);let[d,f]=Xu(o);switch(d){case Vc:{let p=o;switch(f){case"bigint":d=$6,p=o.toString();break;case"function":case"symbol":if(e)throw new TypeError("unable to serialize "+f);p=null;break;case"undefined":return l([j6],o)}return l([d,p],o)}case no:{if(f){let T=o;return f==="DataView"?T=new Uint8Array(o.buffer):f==="ArrayBuffer"&&(T=new Uint8Array(o)),l([f,[...T]],o)}const p=[],E=l([d,p],o);for(const T of o)p.push(s(T));return E}case kc:{if(f)switch(f){case"BigInt":return l([f,o.toString()],o);case"Boolean":case"Number":case"String":return l([f,o.valueOf()],o)}if(t&&"toJSON"in o)return s(o.toJSON());const p=[],E=l([d,p],o);for(const T of G9(o))(e||!j0(Xu(o[T])))&&p.push([s(T),s(o[T])]);return E}case mm:return l([d,o.toISOString()],o);case pm:{const{source:p,flags:E}=o;return l([d,{source:p,flags:E}],o)}case gm:{const p=[],E=l([d,p],o);for(const[T,v]of o)(e||!(j0(Xu(T))||j0(Xu(v))))&&p.push([s(T),s(v)]);return E}case bm:{const p=[],E=l([d,p],o);for(const T of o)(e||!j0(Xu(T)))&&p.push(s(T));return E}}const{message:h}=o;return l([d,{name:f,message:h}],o)};return s},ob=(e,{json:t,lossy:n}={})=>{const a=[];return V9(!(t||n),!!t,new Map,a)(e),a},Os=typeof structuredClone=="function"?(e,t)=>t&&("json"in t||"lossy"in t)?ub(ob(e,t)):structuredClone(e):(e,t)=>ub(ob(e,t));function K9(e,t){const n=[{type:"text",value:"↩"}];return t>1&&n.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(t)}]}),n}function j9(e,t){return"Back to reference "+(e+1)+(t>1?"-"+t:"")}function X9(e){const t=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",n=e.options.footnoteBackContent||K9,a=e.options.footnoteBackLabel||j9,l=e.options.footnoteLabel||"Footnotes",s=e.options.footnoteLabelTagName||"h2",o=e.options.footnoteLabelProperties||{className:["sr-only"]},d=[];let f=-1;for(;++f<e.footnoteOrder.length;){const h=e.footnoteById.get(e.footnoteOrder[f]);if(!h)continue;const p=e.all(h),E=String(h.identifier).toUpperCase(),T=Bs(E.toLowerCase());let v=0;const x=[],N=e.footnoteCounts.get(E);for(;N!==void 0&&++v<=N;){x.length>0&&x.push({type:"text",value:" "});let I=typeof n=="string"?n:n(f,v);typeof I=="string"&&(I={type:"text",value:I}),x.push({type:"element",tagName:"a",properties:{href:"#"+t+"fnref-"+T+(v>1?"-"+v:""),dataFootnoteBackref:"",ariaLabel:typeof a=="string"?a:a(f,v),className:["data-footnote-backref"]},children:Array.isArray(I)?I:[I]})}const D=p[p.length-1];if(D&&D.type==="element"&&D.tagName==="p"){const I=D.children[D.children.length-1];I&&I.type==="text"?I.value+=" ":D.children.push({type:"text",value:" "}),D.children.push(...x)}else p.push(...x);const C={type:"element",tagName:"li",properties:{id:t+"fn-"+T},children:e.wrap(p,!0)};e.patch(h,C),d.push(C)}if(d.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:s,properties:{...Os(o),id:"footnote-label"},children:[{type:"text",value:l}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:e.wrap(d,!0)},{type:"text",value:`
`}]}}const _o=function(e){if(e==null)return Z9;if(typeof e=="function")return Kc(e);if(typeof e=="object")return Array.isArray(e)?$9(e):W9(e);if(typeof e=="string")return Q9(e);throw new Error("Expected function, string, or object as test")};function $9(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=_o(e[n]);return Kc(a);function a(...l){let s=-1;for(;++s<t.length;)if(t[s].apply(this,l))return!0;return!1}}function W9(e){const t=e;return Kc(n);function n(a){const l=a;let s;for(s in e)if(l[s]!==t[s])return!1;return!0}}function Q9(e){return Kc(t);function t(n){return n&&n.type===e}}function Kc(e){return t;function t(n,a,l){return!!(J9(n)&&e.call(this,n,typeof a=="number"?a:void 0,l||void 0))}}function Z9(){return!0}function J9(e){return e!==null&&typeof e=="object"&&"type"in e}const W6=[],eS=!0,A1=!1,Q6="skip";function Em(e,t,n,a){let l;typeof t=="function"&&typeof n!="function"?(a=n,n=t):l=t;const s=_o(l),o=a?-1:1;d(e,void 0,[])();function d(f,h,p){const E=f&&typeof f=="object"?f:{};if(typeof E.type=="string"){const v=typeof E.tagName=="string"?E.tagName:typeof E.name=="string"?E.name:void 0;Object.defineProperty(T,"name",{value:"node ("+(f.type+(v?"<"+v+">":""))+")"})}return T;function T(){let v=W6,x,N,D;if((!t||s(f,h,p[p.length-1]||void 0))&&(v=tS(n(f,p)),v[0]===A1))return v;if("children"in f&&f.children){const C=f;if(C.children&&v[0]!==Q6)for(N=(a?C.children.length:-1)+o,D=p.concat(C);N>-1&&N<C.children.length;){const I=C.children[N];if(x=d(I,N,D)(),x[0]===A1)return x;N=typeof x[1]=="number"?x[1]:N+o}}return v}}}function tS(e){return Array.isArray(e)?e:typeof e=="number"?[eS,e]:e==null?W6:[e]}function So(e,t,n,a){let l,s,o;typeof t=="function"&&typeof n!="function"?(s=void 0,o=t,l=n):(s=t,o=n,l=a),Em(e,s,d,l);function d(f,h){const p=h[h.length-1],E=p?p.children.indexOf(f):void 0;return o(f,E,p)}}const x1={}.hasOwnProperty,nS={};function rS(e,t){const n=t||nS,a=new Map,l=new Map,s=new Map,o={...F9,...n.handlers},d={all:h,applyData:iS,definitionById:a,footnoteById:l,footnoteCounts:s,footnoteOrder:[],handlers:o,one:f,options:n,patch:aS,wrap:sS};return So(e,function(p){if(p.type==="definition"||p.type==="footnoteDefinition"){const E=p.type==="definition"?a:l,T=String(p.identifier).toUpperCase();E.has(T)||E.set(T,p)}}),d;function f(p,E){const T=p.type,v=d.handlers[T];if(x1.call(d.handlers,T)&&v)return v(d,p,E);if(d.options.passThrough&&d.options.passThrough.includes(T)){if("children"in p){const{children:N,...D}=p,C=Os(D);return C.children=d.all(p),C}return Os(p)}return(d.options.unknownHandler||lS)(d,p,E)}function h(p){const E=[];if("children"in p){const T=p.children;let v=-1;for(;++v<T.length;){const x=d.one(T[v],p);if(x){if(v&&T[v-1].type==="break"&&(!Array.isArray(x)&&x.type==="text"&&(x.value=cb(x.value)),!Array.isArray(x)&&x.type==="element")){const N=x.children[0];N&&N.type==="text"&&(N.value=cb(N.value))}Array.isArray(x)?E.push(...x):E.push(x)}}}return E}}function aS(e,t){e.position&&(t.position=jv(e))}function iS(e,t){let n=t;if(e&&e.data){const a=e.data.hName,l=e.data.hChildren,s=e.data.hProperties;if(typeof a=="string")if(n.type==="element")n.tagName=a;else{const o="children"in n?n.children:[n];n={type:"element",tagName:a,properties:{},children:o}}n.type==="element"&&s&&Object.assign(n.properties,Os(s)),"children"in n&&n.children&&l!==null&&l!==void 0&&(n.children=l)}return n}function lS(e,t){const n=t.data||{},a="value"in t&&!(x1.call(n,"hProperties")||x1.call(n,"hChildren"))?{type:"text",value:t.value}:{type:"element",tagName:"div",properties:{},children:e.all(t)};return e.patch(t,a),e.applyData(t,a)}function sS(e,t){const n=[];let a=-1;for(t&&n.push({type:"text",value:`
`});++a<e.length;)a&&n.push({type:"text",value:`
`}),n.push(e[a]);return t&&e.length>0&&n.push({type:"text",value:`
`}),n}function cb(e){let t=0,n=e.charCodeAt(t);for(;n===9||n===32;)t++,n=e.charCodeAt(t);return e.slice(t)}function db(e,t){const n=rS(e,t),a=n.one(e,void 0),l=X9(n),s=Array.isArray(a)?{type:"root",children:a}:a||{type:"root",children:[]};return l&&s.children.push({type:"text",value:`
`},l),s}function uS(e,t){return e&&"run"in e?async function(n,a){const l=db(n,{file:a,...t});await e.run(l,a)}:function(n,a){return db(n,{file:a,...e||t})}}function fb(e){if(e)throw e}var Sh,hb;function oS(){if(hb)return Sh;hb=1;var e=Object.prototype.hasOwnProperty,t=Object.prototype.toString,n=Object.defineProperty,a=Object.getOwnPropertyDescriptor,l=function(h){return typeof Array.isArray=="function"?Array.isArray(h):t.call(h)==="[object Array]"},s=function(h){if(!h||t.call(h)!=="[object Object]")return!1;var p=e.call(h,"constructor"),E=h.constructor&&h.constructor.prototype&&e.call(h.constructor.prototype,"isPrototypeOf");if(h.constructor&&!p&&!E)return!1;var T;for(T in h);return typeof T>"u"||e.call(h,T)},o=function(h,p){n&&p.name==="__proto__"?n(h,p.name,{enumerable:!0,configurable:!0,value:p.newValue,writable:!0}):h[p.name]=p.newValue},d=function(h,p){if(p==="__proto__")if(e.call(h,p)){if(a)return a(h,p).value}else return;return h[p]};return Sh=function f(){var h,p,E,T,v,x,N=arguments[0],D=1,C=arguments.length,I=!1;for(typeof N=="boolean"&&(I=N,N=arguments[1]||{},D=2),(N==null||typeof N!="object"&&typeof N!="function")&&(N={});D<C;++D)if(h=arguments[D],h!=null)for(p in h)E=d(N,p),T=d(h,p),N!==T&&(I&&T&&(s(T)||(v=l(T)))?(v?(v=!1,x=E&&l(E)?E:[]):x=E&&s(E)?E:{},o(N,{name:p,newValue:f(I,x,T)})):typeof T<"u"&&o(N,{name:p,newValue:T}));return N},Sh}var cS=oS();const Ah=zc(cS);function k1(e){if(typeof e!="object"||e===null)return!1;const t=Object.getPrototypeOf(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)}function dS(){const e=[],t={run:n,use:a};return t;function n(...l){let s=-1;const o=l.pop();if(typeof o!="function")throw new TypeError("Expected function as last argument, not "+o);d(null,...l);function d(f,...h){const p=e[++s];let E=-1;if(f){o(f);return}for(;++E<l.length;)(h[E]===null||h[E]===void 0)&&(h[E]=l[E]);l=h,p?fS(p,d)(...h):o(null,...h)}}function a(l){if(typeof l!="function")throw new TypeError("Expected `middelware` to be a function, not "+l);return e.push(l),t}}function fS(e,t){let n;return a;function a(...o){const d=e.length>o.length;let f;d&&o.push(l);try{f=e.apply(this,o)}catch(h){const p=h;if(d&&n)throw p;return l(p)}d||(f&&f.then&&typeof f.then=="function"?f.then(s,l):f instanceof Error?l(f):s(f))}function l(o,...d){n||(n=!0,t(o,...d))}function s(o){l(null,o)}}const Sa={basename:hS,dirname:mS,extname:pS,join:gS,sep:"/"};function hS(e,t){if(t!==void 0&&typeof t!="string")throw new TypeError('"ext" argument must be a string');Ao(e);let n=0,a=-1,l=e.length,s;if(t===void 0||t.length===0||t.length>e.length){for(;l--;)if(e.codePointAt(l)===47){if(s){n=l+1;break}}else a<0&&(s=!0,a=l+1);return a<0?"":e.slice(n,a)}if(t===e)return"";let o=-1,d=t.length-1;for(;l--;)if(e.codePointAt(l)===47){if(s){n=l+1;break}}else o<0&&(s=!0,o=l+1),d>-1&&(e.codePointAt(l)===t.codePointAt(d--)?d<0&&(a=l):(d=-1,a=o));return n===a?a=o:a<0&&(a=e.length),e.slice(n,a)}function mS(e){if(Ao(e),e.length===0)return".";let t=-1,n=e.length,a;for(;--n;)if(e.codePointAt(n)===47){if(a){t=n;break}}else a||(a=!0);return t<0?e.codePointAt(0)===47?"/":".":t===1&&e.codePointAt(0)===47?"//":e.slice(0,t)}function pS(e){Ao(e);let t=e.length,n=-1,a=0,l=-1,s=0,o;for(;t--;){const d=e.codePointAt(t);if(d===47){if(o){a=t+1;break}continue}n<0&&(o=!0,n=t+1),d===46?l<0?l=t:s!==1&&(s=1):l>-1&&(s=-1)}return l<0||n<0||s===0||s===1&&l===n-1&&l===a+1?"":e.slice(l,n)}function gS(...e){let t=-1,n;for(;++t<e.length;)Ao(e[t]),e[t]&&(n=n===void 0?e[t]:n+"/"+e[t]);return n===void 0?".":bS(n)}function bS(e){Ao(e);const t=e.codePointAt(0)===47;let n=ES(e,!t);return n.length===0&&!t&&(n="."),n.length>0&&e.codePointAt(e.length-1)===47&&(n+="/"),t?"/"+n:n}function ES(e,t){let n="",a=0,l=-1,s=0,o=-1,d,f;for(;++o<=e.length;){if(o<e.length)d=e.codePointAt(o);else{if(d===47)break;d=47}if(d===47){if(!(l===o-1||s===1))if(l!==o-1&&s===2){if(n.length<2||a!==2||n.codePointAt(n.length-1)!==46||n.codePointAt(n.length-2)!==46){if(n.length>2){if(f=n.lastIndexOf("/"),f!==n.length-1){f<0?(n="",a=0):(n=n.slice(0,f),a=n.length-1-n.lastIndexOf("/")),l=o,s=0;continue}}else if(n.length>0){n="",a=0,l=o,s=0;continue}}t&&(n=n.length>0?n+"/..":"..",a=2)}else n.length>0?n+="/"+e.slice(l+1,o):n=e.slice(l+1,o),a=o-l-1;l=o,s=0}else d===46&&s>-1?s++:s=-1}return n}function Ao(e){if(typeof e!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}const yS={cwd:vS};function vS(){return"/"}function N1(e){return!!(e!==null&&typeof e=="object"&&"href"in e&&e.href&&"protocol"in e&&e.protocol&&e.auth===void 0)}function TS(e){if(typeof e=="string")e=new URL(e);else if(!N1(e)){const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`");throw t.code="ERR_INVALID_ARG_TYPE",t}if(e.protocol!=="file:"){const t=new TypeError("The URL must be of scheme file");throw t.code="ERR_INVALID_URL_SCHEME",t}return _S(e)}function _S(e){if(e.hostname!==""){const a=new TypeError('File URL host must be "localhost" or empty on darwin');throw a.code="ERR_INVALID_FILE_URL_HOST",a}const t=e.pathname;let n=-1;for(;++n<t.length;)if(t.codePointAt(n)===37&&t.codePointAt(n+1)===50){const a=t.codePointAt(n+2);if(a===70||a===102){const l=new TypeError("File URL path must not include encoded / characters");throw l.code="ERR_INVALID_FILE_URL_PATH",l}}return decodeURIComponent(t)}const xh=["history","path","basename","stem","extname","dirname"];class Z6{constructor(t){let n;t?N1(t)?n={path:t}:typeof t=="string"||SS(t)?n={value:t}:n=t:n={},this.cwd="cwd"in n?"":yS.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let a=-1;for(;++a<xh.length;){const s=xh[a];s in n&&n[s]!==void 0&&n[s]!==null&&(this[s]=s==="history"?[...n[s]]:n[s])}let l;for(l in n)xh.includes(l)||(this[l]=n[l])}get basename(){return typeof this.path=="string"?Sa.basename(this.path):void 0}set basename(t){Nh(t,"basename"),kh(t,"basename"),this.path=Sa.join(this.dirname||"",t)}get dirname(){return typeof this.path=="string"?Sa.dirname(this.path):void 0}set dirname(t){mb(this.basename,"dirname"),this.path=Sa.join(t||"",this.basename)}get extname(){return typeof this.path=="string"?Sa.extname(this.path):void 0}set extname(t){if(kh(t,"extname"),mb(this.dirname,"extname"),t){if(t.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(t.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=Sa.join(this.dirname,this.stem+(t||""))}get path(){return this.history[this.history.length-1]}set path(t){N1(t)&&(t=TS(t)),Nh(t,"path"),this.path!==t&&this.history.push(t)}get stem(){return typeof this.path=="string"?Sa.basename(this.path,this.extname):void 0}set stem(t){Nh(t,"stem"),kh(t,"stem"),this.path=Sa.join(this.dirname||"",t+(this.extname||""))}fail(t,n,a){const l=this.message(t,n,a);throw l.fatal=!0,l}info(t,n,a){const l=this.message(t,n,a);return l.fatal=void 0,l}message(t,n,a){const l=new Wn(t,n,a);return this.path&&(l.name=this.path+":"+l.name,l.file=this.path),l.fatal=!1,this.messages.push(l),l}toString(t){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(t||void 0).decode(this.value)}}function kh(e,t){if(e&&e.includes(Sa.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+Sa.sep+"`")}function Nh(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}function mb(e,t){if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}function SS(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const AS=function(e){const a=this.constructor.prototype,l=a[e],s=function(){return l.apply(s,arguments)};return Object.setPrototypeOf(s,a),s},xS={}.hasOwnProperty;class ym extends AS{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=dS()}copy(){const t=new ym;let n=-1;for(;++n<this.attachers.length;){const a=this.attachers[n];t.use(...a)}return t.data(Ah(!0,{},this.namespace)),t}data(t,n){return typeof t=="string"?arguments.length===2?(Oh("data",this.frozen),this.namespace[t]=n,this):xS.call(this.namespace,t)&&this.namespace[t]||void 0:t?(Oh("data",this.frozen),this.namespace=t,this):this.namespace}freeze(){if(this.frozen)return this;const t=this;for(;++this.freezeIndex<this.attachers.length;){const[n,...a]=this.attachers[this.freezeIndex];if(a[0]===!1)continue;a[0]===!0&&(a[0]=void 0);const l=n.call(t,...a);typeof l=="function"&&this.transformers.use(l)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(t){this.freeze();const n=X0(t),a=this.parser||this.Parser;return wh("parse",a),a(String(n),n)}process(t,n){const a=this;return this.freeze(),wh("process",this.parser||this.Parser),Ch("process",this.compiler||this.Compiler),n?l(void 0,n):new Promise(l);function l(s,o){const d=X0(t),f=a.parse(d);a.run(f,d,function(p,E,T){if(p||!E||!T)return h(p);const v=E,x=a.stringify(v,T);wS(x)?T.value=x:T.result=x,h(p,T)});function h(p,E){p||!E?o(p):s?s(E):n(void 0,E)}}}processSync(t){let n=!1,a;return this.freeze(),wh("processSync",this.parser||this.Parser),Ch("processSync",this.compiler||this.Compiler),this.process(t,l),gb("processSync","process",n),a;function l(s,o){n=!0,fb(s),a=o}}run(t,n,a){pb(t),this.freeze();const l=this.transformers;return!a&&typeof n=="function"&&(a=n,n=void 0),a?s(void 0,a):new Promise(s);function s(o,d){const f=X0(n);l.run(t,f,h);function h(p,E,T){const v=E||t;p?d(p):o?o(v):a(void 0,v,T)}}}runSync(t,n){let a=!1,l;return this.run(t,n,s),gb("runSync","run",a),l;function s(o,d){fb(o),l=d,a=!0}}stringify(t,n){this.freeze();const a=X0(n),l=this.compiler||this.Compiler;return Ch("stringify",l),pb(t),l(t,a)}use(t,...n){const a=this.attachers,l=this.namespace;if(Oh("use",this.frozen),t!=null)if(typeof t=="function")f(t,n);else if(typeof t=="object")Array.isArray(t)?d(t):o(t);else throw new TypeError("Expected usable value, not `"+t+"`");return this;function s(h){if(typeof h=="function")f(h,[]);else if(typeof h=="object")if(Array.isArray(h)){const[p,...E]=h;f(p,E)}else o(h);else throw new TypeError("Expected usable value, not `"+h+"`")}function o(h){if(!("plugins"in h)&&!("settings"in h))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");d(h.plugins),h.settings&&(l.settings=Ah(!0,l.settings,h.settings))}function d(h){let p=-1;if(h!=null)if(Array.isArray(h))for(;++p<h.length;){const E=h[p];s(E)}else throw new TypeError("Expected a list of plugins, not `"+h+"`")}function f(h,p){let E=-1,T=-1;for(;++E<a.length;)if(a[E][0]===h){T=E;break}if(T===-1)a.push([h,...p]);else if(p.length>0){let[v,...x]=p;const N=a[T][1];k1(N)&&k1(v)&&(v=Ah(!0,N,v)),a[T]=[h,v,...x]}}}}const kS=new ym().freeze();function wh(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `parser`")}function Ch(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `compiler`")}function Oh(e,t){if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function pb(e){if(!k1(e)||typeof e.type!="string")throw new TypeError("Expected node, got `"+e+"`")}function gb(e,t,n){if(!n)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}function X0(e){return NS(e)?e:new Z6(e)}function NS(e){return!!(e&&typeof e=="object"&&"message"in e&&"messages"in e)}function wS(e){return typeof e=="string"||CS(e)}function CS(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const OS="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",bb=[],Eb={allowDangerousHtml:!0},RS=/^(https?|ircs?|mailto|xmpp)$/i,MS=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"className",id:"remove-classname"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function DS(e){const t=IS(e),n=LS(e);return BS(t.runSync(t.parse(n),n),e)}function IS(e){const t=e.rehypePlugins||bb,n=e.remarkPlugins||bb,a=e.remarkRehypeOptions?{...e.remarkRehypeOptions,...Eb}:Eb;return kS().use(p9).use(n).use(uS,a).use(t)}function LS(e){const t=e.children||"",n=new Z6;return typeof t=="string"&&(n.value=t),n}function BS(e,t){const n=t.allowedElements,a=t.allowElement,l=t.components,s=t.disallowedElements,o=t.skipHtml,d=t.unwrapDisallowed,f=t.urlTransform||PS;for(const p of MS)Object.hasOwn(t,p.from)&&(""+p.from+(p.to?"use `"+p.to+"` instead":"remove it")+OS+p.id,void 0);return So(e,h),Zv(e,{Fragment:gt.Fragment,components:l,ignoreInvalidStyle:!0,jsx:gt.jsx,jsxs:gt.jsxs,passKeys:!0,passNode:!0});function h(p,E,T){if(p.type==="raw"&&T&&typeof E=="number")return o?T.children.splice(E,1):T.children[E]={type:"text",value:p.value},E;if(p.type==="element"){let v;for(v in vh)if(Object.hasOwn(vh,v)&&Object.hasOwn(p.properties,v)){const x=p.properties[v],N=vh[v];(N===null||N.includes(p.tagName))&&(p.properties[v]=f(String(x||""),v,p))}}if(p.type==="element"){let v=n?!n.includes(p.tagName):s?s.includes(p.tagName):!1;if(!v&&a&&typeof E=="number"&&(v=!a(p,E,T)),v&&T&&typeof E=="number")return d&&p.children?T.children.splice(E,1,...p.children):T.children.splice(E,1),E}}}function PS(e){const t=e.indexOf(":"),n=e.indexOf("?"),a=e.indexOf("#"),l=e.indexOf("/");return t===-1||l!==-1&&t>l||n!==-1&&t>n||a!==-1&&t>a||RS.test(e.slice(0,t))?e:""}function yb(e,t){const n=String(e);if(typeof t!="string")throw new TypeError("Expected character");let a=0,l=n.indexOf(t);for(;l!==-1;)a++,l=n.indexOf(t,l+t.length);return a}function US(e){if(typeof e!="string")throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}function zS(e,t,n){const l=_o((n||{}).ignore||[]),s=HS(t);let o=-1;for(;++o<s.length;)Em(e,"text",d);function d(h,p){let E=-1,T;for(;++E<p.length;){const v=p[E],x=T?T.children:void 0;if(l(v,x?x.indexOf(v):void 0,T))return;T=v}if(T)return f(h,p)}function f(h,p){const E=p[p.length-1],T=s[o][0],v=s[o][1];let x=0;const D=E.children.indexOf(h);let C=!1,I=[];T.lastIndex=0;let F=T.exec(h.value);for(;F;){const J=F.index,K={index:F.index,input:F.input,stack:[...p,h]};let U=v(...F,K);if(typeof U=="string"&&(U=U.length>0?{type:"text",value:U}:void 0),U===!1?T.lastIndex=J+1:(x!==J&&I.push({type:"text",value:h.value.slice(x,J)}),Array.isArray(U)?I.push(...U):U&&I.push(U),x=J+F[0].length,C=!0),!T.global)break;F=T.exec(h.value)}return C?(x<h.value.length&&I.push({type:"text",value:h.value.slice(x)}),E.children.splice(D,1,...I)):I=[h],D+I.length}}function HS(e){const t=[];if(!Array.isArray(e))throw new TypeError("Expected find and replace tuple or list of tuples");const n=!e[0]||Array.isArray(e[0])?e:[e];let a=-1;for(;++a<n.length;){const l=n[a];t.push([FS(l[0]),qS(l[1])])}return t}function FS(e){return typeof e=="string"?new RegExp(US(e),"g"):e}function qS(e){return typeof e=="function"?e:function(){return e}}const Rh="phrasing",Mh=["autolink","link","image","label"];function YS(){return{transforms:[WS],enter:{literalAutolink:VS,literalAutolinkEmail:Dh,literalAutolinkHttp:Dh,literalAutolinkWww:Dh},exit:{literalAutolink:$S,literalAutolinkEmail:XS,literalAutolinkHttp:KS,literalAutolinkWww:jS}}}function GS(){return{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct:Rh,notInConstruct:Mh},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct:Rh,notInConstruct:Mh},{character:":",before:"[ps]",after:"\\/",inConstruct:Rh,notInConstruct:Mh}]}}function VS(e){this.enter({type:"link",title:null,url:"",children:[]},e)}function Dh(e){this.config.enter.autolinkProtocol.call(this,e)}function KS(e){this.config.exit.autolinkProtocol.call(this,e)}function jS(e){this.config.exit.data.call(this,e);const t=this.stack[this.stack.length-1];t.type,t.url="http://"+this.sliceSerialize(e)}function XS(e){this.config.exit.autolinkEmail.call(this,e)}function $S(e){this.exit(e)}function WS(e){zS(e,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,QS],[new RegExp("(?<=^|\\s|\\p{P}|\\p{S})([-.\\w+]+)@([-\\w]+(?:\\.[-\\w]+)+)","gu"),ZS]],{ignore:["link","linkReference"]})}function QS(e,t,n,a,l){let s="";if(!J6(l)||(/^w/i.test(t)&&(n=t+n,t="",s="http://"),!JS(n)))return!1;const o=eA(n+a);if(!o[0])return!1;const d={type:"link",title:null,url:s+t+o[0],children:[{type:"text",value:t+o[0]}]};return o[1]?[d,{type:"text",value:o[1]}]:d}function ZS(e,t,n,a){return!J6(a,!0)||/[-\d_]$/.test(n)?!1:{type:"link",title:null,url:"mailto:"+t+"@"+n,children:[{type:"text",value:t+"@"+n}]}}function JS(e){const t=e.split(".");return!(t.length<2||t[t.length-1]&&(/_/.test(t[t.length-1])||!/[a-zA-Z\d]/.test(t[t.length-1]))||t[t.length-2]&&(/_/.test(t[t.length-2])||!/[a-zA-Z\d]/.test(t[t.length-2])))}function eA(e){const t=/[!"&'),.:;<>?\]}]+$/.exec(e);if(!t)return[e,void 0];e=e.slice(0,t.index);let n=t[0],a=n.indexOf(")");const l=yb(e,"(");let s=yb(e,")");for(;a!==-1&&l>s;)e+=n.slice(0,a+1),n=n.slice(a+1),a=n.indexOf(")"),s++;return[e,n]}function J6(e,t){const n=e.input.charCodeAt(e.index-1);return(e.index===0||Rl(n)||Yc(n))&&(!t||n!==47)}eE.peek=oA;function tA(){this.buffer()}function nA(e){this.enter({type:"footnoteReference",identifier:"",label:""},e)}function rA(){this.buffer()}function aA(e){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},e)}function iA(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=ha(this.sliceSerialize(e)).toLowerCase(),n.label=t}function lA(e){this.exit(e)}function sA(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=ha(this.sliceSerialize(e)).toLowerCase(),n.label=t}function uA(e){this.exit(e)}function oA(){return"["}function eE(e,t,n,a){const l=n.createTracker(a);let s=l.move("[^");const o=n.enter("footnoteReference"),d=n.enter("reference");return s+=l.move(n.safe(n.associationId(e),{after:"]",before:s})),d(),o(),s+=l.move("]"),s}function cA(){return{enter:{gfmFootnoteCallString:tA,gfmFootnoteCall:nA,gfmFootnoteDefinitionLabelString:rA,gfmFootnoteDefinition:aA},exit:{gfmFootnoteCallString:iA,gfmFootnoteCall:lA,gfmFootnoteDefinitionLabelString:sA,gfmFootnoteDefinition:uA}}}function dA(e){let t=!1;return e&&e.firstLineBlank&&(t=!0),{handlers:{footnoteDefinition:n,footnoteReference:eE},unsafe:[{character:"[",inConstruct:["label","phrasing","reference"]}]};function n(a,l,s,o){const d=s.createTracker(o);let f=d.move("[^");const h=s.enter("footnoteDefinition"),p=s.enter("label");return f+=d.move(s.safe(s.associationId(a),{before:f,after:"]"})),p(),f+=d.move("]:"),a.children&&a.children.length>0&&(d.shift(4),f+=d.move((t?`
`:" ")+s.indentLines(s.containerFlow(a,d.current()),t?tE:fA))),h(),f}}function fA(e,t,n){return t===0?e:tE(e,t,n)}function tE(e,t,n){return(n?"":"    ")+e}const hA=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];nE.peek=EA;function mA(){return{canContainEols:["delete"],enter:{strikethrough:gA},exit:{strikethrough:bA}}}function pA(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:hA}],handlers:{delete:nE}}}function gA(e){this.enter({type:"delete",children:[]},e)}function bA(e){this.exit(e)}function nE(e,t,n,a){const l=n.createTracker(a),s=n.enter("strikethrough");let o=l.move("~~");return o+=n.containerPhrasing(e,{...l.current(),before:o,after:"~"}),o+=l.move("~~"),s(),o}function EA(){return"~"}function yA(e){return e.length}function vA(e,t){const n=t||{},a=(n.align||[]).concat(),l=n.stringLength||yA,s=[],o=[],d=[],f=[];let h=0,p=-1;for(;++p<e.length;){const N=[],D=[];let C=-1;for(e[p].length>h&&(h=e[p].length);++C<e[p].length;){const I=TA(e[p][C]);if(n.alignDelimiters!==!1){const F=l(I);D[C]=F,(f[C]===void 0||F>f[C])&&(f[C]=F)}N.push(I)}o[p]=N,d[p]=D}let E=-1;if(typeof a=="object"&&"length"in a)for(;++E<h;)s[E]=vb(a[E]);else{const N=vb(a);for(;++E<h;)s[E]=N}E=-1;const T=[],v=[];for(;++E<h;){const N=s[E];let D="",C="";N===99?(D=":",C=":"):N===108?D=":":N===114&&(C=":");let I=n.alignDelimiters===!1?1:Math.max(1,f[E]-D.length-C.length);const F=D+"-".repeat(I)+C;n.alignDelimiters!==!1&&(I=D.length+I+C.length,I>f[E]&&(f[E]=I),v[E]=I),T[E]=F}o.splice(1,0,T),d.splice(1,0,v),p=-1;const x=[];for(;++p<o.length;){const N=o[p],D=d[p];E=-1;const C=[];for(;++E<h;){const I=N[E]||"";let F="",J="";if(n.alignDelimiters!==!1){const K=f[E]-(D[E]||0),U=s[E];U===114?F=" ".repeat(K):U===99?K%2?(F=" ".repeat(K/2+.5),J=" ".repeat(K/2-.5)):(F=" ".repeat(K/2),J=F):J=" ".repeat(K)}n.delimiterStart!==!1&&!E&&C.push("|"),n.padding!==!1&&!(n.alignDelimiters===!1&&I==="")&&(n.delimiterStart!==!1||E)&&C.push(" "),n.alignDelimiters!==!1&&C.push(F),C.push(I),n.alignDelimiters!==!1&&C.push(J),n.padding!==!1&&C.push(" "),(n.delimiterEnd!==!1||E!==h-1)&&C.push("|")}x.push(n.delimiterEnd===!1?C.join("").replace(/ +$/,""):C.join(""))}return x.join(`
`)}function TA(e){return e==null?"":String(e)}function vb(e){const t=typeof e=="string"?e.codePointAt(0):0;return t===67||t===99?99:t===76||t===108?108:t===82||t===114?114:0}const Tb={}.hasOwnProperty;function rE(e,t){const n=t||{};function a(l,...s){let o=a.invalid;const d=a.handlers;if(l&&Tb.call(l,e)){const f=String(l[e]);o=Tb.call(d,f)?d[f]:a.unknown}if(o)return o.call(this,l,...s)}return a.handlers=n.handlers||{},a.invalid=n.invalid,a.unknown=n.unknown,a}function _A(e,t,n,a){const l=n.enter("blockquote"),s=n.createTracker(a);s.move("> "),s.shift(2);const o=n.indentLines(n.containerFlow(e,s.current()),SA);return l(),o}function SA(e,t,n){return">"+(n?"":" ")+e}function AA(e,t){return _b(e,t.inConstruct,!0)&&!_b(e,t.notInConstruct,!1)}function _b(e,t,n){if(typeof t=="string"&&(t=[t]),!t||t.length===0)return n;let a=-1;for(;++a<t.length;)if(e.includes(t[a]))return!0;return!1}function Sb(e,t,n,a){let l=-1;for(;++l<n.unsafe.length;)if(n.unsafe[l].character===`
`&&AA(n.stack,n.unsafe[l]))return/[ \t]/.test(a.before)?"":" ";return`\\
`}function aE(e,t){const n=String(e);let a=n.indexOf(t),l=a,s=0,o=0;if(typeof t!="string")throw new TypeError("Expected substring");for(;a!==-1;)a===l?++s>o&&(o=s):s=1,l=a+t.length,a=n.indexOf(t,l);return o}function xA(e,t){return!!(t.options.fences===!1&&e.value&&!e.lang&&/[^ \r\n]/.test(e.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(e.value))}function kA(e){const t=e.options.fence||"`";if(t!=="`"&&t!=="~")throw new Error("Cannot serialize code with `"+t+"` for `options.fence`, expected `` ` `` or `~`");return t}function NA(e,t,n,a){const l=kA(n),s=e.value||"",o=l==="`"?"GraveAccent":"Tilde";if(xA(e,n)){const E=n.enter("codeIndented"),T=n.indentLines(s,wA);return E(),T}const d=n.createTracker(a),f=l.repeat(Math.max(aE(s,l)+1,3)),h=n.enter("codeFenced");let p=d.move(f);if(e.lang){const E=n.enter(`codeFencedLang${o}`);p+=d.move(n.safe(e.lang,{before:p,after:" ",encode:["`"],...d.current()})),E()}if(e.lang&&e.meta){const E=n.enter(`codeFencedMeta${o}`);p+=d.move(" "),p+=d.move(n.safe(e.meta,{before:p,after:`
`,encode:["`"],...d.current()})),E()}return p+=d.move(`
`),s&&(p+=d.move(s+`
`)),p+=d.move(f),h(),p}function wA(e,t,n){return(n?"":"    ")+e}function vm(e){const t=e.options.quote||'"';if(t!=='"'&&t!=="'")throw new Error("Cannot serialize title with `"+t+"` for `options.quote`, expected `\"`, or `'`");return t}function CA(e,t,n,a){const l=vm(n),s=l==='"'?"Quote":"Apostrophe",o=n.enter("definition");let d=n.enter("label");const f=n.createTracker(a);let h=f.move("[");return h+=f.move(n.safe(n.associationId(e),{before:h,after:"]",...f.current()})),h+=f.move("]: "),d(),!e.url||/[\0- \u007F]/.test(e.url)?(d=n.enter("destinationLiteral"),h+=f.move("<"),h+=f.move(n.safe(e.url,{before:h,after:">",...f.current()})),h+=f.move(">")):(d=n.enter("destinationRaw"),h+=f.move(n.safe(e.url,{before:h,after:e.title?" ":`
`,...f.current()}))),d(),e.title&&(d=n.enter(`title${s}`),h+=f.move(" "+l),h+=f.move(n.safe(e.title,{before:h,after:l,...f.current()})),h+=f.move(l),d()),o(),h}function OA(e){const t=e.options.emphasis||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize emphasis with `"+t+"` for `options.emphasis`, expected `*`, or `_`");return t}function po(e){return"&#x"+e.toString(16).toUpperCase()+";"}function Nc(e,t,n){const a=Cs(e),l=Cs(t);return a===void 0?l===void 0?n==="_"?{inside:!0,outside:!0}:{inside:!1,outside:!1}:l===1?{inside:!0,outside:!0}:{inside:!1,outside:!0}:a===1?l===void 0?{inside:!1,outside:!1}:l===1?{inside:!0,outside:!0}:{inside:!1,outside:!1}:l===void 0?{inside:!1,outside:!1}:l===1?{inside:!0,outside:!1}:{inside:!1,outside:!1}}iE.peek=RA;function iE(e,t,n,a){const l=OA(n),s=n.enter("emphasis"),o=n.createTracker(a),d=o.move(l);let f=o.move(n.containerPhrasing(e,{after:l,before:d,...o.current()}));const h=f.charCodeAt(0),p=Nc(a.before.charCodeAt(a.before.length-1),h,l);p.inside&&(f=po(h)+f.slice(1));const E=f.charCodeAt(f.length-1),T=Nc(a.after.charCodeAt(0),E,l);T.inside&&(f=f.slice(0,-1)+po(E));const v=o.move(l);return s(),n.attentionEncodeSurroundingInfo={after:T.outside,before:p.outside},d+f+v}function RA(e,t,n){return n.options.emphasis||"*"}function MA(e,t){let n=!1;return So(e,function(a){if("value"in a&&/\r?\n|\r/.test(a.value)||a.type==="break")return n=!0,A1}),!!((!e.depth||e.depth<3)&&dm(e)&&(t.options.setext||n))}function DA(e,t,n,a){const l=Math.max(Math.min(6,e.depth||1),1),s=n.createTracker(a);if(MA(e,n)){const p=n.enter("headingSetext"),E=n.enter("phrasing"),T=n.containerPhrasing(e,{...s.current(),before:`
`,after:`
`});return E(),p(),T+`
`+(l===1?"=":"-").repeat(T.length-(Math.max(T.lastIndexOf("\r"),T.lastIndexOf(`
`))+1))}const o="#".repeat(l),d=n.enter("headingAtx"),f=n.enter("phrasing");s.move(o+" ");let h=n.containerPhrasing(e,{before:"# ",after:`
`,...s.current()});return/^[\t ]/.test(h)&&(h=po(h.charCodeAt(0))+h.slice(1)),h=h?o+" "+h:o,n.options.closeAtx&&(h+=" "+o),f(),d(),h}lE.peek=IA;function lE(e){return e.value||""}function IA(){return"<"}sE.peek=LA;function sE(e,t,n,a){const l=vm(n),s=l==='"'?"Quote":"Apostrophe",o=n.enter("image");let d=n.enter("label");const f=n.createTracker(a);let h=f.move("![");return h+=f.move(n.safe(e.alt,{before:h,after:"]",...f.current()})),h+=f.move("]("),d(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(d=n.enter("destinationLiteral"),h+=f.move("<"),h+=f.move(n.safe(e.url,{before:h,after:">",...f.current()})),h+=f.move(">")):(d=n.enter("destinationRaw"),h+=f.move(n.safe(e.url,{before:h,after:e.title?" ":")",...f.current()}))),d(),e.title&&(d=n.enter(`title${s}`),h+=f.move(" "+l),h+=f.move(n.safe(e.title,{before:h,after:l,...f.current()})),h+=f.move(l),d()),h+=f.move(")"),o(),h}function LA(){return"!"}uE.peek=BA;function uE(e,t,n,a){const l=e.referenceType,s=n.enter("imageReference");let o=n.enter("label");const d=n.createTracker(a);let f=d.move("![");const h=n.safe(e.alt,{before:f,after:"]",...d.current()});f+=d.move(h+"]["),o();const p=n.stack;n.stack=[],o=n.enter("reference");const E=n.safe(n.associationId(e),{before:f,after:"]",...d.current()});return o(),n.stack=p,s(),l==="full"||!h||h!==E?f+=d.move(E+"]"):l==="shortcut"?f=f.slice(0,-1):f+=d.move("]"),f}function BA(){return"!"}oE.peek=PA;function oE(e,t,n){let a=e.value||"",l="`",s=-1;for(;new RegExp("(^|[^`])"+l+"([^`]|$)").test(a);)l+="`";for(/[^ \r\n]/.test(a)&&(/^[ \r\n]/.test(a)&&/[ \r\n]$/.test(a)||/^`|`$/.test(a))&&(a=" "+a+" ");++s<n.unsafe.length;){const o=n.unsafe[s],d=n.compilePattern(o);let f;if(o.atBreak)for(;f=d.exec(a);){let h=f.index;a.charCodeAt(h)===10&&a.charCodeAt(h-1)===13&&h--,a=a.slice(0,h)+" "+a.slice(f.index+1)}}return l+a+l}function PA(){return"`"}function cE(e,t){const n=dm(e);return!!(!t.options.resourceLink&&e.url&&!e.title&&e.children&&e.children.length===1&&e.children[0].type==="text"&&(n===e.url||"mailto:"+n===e.url)&&/^[a-z][a-z+.-]+:/i.test(e.url)&&!/[\0- <>\u007F]/.test(e.url))}dE.peek=UA;function dE(e,t,n,a){const l=vm(n),s=l==='"'?"Quote":"Apostrophe",o=n.createTracker(a);let d,f;if(cE(e,n)){const p=n.stack;n.stack=[],d=n.enter("autolink");let E=o.move("<");return E+=o.move(n.containerPhrasing(e,{before:E,after:">",...o.current()})),E+=o.move(">"),d(),n.stack=p,E}d=n.enter("link"),f=n.enter("label");let h=o.move("[");return h+=o.move(n.containerPhrasing(e,{before:h,after:"](",...o.current()})),h+=o.move("]("),f(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(f=n.enter("destinationLiteral"),h+=o.move("<"),h+=o.move(n.safe(e.url,{before:h,after:">",...o.current()})),h+=o.move(">")):(f=n.enter("destinationRaw"),h+=o.move(n.safe(e.url,{before:h,after:e.title?" ":")",...o.current()}))),f(),e.title&&(f=n.enter(`title${s}`),h+=o.move(" "+l),h+=o.move(n.safe(e.title,{before:h,after:l,...o.current()})),h+=o.move(l),f()),h+=o.move(")"),d(),h}function UA(e,t,n){return cE(e,n)?"<":"["}fE.peek=zA;function fE(e,t,n,a){const l=e.referenceType,s=n.enter("linkReference");let o=n.enter("label");const d=n.createTracker(a);let f=d.move("[");const h=n.containerPhrasing(e,{before:f,after:"]",...d.current()});f+=d.move(h+"]["),o();const p=n.stack;n.stack=[],o=n.enter("reference");const E=n.safe(n.associationId(e),{before:f,after:"]",...d.current()});return o(),n.stack=p,s(),l==="full"||!h||h!==E?f+=d.move(E+"]"):l==="shortcut"?f=f.slice(0,-1):f+=d.move("]"),f}function zA(){return"["}function Tm(e){const t=e.options.bullet||"*";if(t!=="*"&&t!=="+"&&t!=="-")throw new Error("Cannot serialize items with `"+t+"` for `options.bullet`, expected `*`, `+`, or `-`");return t}function HA(e){const t=Tm(e),n=e.options.bulletOther;if(!n)return t==="*"?"-":"*";if(n!=="*"&&n!=="+"&&n!=="-")throw new Error("Cannot serialize items with `"+n+"` for `options.bulletOther`, expected `*`, `+`, or `-`");if(n===t)throw new Error("Expected `bullet` (`"+t+"`) and `bulletOther` (`"+n+"`) to be different");return n}function FA(e){const t=e.options.bulletOrdered||".";if(t!=="."&&t!==")")throw new Error("Cannot serialize items with `"+t+"` for `options.bulletOrdered`, expected `.` or `)`");return t}function hE(e){const t=e.options.rule||"*";if(t!=="*"&&t!=="-"&&t!=="_")throw new Error("Cannot serialize rules with `"+t+"` for `options.rule`, expected `*`, `-`, or `_`");return t}function qA(e,t,n,a){const l=n.enter("list"),s=n.bulletCurrent;let o=e.ordered?FA(n):Tm(n);const d=e.ordered?o==="."?")":".":HA(n);let f=t&&n.bulletLastUsed?o===n.bulletLastUsed:!1;if(!e.ordered){const p=e.children?e.children[0]:void 0;if((o==="*"||o==="-")&&p&&(!p.children||!p.children[0])&&n.stack[n.stack.length-1]==="list"&&n.stack[n.stack.length-2]==="listItem"&&n.stack[n.stack.length-3]==="list"&&n.stack[n.stack.length-4]==="listItem"&&n.indexStack[n.indexStack.length-1]===0&&n.indexStack[n.indexStack.length-2]===0&&n.indexStack[n.indexStack.length-3]===0&&(f=!0),hE(n)===o&&p){let E=-1;for(;++E<e.children.length;){const T=e.children[E];if(T&&T.type==="listItem"&&T.children&&T.children[0]&&T.children[0].type==="thematicBreak"){f=!0;break}}}}f&&(o=d),n.bulletCurrent=o;const h=n.containerFlow(e,a);return n.bulletLastUsed=o,n.bulletCurrent=s,l(),h}function YA(e){const t=e.options.listItemIndent||"one";if(t!=="tab"&&t!=="one"&&t!=="mixed")throw new Error("Cannot serialize items with `"+t+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return t}function GA(e,t,n,a){const l=YA(n);let s=n.bulletCurrent||Tm(n);t&&t.type==="list"&&t.ordered&&(s=(typeof t.start=="number"&&t.start>-1?t.start:1)+(n.options.incrementListMarker===!1?0:t.children.indexOf(e))+s);let o=s.length+1;(l==="tab"||l==="mixed"&&(t&&t.type==="list"&&t.spread||e.spread))&&(o=Math.ceil(o/4)*4);const d=n.createTracker(a);d.move(s+" ".repeat(o-s.length)),d.shift(o);const f=n.enter("listItem"),h=n.indentLines(n.containerFlow(e,d.current()),p);return f(),h;function p(E,T,v){return T?(v?"":" ".repeat(o))+E:(v?s:s+" ".repeat(o-s.length))+E}}function VA(e,t,n,a){const l=n.enter("paragraph"),s=n.enter("phrasing"),o=n.containerPhrasing(e,a);return s(),l(),o}const KA=_o(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"]);function jA(e,t,n,a){return(e.children.some(function(o){return KA(o)})?n.containerPhrasing:n.containerFlow).call(n,e,a)}function XA(e){const t=e.options.strong||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize strong with `"+t+"` for `options.strong`, expected `*`, or `_`");return t}mE.peek=$A;function mE(e,t,n,a){const l=XA(n),s=n.enter("strong"),o=n.createTracker(a),d=o.move(l+l);let f=o.move(n.containerPhrasing(e,{after:l,before:d,...o.current()}));const h=f.charCodeAt(0),p=Nc(a.before.charCodeAt(a.before.length-1),h,l);p.inside&&(f=po(h)+f.slice(1));const E=f.charCodeAt(f.length-1),T=Nc(a.after.charCodeAt(0),E,l);T.inside&&(f=f.slice(0,-1)+po(E));const v=o.move(l+l);return s(),n.attentionEncodeSurroundingInfo={after:T.outside,before:p.outside},d+f+v}function $A(e,t,n){return n.options.strong||"*"}function WA(e,t,n,a){return n.safe(e.value,a)}function QA(e){const t=e.options.ruleRepetition||3;if(t<3)throw new Error("Cannot serialize rules with repetition `"+t+"` for `options.ruleRepetition`, expected `3` or more");return t}function ZA(e,t,n){const a=(hE(n)+(n.options.ruleSpaces?" ":"")).repeat(QA(n));return n.options.ruleSpaces?a.slice(0,-1):a}const pE={blockquote:_A,break:Sb,code:NA,definition:CA,emphasis:iE,hardBreak:Sb,heading:DA,html:lE,image:sE,imageReference:uE,inlineCode:oE,link:dE,linkReference:fE,list:qA,listItem:GA,paragraph:VA,root:jA,strong:mE,text:WA,thematicBreak:ZA};function JA(){return{enter:{table:ex,tableData:Ab,tableHeader:Ab,tableRow:nx},exit:{codeText:rx,table:tx,tableData:Ih,tableHeader:Ih,tableRow:Ih}}}function ex(e){const t=e._align;this.enter({type:"table",align:t.map(function(n){return n==="none"?null:n}),children:[]},e),this.data.inTable=!0}function tx(e){this.exit(e),this.data.inTable=void 0}function nx(e){this.enter({type:"tableRow",children:[]},e)}function Ih(e){this.exit(e)}function Ab(e){this.enter({type:"tableCell",children:[]},e)}function rx(e){let t=this.resume();this.data.inTable&&(t=t.replace(/\\([\\|])/g,ax));const n=this.stack[this.stack.length-1];n.type,n.value=t,this.exit(e)}function ax(e,t){return t==="|"?t:e}function ix(e){const t=e||{},n=t.tableCellPadding,a=t.tablePipeAlign,l=t.stringLength,s=n?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:T,table:o,tableCell:f,tableRow:d}};function o(v,x,N,D){return h(p(v,N,D),v.align)}function d(v,x,N,D){const C=E(v,N,D),I=h([C]);return I.slice(0,I.indexOf(`
`))}function f(v,x,N,D){const C=N.enter("tableCell"),I=N.enter("phrasing"),F=N.containerPhrasing(v,{...D,before:s,after:s});return I(),C(),F}function h(v,x){return vA(v,{align:x,alignDelimiters:a,padding:n,stringLength:l})}function p(v,x,N){const D=v.children;let C=-1;const I=[],F=x.enter("table");for(;++C<D.length;)I[C]=E(D[C],x,N);return F(),I}function E(v,x,N){const D=v.children;let C=-1;const I=[],F=x.enter("tableRow");for(;++C<D.length;)I[C]=f(D[C],v,x,N);return F(),I}function T(v,x,N){let D=pE.inlineCode(v,x,N);return N.stack.includes("tableCell")&&(D=D.replace(/\|/g,"\\$&")),D}}function lx(){return{exit:{taskListCheckValueChecked:xb,taskListCheckValueUnchecked:xb,paragraph:ux}}}function sx(){return{unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:ox}}}function xb(e){const t=this.stack[this.stack.length-2];t.type,t.checked=e.type==="taskListCheckValueChecked"}function ux(e){const t=this.stack[this.stack.length-2];if(t&&t.type==="listItem"&&typeof t.checked=="boolean"){const n=this.stack[this.stack.length-1];n.type;const a=n.children[0];if(a&&a.type==="text"){const l=t.children;let s=-1,o;for(;++s<l.length;){const d=l[s];if(d.type==="paragraph"){o=d;break}}o===n&&(a.value=a.value.slice(1),a.value.length===0?n.children.shift():n.position&&a.position&&typeof a.position.start.offset=="number"&&(a.position.start.column++,a.position.start.offset++,n.position.start=Object.assign({},a.position.start)))}}this.exit(e)}function ox(e,t,n,a){const l=e.children[0],s=typeof e.checked=="boolean"&&l&&l.type==="paragraph",o="["+(e.checked?"x":" ")+"] ",d=n.createTracker(a);s&&d.move(o);let f=pE.listItem(e,t,n,{...a,...d.current()});return s&&(f=f.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,h)),f;function h(p){return p+o}}function cx(){return[YS(),cA(),mA(),JA(),lx()]}function dx(e){return{extensions:[GS(),dA(e),pA(),ix(e),sx()]}}const fx={tokenize:Ex,partial:!0},gE={tokenize:yx,partial:!0},bE={tokenize:vx,partial:!0},EE={tokenize:Tx,partial:!0},hx={tokenize:_x,partial:!0},yE={name:"wwwAutolink",tokenize:gx,previous:TE},vE={name:"protocolAutolink",tokenize:bx,previous:_E},oi={name:"emailAutolink",tokenize:px,previous:SE},Ra={};function mx(){return{text:Ra}}let kl=48;for(;kl<123;)Ra[kl]=oi,kl++,kl===58?kl=65:kl===91&&(kl=97);Ra[43]=oi;Ra[45]=oi;Ra[46]=oi;Ra[95]=oi;Ra[72]=[oi,vE];Ra[104]=[oi,vE];Ra[87]=[oi,yE];Ra[119]=[oi,yE];function px(e,t,n){const a=this;let l,s;return o;function o(E){return!w1(E)||!SE.call(a,a.previous)||_m(a.events)?n(E):(e.enter("literalAutolink"),e.enter("literalAutolinkEmail"),d(E))}function d(E){return w1(E)?(e.consume(E),d):E===64?(e.consume(E),f):n(E)}function f(E){return E===46?e.check(hx,p,h)(E):E===45||E===95||$n(E)?(s=!0,e.consume(E),f):p(E)}function h(E){return e.consume(E),l=!0,f}function p(E){return s&&l&&lr(a.previous)?(e.exit("literalAutolinkEmail"),e.exit("literalAutolink"),t(E)):n(E)}}function gx(e,t,n){const a=this;return l;function l(o){return o!==87&&o!==119||!TE.call(a,a.previous)||_m(a.events)?n(o):(e.enter("literalAutolink"),e.enter("literalAutolinkWww"),e.check(fx,e.attempt(gE,e.attempt(bE,s),n),n)(o))}function s(o){return e.exit("literalAutolinkWww"),e.exit("literalAutolink"),t(o)}}function bx(e,t,n){const a=this;let l="",s=!1;return o;function o(E){return(E===72||E===104)&&_E.call(a,a.previous)&&!_m(a.events)?(e.enter("literalAutolink"),e.enter("literalAutolinkHttp"),l+=String.fromCodePoint(E),e.consume(E),d):n(E)}function d(E){if(lr(E)&&l.length<5)return l+=String.fromCodePoint(E),e.consume(E),d;if(E===58){const T=l.toLowerCase();if(T==="http"||T==="https")return e.consume(E),f}return n(E)}function f(E){return E===47?(e.consume(E),s?h:(s=!0,f)):n(E)}function h(E){return E===null||xc(E)||Gt(E)||Rl(E)||Yc(E)?n(E):e.attempt(gE,e.attempt(bE,p),n)(E)}function p(E){return e.exit("literalAutolinkHttp"),e.exit("literalAutolink"),t(E)}}function Ex(e,t,n){let a=0;return l;function l(o){return(o===87||o===119)&&a<3?(a++,e.consume(o),l):o===46&&a===3?(e.consume(o),s):n(o)}function s(o){return o===null?n(o):t(o)}}function yx(e,t,n){let a,l,s;return o;function o(h){return h===46||h===95?e.check(EE,f,d)(h):h===null||Gt(h)||Rl(h)||h!==45&&Yc(h)?f(h):(s=!0,e.consume(h),o)}function d(h){return h===95?a=!0:(l=a,a=void 0),e.consume(h),o}function f(h){return l||a||!s?n(h):t(h)}}function vx(e,t){let n=0,a=0;return l;function l(o){return o===40?(n++,e.consume(o),l):o===41&&a<n?s(o):o===33||o===34||o===38||o===39||o===41||o===42||o===44||o===46||o===58||o===59||o===60||o===63||o===93||o===95||o===126?e.check(EE,t,s)(o):o===null||Gt(o)||Rl(o)?t(o):(e.consume(o),l)}function s(o){return o===41&&a++,e.consume(o),l}}function Tx(e,t,n){return a;function a(d){return d===33||d===34||d===39||d===41||d===42||d===44||d===46||d===58||d===59||d===63||d===95||d===126?(e.consume(d),a):d===38?(e.consume(d),s):d===93?(e.consume(d),l):d===60||d===null||Gt(d)||Rl(d)?t(d):n(d)}function l(d){return d===null||d===40||d===91||Gt(d)||Rl(d)?t(d):a(d)}function s(d){return lr(d)?o(d):n(d)}function o(d){return d===59?(e.consume(d),a):lr(d)?(e.consume(d),o):n(d)}}function _x(e,t,n){return a;function a(s){return e.consume(s),l}function l(s){return $n(s)?n(s):t(s)}}function TE(e){return e===null||e===40||e===42||e===95||e===91||e===93||e===126||Gt(e)}function _E(e){return!lr(e)}function SE(e){return!(e===47||w1(e))}function w1(e){return e===43||e===45||e===46||e===95||$n(e)}function _m(e){let t=e.length,n=!1;for(;t--;){const a=e[t][1];if((a.type==="labelLink"||a.type==="labelImage")&&!a._balanced){n=!0;break}if(a._gfmAutolinkLiteralWalkedInto){n=!1;break}}return e.length>0&&!n&&(e[e.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),n}const Sx={tokenize:Rx,partial:!0};function Ax(){return{document:{91:{name:"gfmFootnoteDefinition",tokenize:wx,continuation:{tokenize:Cx},exit:Ox}},text:{91:{name:"gfmFootnoteCall",tokenize:Nx},93:{name:"gfmPotentialFootnoteCall",add:"after",tokenize:xx,resolveTo:kx}}}}function xx(e,t,n){const a=this;let l=a.events.length;const s=a.parser.gfmFootnotes||(a.parser.gfmFootnotes=[]);let o;for(;l--;){const f=a.events[l][1];if(f.type==="labelImage"){o=f;break}if(f.type==="gfmFootnoteCall"||f.type==="labelLink"||f.type==="label"||f.type==="image"||f.type==="link")break}return d;function d(f){if(!o||!o._balanced)return n(f);const h=ha(a.sliceSerialize({start:o.end,end:a.now()}));return h.codePointAt(0)!==94||!s.includes(h.slice(1))?n(f):(e.enter("gfmFootnoteCallLabelMarker"),e.consume(f),e.exit("gfmFootnoteCallLabelMarker"),t(f))}}function kx(e,t){let n=e.length;for(;n--;)if(e[n][1].type==="labelImage"&&e[n][0]==="enter"){e[n][1];break}e[n+1][1].type="data",e[n+3][1].type="gfmFootnoteCallLabelMarker";const a={type:"gfmFootnoteCall",start:Object.assign({},e[n+3][1].start),end:Object.assign({},e[e.length-1][1].end)},l={type:"gfmFootnoteCallMarker",start:Object.assign({},e[n+3][1].end),end:Object.assign({},e[n+3][1].end)};l.end.column++,l.end.offset++,l.end._bufferIndex++;const s={type:"gfmFootnoteCallString",start:Object.assign({},l.end),end:Object.assign({},e[e.length-1][1].start)},o={type:"chunkString",contentType:"string",start:Object.assign({},s.start),end:Object.assign({},s.end)},d=[e[n+1],e[n+2],["enter",a,t],e[n+3],e[n+4],["enter",l,t],["exit",l,t],["enter",s,t],["enter",o,t],["exit",o,t],["exit",s,t],e[e.length-2],e[e.length-1],["exit",a,t]];return e.splice(n,e.length-n+1,...d),e}function Nx(e,t,n){const a=this,l=a.parser.gfmFootnotes||(a.parser.gfmFootnotes=[]);let s=0,o;return d;function d(E){return e.enter("gfmFootnoteCall"),e.enter("gfmFootnoteCallLabelMarker"),e.consume(E),e.exit("gfmFootnoteCallLabelMarker"),f}function f(E){return E!==94?n(E):(e.enter("gfmFootnoteCallMarker"),e.consume(E),e.exit("gfmFootnoteCallMarker"),e.enter("gfmFootnoteCallString"),e.enter("chunkString").contentType="string",h)}function h(E){if(s>999||E===93&&!o||E===null||E===91||Gt(E))return n(E);if(E===93){e.exit("chunkString");const T=e.exit("gfmFootnoteCallString");return l.includes(ha(a.sliceSerialize(T)))?(e.enter("gfmFootnoteCallLabelMarker"),e.consume(E),e.exit("gfmFootnoteCallLabelMarker"),e.exit("gfmFootnoteCall"),t):n(E)}return Gt(E)||(o=!0),s++,e.consume(E),E===92?p:h}function p(E){return E===91||E===92||E===93?(e.consume(E),s++,h):h(E)}}function wx(e,t,n){const a=this,l=a.parser.gfmFootnotes||(a.parser.gfmFootnotes=[]);let s,o=0,d;return f;function f(x){return e.enter("gfmFootnoteDefinition")._container=!0,e.enter("gfmFootnoteDefinitionLabel"),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(x),e.exit("gfmFootnoteDefinitionLabelMarker"),h}function h(x){return x===94?(e.enter("gfmFootnoteDefinitionMarker"),e.consume(x),e.exit("gfmFootnoteDefinitionMarker"),e.enter("gfmFootnoteDefinitionLabelString"),e.enter("chunkString").contentType="string",p):n(x)}function p(x){if(o>999||x===93&&!d||x===null||x===91||Gt(x))return n(x);if(x===93){e.exit("chunkString");const N=e.exit("gfmFootnoteDefinitionLabelString");return s=ha(a.sliceSerialize(N)),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(x),e.exit("gfmFootnoteDefinitionLabelMarker"),e.exit("gfmFootnoteDefinitionLabel"),T}return Gt(x)||(d=!0),o++,e.consume(x),x===92?E:p}function E(x){return x===91||x===92||x===93?(e.consume(x),o++,p):p(x)}function T(x){return x===58?(e.enter("definitionMarker"),e.consume(x),e.exit("definitionMarker"),l.includes(s)||l.push(s),yt(e,v,"gfmFootnoteDefinitionWhitespace")):n(x)}function v(x){return t(x)}}function Cx(e,t,n){return e.check(To,t,e.attempt(Sx,t,n))}function Ox(e){e.exit("gfmFootnoteDefinition")}function Rx(e,t,n){const a=this;return yt(e,l,"gfmFootnoteDefinitionIndent",5);function l(s){const o=a.events[a.events.length-1];return o&&o[1].type==="gfmFootnoteDefinitionIndent"&&o[2].sliceSerialize(o[1],!0).length===4?t(s):n(s)}}function Mx(e){let n=(e||{}).singleTilde;const a={name:"strikethrough",tokenize:s,resolveAll:l};return n==null&&(n=!0),{text:{126:a},insideSpan:{null:[a]},attentionMarkers:{null:[126]}};function l(o,d){let f=-1;for(;++f<o.length;)if(o[f][0]==="enter"&&o[f][1].type==="strikethroughSequenceTemporary"&&o[f][1]._close){let h=f;for(;h--;)if(o[h][0]==="exit"&&o[h][1].type==="strikethroughSequenceTemporary"&&o[h][1]._open&&o[f][1].end.offset-o[f][1].start.offset===o[h][1].end.offset-o[h][1].start.offset){o[f][1].type="strikethroughSequence",o[h][1].type="strikethroughSequence";const p={type:"strikethrough",start:Object.assign({},o[h][1].start),end:Object.assign({},o[f][1].end)},E={type:"strikethroughText",start:Object.assign({},o[h][1].end),end:Object.assign({},o[f][1].start)},T=[["enter",p,d],["enter",o[h][1],d],["exit",o[h][1],d],["enter",E,d]],v=d.parser.constructs.insideSpan.null;v&&Pr(T,T.length,0,Gc(v,o.slice(h+1,f),d)),Pr(T,T.length,0,[["exit",E,d],["enter",o[f][1],d],["exit",o[f][1],d],["exit",p,d]]),Pr(o,h-1,f-h+3,T),f=h+T.length-2;break}}for(f=-1;++f<o.length;)o[f][1].type==="strikethroughSequenceTemporary"&&(o[f][1].type="data");return o}function s(o,d,f){const h=this.previous,p=this.events;let E=0;return T;function T(x){return h===126&&p[p.length-1][1].type!=="characterEscape"?f(x):(o.enter("strikethroughSequenceTemporary"),v(x))}function v(x){const N=Cs(h);if(x===126)return E>1?f(x):(o.consume(x),E++,v);if(E<2&&!n)return f(x);const D=o.exit("strikethroughSequenceTemporary"),C=Cs(x);return D._open=!C||C===2&&!!N,D._close=!N||N===2&&!!C,d(x)}}}class Dx{constructor(){this.map=[]}add(t,n,a){Ix(this,t,n,a)}consume(t){if(this.map.sort(function(s,o){return s[0]-o[0]}),this.map.length===0)return;let n=this.map.length;const a=[];for(;n>0;)n-=1,a.push(t.slice(this.map[n][0]+this.map[n][1]),this.map[n][2]),t.length=this.map[n][0];a.push(t.slice()),t.length=0;let l=a.pop();for(;l;){for(const s of l)t.push(s);l=a.pop()}this.map.length=0}}function Ix(e,t,n,a){let l=0;if(!(n===0&&a.length===0)){for(;l<e.map.length;){if(e.map[l][0]===t){e.map[l][1]+=n,e.map[l][2].push(...a);return}l+=1}e.map.push([t,n,a])}}function Lx(e,t){let n=!1;const a=[];for(;t<e.length;){const l=e[t];if(n){if(l[0]==="enter")l[1].type==="tableContent"&&a.push(e[t+1][1].type==="tableDelimiterMarker"?"left":"none");else if(l[1].type==="tableContent"){if(e[t-1][1].type==="tableDelimiterMarker"){const s=a.length-1;a[s]=a[s]==="left"?"center":"right"}}else if(l[1].type==="tableDelimiterRow")break}else l[0]==="enter"&&l[1].type==="tableDelimiterRow"&&(n=!0);t+=1}return a}function Bx(){return{flow:{null:{name:"table",tokenize:Px,resolveAll:Ux}}}}function Px(e,t,n){const a=this;let l=0,s=0,o;return d;function d(G){let ge=a.events.length-1;for(;ge>-1;){const fe=a.events[ge][1].type;if(fe==="lineEnding"||fe==="linePrefix")ge--;else break}const ce=ge>-1?a.events[ge][1].type:null,Se=ce==="tableHead"||ce==="tableRow"?U:f;return Se===U&&a.parser.lazy[a.now().line]?n(G):Se(G)}function f(G){return e.enter("tableHead"),e.enter("tableRow"),h(G)}function h(G){return G===124||(o=!0,s+=1),p(G)}function p(G){return G===null?n(G):Ye(G)?s>1?(s=0,a.interrupt=!0,e.exit("tableRow"),e.enter("lineEnding"),e.consume(G),e.exit("lineEnding"),v):n(G):St(G)?yt(e,p,"whitespace")(G):(s+=1,o&&(o=!1,l+=1),G===124?(e.enter("tableCellDivider"),e.consume(G),e.exit("tableCellDivider"),o=!0,p):(e.enter("data"),E(G)))}function E(G){return G===null||G===124||Gt(G)?(e.exit("data"),p(G)):(e.consume(G),G===92?T:E)}function T(G){return G===92||G===124?(e.consume(G),E):E(G)}function v(G){return a.interrupt=!1,a.parser.lazy[a.now().line]?n(G):(e.enter("tableDelimiterRow"),o=!1,St(G)?yt(e,x,"linePrefix",a.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(G):x(G))}function x(G){return G===45||G===58?D(G):G===124?(o=!0,e.enter("tableCellDivider"),e.consume(G),e.exit("tableCellDivider"),N):K(G)}function N(G){return St(G)?yt(e,D,"whitespace")(G):D(G)}function D(G){return G===58?(s+=1,o=!0,e.enter("tableDelimiterMarker"),e.consume(G),e.exit("tableDelimiterMarker"),C):G===45?(s+=1,C(G)):G===null||Ye(G)?J(G):K(G)}function C(G){return G===45?(e.enter("tableDelimiterFiller"),I(G)):K(G)}function I(G){return G===45?(e.consume(G),I):G===58?(o=!0,e.exit("tableDelimiterFiller"),e.enter("tableDelimiterMarker"),e.consume(G),e.exit("tableDelimiterMarker"),F):(e.exit("tableDelimiterFiller"),F(G))}function F(G){return St(G)?yt(e,J,"whitespace")(G):J(G)}function J(G){return G===124?x(G):G===null||Ye(G)?!o||l!==s?K(G):(e.exit("tableDelimiterRow"),e.exit("tableHead"),t(G)):K(G)}function K(G){return n(G)}function U(G){return e.enter("tableRow"),le(G)}function le(G){return G===124?(e.enter("tableCellDivider"),e.consume(G),e.exit("tableCellDivider"),le):G===null||Ye(G)?(e.exit("tableRow"),t(G)):St(G)?yt(e,le,"whitespace")(G):(e.enter("data"),ae(G))}function ae(G){return G===null||G===124||Gt(G)?(e.exit("data"),le(G)):(e.consume(G),G===92?se:ae)}function se(G){return G===92||G===124?(e.consume(G),ae):ae(G)}}function Ux(e,t){let n=-1,a=!0,l=0,s=[0,0,0,0],o=[0,0,0,0],d=!1,f=0,h,p,E;const T=new Dx;for(;++n<e.length;){const v=e[n],x=v[1];v[0]==="enter"?x.type==="tableHead"?(d=!1,f!==0&&(kb(T,t,f,h,p),p=void 0,f=0),h={type:"table",start:Object.assign({},x.start),end:Object.assign({},x.end)},T.add(n,0,[["enter",h,t]])):x.type==="tableRow"||x.type==="tableDelimiterRow"?(a=!0,E=void 0,s=[0,0,0,0],o=[0,n+1,0,0],d&&(d=!1,p={type:"tableBody",start:Object.assign({},x.start),end:Object.assign({},x.end)},T.add(n,0,[["enter",p,t]])),l=x.type==="tableDelimiterRow"?2:p?3:1):l&&(x.type==="data"||x.type==="tableDelimiterMarker"||x.type==="tableDelimiterFiller")?(a=!1,o[2]===0&&(s[1]!==0&&(o[0]=o[1],E=$0(T,t,s,l,void 0,E),s=[0,0,0,0]),o[2]=n)):x.type==="tableCellDivider"&&(a?a=!1:(s[1]!==0&&(o[0]=o[1],E=$0(T,t,s,l,void 0,E)),s=o,o=[s[1],n,0,0])):x.type==="tableHead"?(d=!0,f=n):x.type==="tableRow"||x.type==="tableDelimiterRow"?(f=n,s[1]!==0?(o[0]=o[1],E=$0(T,t,s,l,n,E)):o[1]!==0&&(E=$0(T,t,o,l,n,E)),l=0):l&&(x.type==="data"||x.type==="tableDelimiterMarker"||x.type==="tableDelimiterFiller")&&(o[3]=n)}for(f!==0&&kb(T,t,f,h,p),T.consume(t.events),n=-1;++n<t.events.length;){const v=t.events[n];v[0]==="enter"&&v[1].type==="table"&&(v[1]._align=Lx(t.events,n))}return e}function $0(e,t,n,a,l,s){const o=a===1?"tableHeader":a===2?"tableDelimiter":"tableData",d="tableContent";n[0]!==0&&(s.end=Object.assign({},ys(t.events,n[0])),e.add(n[0],0,[["exit",s,t]]));const f=ys(t.events,n[1]);if(s={type:o,start:Object.assign({},f),end:Object.assign({},f)},e.add(n[1],0,[["enter",s,t]]),n[2]!==0){const h=ys(t.events,n[2]),p=ys(t.events,n[3]),E={type:d,start:Object.assign({},h),end:Object.assign({},p)};if(e.add(n[2],0,[["enter",E,t]]),a!==2){const T=t.events[n[2]],v=t.events[n[3]];if(T[1].end=Object.assign({},v[1].end),T[1].type="chunkText",T[1].contentType="text",n[3]>n[2]+1){const x=n[2]+1,N=n[3]-n[2]-1;e.add(x,N,[])}}e.add(n[3]+1,0,[["exit",E,t]])}return l!==void 0&&(s.end=Object.assign({},ys(t.events,l)),e.add(l,0,[["exit",s,t]]),s=void 0),s}function kb(e,t,n,a,l){const s=[],o=ys(t.events,n);l&&(l.end=Object.assign({},o),s.push(["exit",l,t])),a.end=Object.assign({},o),s.push(["exit",a,t]),e.add(n+1,0,s)}function ys(e,t){const n=e[t],a=n[0]==="enter"?"start":"end";return n[1][a]}const zx={name:"tasklistCheck",tokenize:Fx};function Hx(){return{text:{91:zx}}}function Fx(e,t,n){const a=this;return l;function l(f){return a.previous!==null||!a._gfmTasklistFirstContentOfListItem?n(f):(e.enter("taskListCheck"),e.enter("taskListCheckMarker"),e.consume(f),e.exit("taskListCheckMarker"),s)}function s(f){return Gt(f)?(e.enter("taskListCheckValueUnchecked"),e.consume(f),e.exit("taskListCheckValueUnchecked"),o):f===88||f===120?(e.enter("taskListCheckValueChecked"),e.consume(f),e.exit("taskListCheckValueChecked"),o):n(f)}function o(f){return f===93?(e.enter("taskListCheckMarker"),e.consume(f),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),d):n(f)}function d(f){return Ye(f)?t(f):St(f)?e.check({tokenize:qx},t,n)(f):n(f)}}function qx(e,t,n){return yt(e,a,"whitespace");function a(l){return l===null?n(l):t(l)}}function Yx(e){return M6([mx(),Ax(),Mx(e),Bx(),Hx()])}const Gx={};function Vx(e){const t=this,n=e||Gx,a=t.data(),l=a.micromarkExtensions||(a.micromarkExtensions=[]),s=a.fromMarkdownExtensions||(a.fromMarkdownExtensions=[]),o=a.toMarkdownExtensions||(a.toMarkdownExtensions=[]);l.push(Yx(n)),s.push(cx()),o.push(dx(n))}const Nb=/[#.]/g;function Kx(e,t){const n=e||"",a={};let l=0,s,o;for(;l<n.length;){Nb.lastIndex=l;const d=Nb.exec(n),f=n.slice(l,d?d.index:n.length);f&&(s?s==="#"?a.id=f:Array.isArray(a.className)?a.className.push(f):a.className=[f]:o=f,l+=f.length),d&&(s=d[0],l++)}return{type:"element",tagName:o||t||"div",properties:a,children:[]}}function AE(e,t,n){const a=n?Wx(n):void 0;function l(s,o,...d){let f;if(s==null){f={type:"root",children:[]};const h=o;d.unshift(h)}else{f=Kx(s,t);const h=f.tagName.toLowerCase(),p=a?a.get(h):void 0;if(f.tagName=p||h,jx(o))d.unshift(o);else for(const[E,T]of Object.entries(o))Xx(e,f.properties,E,T)}for(const h of d)C1(f.children,h);return f.type==="element"&&f.tagName==="template"&&(f.content={type:"root",children:f.children},f.children=[]),f}return l}function jx(e){if(e===null||typeof e!="object"||Array.isArray(e))return!0;if(typeof e.type!="string")return!1;const t=e,n=Object.keys(e);for(const a of n){const l=t[a];if(l&&typeof l=="object"){if(!Array.isArray(l))return!0;const s=l;for(const o of s)if(typeof o!="number"&&typeof o!="string")return!0}}return!!("children"in e&&Array.isArray(e.children))}function Xx(e,t,n,a){const l=sm(e,n);let s;if(a!=null){if(typeof a=="number"){if(Number.isNaN(a))return;s=a}else typeof a=="boolean"?s=a:typeof a=="string"?l.spaceSeparated?s=H4(a):l.commaSeparated?s=L4(a):l.commaOrSpaceSeparated?s=H4(L4(a).join(" ")):s=wb(l,l.property,a):Array.isArray(a)?s=[...a]:s=l.property==="style"?$x(a):String(a);if(Array.isArray(s)){const o=[];for(const d of s)o.push(wb(l,l.property,d));s=o}l.property==="className"&&Array.isArray(t.className)&&(s=t.className.concat(s)),t[l.property]=s}}function C1(e,t){if(t!=null)if(typeof t=="number"||typeof t=="string")e.push({type:"text",value:String(t)});else if(Array.isArray(t))for(const n of t)C1(e,n);else if(typeof t=="object"&&"type"in t)t.type==="root"?C1(e,t.children):e.push(t);else throw new Error("Expected node, nodes, or string, got `"+t+"`")}function wb(e,t,n){if(typeof n=="string"){if(e.number&&n&&!Number.isNaN(Number(n)))return Number(n);if((e.boolean||e.overloadedBoolean)&&(n===""||ho(n)===ho(t)))return!0}return n}function $x(e){const t=[];for(const[n,a]of Object.entries(e))t.push([n,a].join(": "));return t.join("; ")}function Wx(e){const t=new Map;for(const n of e)t.set(n.toLowerCase(),n);return t}const Qx=["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","solidColor","textArea","textPath"],xE=AE(Fc,"div"),kE=AE(Ls,"g",Qx);function Zx(e){const t=String(e),n=[];return{toOffset:l,toPoint:a};function a(s){if(typeof s=="number"&&s>-1&&s<=t.length){let o=0;for(;;){let d=n[o];if(d===void 0){const f=Cb(t,n[o-1]);d=f===-1?t.length+1:f+1,n[o]=d}if(d>s)return{line:o+1,column:s-(o>0?n[o-1]:0)+1,offset:s};o++}}}function l(s){if(s&&typeof s.line=="number"&&typeof s.column=="number"&&!Number.isNaN(s.line)&&!Number.isNaN(s.column)){for(;n.length<s.line;){const d=n[n.length-1],f=Cb(t,d),h=f===-1?t.length+1:f+1;if(d===h)break;n.push(h)}const o=(s.line>1?n[s.line-2]:0)+s.column-1;if(o<n[s.line-1])return o}}}function Cb(e,t){const n=e.indexOf("\r",t),a=e.indexOf(`
`,t);return a===-1?n:n===-1||n+1===a?a:n<a?n:a}const ka={html:"http://www.w3.org/1999/xhtml",mathml:"http://www.w3.org/1998/Math/MathML",svg:"http://www.w3.org/2000/svg",xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"},NE={}.hasOwnProperty,Jx=Object.prototype;function ek(e,t){const n=t||{};return Sm({file:n.file||void 0,location:!1,schema:n.space==="svg"?Ls:Fc,verbose:n.verbose||!1},e)}function Sm(e,t){let n;switch(t.nodeName){case"#comment":{const a=t;return n={type:"comment",value:a.data},yc(e,a,n),n}case"#document":case"#document-fragment":{const a=t,l="mode"in a?a.mode==="quirks"||a.mode==="limited-quirks":!1;if(n={type:"root",children:wE(e,t.childNodes),data:{quirksMode:l}},e.file&&e.location){const s=String(e.file),o=Zx(s),d=o.toPoint(0),f=o.toPoint(s.length);n.position={start:d,end:f}}return n}case"#documentType":{const a=t;return n={type:"doctype"},yc(e,a,n),n}case"#text":{const a=t;return n={type:"text",value:a.value},yc(e,a,n),n}default:return n=tk(e,t),n}}function wE(e,t){let n=-1;const a=[];for(;++n<t.length;){const l=Sm(e,t[n]);a.push(l)}return a}function tk(e,t){const n=e.schema;e.schema=t.namespaceURI===ka.svg?Ls:Fc;let a=-1;const l={};for(;++a<t.attrs.length;){const d=t.attrs[a],f=(d.prefix?d.prefix+":":"")+d.name;NE.call(Jx,f)||(l[f]=d.value)}const o=(e.schema.space==="svg"?kE:xE)(t.tagName,l,wE(e,t.childNodes));if(yc(e,t,o),o.tagName==="template"){const d=t,f=d.sourceCodeLocation,h=f&&f.startTag&&xs(f.startTag),p=f&&f.endTag&&xs(f.endTag),E=Sm(e,d.content);h&&p&&e.file&&(E.position={start:h.end,end:p.start}),o.content=E}return e.schema=n,o}function yc(e,t,n){if("sourceCodeLocation"in t&&t.sourceCodeLocation&&e.file){const a=nk(e,n,t.sourceCodeLocation);a&&(e.location=!0,n.position=a)}}function nk(e,t,n){const a=xs(n);if(t.type==="element"){const l=t.children[t.children.length-1];if(a&&!n.endTag&&l&&l.position&&l.position.end&&(a.end=Object.assign({},l.position.end)),e.verbose){const s={};let o;if(n.attrs)for(o in n.attrs)NE.call(n.attrs,o)&&(s[sm(e.schema,o).property]=xs(n.attrs[o]));n.startTag;const d=xs(n.startTag),f=n.endTag?xs(n.endTag):void 0,h={opening:d};f&&(h.closing=f),h.properties=s,t.data={position:h}}}return a}function xs(e){const t=Ob({line:e.startLine,column:e.startCol,offset:e.startOffset}),n=Ob({line:e.endLine,column:e.endCol,offset:e.endOffset});return t||n?{start:t,end:n}:void 0}function Ob(e){return e.line&&e.column?e:void 0}class xo{constructor(t,n,a){this.property=t,this.normal=n,a&&(this.space=a)}}xo.prototype.property={};xo.prototype.normal={};xo.prototype.space=null;function CE(e,t){const n={},a={};let l=-1;for(;++l<e.length;)Object.assign(n,e[l].property),Object.assign(a,e[l].normal);return new xo(n,a,t)}function O1(e){return e.toLowerCase()}class na{constructor(t,n){this.property=t,this.attribute=n}}na.prototype.space=null;na.prototype.boolean=!1;na.prototype.booleanish=!1;na.prototype.overloadedBoolean=!1;na.prototype.number=!1;na.prototype.commaSeparated=!1;na.prototype.spaceSeparated=!1;na.prototype.commaOrSpaceSeparated=!1;na.prototype.mustUseProperty=!1;na.prototype.defined=!1;let rk=0;const ot=Dl(),Nn=Dl(),OE=Dl(),Ce=Dl(),Xt=Dl(),Ns=Dl(),Ir=Dl();function Dl(){return 2**++rk}const R1=Object.freeze(Object.defineProperty({__proto__:null,boolean:ot,booleanish:Nn,commaOrSpaceSeparated:Ir,commaSeparated:Ns,number:Ce,overloadedBoolean:OE,spaceSeparated:Xt},Symbol.toStringTag,{value:"Module"})),Lh=Object.keys(R1);class Am extends na{constructor(t,n,a,l){let s=-1;if(super(t,n),Rb(this,"space",l),typeof a=="number")for(;++s<Lh.length;){const o=Lh[s];Rb(this,Lh[s],(a&R1[o])===R1[o])}}}Am.prototype.defined=!0;function Rb(e,t,n){n&&(e[t]=n)}const ak={}.hasOwnProperty;function Ps(e){const t={},n={};let a;for(a in e.properties)if(ak.call(e.properties,a)){const l=e.properties[a],s=new Am(a,e.transform(e.attributes||{},a),l,e.space);e.mustUseProperty&&e.mustUseProperty.includes(a)&&(s.mustUseProperty=!0),t[a]=s,n[O1(a)]=a,n[O1(s.attribute)]=a}return new xo(t,n,e.space)}const RE=Ps({space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()},properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null}}),ME=Ps({space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()},properties:{xmlLang:null,xmlBase:null,xmlSpace:null}});function DE(e,t){return t in e?e[t]:t}function IE(e,t){return DE(e,t.toLowerCase())}const LE=Ps({space:"xmlns",attributes:{xmlnsxlink:"xmlns:xlink"},transform:IE,properties:{xmlns:null,xmlnsXLink:null}}),BE=Ps({transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()},properties:{ariaActiveDescendant:null,ariaAtomic:Nn,ariaAutoComplete:null,ariaBusy:Nn,ariaChecked:Nn,ariaColCount:Ce,ariaColIndex:Ce,ariaColSpan:Ce,ariaControls:Xt,ariaCurrent:null,ariaDescribedBy:Xt,ariaDetails:null,ariaDisabled:Nn,ariaDropEffect:Xt,ariaErrorMessage:null,ariaExpanded:Nn,ariaFlowTo:Xt,ariaGrabbed:Nn,ariaHasPopup:null,ariaHidden:Nn,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:Xt,ariaLevel:Ce,ariaLive:null,ariaModal:Nn,ariaMultiLine:Nn,ariaMultiSelectable:Nn,ariaOrientation:null,ariaOwns:Xt,ariaPlaceholder:null,ariaPosInSet:Ce,ariaPressed:Nn,ariaReadOnly:Nn,ariaRelevant:null,ariaRequired:Nn,ariaRoleDescription:Xt,ariaRowCount:Ce,ariaRowIndex:Ce,ariaRowSpan:Ce,ariaSelected:Nn,ariaSetSize:Ce,ariaSort:null,ariaValueMax:Ce,ariaValueMin:Ce,ariaValueNow:Ce,ariaValueText:null,role:null}}),ik=Ps({space:"html",attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},transform:IE,mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:Ns,acceptCharset:Xt,accessKey:Xt,action:null,allow:null,allowFullScreen:ot,allowPaymentRequest:ot,allowUserMedia:ot,alt:null,as:null,async:ot,autoCapitalize:null,autoComplete:Xt,autoFocus:ot,autoPlay:ot,blocking:Xt,capture:null,charSet:null,checked:ot,cite:null,className:Xt,cols:Ce,colSpan:null,content:null,contentEditable:Nn,controls:ot,controlsList:Xt,coords:Ce|Ns,crossOrigin:null,data:null,dateTime:null,decoding:null,default:ot,defer:ot,dir:null,dirName:null,disabled:ot,download:OE,draggable:Nn,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:ot,formTarget:null,headers:Xt,height:Ce,hidden:ot,high:Ce,href:null,hrefLang:null,htmlFor:Xt,httpEquiv:Xt,id:null,imageSizes:null,imageSrcSet:null,inert:ot,inputMode:null,integrity:null,is:null,isMap:ot,itemId:null,itemProp:Xt,itemRef:Xt,itemScope:ot,itemType:Xt,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:ot,low:Ce,manifest:null,max:null,maxLength:Ce,media:null,method:null,min:null,minLength:Ce,multiple:ot,muted:ot,name:null,nonce:null,noModule:ot,noValidate:ot,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:ot,optimum:Ce,pattern:null,ping:Xt,placeholder:null,playsInline:ot,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:ot,referrerPolicy:null,rel:Xt,required:ot,reversed:ot,rows:Ce,rowSpan:Ce,sandbox:Xt,scope:null,scoped:ot,seamless:ot,selected:ot,shadowRootClonable:ot,shadowRootDelegatesFocus:ot,shadowRootMode:null,shape:null,size:Ce,sizes:null,slot:null,span:Ce,spellCheck:Nn,src:null,srcDoc:null,srcLang:null,srcSet:null,start:Ce,step:null,style:null,tabIndex:Ce,target:null,title:null,translate:null,type:null,typeMustMatch:ot,useMap:null,value:Nn,width:Ce,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:Xt,axis:null,background:null,bgColor:null,border:Ce,borderColor:null,bottomMargin:Ce,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:ot,declare:ot,event:null,face:null,frame:null,frameBorder:null,hSpace:Ce,leftMargin:Ce,link:null,longDesc:null,lowSrc:null,marginHeight:Ce,marginWidth:Ce,noResize:ot,noHref:ot,noShade:ot,noWrap:ot,object:null,profile:null,prompt:null,rev:null,rightMargin:Ce,rules:null,scheme:null,scrolling:Nn,standby:null,summary:null,text:null,topMargin:Ce,valueType:null,version:null,vAlign:null,vLink:null,vSpace:Ce,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:ot,disableRemotePlayback:ot,prefix:null,property:null,results:Ce,security:null,unselectable:null}}),lk=Ps({space:"svg",attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},transform:DE,properties:{about:Ir,accentHeight:Ce,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:Ce,amplitude:Ce,arabicForm:null,ascent:Ce,attributeName:null,attributeType:null,azimuth:Ce,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:Ce,by:null,calcMode:null,capHeight:Ce,className:Xt,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:Ce,diffuseConstant:Ce,direction:null,display:null,dur:null,divisor:Ce,dominantBaseline:null,download:ot,dx:null,dy:null,edgeMode:null,editable:null,elevation:Ce,enableBackground:null,end:null,event:null,exponent:Ce,externalResourcesRequired:null,fill:null,fillOpacity:Ce,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:Ns,g2:Ns,glyphName:Ns,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:Ce,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:Ce,horizOriginX:Ce,horizOriginY:Ce,id:null,ideographic:Ce,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:Ce,k:Ce,k1:Ce,k2:Ce,k3:Ce,k4:Ce,kernelMatrix:Ir,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:Ce,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:Ce,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:Ce,overlineThickness:Ce,paintOrder:null,panose1:null,path:null,pathLength:Ce,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:Xt,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:Ce,pointsAtY:Ce,pointsAtZ:Ce,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:Ir,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:Ir,rev:Ir,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:Ir,requiredFeatures:Ir,requiredFonts:Ir,requiredFormats:Ir,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:Ce,specularExponent:Ce,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:Ce,strikethroughThickness:Ce,string:null,stroke:null,strokeDashArray:Ir,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:Ce,strokeOpacity:Ce,strokeWidth:null,style:null,surfaceScale:Ce,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:Ir,tabIndex:Ce,tableValues:null,target:null,targetX:Ce,targetY:Ce,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:Ir,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:Ce,underlineThickness:Ce,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:Ce,values:null,vAlphabetic:Ce,vMathematical:Ce,vectorEffect:null,vHanging:Ce,vIdeographic:Ce,version:null,vertAdvY:Ce,vertOriginX:Ce,vertOriginY:Ce,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:Ce,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null}}),sk=/^data[-\w.:]+$/i,Mb=/-[a-z]/g,uk=/[A-Z]/g;function ok(e,t){const n=O1(t);let a=t,l=na;if(n in e.normal)return e.property[e.normal[n]];if(n.length>4&&n.slice(0,4)==="data"&&sk.test(t)){if(t.charAt(4)==="-"){const s=t.slice(5).replace(Mb,dk);a="data"+s.charAt(0).toUpperCase()+s.slice(1)}else{const s=t.slice(4);if(!Mb.test(s)){let o=s.replace(uk,ck);o.charAt(0)!=="-"&&(o="-"+o),t="data"+o}}l=Am}return new l(a,t)}function ck(e){return"-"+e.toLowerCase()}function dk(e){return e.charAt(1).toUpperCase()}const fk=CE([ME,RE,LE,BE,ik],"html"),PE=CE([ME,RE,LE,BE,lk],"svg"),hk={},mk={}.hasOwnProperty,UE=rE("type",{handlers:{root:gk,element:Tk,text:yk,comment:vk,doctype:Ek}});function pk(e,t){const a=(t||hk).space;return UE(e,a==="svg"?PE:fk)}function gk(e,t){const n={nodeName:"#document",mode:(e.data||{}).quirksMode?"quirks":"no-quirks",childNodes:[]};return n.childNodes=xm(e.children,n,t),Us(e,n),n}function bk(e,t){const n={nodeName:"#document-fragment",childNodes:[]};return n.childNodes=xm(e.children,n,t),Us(e,n),n}function Ek(e){const t={nodeName:"#documentType",name:"html",publicId:"",systemId:"",parentNode:null};return Us(e,t),t}function yk(e){const t={nodeName:"#text",value:e.value,parentNode:null};return Us(e,t),t}function vk(e){const t={nodeName:"#comment",data:e.value,parentNode:null};return Us(e,t),t}function Tk(e,t){const n=t;let a=n;e.type==="element"&&e.tagName.toLowerCase()==="svg"&&n.space==="html"&&(a=PE);const l=[];let s;if(e.properties){for(s in e.properties)if(s!=="children"&&mk.call(e.properties,s)){const f=_k(a,s,e.properties[s]);f&&l.push(f)}}const o=a.space,d={nodeName:e.tagName,tagName:e.tagName,attrs:l,namespaceURI:ka[o],childNodes:[],parentNode:null};return d.childNodes=xm(e.children,d,a),Us(e,d),e.tagName==="template"&&e.content&&(d.content=bk(e.content,a)),d}function _k(e,t,n){const a=ok(e,t);if(n===!1||n===null||n===void 0||typeof n=="number"&&Number.isNaN(n)||!n&&a.boolean)return;Array.isArray(n)&&(n=a.commaSeparated?b6(n):x6(n));const l={name:a.attribute,value:n===!0?"":String(n)};if(a.space&&a.space!=="html"&&a.space!=="svg"){const s=l.name.indexOf(":");s<0?l.prefix="":(l.name=l.name.slice(s+1),l.prefix=a.attribute.slice(0,s)),l.namespace=ka[a.space]}return l}function xm(e,t,n){let a=-1;const l=[];if(e)for(;++a<e.length;){const s=UE(e[a],n);s.parentNode=t,l.push(s)}return l}function Us(e,t){const n=e.position;n&&n.start&&n.end&&(n.start.offset,n.end.offset,t.sourceCodeLocation={startLine:n.start.line,startCol:n.start.column,startOffset:n.start.offset,endLine:n.end.line,endCol:n.end.column,endOffset:n.end.offset})}const Sk=["area","base","basefont","bgsound","br","col","command","embed","frame","hr","image","img","input","keygen","link","meta","param","source","track","wbr"],Ak=new Set([65534,65535,131070,131071,196606,196607,262142,262143,327678,327679,393214,393215,458750,458751,524286,524287,589822,589823,655358,655359,720894,720895,786430,786431,851966,851967,917502,917503,983038,983039,1048574,1048575,1114110,1114111]),nn="�";var M;(function(e){e[e.EOF=-1]="EOF",e[e.NULL=0]="NULL",e[e.TABULATION=9]="TABULATION",e[e.CARRIAGE_RETURN=13]="CARRIAGE_RETURN",e[e.LINE_FEED=10]="LINE_FEED",e[e.FORM_FEED=12]="FORM_FEED",e[e.SPACE=32]="SPACE",e[e.EXCLAMATION_MARK=33]="EXCLAMATION_MARK",e[e.QUOTATION_MARK=34]="QUOTATION_MARK",e[e.AMPERSAND=38]="AMPERSAND",e[e.APOSTROPHE=39]="APOSTROPHE",e[e.HYPHEN_MINUS=45]="HYPHEN_MINUS",e[e.SOLIDUS=47]="SOLIDUS",e[e.DIGIT_0=48]="DIGIT_0",e[e.DIGIT_9=57]="DIGIT_9",e[e.SEMICOLON=59]="SEMICOLON",e[e.LESS_THAN_SIGN=60]="LESS_THAN_SIGN",e[e.EQUALS_SIGN=61]="EQUALS_SIGN",e[e.GREATER_THAN_SIGN=62]="GREATER_THAN_SIGN",e[e.QUESTION_MARK=63]="QUESTION_MARK",e[e.LATIN_CAPITAL_A=65]="LATIN_CAPITAL_A",e[e.LATIN_CAPITAL_Z=90]="LATIN_CAPITAL_Z",e[e.RIGHT_SQUARE_BRACKET=93]="RIGHT_SQUARE_BRACKET",e[e.GRAVE_ACCENT=96]="GRAVE_ACCENT",e[e.LATIN_SMALL_A=97]="LATIN_SMALL_A",e[e.LATIN_SMALL_Z=122]="LATIN_SMALL_Z"})(M||(M={}));const br={DASH_DASH:"--",CDATA_START:"[CDATA[",DOCTYPE:"doctype",SCRIPT:"script",PUBLIC:"public",SYSTEM:"system"};function zE(e){return e>=55296&&e<=57343}function xk(e){return e>=56320&&e<=57343}function kk(e,t){return(e-55296)*1024+9216+t}function HE(e){return e!==32&&e!==10&&e!==13&&e!==9&&e!==12&&e>=1&&e<=31||e>=127&&e<=159}function FE(e){return e>=64976&&e<=65007||Ak.has(e)}var ie;(function(e){e.controlCharacterInInputStream="control-character-in-input-stream",e.noncharacterInInputStream="noncharacter-in-input-stream",e.surrogateInInputStream="surrogate-in-input-stream",e.nonVoidHtmlElementStartTagWithTrailingSolidus="non-void-html-element-start-tag-with-trailing-solidus",e.endTagWithAttributes="end-tag-with-attributes",e.endTagWithTrailingSolidus="end-tag-with-trailing-solidus",e.unexpectedSolidusInTag="unexpected-solidus-in-tag",e.unexpectedNullCharacter="unexpected-null-character",e.unexpectedQuestionMarkInsteadOfTagName="unexpected-question-mark-instead-of-tag-name",e.invalidFirstCharacterOfTagName="invalid-first-character-of-tag-name",e.unexpectedEqualsSignBeforeAttributeName="unexpected-equals-sign-before-attribute-name",e.missingEndTagName="missing-end-tag-name",e.unexpectedCharacterInAttributeName="unexpected-character-in-attribute-name",e.unknownNamedCharacterReference="unknown-named-character-reference",e.missingSemicolonAfterCharacterReference="missing-semicolon-after-character-reference",e.unexpectedCharacterAfterDoctypeSystemIdentifier="unexpected-character-after-doctype-system-identifier",e.unexpectedCharacterInUnquotedAttributeValue="unexpected-character-in-unquoted-attribute-value",e.eofBeforeTagName="eof-before-tag-name",e.eofInTag="eof-in-tag",e.missingAttributeValue="missing-attribute-value",e.missingWhitespaceBetweenAttributes="missing-whitespace-between-attributes",e.missingWhitespaceAfterDoctypePublicKeyword="missing-whitespace-after-doctype-public-keyword",e.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers="missing-whitespace-between-doctype-public-and-system-identifiers",e.missingWhitespaceAfterDoctypeSystemKeyword="missing-whitespace-after-doctype-system-keyword",e.missingQuoteBeforeDoctypePublicIdentifier="missing-quote-before-doctype-public-identifier",e.missingQuoteBeforeDoctypeSystemIdentifier="missing-quote-before-doctype-system-identifier",e.missingDoctypePublicIdentifier="missing-doctype-public-identifier",e.missingDoctypeSystemIdentifier="missing-doctype-system-identifier",e.abruptDoctypePublicIdentifier="abrupt-doctype-public-identifier",e.abruptDoctypeSystemIdentifier="abrupt-doctype-system-identifier",e.cdataInHtmlContent="cdata-in-html-content",e.incorrectlyOpenedComment="incorrectly-opened-comment",e.eofInScriptHtmlCommentLikeText="eof-in-script-html-comment-like-text",e.eofInDoctype="eof-in-doctype",e.nestedComment="nested-comment",e.abruptClosingOfEmptyComment="abrupt-closing-of-empty-comment",e.eofInComment="eof-in-comment",e.incorrectlyClosedComment="incorrectly-closed-comment",e.eofInCdata="eof-in-cdata",e.absenceOfDigitsInNumericCharacterReference="absence-of-digits-in-numeric-character-reference",e.nullCharacterReference="null-character-reference",e.surrogateCharacterReference="surrogate-character-reference",e.characterReferenceOutsideUnicodeRange="character-reference-outside-unicode-range",e.controlCharacterReference="control-character-reference",e.noncharacterCharacterReference="noncharacter-character-reference",e.missingWhitespaceBeforeDoctypeName="missing-whitespace-before-doctype-name",e.missingDoctypeName="missing-doctype-name",e.invalidCharacterSequenceAfterDoctypeName="invalid-character-sequence-after-doctype-name",e.duplicateAttribute="duplicate-attribute",e.nonConformingDoctype="non-conforming-doctype",e.missingDoctype="missing-doctype",e.misplacedDoctype="misplaced-doctype",e.endTagWithoutMatchingOpenElement="end-tag-without-matching-open-element",e.closingOfElementWithOpenChildElements="closing-of-element-with-open-child-elements",e.disallowedContentInNoscriptInHead="disallowed-content-in-noscript-in-head",e.openElementsLeftAfterEof="open-elements-left-after-eof",e.abandonedHeadElementChild="abandoned-head-element-child",e.misplacedStartTagForHeadElement="misplaced-start-tag-for-head-element",e.nestedNoscriptInHead="nested-noscript-in-head",e.eofInElementThatCanContainOnlyText="eof-in-element-that-can-contain-only-text"})(ie||(ie={}));const Nk=65536;class wk{constructor(t){this.handler=t,this.html="",this.pos=-1,this.lastGapPos=-2,this.gapStack=[],this.skipNextNewLine=!1,this.lastChunkWritten=!1,this.endOfChunkHit=!1,this.bufferWaterline=Nk,this.isEol=!1,this.lineStartPos=0,this.droppedBufferSize=0,this.line=1,this.lastErrOffset=-1}get col(){return this.pos-this.lineStartPos+ +(this.lastGapPos!==this.pos)}get offset(){return this.droppedBufferSize+this.pos}getError(t,n){const{line:a,col:l,offset:s}=this,o=l+n,d=s+n;return{code:t,startLine:a,endLine:a,startCol:o,endCol:o,startOffset:d,endOffset:d}}_err(t){this.handler.onParseError&&this.lastErrOffset!==this.offset&&(this.lastErrOffset=this.offset,this.handler.onParseError(this.getError(t,0)))}_addGap(){this.gapStack.push(this.lastGapPos),this.lastGapPos=this.pos}_processSurrogate(t){if(this.pos!==this.html.length-1){const n=this.html.charCodeAt(this.pos+1);if(xk(n))return this.pos++,this._addGap(),kk(t,n)}else if(!this.lastChunkWritten)return this.endOfChunkHit=!0,M.EOF;return this._err(ie.surrogateInInputStream),t}willDropParsedChunk(){return this.pos>this.bufferWaterline}dropParsedChunk(){this.willDropParsedChunk()&&(this.html=this.html.substring(this.pos),this.lineStartPos-=this.pos,this.droppedBufferSize+=this.pos,this.pos=0,this.lastGapPos=-2,this.gapStack.length=0)}write(t,n){this.html.length>0?this.html+=t:this.html=t,this.endOfChunkHit=!1,this.lastChunkWritten=n}insertHtmlAtCurrentPos(t){this.html=this.html.substring(0,this.pos+1)+t+this.html.substring(this.pos+1),this.endOfChunkHit=!1}startsWith(t,n){if(this.pos+t.length>this.html.length)return this.endOfChunkHit=!this.lastChunkWritten,!1;if(n)return this.html.startsWith(t,this.pos);for(let a=0;a<t.length;a++)if((this.html.charCodeAt(this.pos+a)|32)!==t.charCodeAt(a))return!1;return!0}peek(t){const n=this.pos+t;if(n>=this.html.length)return this.endOfChunkHit=!this.lastChunkWritten,M.EOF;const a=this.html.charCodeAt(n);return a===M.CARRIAGE_RETURN?M.LINE_FEED:a}advance(){if(this.pos++,this.isEol&&(this.isEol=!1,this.line++,this.lineStartPos=this.pos),this.pos>=this.html.length)return this.endOfChunkHit=!this.lastChunkWritten,M.EOF;let t=this.html.charCodeAt(this.pos);return t===M.CARRIAGE_RETURN?(this.isEol=!0,this.skipNextNewLine=!0,M.LINE_FEED):t===M.LINE_FEED&&(this.isEol=!0,this.skipNextNewLine)?(this.line--,this.skipNextNewLine=!1,this._addGap(),this.advance()):(this.skipNextNewLine=!1,zE(t)&&(t=this._processSurrogate(t)),this.handler.onParseError===null||t>31&&t<127||t===M.LINE_FEED||t===M.CARRIAGE_RETURN||t>159&&t<64976||this._checkForProblematicCharacters(t),t)}_checkForProblematicCharacters(t){HE(t)?this._err(ie.controlCharacterInInputStream):FE(t)&&this._err(ie.noncharacterInInputStream)}retreat(t){for(this.pos-=t;this.pos<this.lastGapPos;)this.lastGapPos=this.gapStack.pop(),this.pos--;this.isEol=!1}}var Et;(function(e){e[e.CHARACTER=0]="CHARACTER",e[e.NULL_CHARACTER=1]="NULL_CHARACTER",e[e.WHITESPACE_CHARACTER=2]="WHITESPACE_CHARACTER",e[e.START_TAG=3]="START_TAG",e[e.END_TAG=4]="END_TAG",e[e.COMMENT=5]="COMMENT",e[e.DOCTYPE=6]="DOCTYPE",e[e.EOF=7]="EOF",e[e.HIBERNATION=8]="HIBERNATION"})(Et||(Et={}));function qE(e,t){for(let n=e.attrs.length-1;n>=0;n--)if(e.attrs[n].name===t)return e.attrs[n].value;return null}const Ck=new Uint16Array('ᵁ<Õıʊҝջאٵ۞ޢߖࠏ੊ઑඡ๭༉༦჊ረዡᐕᒝᓃᓟᔥ\0\0\0\0\0\0ᕫᛍᦍᰒᷝ὾⁠↰⊍⏀⏻⑂⠤⤒ⴈ⹈⿎〖㊺㘹㞬㣾㨨㩱㫠㬮ࠀEMabcfglmnoprstu\\bfms¦³¹ÈÏlig耻Æ䃆P耻&䀦cute耻Á䃁reve;䄂Āiyx}rc耻Â䃂;䐐r;쀀𝔄rave耻À䃀pha;䎑acr;䄀d;橓Āgp¡on;䄄f;쀀𝔸plyFunction;恡ing耻Å䃅Ācs¾Ãr;쀀𝒜ign;扔ilde耻Ã䃃ml耻Ä䃄ЀaceforsuåûþėĜĢħĪĀcrêòkslash;或Ŷöø;櫧ed;挆y;䐑ƀcrtąċĔause;戵noullis;愬a;䎒r;쀀𝔅pf;쀀𝔹eve;䋘còēmpeq;扎܀HOacdefhilorsuōőŖƀƞƢƵƷƺǜȕɳɸɾcy;䐧PY耻©䂩ƀcpyŝŢźute;䄆Ā;iŧŨ拒talDifferentialD;慅leys;愭ȀaeioƉƎƔƘron;䄌dil耻Ç䃇rc;䄈nint;戰ot;䄊ĀdnƧƭilla;䂸terDot;䂷òſi;䎧rcleȀDMPTǇǋǑǖot;抙inus;抖lus;投imes;抗oĀcsǢǸkwiseContourIntegral;戲eCurlyĀDQȃȏoubleQuote;思uote;怙ȀlnpuȞȨɇɕonĀ;eȥȦ户;橴ƀgitȯȶȺruent;扡nt;戯ourIntegral;戮ĀfrɌɎ;愂oduct;成nterClockwiseContourIntegral;戳oss;樯cr;쀀𝒞pĀ;Cʄʅ拓ap;才րDJSZacefiosʠʬʰʴʸˋ˗ˡ˦̳ҍĀ;oŹʥtrahd;椑cy;䐂cy;䐅cy;䐏ƀgrsʿ˄ˇger;怡r;憡hv;櫤Āayː˕ron;䄎;䐔lĀ;t˝˞戇a;䎔r;쀀𝔇Āaf˫̧Ācm˰̢riticalȀADGT̖̜̀̆cute;䂴oŴ̋̍;䋙bleAcute;䋝rave;䁠ilde;䋜ond;拄ferentialD;慆Ѱ̽\0\0\0͔͂\0Ѕf;쀀𝔻ƀ;DE͈͉͍䂨ot;惜qual;扐blèCDLRUVͣͲ΂ϏϢϸontourIntegraìȹoɴ͹\0\0ͻ»͉nArrow;懓Āeo·ΤftƀARTΐΖΡrrow;懐ightArrow;懔eåˊngĀLRΫτeftĀARγιrrow;柸ightArrow;柺ightArrow;柹ightĀATϘϞrrow;懒ee;抨pɁϩ\0\0ϯrrow;懑ownArrow;懕erticalBar;戥ǹABLRTaВЪаўѿͼrrowƀ;BUНОТ憓ar;椓pArrow;懵reve;䌑eft˒к\0ц\0ѐightVector;楐eeVector;楞ectorĀ;Bљњ憽ar;楖ightǔѧ\0ѱeeVector;楟ectorĀ;BѺѻ懁ar;楗eeĀ;A҆҇护rrow;憧ĀctҒҗr;쀀𝒟rok;䄐ࠀNTacdfglmopqstuxҽӀӄӋӞӢӧӮӵԡԯԶՒ՝ՠեG;䅊H耻Ð䃐cute耻É䃉ƀaiyӒӗӜron;䄚rc耻Ê䃊;䐭ot;䄖r;쀀𝔈rave耻È䃈ement;戈ĀapӺӾcr;䄒tyɓԆ\0\0ԒmallSquare;旻erySmallSquare;斫ĀgpԦԪon;䄘f;쀀𝔼silon;䎕uĀaiԼՉlĀ;TՂՃ橵ilde;扂librium;懌Āci՗՚r;愰m;橳a;䎗ml耻Ë䃋Āipժկsts;戃onentialE;慇ʀcfiosօֈ֍ֲ׌y;䐤r;쀀𝔉lledɓ֗\0\0֣mallSquare;旼erySmallSquare;斪Ͱֺ\0ֿ\0\0ׄf;쀀𝔽All;戀riertrf;愱cò׋؀JTabcdfgorstר׬ׯ׺؀ؒؖ؛؝أ٬ٲcy;䐃耻>䀾mmaĀ;d׷׸䎓;䏜reve;䄞ƀeiy؇،ؐdil;䄢rc;䄜;䐓ot;䄠r;쀀𝔊;拙pf;쀀𝔾eater̀EFGLSTصلَٖٛ٦qualĀ;Lؾؿ扥ess;招ullEqual;执reater;檢ess;扷lantEqual;橾ilde;扳cr;쀀𝒢;扫ЀAacfiosuڅڋږڛڞڪھۊRDcy;䐪Āctڐڔek;䋇;䁞irc;䄤r;愌lbertSpace;愋ǰگ\0ڲf;愍izontalLine;攀Āctۃۅòکrok;䄦mpńېۘownHumðįqual;扏܀EJOacdfgmnostuۺ۾܃܇܎ܚܞܡܨ݄ݸދޏޕcy;䐕lig;䄲cy;䐁cute耻Í䃍Āiyܓܘrc耻Î䃎;䐘ot;䄰r;愑rave耻Ì䃌ƀ;apܠܯܿĀcgܴܷr;䄪inaryI;慈lieóϝǴ݉\0ݢĀ;eݍݎ戬Āgrݓݘral;戫section;拂isibleĀCTݬݲomma;恣imes;恢ƀgptݿރވon;䄮f;쀀𝕀a;䎙cr;愐ilde;䄨ǫޚ\0ޞcy;䐆l耻Ï䃏ʀcfosuެ޷޼߂ߐĀiyޱ޵rc;䄴;䐙r;쀀𝔍pf;쀀𝕁ǣ߇\0ߌr;쀀𝒥rcy;䐈kcy;䐄΀HJacfosߤߨ߽߬߱ࠂࠈcy;䐥cy;䐌ppa;䎚Āey߶߻dil;䄶;䐚r;쀀𝔎pf;쀀𝕂cr;쀀𝒦րJTaceflmostࠥࠩࠬࡐࡣ঳সে্਷ੇcy;䐉耻<䀼ʀcmnpr࠷࠼ࡁࡄࡍute;䄹bda;䎛g;柪lacetrf;愒r;憞ƀaeyࡗ࡜ࡡron;䄽dil;䄻;䐛Āfsࡨ॰tԀACDFRTUVarࡾࢩࢱࣦ࣠ࣼयज़ΐ४Ānrࢃ࢏gleBracket;柨rowƀ;BR࢙࢚࢞憐ar;懤ightArrow;懆eiling;挈oǵࢷ\0ࣃbleBracket;柦nǔࣈ\0࣒eeVector;楡ectorĀ;Bࣛࣜ懃ar;楙loor;挊ightĀAV࣯ࣵrrow;憔ector;楎Āerँगeƀ;AVउऊऐ抣rrow;憤ector;楚iangleƀ;BEतथऩ抲ar;槏qual;抴pƀDTVषूौownVector;楑eeVector;楠ectorĀ;Bॖॗ憿ar;楘ectorĀ;B॥०憼ar;楒ightáΜs̀EFGLSTॾঋকঝঢভqualGreater;拚ullEqual;扦reater;扶ess;檡lantEqual;橽ilde;扲r;쀀𝔏Ā;eঽা拘ftarrow;懚idot;䄿ƀnpw৔ਖਛgȀLRlr৞৷ਂਐeftĀAR০৬rrow;柵ightArrow;柷ightArrow;柶eftĀarγਊightáοightáϊf;쀀𝕃erĀLRਢਬeftArrow;憙ightArrow;憘ƀchtਾੀੂòࡌ;憰rok;䅁;扪Ѐacefiosuਗ਼੝੠੷੼અઋ઎p;椅y;䐜Ādl੥੯iumSpace;恟lintrf;愳r;쀀𝔐nusPlus;戓pf;쀀𝕄cò੶;䎜ҀJacefostuણધભીଔଙඑ඗ඞcy;䐊cute;䅃ƀaey઴હાron;䅇dil;䅅;䐝ƀgswે૰଎ativeƀMTV૓૟૨ediumSpace;怋hiĀcn૦૘ë૙eryThiî૙tedĀGL૸ଆreaterGreateòٳessLesóੈLine;䀊r;쀀𝔑ȀBnptଢନଷ଺reak;恠BreakingSpace;䂠f;愕ڀ;CDEGHLNPRSTV୕ୖ୪୼஡௫ఄ౞಄ದ೘ൡඅ櫬Āou୛୤ngruent;扢pCap;扭oubleVerticalBar;戦ƀlqxஃஊ஛ement;戉ualĀ;Tஒஓ扠ilde;쀀≂̸ists;戄reater΀;EFGLSTஶஷ஽௉௓௘௥扯qual;扱ullEqual;쀀≧̸reater;쀀≫̸ess;批lantEqual;쀀⩾̸ilde;扵umpń௲௽ownHump;쀀≎̸qual;쀀≏̸eĀfsఊధtTriangleƀ;BEచఛడ拪ar;쀀⧏̸qual;括s̀;EGLSTవశ఼ౄోౘ扮qual;扰reater;扸ess;쀀≪̸lantEqual;쀀⩽̸ilde;扴estedĀGL౨౹reaterGreater;쀀⪢̸essLess;쀀⪡̸recedesƀ;ESಒಓಛ技qual;쀀⪯̸lantEqual;拠ĀeiಫಹverseElement;戌ghtTriangleƀ;BEೋೌ೒拫ar;쀀⧐̸qual;拭ĀquೝഌuareSuĀbp೨೹setĀ;E೰ೳ쀀⊏̸qual;拢ersetĀ;Eഃആ쀀⊐̸qual;拣ƀbcpഓതൎsetĀ;Eഛഞ쀀⊂⃒qual;抈ceedsȀ;ESTലള഻െ抁qual;쀀⪰̸lantEqual;拡ilde;쀀≿̸ersetĀ;E൘൛쀀⊃⃒qual;抉ildeȀ;EFT൮൯൵ൿ扁qual;扄ullEqual;扇ilde;扉erticalBar;戤cr;쀀𝒩ilde耻Ñ䃑;䎝܀Eacdfgmoprstuvලෂ෉෕ෛ෠෧෼ขภยา฿ไlig;䅒cute耻Ó䃓Āiy෎ීrc耻Ô䃔;䐞blac;䅐r;쀀𝔒rave耻Ò䃒ƀaei෮ෲ෶cr;䅌ga;䎩cron;䎟pf;쀀𝕆enCurlyĀDQฎบoubleQuote;怜uote;怘;橔Āclวฬr;쀀𝒪ash耻Ø䃘iŬื฼de耻Õ䃕es;樷ml耻Ö䃖erĀBP๋๠Āar๐๓r;怾acĀek๚๜;揞et;掴arenthesis;揜Ҁacfhilors๿ງຊຏຒດຝະ໼rtialD;戂y;䐟r;쀀𝔓i;䎦;䎠usMinus;䂱Āipຢອncareplanåڝf;愙Ȁ;eio຺ູ໠໤檻cedesȀ;EST່້໏໚扺qual;檯lantEqual;扼ilde;找me;怳Ādp໩໮uct;戏ortionĀ;aȥ໹l;戝Āci༁༆r;쀀𝒫;䎨ȀUfos༑༖༛༟OT耻"䀢r;쀀𝔔pf;愚cr;쀀𝒬؀BEacefhiorsu༾གྷཇའཱིྦྷྪྭ႖ႩႴႾarr;椐G耻®䂮ƀcnrཎནབute;䅔g;柫rĀ;tཛྷཝ憠l;椖ƀaeyཧཬཱron;䅘dil;䅖;䐠Ā;vླྀཹ愜erseĀEUྂྙĀlq྇ྎement;戋uilibrium;懋pEquilibrium;楯r»ཹo;䎡ghtЀACDFTUVa࿁࿫࿳ဢဨၛႇϘĀnr࿆࿒gleBracket;柩rowƀ;BL࿜࿝࿡憒ar;懥eftArrow;懄eiling;按oǵ࿹\0စbleBracket;柧nǔည\0နeeVector;楝ectorĀ;Bဝသ懂ar;楕loor;挋Āerိ၃eƀ;AVဵံြ抢rrow;憦ector;楛iangleƀ;BEၐၑၕ抳ar;槐qual;抵pƀDTVၣၮၸownVector;楏eeVector;楜ectorĀ;Bႂႃ憾ar;楔ectorĀ;B႑႒懀ar;楓Āpuႛ႞f;愝ndImplies;楰ightarrow;懛ĀchႹႼr;愛;憱leDelayed;槴ڀHOacfhimoqstuფჱჷჽᄙᄞᅑᅖᅡᅧᆵᆻᆿĀCcჩხHcy;䐩y;䐨FTcy;䐬cute;䅚ʀ;aeiyᄈᄉᄎᄓᄗ檼ron;䅠dil;䅞rc;䅜;䐡r;쀀𝔖ortȀDLRUᄪᄴᄾᅉownArrow»ОeftArrow»࢚ightArrow»࿝pArrow;憑gma;䎣allCircle;战pf;쀀𝕊ɲᅭ\0\0ᅰt;戚areȀ;ISUᅻᅼᆉᆯ斡ntersection;抓uĀbpᆏᆞsetĀ;Eᆗᆘ抏qual;抑ersetĀ;Eᆨᆩ抐qual;抒nion;抔cr;쀀𝒮ar;拆ȀbcmpᇈᇛሉላĀ;sᇍᇎ拐etĀ;Eᇍᇕqual;抆ĀchᇠህeedsȀ;ESTᇭᇮᇴᇿ扻qual;檰lantEqual;扽ilde;承Tháྌ;我ƀ;esሒሓሣ拑rsetĀ;Eሜም抃qual;抇et»ሓրHRSacfhiorsሾቄ቉ቕ቞ቱቶኟዂወዑORN耻Þ䃞ADE;愢ĀHc቎ቒcy;䐋y;䐦Ābuቚቜ;䀉;䎤ƀaeyብቪቯron;䅤dil;䅢;䐢r;쀀𝔗Āeiቻ኉ǲኀ\0ኇefore;戴a;䎘Ācn኎ኘkSpace;쀀  Space;怉ldeȀ;EFTካኬኲኼ戼qual;扃ullEqual;扅ilde;扈pf;쀀𝕋ipleDot;惛Āctዖዛr;쀀𝒯rok;䅦ૡዷጎጚጦ\0ጬጱ\0\0\0\0\0ጸጽ፷ᎅ\0᏿ᐄᐊᐐĀcrዻጁute耻Ú䃚rĀ;oጇገ憟cir;楉rǣጓ\0጖y;䐎ve;䅬Āiyጞጣrc耻Û䃛;䐣blac;䅰r;쀀𝔘rave耻Ù䃙acr;䅪Ādiፁ፩erĀBPፈ፝Āarፍፐr;䁟acĀekፗፙ;揟et;掵arenthesis;揝onĀ;P፰፱拃lus;抎Āgp፻፿on;䅲f;쀀𝕌ЀADETadps᎕ᎮᎸᏄϨᏒᏗᏳrrowƀ;BDᅐᎠᎤar;椒ownArrow;懅ownArrow;憕quilibrium;楮eeĀ;AᏋᏌ报rrow;憥ownáϳerĀLRᏞᏨeftArrow;憖ightArrow;憗iĀ;lᏹᏺ䏒on;䎥ing;䅮cr;쀀𝒰ilde;䅨ml耻Ü䃜ҀDbcdefosvᐧᐬᐰᐳᐾᒅᒊᒐᒖash;披ar;櫫y;䐒ashĀ;lᐻᐼ抩;櫦Āerᑃᑅ;拁ƀbtyᑌᑐᑺar;怖Ā;iᑏᑕcalȀBLSTᑡᑥᑪᑴar;戣ine;䁼eparator;杘ilde;所ThinSpace;怊r;쀀𝔙pf;쀀𝕍cr;쀀𝒱dash;抪ʀcefosᒧᒬᒱᒶᒼirc;䅴dge;拀r;쀀𝔚pf;쀀𝕎cr;쀀𝒲Ȁfiosᓋᓐᓒᓘr;쀀𝔛;䎞pf;쀀𝕏cr;쀀𝒳ҀAIUacfosuᓱᓵᓹᓽᔄᔏᔔᔚᔠcy;䐯cy;䐇cy;䐮cute耻Ý䃝Āiyᔉᔍrc;䅶;䐫r;쀀𝔜pf;쀀𝕐cr;쀀𝒴ml;䅸ЀHacdefosᔵᔹᔿᕋᕏᕝᕠᕤcy;䐖cute;䅹Āayᕄᕉron;䅽;䐗ot;䅻ǲᕔ\0ᕛoWidtè૙a;䎖r;愨pf;愤cr;쀀𝒵௡ᖃᖊᖐ\0ᖰᖶᖿ\0\0\0\0ᗆᗛᗫᙟ᙭\0ᚕ᚛ᚲᚹ\0ᚾcute耻á䃡reve;䄃̀;Ediuyᖜᖝᖡᖣᖨᖭ戾;쀀∾̳;房rc耻â䃢te肻´̆;䐰lig耻æ䃦Ā;r²ᖺ;쀀𝔞rave耻à䃠ĀepᗊᗖĀfpᗏᗔsym;愵èᗓha;䎱ĀapᗟcĀclᗤᗧr;䄁g;樿ɤᗰ\0\0ᘊʀ;adsvᗺᗻᗿᘁᘇ戧nd;橕;橜lope;橘;橚΀;elmrszᘘᘙᘛᘞᘿᙏᙙ戠;榤e»ᘙsdĀ;aᘥᘦ戡ѡᘰᘲᘴᘶᘸᘺᘼᘾ;榨;榩;榪;榫;榬;榭;榮;榯tĀ;vᙅᙆ戟bĀ;dᙌᙍ抾;榝Āptᙔᙗh;戢»¹arr;捼Āgpᙣᙧon;䄅f;쀀𝕒΀;Eaeiop዁ᙻᙽᚂᚄᚇᚊ;橰cir;橯;扊d;手s;䀧roxĀ;e዁ᚒñᚃing耻å䃥ƀctyᚡᚦᚨr;쀀𝒶;䀪mpĀ;e዁ᚯñʈilde耻ã䃣ml耻ä䃤Āciᛂᛈoninôɲnt;樑ࠀNabcdefiklnoprsu᛭ᛱᜰ᜼ᝃᝈ᝸᝽០៦ᠹᡐᜍ᤽᥈ᥰot;櫭Ācrᛶ᜞kȀcepsᜀᜅᜍᜓong;扌psilon;䏶rime;怵imĀ;e᜚᜛戽q;拍Ŷᜢᜦee;抽edĀ;gᜬᜭ挅e»ᜭrkĀ;t፜᜷brk;掶Āoyᜁᝁ;䐱quo;怞ʀcmprtᝓ᝛ᝡᝤᝨausĀ;eĊĉptyv;榰séᜌnoõēƀahwᝯ᝱ᝳ;䎲;愶een;扬r;쀀𝔟g΀costuvwឍឝឳេ៕៛៞ƀaiuបពរðݠrc;旯p»፱ƀdptឤឨឭot;樀lus;樁imes;樂ɱឹ\0\0ើcup;樆ar;昅riangleĀdu៍្own;施p;斳plus;樄eåᑄåᒭarow;植ƀako៭ᠦᠵĀcn៲ᠣkƀlst៺֫᠂ozenge;槫riangleȀ;dlr᠒᠓᠘᠝斴own;斾eft;旂ight;斸k;搣Ʊᠫ\0ᠳƲᠯ\0ᠱ;斒;斑4;斓ck;斈ĀeoᠾᡍĀ;qᡃᡆ쀀=⃥uiv;쀀≡⃥t;挐Ȁptwxᡙᡞᡧᡬf;쀀𝕓Ā;tᏋᡣom»Ꮜtie;拈؀DHUVbdhmptuvᢅᢖᢪᢻᣗᣛᣬ᣿ᤅᤊᤐᤡȀLRlrᢎᢐᢒᢔ;敗;敔;敖;敓ʀ;DUduᢡᢢᢤᢦᢨ敐;敦;敩;敤;敧ȀLRlrᢳᢵᢷᢹ;敝;敚;敜;教΀;HLRhlrᣊᣋᣍᣏᣑᣓᣕ救;敬;散;敠;敫;敢;敟ox;槉ȀLRlrᣤᣦᣨᣪ;敕;敒;攐;攌ʀ;DUduڽ᣷᣹᣻᣽;敥;敨;攬;攴inus;抟lus;択imes;抠ȀLRlrᤙᤛᤝ᤟;敛;敘;攘;攔΀;HLRhlrᤰᤱᤳᤵᤷ᤻᤹攂;敪;敡;敞;攼;攤;攜Āevģ᥂bar耻¦䂦Ȁceioᥑᥖᥚᥠr;쀀𝒷mi;恏mĀ;e᜚᜜lƀ;bhᥨᥩᥫ䁜;槅sub;柈Ŭᥴ᥾lĀ;e᥹᥺怢t»᥺pƀ;Eeįᦅᦇ;檮Ā;qۜۛೡᦧ\0᧨ᨑᨕᨲ\0ᨷᩐ\0\0᪴\0\0᫁\0\0ᬡᬮ᭍᭒\0᯽\0ᰌƀcpr᦭ᦲ᧝ute;䄇̀;abcdsᦿᧀᧄ᧊᧕᧙戩nd;橄rcup;橉Āau᧏᧒p;橋p;橇ot;橀;쀀∩︀Āeo᧢᧥t;恁îړȀaeiu᧰᧻ᨁᨅǰ᧵\0᧸s;橍on;䄍dil耻ç䃧rc;䄉psĀ;sᨌᨍ橌m;橐ot;䄋ƀdmnᨛᨠᨦil肻¸ƭptyv;榲t脀¢;eᨭᨮ䂢räƲr;쀀𝔠ƀceiᨽᩀᩍy;䑇ckĀ;mᩇᩈ朓ark»ᩈ;䏇r΀;Ecefms᩟᩠ᩢᩫ᪤᪪᪮旋;槃ƀ;elᩩᩪᩭ䋆q;扗eɡᩴ\0\0᪈rrowĀlr᩼᪁eft;憺ight;憻ʀRSacd᪒᪔᪖᪚᪟»ཇ;擈st;抛irc;抚ash;抝nint;樐id;櫯cir;槂ubsĀ;u᪻᪼晣it»᪼ˬ᫇᫔᫺\0ᬊonĀ;eᫍᫎ䀺Ā;qÇÆɭ᫙\0\0᫢aĀ;t᫞᫟䀬;䁀ƀ;fl᫨᫩᫫戁îᅠeĀmx᫱᫶ent»᫩eóɍǧ᫾\0ᬇĀ;dኻᬂot;橭nôɆƀfryᬐᬔᬗ;쀀𝕔oäɔ脀©;sŕᬝr;愗Āaoᬥᬩrr;憵ss;朗Ācuᬲᬷr;쀀𝒸Ābpᬼ᭄Ā;eᭁᭂ櫏;櫑Ā;eᭉᭊ櫐;櫒dot;拯΀delprvw᭠᭬᭷ᮂᮬᯔ᯹arrĀlr᭨᭪;椸;椵ɰ᭲\0\0᭵r;拞c;拟arrĀ;p᭿ᮀ憶;椽̀;bcdosᮏᮐᮖᮡᮥᮨ截rcap;橈Āauᮛᮞp;橆p;橊ot;抍r;橅;쀀∪︀Ȁalrv᮵ᮿᯞᯣrrĀ;mᮼᮽ憷;椼yƀevwᯇᯔᯘqɰᯎ\0\0ᯒreã᭳uã᭵ee;拎edge;拏en耻¤䂤earrowĀlrᯮ᯳eft»ᮀight»ᮽeäᯝĀciᰁᰇoninôǷnt;戱lcty;挭ঀAHabcdefhijlorstuwz᰸᰻᰿ᱝᱩᱵᲊᲞᲬᲷ᳻᳿ᴍᵻᶑᶫᶻ᷆᷍rò΁ar;楥Ȁglrs᱈ᱍ᱒᱔ger;怠eth;愸òᄳhĀ;vᱚᱛ怐»ऊūᱡᱧarow;椏aã̕Āayᱮᱳron;䄏;䐴ƀ;ao̲ᱼᲄĀgrʿᲁr;懊tseq;橷ƀglmᲑᲔᲘ耻°䂰ta;䎴ptyv;榱ĀirᲣᲨsht;楿;쀀𝔡arĀlrᲳᲵ»ࣜ»သʀaegsv᳂͸᳖᳜᳠mƀ;oș᳊᳔ndĀ;ș᳑uit;晦amma;䏝in;拲ƀ;io᳧᳨᳸䃷de脀÷;o᳧ᳰntimes;拇nø᳷cy;䑒cɯᴆ\0\0ᴊrn;挞op;挍ʀlptuwᴘᴝᴢᵉᵕlar;䀤f;쀀𝕕ʀ;emps̋ᴭᴷᴽᵂqĀ;d͒ᴳot;扑inus;戸lus;戔quare;抡blebarwedgåúnƀadhᄮᵝᵧownarrowóᲃarpoonĀlrᵲᵶefôᲴighôᲶŢᵿᶅkaro÷གɯᶊ\0\0ᶎrn;挟op;挌ƀcotᶘᶣᶦĀryᶝᶡ;쀀𝒹;䑕l;槶rok;䄑Ādrᶰᶴot;拱iĀ;fᶺ᠖斿Āah᷀᷃ròЩaòྦangle;榦Āci᷒ᷕy;䑟grarr;柿ऀDacdefglmnopqrstuxḁḉḙḸոḼṉṡṾấắẽỡἪἷὄ὎὚ĀDoḆᴴoôᲉĀcsḎḔute耻é䃩ter;橮ȀaioyḢḧḱḶron;䄛rĀ;cḭḮ扖耻ê䃪lon;払;䑍ot;䄗ĀDrṁṅot;扒;쀀𝔢ƀ;rsṐṑṗ檚ave耻è䃨Ā;dṜṝ檖ot;檘Ȁ;ilsṪṫṲṴ檙nters;揧;愓Ā;dṹṺ檕ot;檗ƀapsẅẉẗcr;䄓tyƀ;svẒẓẕ戅et»ẓpĀ1;ẝẤĳạả;怄;怅怃ĀgsẪẬ;䅋p;怂ĀgpẴẸon;䄙f;쀀𝕖ƀalsỄỎỒrĀ;sỊị拕l;槣us;橱iƀ;lvỚớở䎵on»ớ;䏵ȀcsuvỪỳἋἣĀioữḱrc»Ḯɩỹ\0\0ỻíՈantĀglἂἆtr»ṝess»Ṻƀaeiἒ἖Ἒls;䀽st;扟vĀ;DȵἠD;橸parsl;槥ĀDaἯἳot;打rr;楱ƀcdiἾὁỸr;愯oô͒ĀahὉὋ;䎷耻ð䃰Āmrὓὗl耻ë䃫o;悬ƀcipὡὤὧl;䀡sôծĀeoὬὴctatioîՙnentialåչৡᾒ\0ᾞ\0ᾡᾧ\0\0ῆῌ\0ΐ\0ῦῪ \0 ⁚llingdotseñṄy;䑄male;晀ƀilrᾭᾳ῁lig;耀ﬃɩᾹ\0\0᾽g;耀ﬀig;耀ﬄ;쀀𝔣lig;耀ﬁlig;쀀fjƀaltῙ῜ῡt;晭ig;耀ﬂns;斱of;䆒ǰ΅\0ῳf;쀀𝕗ĀakֿῷĀ;vῼ´拔;櫙artint;樍Āao‌⁕Ācs‑⁒α‚‰‸⁅⁈\0⁐β•‥‧‪‬\0‮耻½䂽;慓耻¼䂼;慕;慙;慛Ƴ‴\0‶;慔;慖ʴ‾⁁\0\0⁃耻¾䂾;慗;慜5;慘ƶ⁌\0⁎;慚;慝8;慞l;恄wn;挢cr;쀀𝒻ࢀEabcdefgijlnorstv₂₉₟₥₰₴⃰⃵⃺⃿℃ℒℸ̗ℾ⅒↞Ā;lٍ₇;檌ƀcmpₐₕ₝ute;䇵maĀ;dₜ᳚䎳;檆reve;䄟Āiy₪₮rc;䄝;䐳ot;䄡Ȁ;lqsؾق₽⃉ƀ;qsؾٌ⃄lanô٥Ȁ;cdl٥⃒⃥⃕c;檩otĀ;o⃜⃝檀Ā;l⃢⃣檂;檄Ā;e⃪⃭쀀⋛︀s;檔r;쀀𝔤Ā;gٳ؛mel;愷cy;䑓Ȁ;Eajٚℌℎℐ;檒;檥;檤ȀEaesℛℝ℩ℴ;扩pĀ;p℣ℤ檊rox»ℤĀ;q℮ℯ檈Ā;q℮ℛim;拧pf;쀀𝕘Āci⅃ⅆr;愊mƀ;el٫ⅎ⅐;檎;檐茀>;cdlqr׮ⅠⅪⅮⅳⅹĀciⅥⅧ;檧r;橺ot;拗Par;榕uest;橼ʀadelsↄⅪ←ٖ↛ǰ↉\0↎proø₞r;楸qĀlqؿ↖lesó₈ií٫Āen↣↭rtneqq;쀀≩︀Å↪ԀAabcefkosy⇄⇇⇱⇵⇺∘∝∯≨≽ròΠȀilmr⇐⇔⇗⇛rsðᒄf»․ilôکĀdr⇠⇤cy;䑊ƀ;cwࣴ⇫⇯ir;楈;憭ar;意irc;䄥ƀalr∁∎∓rtsĀ;u∉∊晥it»∊lip;怦con;抹r;쀀𝔥sĀew∣∩arow;椥arow;椦ʀamopr∺∾≃≞≣rr;懿tht;戻kĀlr≉≓eftarrow;憩ightarrow;憪f;쀀𝕙bar;怕ƀclt≯≴≸r;쀀𝒽asè⇴rok;䄧Ābp⊂⊇ull;恃hen»ᱛૡ⊣\0⊪\0⊸⋅⋎\0⋕⋳\0\0⋸⌢⍧⍢⍿\0⎆⎪⎴cute耻í䃭ƀ;iyݱ⊰⊵rc耻î䃮;䐸Ācx⊼⊿y;䐵cl耻¡䂡ĀfrΟ⋉;쀀𝔦rave耻ì䃬Ȁ;inoܾ⋝⋩⋮Āin⋢⋦nt;樌t;戭fin;槜ta;愩lig;䄳ƀaop⋾⌚⌝ƀcgt⌅⌈⌗r;䄫ƀelpܟ⌏⌓inåގarôܠh;䄱f;抷ed;䆵ʀ;cfotӴ⌬⌱⌽⍁are;愅inĀ;t⌸⌹戞ie;槝doô⌙ʀ;celpݗ⍌⍐⍛⍡al;抺Āgr⍕⍙eróᕣã⍍arhk;樗rod;樼Ȁcgpt⍯⍲⍶⍻y;䑑on;䄯f;쀀𝕚a;䎹uest耻¿䂿Āci⎊⎏r;쀀𝒾nʀ;EdsvӴ⎛⎝⎡ӳ;拹ot;拵Ā;v⎦⎧拴;拳Ā;iݷ⎮lde;䄩ǫ⎸\0⎼cy;䑖l耻ï䃯̀cfmosu⏌⏗⏜⏡⏧⏵Āiy⏑⏕rc;䄵;䐹r;쀀𝔧ath;䈷pf;쀀𝕛ǣ⏬\0⏱r;쀀𝒿rcy;䑘kcy;䑔Ѐacfghjos␋␖␢␧␭␱␵␻ppaĀ;v␓␔䎺;䏰Āey␛␠dil;䄷;䐺r;쀀𝔨reen;䄸cy;䑅cy;䑜pf;쀀𝕜cr;쀀𝓀஀ABEHabcdefghjlmnoprstuv⑰⒁⒆⒍⒑┎┽╚▀♎♞♥♹♽⚚⚲⛘❝❨➋⟀⠁⠒ƀart⑷⑺⑼rò৆òΕail;椛arr;椎Ā;gঔ⒋;檋ar;楢ॣ⒥\0⒪\0⒱\0\0\0\0\0⒵Ⓔ\0ⓆⓈⓍ\0⓹ute;䄺mptyv;榴raîࡌbda;䎻gƀ;dlࢎⓁⓃ;榑åࢎ;檅uo耻«䂫rЀ;bfhlpst࢙ⓞⓦⓩ⓫⓮⓱⓵Ā;f࢝ⓣs;椟s;椝ë≒p;憫l;椹im;楳l;憢ƀ;ae⓿─┄檫il;椙Ā;s┉┊檭;쀀⪭︀ƀabr┕┙┝rr;椌rk;杲Āak┢┬cĀek┨┪;䁻;䁛Āes┱┳;榋lĀdu┹┻;榏;榍Ȁaeuy╆╋╖╘ron;䄾Ādi═╔il;䄼ìࢰâ┩;䐻Ȁcqrs╣╦╭╽a;椶uoĀ;rนᝆĀdu╲╷har;楧shar;楋h;憲ʀ;fgqs▋▌উ◳◿扤tʀahlrt▘▤▷◂◨rrowĀ;t࢙□aé⓶arpoonĀdu▯▴own»њp»०eftarrows;懇ightƀahs◍◖◞rrowĀ;sࣴࢧarpoonó྘quigarro÷⇰hreetimes;拋ƀ;qs▋ও◺lanôবʀ;cdgsব☊☍☝☨c;檨otĀ;o☔☕橿Ā;r☚☛檁;檃Ā;e☢☥쀀⋚︀s;檓ʀadegs☳☹☽♉♋pproøⓆot;拖qĀgq♃♅ôউgtò⒌ôছiíলƀilr♕࣡♚sht;楼;쀀𝔩Ā;Eজ♣;檑š♩♶rĀdu▲♮Ā;l॥♳;楪lk;斄cy;䑙ʀ;achtੈ⚈⚋⚑⚖rò◁orneòᴈard;楫ri;旺Āio⚟⚤dot;䅀ustĀ;a⚬⚭掰che»⚭ȀEaes⚻⚽⛉⛔;扨pĀ;p⛃⛄檉rox»⛄Ā;q⛎⛏檇Ā;q⛎⚻im;拦Ѐabnoptwz⛩⛴⛷✚✯❁❇❐Ānr⛮⛱g;柬r;懽rëࣁgƀlmr⛿✍✔eftĀar০✇ightá৲apsto;柼ightá৽parrowĀlr✥✩efô⓭ight;憬ƀafl✶✹✽r;榅;쀀𝕝us;樭imes;樴š❋❏st;戗áፎƀ;ef❗❘᠀旊nge»❘arĀ;l❤❥䀨t;榓ʀachmt❳❶❼➅➇ròࢨorneòᶌarĀ;d྘➃;業;怎ri;抿̀achiqt➘➝ੀ➢➮➻quo;怹r;쀀𝓁mƀ;egল➪➬;檍;檏Ābu┪➳oĀ;rฟ➹;怚rok;䅂萀<;cdhilqrࠫ⟒☹⟜⟠⟥⟪⟰Āci⟗⟙;檦r;橹reå◲mes;拉arr;楶uest;橻ĀPi⟵⟹ar;榖ƀ;ef⠀भ᠛旃rĀdu⠇⠍shar;楊har;楦Āen⠗⠡rtneqq;쀀≨︀Å⠞܀Dacdefhilnopsu⡀⡅⢂⢎⢓⢠⢥⢨⣚⣢⣤ઃ⣳⤂Dot;戺Ȁclpr⡎⡒⡣⡽r耻¯䂯Āet⡗⡙;時Ā;e⡞⡟朠se»⡟Ā;sျ⡨toȀ;dluျ⡳⡷⡻owîҌefôएðᏑker;斮Āoy⢇⢌mma;権;䐼ash;怔asuredangle»ᘦr;쀀𝔪o;愧ƀcdn⢯⢴⣉ro耻µ䂵Ȁ;acdᑤ⢽⣀⣄sôᚧir;櫰ot肻·Ƶusƀ;bd⣒ᤃ⣓戒Ā;uᴼ⣘;横ţ⣞⣡p;櫛ò−ðઁĀdp⣩⣮els;抧f;쀀𝕞Āct⣸⣽r;쀀𝓂pos»ᖝƀ;lm⤉⤊⤍䎼timap;抸ఀGLRVabcdefghijlmoprstuvw⥂⥓⥾⦉⦘⧚⧩⨕⨚⩘⩝⪃⪕⪤⪨⬄⬇⭄⭿⮮ⰴⱧⱼ⳩Āgt⥇⥋;쀀⋙̸Ā;v⥐௏쀀≫⃒ƀelt⥚⥲⥶ftĀar⥡⥧rrow;懍ightarrow;懎;쀀⋘̸Ā;v⥻ే쀀≪⃒ightarrow;懏ĀDd⦎⦓ash;抯ash;抮ʀbcnpt⦣⦧⦬⦱⧌la»˞ute;䅄g;쀀∠⃒ʀ;Eiop඄⦼⧀⧅⧈;쀀⩰̸d;쀀≋̸s;䅉roø඄urĀ;a⧓⧔普lĀ;s⧓ସǳ⧟\0⧣p肻 ଷmpĀ;e௹ఀʀaeouy⧴⧾⨃⨐⨓ǰ⧹\0⧻;橃on;䅈dil;䅆ngĀ;dൾ⨊ot;쀀⩭̸p;橂;䐽ash;怓΀;Aadqsxஒ⨩⨭⨻⩁⩅⩐rr;懗rĀhr⨳⨶k;椤Ā;oᏲᏰot;쀀≐̸uiöୣĀei⩊⩎ar;椨í஘istĀ;s஠டr;쀀𝔫ȀEest௅⩦⩹⩼ƀ;qs஼⩭௡ƀ;qs஼௅⩴lanô௢ií௪Ā;rஶ⪁»ஷƀAap⪊⪍⪑rò⥱rr;憮ar;櫲ƀ;svྍ⪜ྌĀ;d⪡⪢拼;拺cy;䑚΀AEadest⪷⪺⪾⫂⫅⫶⫹rò⥦;쀀≦̸rr;憚r;急Ȁ;fqs఻⫎⫣⫯tĀar⫔⫙rro÷⫁ightarro÷⪐ƀ;qs఻⪺⫪lanôౕĀ;sౕ⫴»శiíౝĀ;rవ⫾iĀ;eచథiäඐĀpt⬌⬑f;쀀𝕟膀¬;in⬙⬚⬶䂬nȀ;Edvஉ⬤⬨⬮;쀀⋹̸ot;쀀⋵̸ǡஉ⬳⬵;拷;拶iĀ;vಸ⬼ǡಸ⭁⭃;拾;拽ƀaor⭋⭣⭩rȀ;ast୻⭕⭚⭟lleì୻l;쀀⫽⃥;쀀∂̸lint;樔ƀ;ceಒ⭰⭳uåಥĀ;cಘ⭸Ā;eಒ⭽ñಘȀAait⮈⮋⮝⮧rò⦈rrƀ;cw⮔⮕⮙憛;쀀⤳̸;쀀↝̸ghtarrow»⮕riĀ;eೋೖ΀chimpqu⮽⯍⯙⬄୸⯤⯯Ȁ;cerല⯆ഷ⯉uå൅;쀀𝓃ortɭ⬅\0\0⯖ará⭖mĀ;e൮⯟Ā;q൴൳suĀbp⯫⯭å೸åഋƀbcp⯶ⰑⰙȀ;Ees⯿ⰀഢⰄ抄;쀀⫅̸etĀ;eഛⰋqĀ;qണⰀcĀ;eലⰗñസȀ;EesⰢⰣൟⰧ抅;쀀⫆̸etĀ;e൘ⰮqĀ;qൠⰣȀgilrⰽⰿⱅⱇìௗlde耻ñ䃱çృiangleĀlrⱒⱜeftĀ;eచⱚñదightĀ;eೋⱥñ೗Ā;mⱬⱭ䎽ƀ;esⱴⱵⱹ䀣ro;愖p;怇ҀDHadgilrsⲏⲔⲙⲞⲣⲰⲶⳓⳣash;抭arr;椄p;쀀≍⃒ash;抬ĀetⲨⲬ;쀀≥⃒;쀀>⃒nfin;槞ƀAetⲽⳁⳅrr;椂;쀀≤⃒Ā;rⳊⳍ쀀<⃒ie;쀀⊴⃒ĀAtⳘⳜrr;椃rie;쀀⊵⃒im;쀀∼⃒ƀAan⳰⳴ⴂrr;懖rĀhr⳺⳽k;椣Ā;oᏧᏥear;椧ቓ᪕\0\0\0\0\0\0\0\0\0\0\0\0\0ⴭ\0ⴸⵈⵠⵥ⵲ⶄᬇ\0\0ⶍⶫ\0ⷈⷎ\0ⷜ⸙⸫⸾⹃Ācsⴱ᪗ute耻ó䃳ĀiyⴼⵅrĀ;c᪞ⵂ耻ô䃴;䐾ʀabios᪠ⵒⵗǈⵚlac;䅑v;樸old;榼lig;䅓Ācr⵩⵭ir;榿;쀀𝔬ͯ⵹\0\0⵼\0ⶂn;䋛ave耻ò䃲;槁Ābmⶈ෴ar;榵Ȁacitⶕ⶘ⶥⶨrò᪀Āir⶝ⶠr;榾oss;榻nå๒;槀ƀaeiⶱⶵⶹcr;䅍ga;䏉ƀcdnⷀⷅǍron;䎿;榶pf;쀀𝕠ƀaelⷔ⷗ǒr;榷rp;榹΀;adiosvⷪⷫⷮ⸈⸍⸐⸖戨rò᪆Ȁ;efmⷷⷸ⸂⸅橝rĀ;oⷾⷿ愴f»ⷿ耻ª䂪耻º䂺gof;抶r;橖lope;橗;橛ƀclo⸟⸡⸧ò⸁ash耻ø䃸l;折iŬⸯ⸴de耻õ䃵esĀ;aǛ⸺s;樶ml耻ö䃶bar;挽ૡ⹞\0⹽\0⺀⺝\0⺢⺹\0\0⻋ຜ\0⼓\0\0⼫⾼\0⿈rȀ;astЃ⹧⹲຅脀¶;l⹭⹮䂶leìЃɩ⹸\0\0⹻m;櫳;櫽y;䐿rʀcimpt⺋⺏⺓ᡥ⺗nt;䀥od;䀮il;怰enk;怱r;쀀𝔭ƀimo⺨⺰⺴Ā;v⺭⺮䏆;䏕maô੶ne;明ƀ;tv⺿⻀⻈䏀chfork»´;䏖Āau⻏⻟nĀck⻕⻝kĀ;h⇴⻛;愎ö⇴sҀ;abcdemst⻳⻴ᤈ⻹⻽⼄⼆⼊⼎䀫cir;樣ir;樢Āouᵀ⼂;樥;橲n肻±ຝim;樦wo;樧ƀipu⼙⼠⼥ntint;樕f;쀀𝕡nd耻£䂣Ԁ;Eaceinosu່⼿⽁⽄⽇⾁⾉⾒⽾⾶;檳p;檷uå໙Ā;c໎⽌̀;acens່⽙⽟⽦⽨⽾pproø⽃urlyeñ໙ñ໎ƀaes⽯⽶⽺pprox;檹qq;檵im;拨iíໟmeĀ;s⾈ຮ怲ƀEas⽸⾐⽺ð⽵ƀdfp໬⾙⾯ƀals⾠⾥⾪lar;挮ine;挒urf;挓Ā;t໻⾴ï໻rel;抰Āci⿀⿅r;쀀𝓅;䏈ncsp;怈̀fiopsu⿚⋢⿟⿥⿫⿱r;쀀𝔮pf;쀀𝕢rime;恗cr;쀀𝓆ƀaeo⿸〉〓tĀei⿾々rnionóڰnt;樖stĀ;e【】䀿ñἙô༔઀ABHabcdefhilmnoprstux぀けさすムㄎㄫㅇㅢㅲㆎ㈆㈕㈤㈩㉘㉮㉲㊐㊰㊷ƀartぇおがròႳòϝail;検aròᱥar;楤΀cdenqrtとふへみわゔヌĀeuねぱ;쀀∽̱te;䅕iãᅮmptyv;榳gȀ;del࿑らるろ;榒;榥å࿑uo耻»䂻rր;abcfhlpstw࿜ガクシスゼゾダッデナp;極Ā;f࿠ゴs;椠;椳s;椞ë≝ð✮l;楅im;楴l;憣;憝Āaiパフil;椚oĀ;nホボ戶aló༞ƀabrョリヮrò៥rk;杳ĀakンヽcĀekヹ・;䁽;䁝Āes㄂㄄;榌lĀduㄊㄌ;榎;榐Ȁaeuyㄗㄜㄧㄩron;䅙Ādiㄡㄥil;䅗ì࿲âヺ;䑀Ȁclqsㄴㄷㄽㅄa;椷dhar;楩uoĀ;rȎȍh;憳ƀacgㅎㅟངlȀ;ipsླྀㅘㅛႜnåႻarôྩt;断ƀilrㅩဣㅮsht;楽;쀀𝔯ĀaoㅷㆆrĀduㅽㅿ»ѻĀ;l႑ㆄ;楬Ā;vㆋㆌ䏁;䏱ƀgns㆕ㇹㇼht̀ahlrstㆤㆰ㇂㇘㇤㇮rrowĀ;t࿜ㆭaéトarpoonĀduㆻㆿowîㅾp»႒eftĀah㇊㇐rrowó࿪arpoonóՑightarrows;應quigarro÷ニhreetimes;拌g;䋚ingdotseñἲƀahm㈍㈐㈓rò࿪aòՑ;怏oustĀ;a㈞㈟掱che»㈟mid;櫮Ȁabpt㈲㈽㉀㉒Ānr㈷㈺g;柭r;懾rëဃƀafl㉇㉊㉎r;榆;쀀𝕣us;樮imes;樵Āap㉝㉧rĀ;g㉣㉤䀩t;榔olint;樒arò㇣Ȁachq㉻㊀Ⴜ㊅quo;怺r;쀀𝓇Ābu・㊊oĀ;rȔȓƀhir㊗㊛㊠reåㇸmes;拊iȀ;efl㊪ၙᠡ㊫方tri;槎luhar;楨;愞ൡ㋕㋛㋟㌬㌸㍱\0㍺㎤\0\0㏬㏰\0㐨㑈㑚㒭㒱㓊㓱\0㘖\0\0㘳cute;䅛quï➺Ԁ;Eaceinpsyᇭ㋳㋵㋿㌂㌋㌏㌟㌦㌩;檴ǰ㋺\0㋼;檸on;䅡uåᇾĀ;dᇳ㌇il;䅟rc;䅝ƀEas㌖㌘㌛;檶p;檺im;择olint;樓iíሄ;䑁otƀ;be㌴ᵇ㌵担;橦΀Aacmstx㍆㍊㍗㍛㍞㍣㍭rr;懘rĀhr㍐㍒ë∨Ā;oਸ਼਴t耻§䂧i;䀻war;椩mĀin㍩ðnuóñt;朶rĀ;o㍶⁕쀀𝔰Ȁacoy㎂㎆㎑㎠rp;景Āhy㎋㎏cy;䑉;䑈rtɭ㎙\0\0㎜iäᑤaraì⹯耻­䂭Āgm㎨㎴maƀ;fv㎱㎲㎲䏃;䏂Ѐ;deglnprካ㏅㏉㏎㏖㏞㏡㏦ot;橪Ā;q኱ኰĀ;E㏓㏔檞;檠Ā;E㏛㏜檝;檟e;扆lus;樤arr;楲aròᄽȀaeit㏸㐈㐏㐗Āls㏽㐄lsetmé㍪hp;樳parsl;槤Ādlᑣ㐔e;挣Ā;e㐜㐝檪Ā;s㐢㐣檬;쀀⪬︀ƀflp㐮㐳㑂tcy;䑌Ā;b㐸㐹䀯Ā;a㐾㐿槄r;挿f;쀀𝕤aĀdr㑍ЂesĀ;u㑔㑕晠it»㑕ƀcsu㑠㑹㒟Āau㑥㑯pĀ;sᆈ㑫;쀀⊓︀pĀ;sᆴ㑵;쀀⊔︀uĀbp㑿㒏ƀ;esᆗᆜ㒆etĀ;eᆗ㒍ñᆝƀ;esᆨᆭ㒖etĀ;eᆨ㒝ñᆮƀ;afᅻ㒦ְrť㒫ֱ»ᅼaròᅈȀcemt㒹㒾㓂㓅r;쀀𝓈tmîñiì㐕aræᆾĀar㓎㓕rĀ;f㓔ឿ昆Āan㓚㓭ightĀep㓣㓪psiloîỠhé⺯s»⡒ʀbcmnp㓻㕞ሉ㖋㖎Ҁ;Edemnprs㔎㔏㔑㔕㔞㔣㔬㔱㔶抂;櫅ot;檽Ā;dᇚ㔚ot;櫃ult;櫁ĀEe㔨㔪;櫋;把lus;檿arr;楹ƀeiu㔽㕒㕕tƀ;en㔎㕅㕋qĀ;qᇚ㔏eqĀ;q㔫㔨m;櫇Ābp㕚㕜;櫕;櫓c̀;acensᇭ㕬㕲㕹㕻㌦pproø㋺urlyeñᇾñᇳƀaes㖂㖈㌛pproø㌚qñ㌗g;晪ڀ123;Edehlmnps㖩㖬㖯ሜ㖲㖴㗀㗉㗕㗚㗟㗨㗭耻¹䂹耻²䂲耻³䂳;櫆Āos㖹㖼t;檾ub;櫘Ā;dሢ㗅ot;櫄sĀou㗏㗒l;柉b;櫗arr;楻ult;櫂ĀEe㗤㗦;櫌;抋lus;櫀ƀeiu㗴㘉㘌tƀ;enሜ㗼㘂qĀ;qሢ㖲eqĀ;q㗧㗤m;櫈Ābp㘑㘓;櫔;櫖ƀAan㘜㘠㘭rr;懙rĀhr㘦㘨ë∮Ā;oਫ਩war;椪lig耻ß䃟௡㙑㙝㙠ዎ㙳㙹\0㙾㛂\0\0\0\0\0㛛㜃\0㜉㝬\0\0\0㞇ɲ㙖\0\0㙛get;挖;䏄rë๟ƀaey㙦㙫㙰ron;䅥dil;䅣;䑂lrec;挕r;쀀𝔱Ȁeiko㚆㚝㚵㚼ǲ㚋\0㚑eĀ4fኄኁaƀ;sv㚘㚙㚛䎸ym;䏑Ācn㚢㚲kĀas㚨㚮pproø዁im»ኬsðኞĀas㚺㚮ð዁rn耻þ䃾Ǭ̟㛆⋧es膀×;bd㛏㛐㛘䃗Ā;aᤏ㛕r;樱;樰ƀeps㛡㛣㜀á⩍Ȁ;bcf҆㛬㛰㛴ot;挶ir;櫱Ā;o㛹㛼쀀𝕥rk;櫚á㍢rime;怴ƀaip㜏㜒㝤dåቈ΀adempst㜡㝍㝀㝑㝗㝜㝟ngleʀ;dlqr㜰㜱㜶㝀㝂斵own»ᶻeftĀ;e⠀㜾ñम;扜ightĀ;e㊪㝋ñၚot;旬inus;樺lus;樹b;槍ime;樻ezium;揢ƀcht㝲㝽㞁Āry㝷㝻;쀀𝓉;䑆cy;䑛rok;䅧Āio㞋㞎xô᝷headĀlr㞗㞠eftarro÷ࡏightarrow»ཝऀAHabcdfghlmoprstuw㟐㟓㟗㟤㟰㟼㠎㠜㠣㠴㡑㡝㡫㢩㣌㣒㣪㣶ròϭar;楣Ācr㟜㟢ute耻ú䃺òᅐrǣ㟪\0㟭y;䑞ve;䅭Āiy㟵㟺rc耻û䃻;䑃ƀabh㠃㠆㠋ròᎭlac;䅱aòᏃĀir㠓㠘sht;楾;쀀𝔲rave耻ù䃹š㠧㠱rĀlr㠬㠮»ॗ»ႃlk;斀Āct㠹㡍ɯ㠿\0\0㡊rnĀ;e㡅㡆挜r»㡆op;挏ri;旸Āal㡖㡚cr;䅫肻¨͉Āgp㡢㡦on;䅳f;쀀𝕦̀adhlsuᅋ㡸㡽፲㢑㢠ownáᎳarpoonĀlr㢈㢌efô㠭ighô㠯iƀ;hl㢙㢚㢜䏅»ᏺon»㢚parrows;懈ƀcit㢰㣄㣈ɯ㢶\0\0㣁rnĀ;e㢼㢽挝r»㢽op;挎ng;䅯ri;旹cr;쀀𝓊ƀdir㣙㣝㣢ot;拰lde;䅩iĀ;f㜰㣨»᠓Āam㣯㣲rò㢨l耻ü䃼angle;榧ހABDacdeflnoprsz㤜㤟㤩㤭㦵㦸㦽㧟㧤㧨㧳㧹㧽㨁㨠ròϷarĀ;v㤦㤧櫨;櫩asèϡĀnr㤲㤷grt;榜΀eknprst㓣㥆㥋㥒㥝㥤㦖appá␕othinçẖƀhir㓫⻈㥙opô⾵Ā;hᎷ㥢ïㆍĀiu㥩㥭gmá㎳Ābp㥲㦄setneqĀ;q㥽㦀쀀⊊︀;쀀⫋︀setneqĀ;q㦏㦒쀀⊋︀;쀀⫌︀Āhr㦛㦟etá㚜iangleĀlr㦪㦯eft»थight»ၑy;䐲ash»ံƀelr㧄㧒㧗ƀ;beⷪ㧋㧏ar;抻q;扚lip;拮Ābt㧜ᑨaòᑩr;쀀𝔳tré㦮suĀbp㧯㧱»ജ»൙pf;쀀𝕧roð໻tré㦴Ācu㨆㨋r;쀀𝓋Ābp㨐㨘nĀEe㦀㨖»㥾nĀEe㦒㨞»㦐igzag;榚΀cefoprs㨶㨻㩖㩛㩔㩡㩪irc;䅵Ādi㩀㩑Ābg㩅㩉ar;機eĀ;qᗺ㩏;扙erp;愘r;쀀𝔴pf;쀀𝕨Ā;eᑹ㩦atèᑹcr;쀀𝓌ૣណ㪇\0㪋\0㪐㪛\0\0㪝㪨㪫㪯\0\0㫃㫎\0㫘ៜ៟tré៑r;쀀𝔵ĀAa㪔㪗ròσrò৶;䎾ĀAa㪡㪤ròθrò৫að✓is;拻ƀdptឤ㪵㪾Āfl㪺ឩ;쀀𝕩imåឲĀAa㫇㫊ròώròਁĀcq㫒ីr;쀀𝓍Āpt៖㫜ré។Ѐacefiosu㫰㫽㬈㬌㬑㬕㬛㬡cĀuy㫶㫻te耻ý䃽;䑏Āiy㬂㬆rc;䅷;䑋n耻¥䂥r;쀀𝔶cy;䑗pf;쀀𝕪cr;쀀𝓎Ācm㬦㬩y;䑎l耻ÿ䃿Ԁacdefhiosw㭂㭈㭔㭘㭤㭩㭭㭴㭺㮀cute;䅺Āay㭍㭒ron;䅾;䐷ot;䅼Āet㭝㭡træᕟa;䎶r;쀀𝔷cy;䐶grarr;懝pf;쀀𝕫cr;쀀𝓏Ājn㮅㮇;怍j;怌'.split("").map(e=>e.charCodeAt(0))),Ok=new Map([[0,65533],[128,8364],[130,8218],[131,402],[132,8222],[133,8230],[134,8224],[135,8225],[136,710],[137,8240],[138,352],[139,8249],[140,338],[142,381],[145,8216],[146,8217],[147,8220],[148,8221],[149,8226],[150,8211],[151,8212],[152,732],[153,8482],[154,353],[155,8250],[156,339],[158,382],[159,376]]);function Rk(e){var t;return e>=55296&&e<=57343||e>1114111?65533:(t=Ok.get(e))!==null&&t!==void 0?t:e}var Hn;(function(e){e[e.NUM=35]="NUM",e[e.SEMI=59]="SEMI",e[e.EQUALS=61]="EQUALS",e[e.ZERO=48]="ZERO",e[e.NINE=57]="NINE",e[e.LOWER_A=97]="LOWER_A",e[e.LOWER_F=102]="LOWER_F",e[e.LOWER_X=120]="LOWER_X",e[e.LOWER_Z=122]="LOWER_Z",e[e.UPPER_A=65]="UPPER_A",e[e.UPPER_F=70]="UPPER_F",e[e.UPPER_Z=90]="UPPER_Z"})(Hn||(Hn={}));const Mk=32;var Xi;(function(e){e[e.VALUE_LENGTH=49152]="VALUE_LENGTH",e[e.BRANCH_LENGTH=16256]="BRANCH_LENGTH",e[e.JUMP_TABLE=127]="JUMP_TABLE"})(Xi||(Xi={}));function M1(e){return e>=Hn.ZERO&&e<=Hn.NINE}function Dk(e){return e>=Hn.UPPER_A&&e<=Hn.UPPER_F||e>=Hn.LOWER_A&&e<=Hn.LOWER_F}function Ik(e){return e>=Hn.UPPER_A&&e<=Hn.UPPER_Z||e>=Hn.LOWER_A&&e<=Hn.LOWER_Z||M1(e)}function Lk(e){return e===Hn.EQUALS||Ik(e)}var zn;(function(e){e[e.EntityStart=0]="EntityStart",e[e.NumericStart=1]="NumericStart",e[e.NumericDecimal=2]="NumericDecimal",e[e.NumericHex=3]="NumericHex",e[e.NamedEntity=4]="NamedEntity"})(zn||(zn={}));var ni;(function(e){e[e.Legacy=0]="Legacy",e[e.Strict=1]="Strict",e[e.Attribute=2]="Attribute"})(ni||(ni={}));class Bk{constructor(t,n,a){this.decodeTree=t,this.emitCodePoint=n,this.errors=a,this.state=zn.EntityStart,this.consumed=1,this.result=0,this.treeIndex=0,this.excess=1,this.decodeMode=ni.Strict}startEntity(t){this.decodeMode=t,this.state=zn.EntityStart,this.result=0,this.treeIndex=0,this.excess=1,this.consumed=1}write(t,n){switch(this.state){case zn.EntityStart:return t.charCodeAt(n)===Hn.NUM?(this.state=zn.NumericStart,this.consumed+=1,this.stateNumericStart(t,n+1)):(this.state=zn.NamedEntity,this.stateNamedEntity(t,n));case zn.NumericStart:return this.stateNumericStart(t,n);case zn.NumericDecimal:return this.stateNumericDecimal(t,n);case zn.NumericHex:return this.stateNumericHex(t,n);case zn.NamedEntity:return this.stateNamedEntity(t,n)}}stateNumericStart(t,n){return n>=t.length?-1:(t.charCodeAt(n)|Mk)===Hn.LOWER_X?(this.state=zn.NumericHex,this.consumed+=1,this.stateNumericHex(t,n+1)):(this.state=zn.NumericDecimal,this.stateNumericDecimal(t,n))}addToNumericResult(t,n,a,l){if(n!==a){const s=a-n;this.result=this.result*Math.pow(l,s)+Number.parseInt(t.substr(n,s),l),this.consumed+=s}}stateNumericHex(t,n){const a=n;for(;n<t.length;){const l=t.charCodeAt(n);if(M1(l)||Dk(l))n+=1;else return this.addToNumericResult(t,a,n,16),this.emitNumericEntity(l,3)}return this.addToNumericResult(t,a,n,16),-1}stateNumericDecimal(t,n){const a=n;for(;n<t.length;){const l=t.charCodeAt(n);if(M1(l))n+=1;else return this.addToNumericResult(t,a,n,10),this.emitNumericEntity(l,2)}return this.addToNumericResult(t,a,n,10),-1}emitNumericEntity(t,n){var a;if(this.consumed<=n)return(a=this.errors)===null||a===void 0||a.absenceOfDigitsInNumericCharacterReference(this.consumed),0;if(t===Hn.SEMI)this.consumed+=1;else if(this.decodeMode===ni.Strict)return 0;return this.emitCodePoint(Rk(this.result),this.consumed),this.errors&&(t!==Hn.SEMI&&this.errors.missingSemicolonAfterCharacterReference(),this.errors.validateNumericCharacterReference(this.result)),this.consumed}stateNamedEntity(t,n){const{decodeTree:a}=this;let l=a[this.treeIndex],s=(l&Xi.VALUE_LENGTH)>>14;for(;n<t.length;n++,this.excess++){const o=t.charCodeAt(n);if(this.treeIndex=Pk(a,l,this.treeIndex+Math.max(1,s),o),this.treeIndex<0)return this.result===0||this.decodeMode===ni.Attribute&&(s===0||Lk(o))?0:this.emitNotTerminatedNamedEntity();if(l=a[this.treeIndex],s=(l&Xi.VALUE_LENGTH)>>14,s!==0){if(o===Hn.SEMI)return this.emitNamedEntityData(this.treeIndex,s,this.consumed+this.excess);this.decodeMode!==ni.Strict&&(this.result=this.treeIndex,this.consumed+=this.excess,this.excess=0)}}return-1}emitNotTerminatedNamedEntity(){var t;const{result:n,decodeTree:a}=this,l=(a[n]&Xi.VALUE_LENGTH)>>14;return this.emitNamedEntityData(n,l,this.consumed),(t=this.errors)===null||t===void 0||t.missingSemicolonAfterCharacterReference(),this.consumed}emitNamedEntityData(t,n,a){const{decodeTree:l}=this;return this.emitCodePoint(n===1?l[t]&~Xi.VALUE_LENGTH:l[t+1],a),n===3&&this.emitCodePoint(l[t+2],a),a}end(){var t;switch(this.state){case zn.NamedEntity:return this.result!==0&&(this.decodeMode!==ni.Attribute||this.result===this.treeIndex)?this.emitNotTerminatedNamedEntity():0;case zn.NumericDecimal:return this.emitNumericEntity(0,2);case zn.NumericHex:return this.emitNumericEntity(0,3);case zn.NumericStart:return(t=this.errors)===null||t===void 0||t.absenceOfDigitsInNumericCharacterReference(this.consumed),0;case zn.EntityStart:return 0}}}function Pk(e,t,n,a){const l=(t&Xi.BRANCH_LENGTH)>>7,s=t&Xi.JUMP_TABLE;if(l===0)return s!==0&&a===s?n:-1;if(s){const f=a-s;return f<0||f>=l?-1:e[n+f]-1}let o=n,d=o+l-1;for(;o<=d;){const f=o+d>>>1,h=e[f];if(h<a)o=f+1;else if(h>a)d=f-1;else return e[f+l]}return-1}var _e;(function(e){e.HTML="http://www.w3.org/1999/xhtml",e.MATHML="http://www.w3.org/1998/Math/MathML",e.SVG="http://www.w3.org/2000/svg",e.XLINK="http://www.w3.org/1999/xlink",e.XML="http://www.w3.org/XML/1998/namespace",e.XMLNS="http://www.w3.org/2000/xmlns/"})(_e||(_e={}));var Ol;(function(e){e.TYPE="type",e.ACTION="action",e.ENCODING="encoding",e.PROMPT="prompt",e.NAME="name",e.COLOR="color",e.FACE="face",e.SIZE="size"})(Ol||(Ol={}));var Wr;(function(e){e.NO_QUIRKS="no-quirks",e.QUIRKS="quirks",e.LIMITED_QUIRKS="limited-quirks"})(Wr||(Wr={}));var W;(function(e){e.A="a",e.ADDRESS="address",e.ANNOTATION_XML="annotation-xml",e.APPLET="applet",e.AREA="area",e.ARTICLE="article",e.ASIDE="aside",e.B="b",e.BASE="base",e.BASEFONT="basefont",e.BGSOUND="bgsound",e.BIG="big",e.BLOCKQUOTE="blockquote",e.BODY="body",e.BR="br",e.BUTTON="button",e.CAPTION="caption",e.CENTER="center",e.CODE="code",e.COL="col",e.COLGROUP="colgroup",e.DD="dd",e.DESC="desc",e.DETAILS="details",e.DIALOG="dialog",e.DIR="dir",e.DIV="div",e.DL="dl",e.DT="dt",e.EM="em",e.EMBED="embed",e.FIELDSET="fieldset",e.FIGCAPTION="figcaption",e.FIGURE="figure",e.FONT="font",e.FOOTER="footer",e.FOREIGN_OBJECT="foreignObject",e.FORM="form",e.FRAME="frame",e.FRAMESET="frameset",e.H1="h1",e.H2="h2",e.H3="h3",e.H4="h4",e.H5="h5",e.H6="h6",e.HEAD="head",e.HEADER="header",e.HGROUP="hgroup",e.HR="hr",e.HTML="html",e.I="i",e.IMG="img",e.IMAGE="image",e.INPUT="input",e.IFRAME="iframe",e.KEYGEN="keygen",e.LABEL="label",e.LI="li",e.LINK="link",e.LISTING="listing",e.MAIN="main",e.MALIGNMARK="malignmark",e.MARQUEE="marquee",e.MATH="math",e.MENU="menu",e.META="meta",e.MGLYPH="mglyph",e.MI="mi",e.MO="mo",e.MN="mn",e.MS="ms",e.MTEXT="mtext",e.NAV="nav",e.NOBR="nobr",e.NOFRAMES="noframes",e.NOEMBED="noembed",e.NOSCRIPT="noscript",e.OBJECT="object",e.OL="ol",e.OPTGROUP="optgroup",e.OPTION="option",e.P="p",e.PARAM="param",e.PLAINTEXT="plaintext",e.PRE="pre",e.RB="rb",e.RP="rp",e.RT="rt",e.RTC="rtc",e.RUBY="ruby",e.S="s",e.SCRIPT="script",e.SEARCH="search",e.SECTION="section",e.SELECT="select",e.SOURCE="source",e.SMALL="small",e.SPAN="span",e.STRIKE="strike",e.STRONG="strong",e.STYLE="style",e.SUB="sub",e.SUMMARY="summary",e.SUP="sup",e.TABLE="table",e.TBODY="tbody",e.TEMPLATE="template",e.TEXTAREA="textarea",e.TFOOT="tfoot",e.TD="td",e.TH="th",e.THEAD="thead",e.TITLE="title",e.TR="tr",e.TRACK="track",e.TT="tt",e.U="u",e.UL="ul",e.SVG="svg",e.VAR="var",e.WBR="wbr",e.XMP="xmp"})(W||(W={}));var b;(function(e){e[e.UNKNOWN=0]="UNKNOWN",e[e.A=1]="A",e[e.ADDRESS=2]="ADDRESS",e[e.ANNOTATION_XML=3]="ANNOTATION_XML",e[e.APPLET=4]="APPLET",e[e.AREA=5]="AREA",e[e.ARTICLE=6]="ARTICLE",e[e.ASIDE=7]="ASIDE",e[e.B=8]="B",e[e.BASE=9]="BASE",e[e.BASEFONT=10]="BASEFONT",e[e.BGSOUND=11]="BGSOUND",e[e.BIG=12]="BIG",e[e.BLOCKQUOTE=13]="BLOCKQUOTE",e[e.BODY=14]="BODY",e[e.BR=15]="BR",e[e.BUTTON=16]="BUTTON",e[e.CAPTION=17]="CAPTION",e[e.CENTER=18]="CENTER",e[e.CODE=19]="CODE",e[e.COL=20]="COL",e[e.COLGROUP=21]="COLGROUP",e[e.DD=22]="DD",e[e.DESC=23]="DESC",e[e.DETAILS=24]="DETAILS",e[e.DIALOG=25]="DIALOG",e[e.DIR=26]="DIR",e[e.DIV=27]="DIV",e[e.DL=28]="DL",e[e.DT=29]="DT",e[e.EM=30]="EM",e[e.EMBED=31]="EMBED",e[e.FIELDSET=32]="FIELDSET",e[e.FIGCAPTION=33]="FIGCAPTION",e[e.FIGURE=34]="FIGURE",e[e.FONT=35]="FONT",e[e.FOOTER=36]="FOOTER",e[e.FOREIGN_OBJECT=37]="FOREIGN_OBJECT",e[e.FORM=38]="FORM",e[e.FRAME=39]="FRAME",e[e.FRAMESET=40]="FRAMESET",e[e.H1=41]="H1",e[e.H2=42]="H2",e[e.H3=43]="H3",e[e.H4=44]="H4",e[e.H5=45]="H5",e[e.H6=46]="H6",e[e.HEAD=47]="HEAD",e[e.HEADER=48]="HEADER",e[e.HGROUP=49]="HGROUP",e[e.HR=50]="HR",e[e.HTML=51]="HTML",e[e.I=52]="I",e[e.IMG=53]="IMG",e[e.IMAGE=54]="IMAGE",e[e.INPUT=55]="INPUT",e[e.IFRAME=56]="IFRAME",e[e.KEYGEN=57]="KEYGEN",e[e.LABEL=58]="LABEL",e[e.LI=59]="LI",e[e.LINK=60]="LINK",e[e.LISTING=61]="LISTING",e[e.MAIN=62]="MAIN",e[e.MALIGNMARK=63]="MALIGNMARK",e[e.MARQUEE=64]="MARQUEE",e[e.MATH=65]="MATH",e[e.MENU=66]="MENU",e[e.META=67]="META",e[e.MGLYPH=68]="MGLYPH",e[e.MI=69]="MI",e[e.MO=70]="MO",e[e.MN=71]="MN",e[e.MS=72]="MS",e[e.MTEXT=73]="MTEXT",e[e.NAV=74]="NAV",e[e.NOBR=75]="NOBR",e[e.NOFRAMES=76]="NOFRAMES",e[e.NOEMBED=77]="NOEMBED",e[e.NOSCRIPT=78]="NOSCRIPT",e[e.OBJECT=79]="OBJECT",e[e.OL=80]="OL",e[e.OPTGROUP=81]="OPTGROUP",e[e.OPTION=82]="OPTION",e[e.P=83]="P",e[e.PARAM=84]="PARAM",e[e.PLAINTEXT=85]="PLAINTEXT",e[e.PRE=86]="PRE",e[e.RB=87]="RB",e[e.RP=88]="RP",e[e.RT=89]="RT",e[e.RTC=90]="RTC",e[e.RUBY=91]="RUBY",e[e.S=92]="S",e[e.SCRIPT=93]="SCRIPT",e[e.SEARCH=94]="SEARCH",e[e.SECTION=95]="SECTION",e[e.SELECT=96]="SELECT",e[e.SOURCE=97]="SOURCE",e[e.SMALL=98]="SMALL",e[e.SPAN=99]="SPAN",e[e.STRIKE=100]="STRIKE",e[e.STRONG=101]="STRONG",e[e.STYLE=102]="STYLE",e[e.SUB=103]="SUB",e[e.SUMMARY=104]="SUMMARY",e[e.SUP=105]="SUP",e[e.TABLE=106]="TABLE",e[e.TBODY=107]="TBODY",e[e.TEMPLATE=108]="TEMPLATE",e[e.TEXTAREA=109]="TEXTAREA",e[e.TFOOT=110]="TFOOT",e[e.TD=111]="TD",e[e.TH=112]="TH",e[e.THEAD=113]="THEAD",e[e.TITLE=114]="TITLE",e[e.TR=115]="TR",e[e.TRACK=116]="TRACK",e[e.TT=117]="TT",e[e.U=118]="U",e[e.UL=119]="UL",e[e.SVG=120]="SVG",e[e.VAR=121]="VAR",e[e.WBR=122]="WBR",e[e.XMP=123]="XMP"})(b||(b={}));const Uk=new Map([[W.A,b.A],[W.ADDRESS,b.ADDRESS],[W.ANNOTATION_XML,b.ANNOTATION_XML],[W.APPLET,b.APPLET],[W.AREA,b.AREA],[W.ARTICLE,b.ARTICLE],[W.ASIDE,b.ASIDE],[W.B,b.B],[W.BASE,b.BASE],[W.BASEFONT,b.BASEFONT],[W.BGSOUND,b.BGSOUND],[W.BIG,b.BIG],[W.BLOCKQUOTE,b.BLOCKQUOTE],[W.BODY,b.BODY],[W.BR,b.BR],[W.BUTTON,b.BUTTON],[W.CAPTION,b.CAPTION],[W.CENTER,b.CENTER],[W.CODE,b.CODE],[W.COL,b.COL],[W.COLGROUP,b.COLGROUP],[W.DD,b.DD],[W.DESC,b.DESC],[W.DETAILS,b.DETAILS],[W.DIALOG,b.DIALOG],[W.DIR,b.DIR],[W.DIV,b.DIV],[W.DL,b.DL],[W.DT,b.DT],[W.EM,b.EM],[W.EMBED,b.EMBED],[W.FIELDSET,b.FIELDSET],[W.FIGCAPTION,b.FIGCAPTION],[W.FIGURE,b.FIGURE],[W.FONT,b.FONT],[W.FOOTER,b.FOOTER],[W.FOREIGN_OBJECT,b.FOREIGN_OBJECT],[W.FORM,b.FORM],[W.FRAME,b.FRAME],[W.FRAMESET,b.FRAMESET],[W.H1,b.H1],[W.H2,b.H2],[W.H3,b.H3],[W.H4,b.H4],[W.H5,b.H5],[W.H6,b.H6],[W.HEAD,b.HEAD],[W.HEADER,b.HEADER],[W.HGROUP,b.HGROUP],[W.HR,b.HR],[W.HTML,b.HTML],[W.I,b.I],[W.IMG,b.IMG],[W.IMAGE,b.IMAGE],[W.INPUT,b.INPUT],[W.IFRAME,b.IFRAME],[W.KEYGEN,b.KEYGEN],[W.LABEL,b.LABEL],[W.LI,b.LI],[W.LINK,b.LINK],[W.LISTING,b.LISTING],[W.MAIN,b.MAIN],[W.MALIGNMARK,b.MALIGNMARK],[W.MARQUEE,b.MARQUEE],[W.MATH,b.MATH],[W.MENU,b.MENU],[W.META,b.META],[W.MGLYPH,b.MGLYPH],[W.MI,b.MI],[W.MO,b.MO],[W.MN,b.MN],[W.MS,b.MS],[W.MTEXT,b.MTEXT],[W.NAV,b.NAV],[W.NOBR,b.NOBR],[W.NOFRAMES,b.NOFRAMES],[W.NOEMBED,b.NOEMBED],[W.NOSCRIPT,b.NOSCRIPT],[W.OBJECT,b.OBJECT],[W.OL,b.OL],[W.OPTGROUP,b.OPTGROUP],[W.OPTION,b.OPTION],[W.P,b.P],[W.PARAM,b.PARAM],[W.PLAINTEXT,b.PLAINTEXT],[W.PRE,b.PRE],[W.RB,b.RB],[W.RP,b.RP],[W.RT,b.RT],[W.RTC,b.RTC],[W.RUBY,b.RUBY],[W.S,b.S],[W.SCRIPT,b.SCRIPT],[W.SEARCH,b.SEARCH],[W.SECTION,b.SECTION],[W.SELECT,b.SELECT],[W.SOURCE,b.SOURCE],[W.SMALL,b.SMALL],[W.SPAN,b.SPAN],[W.STRIKE,b.STRIKE],[W.STRONG,b.STRONG],[W.STYLE,b.STYLE],[W.SUB,b.SUB],[W.SUMMARY,b.SUMMARY],[W.SUP,b.SUP],[W.TABLE,b.TABLE],[W.TBODY,b.TBODY],[W.TEMPLATE,b.TEMPLATE],[W.TEXTAREA,b.TEXTAREA],[W.TFOOT,b.TFOOT],[W.TD,b.TD],[W.TH,b.TH],[W.THEAD,b.THEAD],[W.TITLE,b.TITLE],[W.TR,b.TR],[W.TRACK,b.TRACK],[W.TT,b.TT],[W.U,b.U],[W.UL,b.UL],[W.SVG,b.SVG],[W.VAR,b.VAR],[W.WBR,b.WBR],[W.XMP,b.XMP]]);function zs(e){var t;return(t=Uk.get(e))!==null&&t!==void 0?t:b.UNKNOWN}const Ae=b,zk={[_e.HTML]:new Set([Ae.ADDRESS,Ae.APPLET,Ae.AREA,Ae.ARTICLE,Ae.ASIDE,Ae.BASE,Ae.BASEFONT,Ae.BGSOUND,Ae.BLOCKQUOTE,Ae.BODY,Ae.BR,Ae.BUTTON,Ae.CAPTION,Ae.CENTER,Ae.COL,Ae.COLGROUP,Ae.DD,Ae.DETAILS,Ae.DIR,Ae.DIV,Ae.DL,Ae.DT,Ae.EMBED,Ae.FIELDSET,Ae.FIGCAPTION,Ae.FIGURE,Ae.FOOTER,Ae.FORM,Ae.FRAME,Ae.FRAMESET,Ae.H1,Ae.H2,Ae.H3,Ae.H4,Ae.H5,Ae.H6,Ae.HEAD,Ae.HEADER,Ae.HGROUP,Ae.HR,Ae.HTML,Ae.IFRAME,Ae.IMG,Ae.INPUT,Ae.LI,Ae.LINK,Ae.LISTING,Ae.MAIN,Ae.MARQUEE,Ae.MENU,Ae.META,Ae.NAV,Ae.NOEMBED,Ae.NOFRAMES,Ae.NOSCRIPT,Ae.OBJECT,Ae.OL,Ae.P,Ae.PARAM,Ae.PLAINTEXT,Ae.PRE,Ae.SCRIPT,Ae.SECTION,Ae.SELECT,Ae.SOURCE,Ae.STYLE,Ae.SUMMARY,Ae.TABLE,Ae.TBODY,Ae.TD,Ae.TEMPLATE,Ae.TEXTAREA,Ae.TFOOT,Ae.TH,Ae.THEAD,Ae.TITLE,Ae.TR,Ae.TRACK,Ae.UL,Ae.WBR,Ae.XMP]),[_e.MATHML]:new Set([Ae.MI,Ae.MO,Ae.MN,Ae.MS,Ae.MTEXT,Ae.ANNOTATION_XML]),[_e.SVG]:new Set([Ae.TITLE,Ae.FOREIGN_OBJECT,Ae.DESC]),[_e.XLINK]:new Set,[_e.XML]:new Set,[_e.XMLNS]:new Set},D1=new Set([Ae.H1,Ae.H2,Ae.H3,Ae.H4,Ae.H5,Ae.H6]);W.STYLE,W.SCRIPT,W.XMP,W.IFRAME,W.NOEMBED,W.NOFRAMES,W.PLAINTEXT;var L;(function(e){e[e.DATA=0]="DATA",e[e.RCDATA=1]="RCDATA",e[e.RAWTEXT=2]="RAWTEXT",e[e.SCRIPT_DATA=3]="SCRIPT_DATA",e[e.PLAINTEXT=4]="PLAINTEXT",e[e.TAG_OPEN=5]="TAG_OPEN",e[e.END_TAG_OPEN=6]="END_TAG_OPEN",e[e.TAG_NAME=7]="TAG_NAME",e[e.RCDATA_LESS_THAN_SIGN=8]="RCDATA_LESS_THAN_SIGN",e[e.RCDATA_END_TAG_OPEN=9]="RCDATA_END_TAG_OPEN",e[e.RCDATA_END_TAG_NAME=10]="RCDATA_END_TAG_NAME",e[e.RAWTEXT_LESS_THAN_SIGN=11]="RAWTEXT_LESS_THAN_SIGN",e[e.RAWTEXT_END_TAG_OPEN=12]="RAWTEXT_END_TAG_OPEN",e[e.RAWTEXT_END_TAG_NAME=13]="RAWTEXT_END_TAG_NAME",e[e.SCRIPT_DATA_LESS_THAN_SIGN=14]="SCRIPT_DATA_LESS_THAN_SIGN",e[e.SCRIPT_DATA_END_TAG_OPEN=15]="SCRIPT_DATA_END_TAG_OPEN",e[e.SCRIPT_DATA_END_TAG_NAME=16]="SCRIPT_DATA_END_TAG_NAME",e[e.SCRIPT_DATA_ESCAPE_START=17]="SCRIPT_DATA_ESCAPE_START",e[e.SCRIPT_DATA_ESCAPE_START_DASH=18]="SCRIPT_DATA_ESCAPE_START_DASH",e[e.SCRIPT_DATA_ESCAPED=19]="SCRIPT_DATA_ESCAPED",e[e.SCRIPT_DATA_ESCAPED_DASH=20]="SCRIPT_DATA_ESCAPED_DASH",e[e.SCRIPT_DATA_ESCAPED_DASH_DASH=21]="SCRIPT_DATA_ESCAPED_DASH_DASH",e[e.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN=22]="SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN",e[e.SCRIPT_DATA_ESCAPED_END_TAG_OPEN=23]="SCRIPT_DATA_ESCAPED_END_TAG_OPEN",e[e.SCRIPT_DATA_ESCAPED_END_TAG_NAME=24]="SCRIPT_DATA_ESCAPED_END_TAG_NAME",e[e.SCRIPT_DATA_DOUBLE_ESCAPE_START=25]="SCRIPT_DATA_DOUBLE_ESCAPE_START",e[e.SCRIPT_DATA_DOUBLE_ESCAPED=26]="SCRIPT_DATA_DOUBLE_ESCAPED",e[e.SCRIPT_DATA_DOUBLE_ESCAPED_DASH=27]="SCRIPT_DATA_DOUBLE_ESCAPED_DASH",e[e.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH=28]="SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH",e[e.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN=29]="SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN",e[e.SCRIPT_DATA_DOUBLE_ESCAPE_END=30]="SCRIPT_DATA_DOUBLE_ESCAPE_END",e[e.BEFORE_ATTRIBUTE_NAME=31]="BEFORE_ATTRIBUTE_NAME",e[e.ATTRIBUTE_NAME=32]="ATTRIBUTE_NAME",e[e.AFTER_ATTRIBUTE_NAME=33]="AFTER_ATTRIBUTE_NAME",e[e.BEFORE_ATTRIBUTE_VALUE=34]="BEFORE_ATTRIBUTE_VALUE",e[e.ATTRIBUTE_VALUE_DOUBLE_QUOTED=35]="ATTRIBUTE_VALUE_DOUBLE_QUOTED",e[e.ATTRIBUTE_VALUE_SINGLE_QUOTED=36]="ATTRIBUTE_VALUE_SINGLE_QUOTED",e[e.ATTRIBUTE_VALUE_UNQUOTED=37]="ATTRIBUTE_VALUE_UNQUOTED",e[e.AFTER_ATTRIBUTE_VALUE_QUOTED=38]="AFTER_ATTRIBUTE_VALUE_QUOTED",e[e.SELF_CLOSING_START_TAG=39]="SELF_CLOSING_START_TAG",e[e.BOGUS_COMMENT=40]="BOGUS_COMMENT",e[e.MARKUP_DECLARATION_OPEN=41]="MARKUP_DECLARATION_OPEN",e[e.COMMENT_START=42]="COMMENT_START",e[e.COMMENT_START_DASH=43]="COMMENT_START_DASH",e[e.COMMENT=44]="COMMENT",e[e.COMMENT_LESS_THAN_SIGN=45]="COMMENT_LESS_THAN_SIGN",e[e.COMMENT_LESS_THAN_SIGN_BANG=46]="COMMENT_LESS_THAN_SIGN_BANG",e[e.COMMENT_LESS_THAN_SIGN_BANG_DASH=47]="COMMENT_LESS_THAN_SIGN_BANG_DASH",e[e.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH=48]="COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH",e[e.COMMENT_END_DASH=49]="COMMENT_END_DASH",e[e.COMMENT_END=50]="COMMENT_END",e[e.COMMENT_END_BANG=51]="COMMENT_END_BANG",e[e.DOCTYPE=52]="DOCTYPE",e[e.BEFORE_DOCTYPE_NAME=53]="BEFORE_DOCTYPE_NAME",e[e.DOCTYPE_NAME=54]="DOCTYPE_NAME",e[e.AFTER_DOCTYPE_NAME=55]="AFTER_DOCTYPE_NAME",e[e.AFTER_DOCTYPE_PUBLIC_KEYWORD=56]="AFTER_DOCTYPE_PUBLIC_KEYWORD",e[e.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER=57]="BEFORE_DOCTYPE_PUBLIC_IDENTIFIER",e[e.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED=58]="DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED",e[e.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED=59]="DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED",e[e.AFTER_DOCTYPE_PUBLIC_IDENTIFIER=60]="AFTER_DOCTYPE_PUBLIC_IDENTIFIER",e[e.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS=61]="BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS",e[e.AFTER_DOCTYPE_SYSTEM_KEYWORD=62]="AFTER_DOCTYPE_SYSTEM_KEYWORD",e[e.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER=63]="BEFORE_DOCTYPE_SYSTEM_IDENTIFIER",e[e.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED=64]="DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED",e[e.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED=65]="DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED",e[e.AFTER_DOCTYPE_SYSTEM_IDENTIFIER=66]="AFTER_DOCTYPE_SYSTEM_IDENTIFIER",e[e.BOGUS_DOCTYPE=67]="BOGUS_DOCTYPE",e[e.CDATA_SECTION=68]="CDATA_SECTION",e[e.CDATA_SECTION_BRACKET=69]="CDATA_SECTION_BRACKET",e[e.CDATA_SECTION_END=70]="CDATA_SECTION_END",e[e.CHARACTER_REFERENCE=71]="CHARACTER_REFERENCE",e[e.AMBIGUOUS_AMPERSAND=72]="AMBIGUOUS_AMPERSAND"})(L||(L={}));const yn={DATA:L.DATA,RCDATA:L.RCDATA,RAWTEXT:L.RAWTEXT,SCRIPT_DATA:L.SCRIPT_DATA,PLAINTEXT:L.PLAINTEXT,CDATA_SECTION:L.CDATA_SECTION};function Hk(e){return e>=M.DIGIT_0&&e<=M.DIGIT_9}function Zu(e){return e>=M.LATIN_CAPITAL_A&&e<=M.LATIN_CAPITAL_Z}function Fk(e){return e>=M.LATIN_SMALL_A&&e<=M.LATIN_SMALL_Z}function Yi(e){return Fk(e)||Zu(e)}function Db(e){return Yi(e)||Hk(e)}function W0(e){return e+32}function YE(e){return e===M.SPACE||e===M.LINE_FEED||e===M.TABULATION||e===M.FORM_FEED}function Ib(e){return YE(e)||e===M.SOLIDUS||e===M.GREATER_THAN_SIGN}function qk(e){return e===M.NULL?ie.nullCharacterReference:e>1114111?ie.characterReferenceOutsideUnicodeRange:zE(e)?ie.surrogateCharacterReference:FE(e)?ie.noncharacterCharacterReference:HE(e)||e===M.CARRIAGE_RETURN?ie.controlCharacterReference:null}class Yk{constructor(t,n){this.options=t,this.handler=n,this.paused=!1,this.inLoop=!1,this.inForeignNode=!1,this.lastStartTagName="",this.active=!1,this.state=L.DATA,this.returnState=L.DATA,this.entityStartPos=0,this.consumedAfterSnapshot=-1,this.currentCharacterToken=null,this.currentToken=null,this.currentAttr={name:"",value:""},this.preprocessor=new wk(n),this.currentLocation=this.getCurrentLocation(-1),this.entityDecoder=new Bk(Ck,(a,l)=>{this.preprocessor.pos=this.entityStartPos+l-1,this._flushCodePointConsumedAsCharacterReference(a)},n.onParseError?{missingSemicolonAfterCharacterReference:()=>{this._err(ie.missingSemicolonAfterCharacterReference,1)},absenceOfDigitsInNumericCharacterReference:a=>{this._err(ie.absenceOfDigitsInNumericCharacterReference,this.entityStartPos-this.preprocessor.pos+a)},validateNumericCharacterReference:a=>{const l=qk(a);l&&this._err(l,1)}}:void 0)}_err(t,n=0){var a,l;(l=(a=this.handler).onParseError)===null||l===void 0||l.call(a,this.preprocessor.getError(t,n))}getCurrentLocation(t){return this.options.sourceCodeLocationInfo?{startLine:this.preprocessor.line,startCol:this.preprocessor.col-t,startOffset:this.preprocessor.offset-t,endLine:-1,endCol:-1,endOffset:-1}:null}_runParsingLoop(){if(!this.inLoop){for(this.inLoop=!0;this.active&&!this.paused;){this.consumedAfterSnapshot=0;const t=this._consume();this._ensureHibernation()||this._callState(t)}this.inLoop=!1}}pause(){this.paused=!0}resume(t){if(!this.paused)throw new Error("Parser was already resumed");this.paused=!1,!this.inLoop&&(this._runParsingLoop(),this.paused||t==null||t())}write(t,n,a){this.active=!0,this.preprocessor.write(t,n),this._runParsingLoop(),this.paused||a==null||a()}insertHtmlAtCurrentPos(t){this.active=!0,this.preprocessor.insertHtmlAtCurrentPos(t),this._runParsingLoop()}_ensureHibernation(){return this.preprocessor.endOfChunkHit?(this.preprocessor.retreat(this.consumedAfterSnapshot),this.consumedAfterSnapshot=0,this.active=!1,!0):!1}_consume(){return this.consumedAfterSnapshot++,this.preprocessor.advance()}_advanceBy(t){this.consumedAfterSnapshot+=t;for(let n=0;n<t;n++)this.preprocessor.advance()}_consumeSequenceIfMatch(t,n){return this.preprocessor.startsWith(t,n)?(this._advanceBy(t.length-1),!0):!1}_createStartTagToken(){this.currentToken={type:Et.START_TAG,tagName:"",tagID:b.UNKNOWN,selfClosing:!1,ackSelfClosing:!1,attrs:[],location:this.getCurrentLocation(1)}}_createEndTagToken(){this.currentToken={type:Et.END_TAG,tagName:"",tagID:b.UNKNOWN,selfClosing:!1,ackSelfClosing:!1,attrs:[],location:this.getCurrentLocation(2)}}_createCommentToken(t){this.currentToken={type:Et.COMMENT,data:"",location:this.getCurrentLocation(t)}}_createDoctypeToken(t){this.currentToken={type:Et.DOCTYPE,name:t,forceQuirks:!1,publicId:null,systemId:null,location:this.currentLocation}}_createCharacterToken(t,n){this.currentCharacterToken={type:t,chars:n,location:this.currentLocation}}_createAttr(t){this.currentAttr={name:t,value:""},this.currentLocation=this.getCurrentLocation(0)}_leaveAttrName(){var t,n;const a=this.currentToken;if(qE(a,this.currentAttr.name)===null){if(a.attrs.push(this.currentAttr),a.location&&this.currentLocation){const l=(t=(n=a.location).attrs)!==null&&t!==void 0?t:n.attrs=Object.create(null);l[this.currentAttr.name]=this.currentLocation,this._leaveAttrValue()}}else this._err(ie.duplicateAttribute)}_leaveAttrValue(){this.currentLocation&&(this.currentLocation.endLine=this.preprocessor.line,this.currentLocation.endCol=this.preprocessor.col,this.currentLocation.endOffset=this.preprocessor.offset)}prepareToken(t){this._emitCurrentCharacterToken(t.location),this.currentToken=null,t.location&&(t.location.endLine=this.preprocessor.line,t.location.endCol=this.preprocessor.col+1,t.location.endOffset=this.preprocessor.offset+1),this.currentLocation=this.getCurrentLocation(-1)}emitCurrentTagToken(){const t=this.currentToken;this.prepareToken(t),t.tagID=zs(t.tagName),t.type===Et.START_TAG?(this.lastStartTagName=t.tagName,this.handler.onStartTag(t)):(t.attrs.length>0&&this._err(ie.endTagWithAttributes),t.selfClosing&&this._err(ie.endTagWithTrailingSolidus),this.handler.onEndTag(t)),this.preprocessor.dropParsedChunk()}emitCurrentComment(t){this.prepareToken(t),this.handler.onComment(t),this.preprocessor.dropParsedChunk()}emitCurrentDoctype(t){this.prepareToken(t),this.handler.onDoctype(t),this.preprocessor.dropParsedChunk()}_emitCurrentCharacterToken(t){if(this.currentCharacterToken){switch(t&&this.currentCharacterToken.location&&(this.currentCharacterToken.location.endLine=t.startLine,this.currentCharacterToken.location.endCol=t.startCol,this.currentCharacterToken.location.endOffset=t.startOffset),this.currentCharacterToken.type){case Et.CHARACTER:{this.handler.onCharacter(this.currentCharacterToken);break}case Et.NULL_CHARACTER:{this.handler.onNullCharacter(this.currentCharacterToken);break}case Et.WHITESPACE_CHARACTER:{this.handler.onWhitespaceCharacter(this.currentCharacterToken);break}}this.currentCharacterToken=null}}_emitEOFToken(){const t=this.getCurrentLocation(0);t&&(t.endLine=t.startLine,t.endCol=t.startCol,t.endOffset=t.startOffset),this._emitCurrentCharacterToken(t),this.handler.onEof({type:Et.EOF,location:t}),this.active=!1}_appendCharToCurrentCharacterToken(t,n){if(this.currentCharacterToken)if(this.currentCharacterToken.type===t){this.currentCharacterToken.chars+=n;return}else this.currentLocation=this.getCurrentLocation(0),this._emitCurrentCharacterToken(this.currentLocation),this.preprocessor.dropParsedChunk();this._createCharacterToken(t,n)}_emitCodePoint(t){const n=YE(t)?Et.WHITESPACE_CHARACTER:t===M.NULL?Et.NULL_CHARACTER:Et.CHARACTER;this._appendCharToCurrentCharacterToken(n,String.fromCodePoint(t))}_emitChars(t){this._appendCharToCurrentCharacterToken(Et.CHARACTER,t)}_startCharacterReference(){this.returnState=this.state,this.state=L.CHARACTER_REFERENCE,this.entityStartPos=this.preprocessor.pos,this.entityDecoder.startEntity(this._isCharacterReferenceInAttribute()?ni.Attribute:ni.Legacy)}_isCharacterReferenceInAttribute(){return this.returnState===L.ATTRIBUTE_VALUE_DOUBLE_QUOTED||this.returnState===L.ATTRIBUTE_VALUE_SINGLE_QUOTED||this.returnState===L.ATTRIBUTE_VALUE_UNQUOTED}_flushCodePointConsumedAsCharacterReference(t){this._isCharacterReferenceInAttribute()?this.currentAttr.value+=String.fromCodePoint(t):this._emitCodePoint(t)}_callState(t){switch(this.state){case L.DATA:{this._stateData(t);break}case L.RCDATA:{this._stateRcdata(t);break}case L.RAWTEXT:{this._stateRawtext(t);break}case L.SCRIPT_DATA:{this._stateScriptData(t);break}case L.PLAINTEXT:{this._statePlaintext(t);break}case L.TAG_OPEN:{this._stateTagOpen(t);break}case L.END_TAG_OPEN:{this._stateEndTagOpen(t);break}case L.TAG_NAME:{this._stateTagName(t);break}case L.RCDATA_LESS_THAN_SIGN:{this._stateRcdataLessThanSign(t);break}case L.RCDATA_END_TAG_OPEN:{this._stateRcdataEndTagOpen(t);break}case L.RCDATA_END_TAG_NAME:{this._stateRcdataEndTagName(t);break}case L.RAWTEXT_LESS_THAN_SIGN:{this._stateRawtextLessThanSign(t);break}case L.RAWTEXT_END_TAG_OPEN:{this._stateRawtextEndTagOpen(t);break}case L.RAWTEXT_END_TAG_NAME:{this._stateRawtextEndTagName(t);break}case L.SCRIPT_DATA_LESS_THAN_SIGN:{this._stateScriptDataLessThanSign(t);break}case L.SCRIPT_DATA_END_TAG_OPEN:{this._stateScriptDataEndTagOpen(t);break}case L.SCRIPT_DATA_END_TAG_NAME:{this._stateScriptDataEndTagName(t);break}case L.SCRIPT_DATA_ESCAPE_START:{this._stateScriptDataEscapeStart(t);break}case L.SCRIPT_DATA_ESCAPE_START_DASH:{this._stateScriptDataEscapeStartDash(t);break}case L.SCRIPT_DATA_ESCAPED:{this._stateScriptDataEscaped(t);break}case L.SCRIPT_DATA_ESCAPED_DASH:{this._stateScriptDataEscapedDash(t);break}case L.SCRIPT_DATA_ESCAPED_DASH_DASH:{this._stateScriptDataEscapedDashDash(t);break}case L.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN:{this._stateScriptDataEscapedLessThanSign(t);break}case L.SCRIPT_DATA_ESCAPED_END_TAG_OPEN:{this._stateScriptDataEscapedEndTagOpen(t);break}case L.SCRIPT_DATA_ESCAPED_END_TAG_NAME:{this._stateScriptDataEscapedEndTagName(t);break}case L.SCRIPT_DATA_DOUBLE_ESCAPE_START:{this._stateScriptDataDoubleEscapeStart(t);break}case L.SCRIPT_DATA_DOUBLE_ESCAPED:{this._stateScriptDataDoubleEscaped(t);break}case L.SCRIPT_DATA_DOUBLE_ESCAPED_DASH:{this._stateScriptDataDoubleEscapedDash(t);break}case L.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH:{this._stateScriptDataDoubleEscapedDashDash(t);break}case L.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN:{this._stateScriptDataDoubleEscapedLessThanSign(t);break}case L.SCRIPT_DATA_DOUBLE_ESCAPE_END:{this._stateScriptDataDoubleEscapeEnd(t);break}case L.BEFORE_ATTRIBUTE_NAME:{this._stateBeforeAttributeName(t);break}case L.ATTRIBUTE_NAME:{this._stateAttributeName(t);break}case L.AFTER_ATTRIBUTE_NAME:{this._stateAfterAttributeName(t);break}case L.BEFORE_ATTRIBUTE_VALUE:{this._stateBeforeAttributeValue(t);break}case L.ATTRIBUTE_VALUE_DOUBLE_QUOTED:{this._stateAttributeValueDoubleQuoted(t);break}case L.ATTRIBUTE_VALUE_SINGLE_QUOTED:{this._stateAttributeValueSingleQuoted(t);break}case L.ATTRIBUTE_VALUE_UNQUOTED:{this._stateAttributeValueUnquoted(t);break}case L.AFTER_ATTRIBUTE_VALUE_QUOTED:{this._stateAfterAttributeValueQuoted(t);break}case L.SELF_CLOSING_START_TAG:{this._stateSelfClosingStartTag(t);break}case L.BOGUS_COMMENT:{this._stateBogusComment(t);break}case L.MARKUP_DECLARATION_OPEN:{this._stateMarkupDeclarationOpen(t);break}case L.COMMENT_START:{this._stateCommentStart(t);break}case L.COMMENT_START_DASH:{this._stateCommentStartDash(t);break}case L.COMMENT:{this._stateComment(t);break}case L.COMMENT_LESS_THAN_SIGN:{this._stateCommentLessThanSign(t);break}case L.COMMENT_LESS_THAN_SIGN_BANG:{this._stateCommentLessThanSignBang(t);break}case L.COMMENT_LESS_THAN_SIGN_BANG_DASH:{this._stateCommentLessThanSignBangDash(t);break}case L.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH:{this._stateCommentLessThanSignBangDashDash(t);break}case L.COMMENT_END_DASH:{this._stateCommentEndDash(t);break}case L.COMMENT_END:{this._stateCommentEnd(t);break}case L.COMMENT_END_BANG:{this._stateCommentEndBang(t);break}case L.DOCTYPE:{this._stateDoctype(t);break}case L.BEFORE_DOCTYPE_NAME:{this._stateBeforeDoctypeName(t);break}case L.DOCTYPE_NAME:{this._stateDoctypeName(t);break}case L.AFTER_DOCTYPE_NAME:{this._stateAfterDoctypeName(t);break}case L.AFTER_DOCTYPE_PUBLIC_KEYWORD:{this._stateAfterDoctypePublicKeyword(t);break}case L.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER:{this._stateBeforeDoctypePublicIdentifier(t);break}case L.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED:{this._stateDoctypePublicIdentifierDoubleQuoted(t);break}case L.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED:{this._stateDoctypePublicIdentifierSingleQuoted(t);break}case L.AFTER_DOCTYPE_PUBLIC_IDENTIFIER:{this._stateAfterDoctypePublicIdentifier(t);break}case L.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS:{this._stateBetweenDoctypePublicAndSystemIdentifiers(t);break}case L.AFTER_DOCTYPE_SYSTEM_KEYWORD:{this._stateAfterDoctypeSystemKeyword(t);break}case L.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER:{this._stateBeforeDoctypeSystemIdentifier(t);break}case L.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED:{this._stateDoctypeSystemIdentifierDoubleQuoted(t);break}case L.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED:{this._stateDoctypeSystemIdentifierSingleQuoted(t);break}case L.AFTER_DOCTYPE_SYSTEM_IDENTIFIER:{this._stateAfterDoctypeSystemIdentifier(t);break}case L.BOGUS_DOCTYPE:{this._stateBogusDoctype(t);break}case L.CDATA_SECTION:{this._stateCdataSection(t);break}case L.CDATA_SECTION_BRACKET:{this._stateCdataSectionBracket(t);break}case L.CDATA_SECTION_END:{this._stateCdataSectionEnd(t);break}case L.CHARACTER_REFERENCE:{this._stateCharacterReference();break}case L.AMBIGUOUS_AMPERSAND:{this._stateAmbiguousAmpersand(t);break}default:throw new Error("Unknown state")}}_stateData(t){switch(t){case M.LESS_THAN_SIGN:{this.state=L.TAG_OPEN;break}case M.AMPERSAND:{this._startCharacterReference();break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this._emitCodePoint(t);break}case M.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateRcdata(t){switch(t){case M.AMPERSAND:{this._startCharacterReference();break}case M.LESS_THAN_SIGN:{this.state=L.RCDATA_LESS_THAN_SIGN;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this._emitChars(nn);break}case M.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateRawtext(t){switch(t){case M.LESS_THAN_SIGN:{this.state=L.RAWTEXT_LESS_THAN_SIGN;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this._emitChars(nn);break}case M.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateScriptData(t){switch(t){case M.LESS_THAN_SIGN:{this.state=L.SCRIPT_DATA_LESS_THAN_SIGN;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this._emitChars(nn);break}case M.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_statePlaintext(t){switch(t){case M.NULL:{this._err(ie.unexpectedNullCharacter),this._emitChars(nn);break}case M.EOF:{this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateTagOpen(t){if(Yi(t))this._createStartTagToken(),this.state=L.TAG_NAME,this._stateTagName(t);else switch(t){case M.EXCLAMATION_MARK:{this.state=L.MARKUP_DECLARATION_OPEN;break}case M.SOLIDUS:{this.state=L.END_TAG_OPEN;break}case M.QUESTION_MARK:{this._err(ie.unexpectedQuestionMarkInsteadOfTagName),this._createCommentToken(1),this.state=L.BOGUS_COMMENT,this._stateBogusComment(t);break}case M.EOF:{this._err(ie.eofBeforeTagName),this._emitChars("<"),this._emitEOFToken();break}default:this._err(ie.invalidFirstCharacterOfTagName),this._emitChars("<"),this.state=L.DATA,this._stateData(t)}}_stateEndTagOpen(t){if(Yi(t))this._createEndTagToken(),this.state=L.TAG_NAME,this._stateTagName(t);else switch(t){case M.GREATER_THAN_SIGN:{this._err(ie.missingEndTagName),this.state=L.DATA;break}case M.EOF:{this._err(ie.eofBeforeTagName),this._emitChars("</"),this._emitEOFToken();break}default:this._err(ie.invalidFirstCharacterOfTagName),this._createCommentToken(2),this.state=L.BOGUS_COMMENT,this._stateBogusComment(t)}}_stateTagName(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:{this.state=L.BEFORE_ATTRIBUTE_NAME;break}case M.SOLIDUS:{this.state=L.SELF_CLOSING_START_TAG;break}case M.GREATER_THAN_SIGN:{this.state=L.DATA,this.emitCurrentTagToken();break}case M.NULL:{this._err(ie.unexpectedNullCharacter),n.tagName+=nn;break}case M.EOF:{this._err(ie.eofInTag),this._emitEOFToken();break}default:n.tagName+=String.fromCodePoint(Zu(t)?W0(t):t)}}_stateRcdataLessThanSign(t){t===M.SOLIDUS?this.state=L.RCDATA_END_TAG_OPEN:(this._emitChars("<"),this.state=L.RCDATA,this._stateRcdata(t))}_stateRcdataEndTagOpen(t){Yi(t)?(this.state=L.RCDATA_END_TAG_NAME,this._stateRcdataEndTagName(t)):(this._emitChars("</"),this.state=L.RCDATA,this._stateRcdata(t))}handleSpecialEndTag(t){if(!this.preprocessor.startsWith(this.lastStartTagName,!1))return!this._ensureHibernation();this._createEndTagToken();const n=this.currentToken;switch(n.tagName=this.lastStartTagName,this.preprocessor.peek(this.lastStartTagName.length)){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:return this._advanceBy(this.lastStartTagName.length),this.state=L.BEFORE_ATTRIBUTE_NAME,!1;case M.SOLIDUS:return this._advanceBy(this.lastStartTagName.length),this.state=L.SELF_CLOSING_START_TAG,!1;case M.GREATER_THAN_SIGN:return this._advanceBy(this.lastStartTagName.length),this.emitCurrentTagToken(),this.state=L.DATA,!1;default:return!this._ensureHibernation()}}_stateRcdataEndTagName(t){this.handleSpecialEndTag(t)&&(this._emitChars("</"),this.state=L.RCDATA,this._stateRcdata(t))}_stateRawtextLessThanSign(t){t===M.SOLIDUS?this.state=L.RAWTEXT_END_TAG_OPEN:(this._emitChars("<"),this.state=L.RAWTEXT,this._stateRawtext(t))}_stateRawtextEndTagOpen(t){Yi(t)?(this.state=L.RAWTEXT_END_TAG_NAME,this._stateRawtextEndTagName(t)):(this._emitChars("</"),this.state=L.RAWTEXT,this._stateRawtext(t))}_stateRawtextEndTagName(t){this.handleSpecialEndTag(t)&&(this._emitChars("</"),this.state=L.RAWTEXT,this._stateRawtext(t))}_stateScriptDataLessThanSign(t){switch(t){case M.SOLIDUS:{this.state=L.SCRIPT_DATA_END_TAG_OPEN;break}case M.EXCLAMATION_MARK:{this.state=L.SCRIPT_DATA_ESCAPE_START,this._emitChars("<!");break}default:this._emitChars("<"),this.state=L.SCRIPT_DATA,this._stateScriptData(t)}}_stateScriptDataEndTagOpen(t){Yi(t)?(this.state=L.SCRIPT_DATA_END_TAG_NAME,this._stateScriptDataEndTagName(t)):(this._emitChars("</"),this.state=L.SCRIPT_DATA,this._stateScriptData(t))}_stateScriptDataEndTagName(t){this.handleSpecialEndTag(t)&&(this._emitChars("</"),this.state=L.SCRIPT_DATA,this._stateScriptData(t))}_stateScriptDataEscapeStart(t){t===M.HYPHEN_MINUS?(this.state=L.SCRIPT_DATA_ESCAPE_START_DASH,this._emitChars("-")):(this.state=L.SCRIPT_DATA,this._stateScriptData(t))}_stateScriptDataEscapeStartDash(t){t===M.HYPHEN_MINUS?(this.state=L.SCRIPT_DATA_ESCAPED_DASH_DASH,this._emitChars("-")):(this.state=L.SCRIPT_DATA,this._stateScriptData(t))}_stateScriptDataEscaped(t){switch(t){case M.HYPHEN_MINUS:{this.state=L.SCRIPT_DATA_ESCAPED_DASH,this._emitChars("-");break}case M.LESS_THAN_SIGN:{this.state=L.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this._emitChars(nn);break}case M.EOF:{this._err(ie.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateScriptDataEscapedDash(t){switch(t){case M.HYPHEN_MINUS:{this.state=L.SCRIPT_DATA_ESCAPED_DASH_DASH,this._emitChars("-");break}case M.LESS_THAN_SIGN:{this.state=L.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this.state=L.SCRIPT_DATA_ESCAPED,this._emitChars(nn);break}case M.EOF:{this._err(ie.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this.state=L.SCRIPT_DATA_ESCAPED,this._emitCodePoint(t)}}_stateScriptDataEscapedDashDash(t){switch(t){case M.HYPHEN_MINUS:{this._emitChars("-");break}case M.LESS_THAN_SIGN:{this.state=L.SCRIPT_DATA_ESCAPED_LESS_THAN_SIGN;break}case M.GREATER_THAN_SIGN:{this.state=L.SCRIPT_DATA,this._emitChars(">");break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this.state=L.SCRIPT_DATA_ESCAPED,this._emitChars(nn);break}case M.EOF:{this._err(ie.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this.state=L.SCRIPT_DATA_ESCAPED,this._emitCodePoint(t)}}_stateScriptDataEscapedLessThanSign(t){t===M.SOLIDUS?this.state=L.SCRIPT_DATA_ESCAPED_END_TAG_OPEN:Yi(t)?(this._emitChars("<"),this.state=L.SCRIPT_DATA_DOUBLE_ESCAPE_START,this._stateScriptDataDoubleEscapeStart(t)):(this._emitChars("<"),this.state=L.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(t))}_stateScriptDataEscapedEndTagOpen(t){Yi(t)?(this.state=L.SCRIPT_DATA_ESCAPED_END_TAG_NAME,this._stateScriptDataEscapedEndTagName(t)):(this._emitChars("</"),this.state=L.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(t))}_stateScriptDataEscapedEndTagName(t){this.handleSpecialEndTag(t)&&(this._emitChars("</"),this.state=L.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(t))}_stateScriptDataDoubleEscapeStart(t){if(this.preprocessor.startsWith(br.SCRIPT,!1)&&Ib(this.preprocessor.peek(br.SCRIPT.length))){this._emitCodePoint(t);for(let n=0;n<br.SCRIPT.length;n++)this._emitCodePoint(this._consume());this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED}else this._ensureHibernation()||(this.state=L.SCRIPT_DATA_ESCAPED,this._stateScriptDataEscaped(t))}_stateScriptDataDoubleEscaped(t){switch(t){case M.HYPHEN_MINUS:{this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED_DASH,this._emitChars("-");break}case M.LESS_THAN_SIGN:{this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN,this._emitChars("<");break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this._emitChars(nn);break}case M.EOF:{this._err(ie.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateScriptDataDoubleEscapedDash(t){switch(t){case M.HYPHEN_MINUS:{this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED_DASH_DASH,this._emitChars("-");break}case M.LESS_THAN_SIGN:{this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN,this._emitChars("<");break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitChars(nn);break}case M.EOF:{this._err(ie.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitCodePoint(t)}}_stateScriptDataDoubleEscapedDashDash(t){switch(t){case M.HYPHEN_MINUS:{this._emitChars("-");break}case M.LESS_THAN_SIGN:{this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED_LESS_THAN_SIGN,this._emitChars("<");break}case M.GREATER_THAN_SIGN:{this.state=L.SCRIPT_DATA,this._emitChars(">");break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitChars(nn);break}case M.EOF:{this._err(ie.eofInScriptHtmlCommentLikeText),this._emitEOFToken();break}default:this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED,this._emitCodePoint(t)}}_stateScriptDataDoubleEscapedLessThanSign(t){t===M.SOLIDUS?(this.state=L.SCRIPT_DATA_DOUBLE_ESCAPE_END,this._emitChars("/")):(this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED,this._stateScriptDataDoubleEscaped(t))}_stateScriptDataDoubleEscapeEnd(t){if(this.preprocessor.startsWith(br.SCRIPT,!1)&&Ib(this.preprocessor.peek(br.SCRIPT.length))){this._emitCodePoint(t);for(let n=0;n<br.SCRIPT.length;n++)this._emitCodePoint(this._consume());this.state=L.SCRIPT_DATA_ESCAPED}else this._ensureHibernation()||(this.state=L.SCRIPT_DATA_DOUBLE_ESCAPED,this._stateScriptDataDoubleEscaped(t))}_stateBeforeAttributeName(t){switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:break;case M.SOLIDUS:case M.GREATER_THAN_SIGN:case M.EOF:{this.state=L.AFTER_ATTRIBUTE_NAME,this._stateAfterAttributeName(t);break}case M.EQUALS_SIGN:{this._err(ie.unexpectedEqualsSignBeforeAttributeName),this._createAttr("="),this.state=L.ATTRIBUTE_NAME;break}default:this._createAttr(""),this.state=L.ATTRIBUTE_NAME,this._stateAttributeName(t)}}_stateAttributeName(t){switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:case M.SOLIDUS:case M.GREATER_THAN_SIGN:case M.EOF:{this._leaveAttrName(),this.state=L.AFTER_ATTRIBUTE_NAME,this._stateAfterAttributeName(t);break}case M.EQUALS_SIGN:{this._leaveAttrName(),this.state=L.BEFORE_ATTRIBUTE_VALUE;break}case M.QUOTATION_MARK:case M.APOSTROPHE:case M.LESS_THAN_SIGN:{this._err(ie.unexpectedCharacterInAttributeName),this.currentAttr.name+=String.fromCodePoint(t);break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this.currentAttr.name+=nn;break}default:this.currentAttr.name+=String.fromCodePoint(Zu(t)?W0(t):t)}}_stateAfterAttributeName(t){switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:break;case M.SOLIDUS:{this.state=L.SELF_CLOSING_START_TAG;break}case M.EQUALS_SIGN:{this.state=L.BEFORE_ATTRIBUTE_VALUE;break}case M.GREATER_THAN_SIGN:{this.state=L.DATA,this.emitCurrentTagToken();break}case M.EOF:{this._err(ie.eofInTag),this._emitEOFToken();break}default:this._createAttr(""),this.state=L.ATTRIBUTE_NAME,this._stateAttributeName(t)}}_stateBeforeAttributeValue(t){switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:break;case M.QUOTATION_MARK:{this.state=L.ATTRIBUTE_VALUE_DOUBLE_QUOTED;break}case M.APOSTROPHE:{this.state=L.ATTRIBUTE_VALUE_SINGLE_QUOTED;break}case M.GREATER_THAN_SIGN:{this._err(ie.missingAttributeValue),this.state=L.DATA,this.emitCurrentTagToken();break}default:this.state=L.ATTRIBUTE_VALUE_UNQUOTED,this._stateAttributeValueUnquoted(t)}}_stateAttributeValueDoubleQuoted(t){switch(t){case M.QUOTATION_MARK:{this.state=L.AFTER_ATTRIBUTE_VALUE_QUOTED;break}case M.AMPERSAND:{this._startCharacterReference();break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this.currentAttr.value+=nn;break}case M.EOF:{this._err(ie.eofInTag),this._emitEOFToken();break}default:this.currentAttr.value+=String.fromCodePoint(t)}}_stateAttributeValueSingleQuoted(t){switch(t){case M.APOSTROPHE:{this.state=L.AFTER_ATTRIBUTE_VALUE_QUOTED;break}case M.AMPERSAND:{this._startCharacterReference();break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this.currentAttr.value+=nn;break}case M.EOF:{this._err(ie.eofInTag),this._emitEOFToken();break}default:this.currentAttr.value+=String.fromCodePoint(t)}}_stateAttributeValueUnquoted(t){switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:{this._leaveAttrValue(),this.state=L.BEFORE_ATTRIBUTE_NAME;break}case M.AMPERSAND:{this._startCharacterReference();break}case M.GREATER_THAN_SIGN:{this._leaveAttrValue(),this.state=L.DATA,this.emitCurrentTagToken();break}case M.NULL:{this._err(ie.unexpectedNullCharacter),this.currentAttr.value+=nn;break}case M.QUOTATION_MARK:case M.APOSTROPHE:case M.LESS_THAN_SIGN:case M.EQUALS_SIGN:case M.GRAVE_ACCENT:{this._err(ie.unexpectedCharacterInUnquotedAttributeValue),this.currentAttr.value+=String.fromCodePoint(t);break}case M.EOF:{this._err(ie.eofInTag),this._emitEOFToken();break}default:this.currentAttr.value+=String.fromCodePoint(t)}}_stateAfterAttributeValueQuoted(t){switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:{this._leaveAttrValue(),this.state=L.BEFORE_ATTRIBUTE_NAME;break}case M.SOLIDUS:{this._leaveAttrValue(),this.state=L.SELF_CLOSING_START_TAG;break}case M.GREATER_THAN_SIGN:{this._leaveAttrValue(),this.state=L.DATA,this.emitCurrentTagToken();break}case M.EOF:{this._err(ie.eofInTag),this._emitEOFToken();break}default:this._err(ie.missingWhitespaceBetweenAttributes),this.state=L.BEFORE_ATTRIBUTE_NAME,this._stateBeforeAttributeName(t)}}_stateSelfClosingStartTag(t){switch(t){case M.GREATER_THAN_SIGN:{const n=this.currentToken;n.selfClosing=!0,this.state=L.DATA,this.emitCurrentTagToken();break}case M.EOF:{this._err(ie.eofInTag),this._emitEOFToken();break}default:this._err(ie.unexpectedSolidusInTag),this.state=L.BEFORE_ATTRIBUTE_NAME,this._stateBeforeAttributeName(t)}}_stateBogusComment(t){const n=this.currentToken;switch(t){case M.GREATER_THAN_SIGN:{this.state=L.DATA,this.emitCurrentComment(n);break}case M.EOF:{this.emitCurrentComment(n),this._emitEOFToken();break}case M.NULL:{this._err(ie.unexpectedNullCharacter),n.data+=nn;break}default:n.data+=String.fromCodePoint(t)}}_stateMarkupDeclarationOpen(t){this._consumeSequenceIfMatch(br.DASH_DASH,!0)?(this._createCommentToken(br.DASH_DASH.length+1),this.state=L.COMMENT_START):this._consumeSequenceIfMatch(br.DOCTYPE,!1)?(this.currentLocation=this.getCurrentLocation(br.DOCTYPE.length+1),this.state=L.DOCTYPE):this._consumeSequenceIfMatch(br.CDATA_START,!0)?this.inForeignNode?this.state=L.CDATA_SECTION:(this._err(ie.cdataInHtmlContent),this._createCommentToken(br.CDATA_START.length+1),this.currentToken.data="[CDATA[",this.state=L.BOGUS_COMMENT):this._ensureHibernation()||(this._err(ie.incorrectlyOpenedComment),this._createCommentToken(2),this.state=L.BOGUS_COMMENT,this._stateBogusComment(t))}_stateCommentStart(t){switch(t){case M.HYPHEN_MINUS:{this.state=L.COMMENT_START_DASH;break}case M.GREATER_THAN_SIGN:{this._err(ie.abruptClosingOfEmptyComment),this.state=L.DATA;const n=this.currentToken;this.emitCurrentComment(n);break}default:this.state=L.COMMENT,this._stateComment(t)}}_stateCommentStartDash(t){const n=this.currentToken;switch(t){case M.HYPHEN_MINUS:{this.state=L.COMMENT_END;break}case M.GREATER_THAN_SIGN:{this._err(ie.abruptClosingOfEmptyComment),this.state=L.DATA,this.emitCurrentComment(n);break}case M.EOF:{this._err(ie.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+="-",this.state=L.COMMENT,this._stateComment(t)}}_stateComment(t){const n=this.currentToken;switch(t){case M.HYPHEN_MINUS:{this.state=L.COMMENT_END_DASH;break}case M.LESS_THAN_SIGN:{n.data+="<",this.state=L.COMMENT_LESS_THAN_SIGN;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),n.data+=nn;break}case M.EOF:{this._err(ie.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+=String.fromCodePoint(t)}}_stateCommentLessThanSign(t){const n=this.currentToken;switch(t){case M.EXCLAMATION_MARK:{n.data+="!",this.state=L.COMMENT_LESS_THAN_SIGN_BANG;break}case M.LESS_THAN_SIGN:{n.data+="<";break}default:this.state=L.COMMENT,this._stateComment(t)}}_stateCommentLessThanSignBang(t){t===M.HYPHEN_MINUS?this.state=L.COMMENT_LESS_THAN_SIGN_BANG_DASH:(this.state=L.COMMENT,this._stateComment(t))}_stateCommentLessThanSignBangDash(t){t===M.HYPHEN_MINUS?this.state=L.COMMENT_LESS_THAN_SIGN_BANG_DASH_DASH:(this.state=L.COMMENT_END_DASH,this._stateCommentEndDash(t))}_stateCommentLessThanSignBangDashDash(t){t!==M.GREATER_THAN_SIGN&&t!==M.EOF&&this._err(ie.nestedComment),this.state=L.COMMENT_END,this._stateCommentEnd(t)}_stateCommentEndDash(t){const n=this.currentToken;switch(t){case M.HYPHEN_MINUS:{this.state=L.COMMENT_END;break}case M.EOF:{this._err(ie.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+="-",this.state=L.COMMENT,this._stateComment(t)}}_stateCommentEnd(t){const n=this.currentToken;switch(t){case M.GREATER_THAN_SIGN:{this.state=L.DATA,this.emitCurrentComment(n);break}case M.EXCLAMATION_MARK:{this.state=L.COMMENT_END_BANG;break}case M.HYPHEN_MINUS:{n.data+="-";break}case M.EOF:{this._err(ie.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+="--",this.state=L.COMMENT,this._stateComment(t)}}_stateCommentEndBang(t){const n=this.currentToken;switch(t){case M.HYPHEN_MINUS:{n.data+="--!",this.state=L.COMMENT_END_DASH;break}case M.GREATER_THAN_SIGN:{this._err(ie.incorrectlyClosedComment),this.state=L.DATA,this.emitCurrentComment(n);break}case M.EOF:{this._err(ie.eofInComment),this.emitCurrentComment(n),this._emitEOFToken();break}default:n.data+="--!",this.state=L.COMMENT,this._stateComment(t)}}_stateDoctype(t){switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:{this.state=L.BEFORE_DOCTYPE_NAME;break}case M.GREATER_THAN_SIGN:{this.state=L.BEFORE_DOCTYPE_NAME,this._stateBeforeDoctypeName(t);break}case M.EOF:{this._err(ie.eofInDoctype),this._createDoctypeToken(null);const n=this.currentToken;n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(ie.missingWhitespaceBeforeDoctypeName),this.state=L.BEFORE_DOCTYPE_NAME,this._stateBeforeDoctypeName(t)}}_stateBeforeDoctypeName(t){if(Zu(t))this._createDoctypeToken(String.fromCharCode(W0(t))),this.state=L.DOCTYPE_NAME;else switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:break;case M.NULL:{this._err(ie.unexpectedNullCharacter),this._createDoctypeToken(nn),this.state=L.DOCTYPE_NAME;break}case M.GREATER_THAN_SIGN:{this._err(ie.missingDoctypeName),this._createDoctypeToken(null);const n=this.currentToken;n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=L.DATA;break}case M.EOF:{this._err(ie.eofInDoctype),this._createDoctypeToken(null);const n=this.currentToken;n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._createDoctypeToken(String.fromCodePoint(t)),this.state=L.DOCTYPE_NAME}}_stateDoctypeName(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:{this.state=L.AFTER_DOCTYPE_NAME;break}case M.GREATER_THAN_SIGN:{this.state=L.DATA,this.emitCurrentDoctype(n);break}case M.NULL:{this._err(ie.unexpectedNullCharacter),n.name+=nn;break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.name+=String.fromCodePoint(Zu(t)?W0(t):t)}}_stateAfterDoctypeName(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:break;case M.GREATER_THAN_SIGN:{this.state=L.DATA,this.emitCurrentDoctype(n);break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._consumeSequenceIfMatch(br.PUBLIC,!1)?this.state=L.AFTER_DOCTYPE_PUBLIC_KEYWORD:this._consumeSequenceIfMatch(br.SYSTEM,!1)?this.state=L.AFTER_DOCTYPE_SYSTEM_KEYWORD:this._ensureHibernation()||(this._err(ie.invalidCharacterSequenceAfterDoctypeName),n.forceQuirks=!0,this.state=L.BOGUS_DOCTYPE,this._stateBogusDoctype(t))}}_stateAfterDoctypePublicKeyword(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:{this.state=L.BEFORE_DOCTYPE_PUBLIC_IDENTIFIER;break}case M.QUOTATION_MARK:{this._err(ie.missingWhitespaceAfterDoctypePublicKeyword),n.publicId="",this.state=L.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED;break}case M.APOSTROPHE:{this._err(ie.missingWhitespaceAfterDoctypePublicKeyword),n.publicId="",this.state=L.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED;break}case M.GREATER_THAN_SIGN:{this._err(ie.missingDoctypePublicIdentifier),n.forceQuirks=!0,this.state=L.DATA,this.emitCurrentDoctype(n);break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(ie.missingQuoteBeforeDoctypePublicIdentifier),n.forceQuirks=!0,this.state=L.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateBeforeDoctypePublicIdentifier(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:break;case M.QUOTATION_MARK:{n.publicId="",this.state=L.DOCTYPE_PUBLIC_IDENTIFIER_DOUBLE_QUOTED;break}case M.APOSTROPHE:{n.publicId="",this.state=L.DOCTYPE_PUBLIC_IDENTIFIER_SINGLE_QUOTED;break}case M.GREATER_THAN_SIGN:{this._err(ie.missingDoctypePublicIdentifier),n.forceQuirks=!0,this.state=L.DATA,this.emitCurrentDoctype(n);break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(ie.missingQuoteBeforeDoctypePublicIdentifier),n.forceQuirks=!0,this.state=L.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateDoctypePublicIdentifierDoubleQuoted(t){const n=this.currentToken;switch(t){case M.QUOTATION_MARK:{this.state=L.AFTER_DOCTYPE_PUBLIC_IDENTIFIER;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),n.publicId+=nn;break}case M.GREATER_THAN_SIGN:{this._err(ie.abruptDoctypePublicIdentifier),n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=L.DATA;break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.publicId+=String.fromCodePoint(t)}}_stateDoctypePublicIdentifierSingleQuoted(t){const n=this.currentToken;switch(t){case M.APOSTROPHE:{this.state=L.AFTER_DOCTYPE_PUBLIC_IDENTIFIER;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),n.publicId+=nn;break}case M.GREATER_THAN_SIGN:{this._err(ie.abruptDoctypePublicIdentifier),n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=L.DATA;break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.publicId+=String.fromCodePoint(t)}}_stateAfterDoctypePublicIdentifier(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:{this.state=L.BETWEEN_DOCTYPE_PUBLIC_AND_SYSTEM_IDENTIFIERS;break}case M.GREATER_THAN_SIGN:{this.state=L.DATA,this.emitCurrentDoctype(n);break}case M.QUOTATION_MARK:{this._err(ie.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers),n.systemId="",this.state=L.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break}case M.APOSTROPHE:{this._err(ie.missingWhitespaceBetweenDoctypePublicAndSystemIdentifiers),n.systemId="",this.state=L.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(ie.missingQuoteBeforeDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=L.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateBetweenDoctypePublicAndSystemIdentifiers(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:break;case M.GREATER_THAN_SIGN:{this.emitCurrentDoctype(n),this.state=L.DATA;break}case M.QUOTATION_MARK:{n.systemId="",this.state=L.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break}case M.APOSTROPHE:{n.systemId="",this.state=L.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(ie.missingQuoteBeforeDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=L.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateAfterDoctypeSystemKeyword(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:{this.state=L.BEFORE_DOCTYPE_SYSTEM_IDENTIFIER;break}case M.QUOTATION_MARK:{this._err(ie.missingWhitespaceAfterDoctypeSystemKeyword),n.systemId="",this.state=L.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break}case M.APOSTROPHE:{this._err(ie.missingWhitespaceAfterDoctypeSystemKeyword),n.systemId="",this.state=L.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break}case M.GREATER_THAN_SIGN:{this._err(ie.missingDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=L.DATA,this.emitCurrentDoctype(n);break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(ie.missingQuoteBeforeDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=L.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateBeforeDoctypeSystemIdentifier(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:break;case M.QUOTATION_MARK:{n.systemId="",this.state=L.DOCTYPE_SYSTEM_IDENTIFIER_DOUBLE_QUOTED;break}case M.APOSTROPHE:{n.systemId="",this.state=L.DOCTYPE_SYSTEM_IDENTIFIER_SINGLE_QUOTED;break}case M.GREATER_THAN_SIGN:{this._err(ie.missingDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=L.DATA,this.emitCurrentDoctype(n);break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(ie.missingQuoteBeforeDoctypeSystemIdentifier),n.forceQuirks=!0,this.state=L.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateDoctypeSystemIdentifierDoubleQuoted(t){const n=this.currentToken;switch(t){case M.QUOTATION_MARK:{this.state=L.AFTER_DOCTYPE_SYSTEM_IDENTIFIER;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),n.systemId+=nn;break}case M.GREATER_THAN_SIGN:{this._err(ie.abruptDoctypeSystemIdentifier),n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=L.DATA;break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.systemId+=String.fromCodePoint(t)}}_stateDoctypeSystemIdentifierSingleQuoted(t){const n=this.currentToken;switch(t){case M.APOSTROPHE:{this.state=L.AFTER_DOCTYPE_SYSTEM_IDENTIFIER;break}case M.NULL:{this._err(ie.unexpectedNullCharacter),n.systemId+=nn;break}case M.GREATER_THAN_SIGN:{this._err(ie.abruptDoctypeSystemIdentifier),n.forceQuirks=!0,this.emitCurrentDoctype(n),this.state=L.DATA;break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:n.systemId+=String.fromCodePoint(t)}}_stateAfterDoctypeSystemIdentifier(t){const n=this.currentToken;switch(t){case M.SPACE:case M.LINE_FEED:case M.TABULATION:case M.FORM_FEED:break;case M.GREATER_THAN_SIGN:{this.emitCurrentDoctype(n),this.state=L.DATA;break}case M.EOF:{this._err(ie.eofInDoctype),n.forceQuirks=!0,this.emitCurrentDoctype(n),this._emitEOFToken();break}default:this._err(ie.unexpectedCharacterAfterDoctypeSystemIdentifier),this.state=L.BOGUS_DOCTYPE,this._stateBogusDoctype(t)}}_stateBogusDoctype(t){const n=this.currentToken;switch(t){case M.GREATER_THAN_SIGN:{this.emitCurrentDoctype(n),this.state=L.DATA;break}case M.NULL:{this._err(ie.unexpectedNullCharacter);break}case M.EOF:{this.emitCurrentDoctype(n),this._emitEOFToken();break}}}_stateCdataSection(t){switch(t){case M.RIGHT_SQUARE_BRACKET:{this.state=L.CDATA_SECTION_BRACKET;break}case M.EOF:{this._err(ie.eofInCdata),this._emitEOFToken();break}default:this._emitCodePoint(t)}}_stateCdataSectionBracket(t){t===M.RIGHT_SQUARE_BRACKET?this.state=L.CDATA_SECTION_END:(this._emitChars("]"),this.state=L.CDATA_SECTION,this._stateCdataSection(t))}_stateCdataSectionEnd(t){switch(t){case M.GREATER_THAN_SIGN:{this.state=L.DATA;break}case M.RIGHT_SQUARE_BRACKET:{this._emitChars("]");break}default:this._emitChars("]]"),this.state=L.CDATA_SECTION,this._stateCdataSection(t)}}_stateCharacterReference(){let t=this.entityDecoder.write(this.preprocessor.html,this.preprocessor.pos);if(t<0)if(this.preprocessor.lastChunkWritten)t=this.entityDecoder.end();else{this.active=!1,this.preprocessor.pos=this.preprocessor.html.length-1,this.consumedAfterSnapshot=0,this.preprocessor.endOfChunkHit=!0;return}t===0?(this.preprocessor.pos=this.entityStartPos,this._flushCodePointConsumedAsCharacterReference(M.AMPERSAND),this.state=!this._isCharacterReferenceInAttribute()&&Db(this.preprocessor.peek(1))?L.AMBIGUOUS_AMPERSAND:this.returnState):this.state=this.returnState}_stateAmbiguousAmpersand(t){Db(t)?this._flushCodePointConsumedAsCharacterReference(t):(t===M.SEMICOLON&&this._err(ie.unknownNamedCharacterReference),this.state=this.returnState,this._callState(t))}}const GE=new Set([b.DD,b.DT,b.LI,b.OPTGROUP,b.OPTION,b.P,b.RB,b.RP,b.RT,b.RTC]),Lb=new Set([...GE,b.CAPTION,b.COLGROUP,b.TBODY,b.TD,b.TFOOT,b.TH,b.THEAD,b.TR]),wc=new Set([b.APPLET,b.CAPTION,b.HTML,b.MARQUEE,b.OBJECT,b.TABLE,b.TD,b.TEMPLATE,b.TH]),Gk=new Set([...wc,b.OL,b.UL]),Vk=new Set([...wc,b.BUTTON]),Bb=new Set([b.ANNOTATION_XML,b.MI,b.MN,b.MO,b.MS,b.MTEXT]),Pb=new Set([b.DESC,b.FOREIGN_OBJECT,b.TITLE]),Kk=new Set([b.TR,b.TEMPLATE,b.HTML]),jk=new Set([b.TBODY,b.TFOOT,b.THEAD,b.TEMPLATE,b.HTML]),Xk=new Set([b.TABLE,b.TEMPLATE,b.HTML]),$k=new Set([b.TD,b.TH]);class Wk{get currentTmplContentOrNode(){return this._isInTemplate()?this.treeAdapter.getTemplateContent(this.current):this.current}constructor(t,n,a){this.treeAdapter=n,this.handler=a,this.items=[],this.tagIDs=[],this.stackTop=-1,this.tmplCount=0,this.currentTagId=b.UNKNOWN,this.current=t}_indexOf(t){return this.items.lastIndexOf(t,this.stackTop)}_isInTemplate(){return this.currentTagId===b.TEMPLATE&&this.treeAdapter.getNamespaceURI(this.current)===_e.HTML}_updateCurrentElement(){this.current=this.items[this.stackTop],this.currentTagId=this.tagIDs[this.stackTop]}push(t,n){this.stackTop++,this.items[this.stackTop]=t,this.current=t,this.tagIDs[this.stackTop]=n,this.currentTagId=n,this._isInTemplate()&&this.tmplCount++,this.handler.onItemPush(t,n,!0)}pop(){const t=this.current;this.tmplCount>0&&this._isInTemplate()&&this.tmplCount--,this.stackTop--,this._updateCurrentElement(),this.handler.onItemPop(t,!0)}replace(t,n){const a=this._indexOf(t);this.items[a]=n,a===this.stackTop&&(this.current=n)}insertAfter(t,n,a){const l=this._indexOf(t)+1;this.items.splice(l,0,n),this.tagIDs.splice(l,0,a),this.stackTop++,l===this.stackTop&&this._updateCurrentElement(),this.current&&this.currentTagId!==void 0&&this.handler.onItemPush(this.current,this.currentTagId,l===this.stackTop)}popUntilTagNamePopped(t){let n=this.stackTop+1;do n=this.tagIDs.lastIndexOf(t,n-1);while(n>0&&this.treeAdapter.getNamespaceURI(this.items[n])!==_e.HTML);this.shortenToLength(Math.max(n,0))}shortenToLength(t){for(;this.stackTop>=t;){const n=this.current;this.tmplCount>0&&this._isInTemplate()&&(this.tmplCount-=1),this.stackTop--,this._updateCurrentElement(),this.handler.onItemPop(n,this.stackTop<t)}}popUntilElementPopped(t){const n=this._indexOf(t);this.shortenToLength(Math.max(n,0))}popUntilPopped(t,n){const a=this._indexOfTagNames(t,n);this.shortenToLength(Math.max(a,0))}popUntilNumberedHeaderPopped(){this.popUntilPopped(D1,_e.HTML)}popUntilTableCellPopped(){this.popUntilPopped($k,_e.HTML)}popAllUpToHtmlElement(){this.tmplCount=0,this.shortenToLength(1)}_indexOfTagNames(t,n){for(let a=this.stackTop;a>=0;a--)if(t.has(this.tagIDs[a])&&this.treeAdapter.getNamespaceURI(this.items[a])===n)return a;return-1}clearBackTo(t,n){const a=this._indexOfTagNames(t,n);this.shortenToLength(a+1)}clearBackToTableContext(){this.clearBackTo(Xk,_e.HTML)}clearBackToTableBodyContext(){this.clearBackTo(jk,_e.HTML)}clearBackToTableRowContext(){this.clearBackTo(Kk,_e.HTML)}remove(t){const n=this._indexOf(t);n>=0&&(n===this.stackTop?this.pop():(this.items.splice(n,1),this.tagIDs.splice(n,1),this.stackTop--,this._updateCurrentElement(),this.handler.onItemPop(t,!1)))}tryPeekProperlyNestedBodyElement(){return this.stackTop>=1&&this.tagIDs[1]===b.BODY?this.items[1]:null}contains(t){return this._indexOf(t)>-1}getCommonAncestor(t){const n=this._indexOf(t)-1;return n>=0?this.items[n]:null}isRootHtmlElementCurrent(){return this.stackTop===0&&this.tagIDs[0]===b.HTML}hasInDynamicScope(t,n){for(let a=this.stackTop;a>=0;a--){const l=this.tagIDs[a];switch(this.treeAdapter.getNamespaceURI(this.items[a])){case _e.HTML:{if(l===t)return!0;if(n.has(l))return!1;break}case _e.SVG:{if(Pb.has(l))return!1;break}case _e.MATHML:{if(Bb.has(l))return!1;break}}}return!0}hasInScope(t){return this.hasInDynamicScope(t,wc)}hasInListItemScope(t){return this.hasInDynamicScope(t,Gk)}hasInButtonScope(t){return this.hasInDynamicScope(t,Vk)}hasNumberedHeaderInScope(){for(let t=this.stackTop;t>=0;t--){const n=this.tagIDs[t];switch(this.treeAdapter.getNamespaceURI(this.items[t])){case _e.HTML:{if(D1.has(n))return!0;if(wc.has(n))return!1;break}case _e.SVG:{if(Pb.has(n))return!1;break}case _e.MATHML:{if(Bb.has(n))return!1;break}}}return!0}hasInTableScope(t){for(let n=this.stackTop;n>=0;n--)if(this.treeAdapter.getNamespaceURI(this.items[n])===_e.HTML)switch(this.tagIDs[n]){case t:return!0;case b.TABLE:case b.HTML:return!1}return!0}hasTableBodyContextInTableScope(){for(let t=this.stackTop;t>=0;t--)if(this.treeAdapter.getNamespaceURI(this.items[t])===_e.HTML)switch(this.tagIDs[t]){case b.TBODY:case b.THEAD:case b.TFOOT:return!0;case b.TABLE:case b.HTML:return!1}return!0}hasInSelectScope(t){for(let n=this.stackTop;n>=0;n--)if(this.treeAdapter.getNamespaceURI(this.items[n])===_e.HTML)switch(this.tagIDs[n]){case t:return!0;case b.OPTION:case b.OPTGROUP:break;default:return!1}return!0}generateImpliedEndTags(){for(;this.currentTagId!==void 0&&GE.has(this.currentTagId);)this.pop()}generateImpliedEndTagsThoroughly(){for(;this.currentTagId!==void 0&&Lb.has(this.currentTagId);)this.pop()}generateImpliedEndTagsWithExclusion(t){for(;this.currentTagId!==void 0&&this.currentTagId!==t&&Lb.has(this.currentTagId);)this.pop()}}const Bh=3;var Aa;(function(e){e[e.Marker=0]="Marker",e[e.Element=1]="Element"})(Aa||(Aa={}));const Ub={type:Aa.Marker};class Qk{constructor(t){this.treeAdapter=t,this.entries=[],this.bookmark=null}_getNoahArkConditionCandidates(t,n){const a=[],l=n.length,s=this.treeAdapter.getTagName(t),o=this.treeAdapter.getNamespaceURI(t);for(let d=0;d<this.entries.length;d++){const f=this.entries[d];if(f.type===Aa.Marker)break;const{element:h}=f;if(this.treeAdapter.getTagName(h)===s&&this.treeAdapter.getNamespaceURI(h)===o){const p=this.treeAdapter.getAttrList(h);p.length===l&&a.push({idx:d,attrs:p})}}return a}_ensureNoahArkCondition(t){if(this.entries.length<Bh)return;const n=this.treeAdapter.getAttrList(t),a=this._getNoahArkConditionCandidates(t,n);if(a.length<Bh)return;const l=new Map(n.map(o=>[o.name,o.value]));let s=0;for(let o=0;o<a.length;o++){const d=a[o];d.attrs.every(f=>l.get(f.name)===f.value)&&(s+=1,s>=Bh&&this.entries.splice(d.idx,1))}}insertMarker(){this.entries.unshift(Ub)}pushElement(t,n){this._ensureNoahArkCondition(t),this.entries.unshift({type:Aa.Element,element:t,token:n})}insertElementAfterBookmark(t,n){const a=this.entries.indexOf(this.bookmark);this.entries.splice(a,0,{type:Aa.Element,element:t,token:n})}removeEntry(t){const n=this.entries.indexOf(t);n!==-1&&this.entries.splice(n,1)}clearToLastMarker(){const t=this.entries.indexOf(Ub);t===-1?this.entries.length=0:this.entries.splice(0,t+1)}getElementEntryInScopeWithTagName(t){const n=this.entries.find(a=>a.type===Aa.Marker||this.treeAdapter.getTagName(a.element)===t);return n&&n.type===Aa.Element?n:null}getElementEntry(t){return this.entries.find(n=>n.type===Aa.Element&&n.element===t)}}const Gi={createDocument(){return{nodeName:"#document",mode:Wr.NO_QUIRKS,childNodes:[]}},createDocumentFragment(){return{nodeName:"#document-fragment",childNodes:[]}},createElement(e,t,n){return{nodeName:e,tagName:e,attrs:n,namespaceURI:t,childNodes:[],parentNode:null}},createCommentNode(e){return{nodeName:"#comment",data:e,parentNode:null}},createTextNode(e){return{nodeName:"#text",value:e,parentNode:null}},appendChild(e,t){e.childNodes.push(t),t.parentNode=e},insertBefore(e,t,n){const a=e.childNodes.indexOf(n);e.childNodes.splice(a,0,t),t.parentNode=e},setTemplateContent(e,t){e.content=t},getTemplateContent(e){return e.content},setDocumentType(e,t,n,a){const l=e.childNodes.find(s=>s.nodeName==="#documentType");if(l)l.name=t,l.publicId=n,l.systemId=a;else{const s={nodeName:"#documentType",name:t,publicId:n,systemId:a,parentNode:null};Gi.appendChild(e,s)}},setDocumentMode(e,t){e.mode=t},getDocumentMode(e){return e.mode},detachNode(e){if(e.parentNode){const t=e.parentNode.childNodes.indexOf(e);e.parentNode.childNodes.splice(t,1),e.parentNode=null}},insertText(e,t){if(e.childNodes.length>0){const n=e.childNodes[e.childNodes.length-1];if(Gi.isTextNode(n)){n.value+=t;return}}Gi.appendChild(e,Gi.createTextNode(t))},insertTextBefore(e,t,n){const a=e.childNodes[e.childNodes.indexOf(n)-1];a&&Gi.isTextNode(a)?a.value+=t:Gi.insertBefore(e,Gi.createTextNode(t),n)},adoptAttributes(e,t){const n=new Set(e.attrs.map(a=>a.name));for(let a=0;a<t.length;a++)n.has(t[a].name)||e.attrs.push(t[a])},getFirstChild(e){return e.childNodes[0]},getChildNodes(e){return e.childNodes},getParentNode(e){return e.parentNode},getAttrList(e){return e.attrs},getTagName(e){return e.tagName},getNamespaceURI(e){return e.namespaceURI},getTextNodeContent(e){return e.value},getCommentNodeContent(e){return e.data},getDocumentTypeNodeName(e){return e.name},getDocumentTypeNodePublicId(e){return e.publicId},getDocumentTypeNodeSystemId(e){return e.systemId},isTextNode(e){return e.nodeName==="#text"},isCommentNode(e){return e.nodeName==="#comment"},isDocumentTypeNode(e){return e.nodeName==="#documentType"},isElementNode(e){return Object.prototype.hasOwnProperty.call(e,"tagName")},setNodeSourceCodeLocation(e,t){e.sourceCodeLocation=t},getNodeSourceCodeLocation(e){return e.sourceCodeLocation},updateNodeSourceCodeLocation(e,t){e.sourceCodeLocation={...e.sourceCodeLocation,...t}}},VE="html",Zk="about:legacy-compat",Jk="http://www.ibm.com/data/dtd/v11/ibmxhtml1-transitional.dtd",KE=["+//silmaril//dtd html pro v0r11 19970101//","-//as//dtd html 3.0 aswedit + extensions//","-//advasoft ltd//dtd html 3.0 aswedit + extensions//","-//ietf//dtd html 2.0 level 1//","-//ietf//dtd html 2.0 level 2//","-//ietf//dtd html 2.0 strict level 1//","-//ietf//dtd html 2.0 strict level 2//","-//ietf//dtd html 2.0 strict//","-//ietf//dtd html 2.0//","-//ietf//dtd html 2.1e//","-//ietf//dtd html 3.0//","-//ietf//dtd html 3.2 final//","-//ietf//dtd html 3.2//","-//ietf//dtd html 3//","-//ietf//dtd html level 0//","-//ietf//dtd html level 1//","-//ietf//dtd html level 2//","-//ietf//dtd html level 3//","-//ietf//dtd html strict level 0//","-//ietf//dtd html strict level 1//","-//ietf//dtd html strict level 2//","-//ietf//dtd html strict level 3//","-//ietf//dtd html strict//","-//ietf//dtd html//","-//metrius//dtd metrius presentational//","-//microsoft//dtd internet explorer 2.0 html strict//","-//microsoft//dtd internet explorer 2.0 html//","-//microsoft//dtd internet explorer 2.0 tables//","-//microsoft//dtd internet explorer 3.0 html strict//","-//microsoft//dtd internet explorer 3.0 html//","-//microsoft//dtd internet explorer 3.0 tables//","-//netscape comm. corp.//dtd html//","-//netscape comm. corp.//dtd strict html//","-//o'reilly and associates//dtd html 2.0//","-//o'reilly and associates//dtd html extended 1.0//","-//o'reilly and associates//dtd html extended relaxed 1.0//","-//sq//dtd html 2.0 hotmetal + extensions//","-//softquad software//dtd hotmetal pro 6.0::19990601::extensions to html 4.0//","-//softquad//dtd hotmetal pro 4.0::19971010::extensions to html 4.0//","-//spyglass//dtd html 2.0 extended//","-//sun microsystems corp.//dtd hotjava html//","-//sun microsystems corp.//dtd hotjava strict html//","-//w3c//dtd html 3 1995-03-24//","-//w3c//dtd html 3.2 draft//","-//w3c//dtd html 3.2 final//","-//w3c//dtd html 3.2//","-//w3c//dtd html 3.2s draft//","-//w3c//dtd html 4.0 frameset//","-//w3c//dtd html 4.0 transitional//","-//w3c//dtd html experimental 19960712//","-//w3c//dtd html experimental 970421//","-//w3c//dtd w3 html//","-//w3o//dtd w3 html 3.0//","-//webtechs//dtd mozilla html 2.0//","-//webtechs//dtd mozilla html//"],eN=[...KE,"-//w3c//dtd html 4.01 frameset//","-//w3c//dtd html 4.01 transitional//"],tN=new Set(["-//w3o//dtd w3 html strict 3.0//en//","-/w3c/dtd html 4.0 transitional/en","html"]),jE=["-//w3c//dtd xhtml 1.0 frameset//","-//w3c//dtd xhtml 1.0 transitional//"],nN=[...jE,"-//w3c//dtd html 4.01 frameset//","-//w3c//dtd html 4.01 transitional//"];function zb(e,t){return t.some(n=>e.startsWith(n))}function rN(e){return e.name===VE&&e.publicId===null&&(e.systemId===null||e.systemId===Zk)}function aN(e){if(e.name!==VE)return Wr.QUIRKS;const{systemId:t}=e;if(t&&t.toLowerCase()===Jk)return Wr.QUIRKS;let{publicId:n}=e;if(n!==null){if(n=n.toLowerCase(),tN.has(n))return Wr.QUIRKS;let a=t===null?eN:KE;if(zb(n,a))return Wr.QUIRKS;if(a=t===null?jE:nN,zb(n,a))return Wr.LIMITED_QUIRKS}return Wr.NO_QUIRKS}const Hb={TEXT_HTML:"text/html",APPLICATION_XML:"application/xhtml+xml"},iN="definitionurl",lN="definitionURL",sN=new Map(["attributeName","attributeType","baseFrequency","baseProfile","calcMode","clipPathUnits","diffuseConstant","edgeMode","filterUnits","glyphRef","gradientTransform","gradientUnits","kernelMatrix","kernelUnitLength","keyPoints","keySplines","keyTimes","lengthAdjust","limitingConeAngle","markerHeight","markerUnits","markerWidth","maskContentUnits","maskUnits","numOctaves","pathLength","patternContentUnits","patternTransform","patternUnits","pointsAtX","pointsAtY","pointsAtZ","preserveAlpha","preserveAspectRatio","primitiveUnits","refX","refY","repeatCount","repeatDur","requiredExtensions","requiredFeatures","specularConstant","specularExponent","spreadMethod","startOffset","stdDeviation","stitchTiles","surfaceScale","systemLanguage","tableValues","targetX","targetY","textLength","viewBox","viewTarget","xChannelSelector","yChannelSelector","zoomAndPan"].map(e=>[e.toLowerCase(),e])),uN=new Map([["xlink:actuate",{prefix:"xlink",name:"actuate",namespace:_e.XLINK}],["xlink:arcrole",{prefix:"xlink",name:"arcrole",namespace:_e.XLINK}],["xlink:href",{prefix:"xlink",name:"href",namespace:_e.XLINK}],["xlink:role",{prefix:"xlink",name:"role",namespace:_e.XLINK}],["xlink:show",{prefix:"xlink",name:"show",namespace:_e.XLINK}],["xlink:title",{prefix:"xlink",name:"title",namespace:_e.XLINK}],["xlink:type",{prefix:"xlink",name:"type",namespace:_e.XLINK}],["xml:lang",{prefix:"xml",name:"lang",namespace:_e.XML}],["xml:space",{prefix:"xml",name:"space",namespace:_e.XML}],["xmlns",{prefix:"",name:"xmlns",namespace:_e.XMLNS}],["xmlns:xlink",{prefix:"xmlns",name:"xlink",namespace:_e.XMLNS}]]),oN=new Map(["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","textPath"].map(e=>[e.toLowerCase(),e])),cN=new Set([b.B,b.BIG,b.BLOCKQUOTE,b.BODY,b.BR,b.CENTER,b.CODE,b.DD,b.DIV,b.DL,b.DT,b.EM,b.EMBED,b.H1,b.H2,b.H3,b.H4,b.H5,b.H6,b.HEAD,b.HR,b.I,b.IMG,b.LI,b.LISTING,b.MENU,b.META,b.NOBR,b.OL,b.P,b.PRE,b.RUBY,b.S,b.SMALL,b.SPAN,b.STRONG,b.STRIKE,b.SUB,b.SUP,b.TABLE,b.TT,b.U,b.UL,b.VAR]);function dN(e){const t=e.tagID;return t===b.FONT&&e.attrs.some(({name:a})=>a===Ol.COLOR||a===Ol.SIZE||a===Ol.FACE)||cN.has(t)}function XE(e){for(let t=0;t<e.attrs.length;t++)if(e.attrs[t].name===iN){e.attrs[t].name=lN;break}}function $E(e){for(let t=0;t<e.attrs.length;t++){const n=sN.get(e.attrs[t].name);n!=null&&(e.attrs[t].name=n)}}function km(e){for(let t=0;t<e.attrs.length;t++){const n=uN.get(e.attrs[t].name);n&&(e.attrs[t].prefix=n.prefix,e.attrs[t].name=n.name,e.attrs[t].namespace=n.namespace)}}function fN(e){const t=oN.get(e.tagName);t!=null&&(e.tagName=t,e.tagID=zs(e.tagName))}function hN(e,t){return t===_e.MATHML&&(e===b.MI||e===b.MO||e===b.MN||e===b.MS||e===b.MTEXT)}function mN(e,t,n){if(t===_e.MATHML&&e===b.ANNOTATION_XML){for(let a=0;a<n.length;a++)if(n[a].name===Ol.ENCODING){const l=n[a].value.toLowerCase();return l===Hb.TEXT_HTML||l===Hb.APPLICATION_XML}}return t===_e.SVG&&(e===b.FOREIGN_OBJECT||e===b.DESC||e===b.TITLE)}function pN(e,t,n,a){return(!a||a===_e.HTML)&&mN(e,t,n)||(!a||a===_e.MATHML)&&hN(e,t)}const gN="hidden",bN=8,EN=3;var z;(function(e){e[e.INITIAL=0]="INITIAL",e[e.BEFORE_HTML=1]="BEFORE_HTML",e[e.BEFORE_HEAD=2]="BEFORE_HEAD",e[e.IN_HEAD=3]="IN_HEAD",e[e.IN_HEAD_NO_SCRIPT=4]="IN_HEAD_NO_SCRIPT",e[e.AFTER_HEAD=5]="AFTER_HEAD",e[e.IN_BODY=6]="IN_BODY",e[e.TEXT=7]="TEXT",e[e.IN_TABLE=8]="IN_TABLE",e[e.IN_TABLE_TEXT=9]="IN_TABLE_TEXT",e[e.IN_CAPTION=10]="IN_CAPTION",e[e.IN_COLUMN_GROUP=11]="IN_COLUMN_GROUP",e[e.IN_TABLE_BODY=12]="IN_TABLE_BODY",e[e.IN_ROW=13]="IN_ROW",e[e.IN_CELL=14]="IN_CELL",e[e.IN_SELECT=15]="IN_SELECT",e[e.IN_SELECT_IN_TABLE=16]="IN_SELECT_IN_TABLE",e[e.IN_TEMPLATE=17]="IN_TEMPLATE",e[e.AFTER_BODY=18]="AFTER_BODY",e[e.IN_FRAMESET=19]="IN_FRAMESET",e[e.AFTER_FRAMESET=20]="AFTER_FRAMESET",e[e.AFTER_AFTER_BODY=21]="AFTER_AFTER_BODY",e[e.AFTER_AFTER_FRAMESET=22]="AFTER_AFTER_FRAMESET"})(z||(z={}));const yN={startLine:-1,startCol:-1,startOffset:-1,endLine:-1,endCol:-1,endOffset:-1},WE=new Set([b.TABLE,b.TBODY,b.TFOOT,b.THEAD,b.TR]),Fb={scriptingEnabled:!0,sourceCodeLocationInfo:!1,treeAdapter:Gi,onParseError:null};let qb=class{constructor(t,n,a=null,l=null){this.fragmentContext=a,this.scriptHandler=l,this.currentToken=null,this.stopped=!1,this.insertionMode=z.INITIAL,this.originalInsertionMode=z.INITIAL,this.headElement=null,this.formElement=null,this.currentNotInHTML=!1,this.tmplInsertionModeStack=[],this.pendingCharacterTokens=[],this.hasNonWhitespacePendingCharacterToken=!1,this.framesetOk=!0,this.skipNextNewLine=!1,this.fosterParentingEnabled=!1,this.options={...Fb,...t},this.treeAdapter=this.options.treeAdapter,this.onParseError=this.options.onParseError,this.onParseError&&(this.options.sourceCodeLocationInfo=!0),this.document=n??this.treeAdapter.createDocument(),this.tokenizer=new Yk(this.options,this),this.activeFormattingElements=new Qk(this.treeAdapter),this.fragmentContextID=a?zs(this.treeAdapter.getTagName(a)):b.UNKNOWN,this._setContextModes(a??this.document,this.fragmentContextID),this.openElements=new Wk(this.document,this.treeAdapter,this)}static parse(t,n){const a=new this(n);return a.tokenizer.write(t,!0),a.document}static getFragmentParser(t,n){const a={...Fb,...n};t??(t=a.treeAdapter.createElement(W.TEMPLATE,_e.HTML,[]));const l=a.treeAdapter.createElement("documentmock",_e.HTML,[]),s=new this(a,l,t);return s.fragmentContextID===b.TEMPLATE&&s.tmplInsertionModeStack.unshift(z.IN_TEMPLATE),s._initTokenizerForFragmentParsing(),s._insertFakeRootElement(),s._resetInsertionMode(),s._findFormInFragmentContext(),s}getFragment(){const t=this.treeAdapter.getFirstChild(this.document),n=this.treeAdapter.createDocumentFragment();return this._adoptNodes(t,n),n}_err(t,n,a){var l;if(!this.onParseError)return;const s=(l=t.location)!==null&&l!==void 0?l:yN,o={code:n,startLine:s.startLine,startCol:s.startCol,startOffset:s.startOffset,endLine:a?s.startLine:s.endLine,endCol:a?s.startCol:s.endCol,endOffset:a?s.startOffset:s.endOffset};this.onParseError(o)}onItemPush(t,n,a){var l,s;(s=(l=this.treeAdapter).onItemPush)===null||s===void 0||s.call(l,t),a&&this.openElements.stackTop>0&&this._setContextModes(t,n)}onItemPop(t,n){var a,l;if(this.options.sourceCodeLocationInfo&&this._setEndLocation(t,this.currentToken),(l=(a=this.treeAdapter).onItemPop)===null||l===void 0||l.call(a,t,this.openElements.current),n){let s,o;this.openElements.stackTop===0&&this.fragmentContext?(s=this.fragmentContext,o=this.fragmentContextID):{current:s,currentTagId:o}=this.openElements,this._setContextModes(s,o)}}_setContextModes(t,n){const a=t===this.document||t&&this.treeAdapter.getNamespaceURI(t)===_e.HTML;this.currentNotInHTML=!a,this.tokenizer.inForeignNode=!a&&t!==void 0&&n!==void 0&&!this._isIntegrationPoint(n,t)}_switchToTextParsing(t,n){this._insertElement(t,_e.HTML),this.tokenizer.state=n,this.originalInsertionMode=this.insertionMode,this.insertionMode=z.TEXT}switchToPlaintextParsing(){this.insertionMode=z.TEXT,this.originalInsertionMode=z.IN_BODY,this.tokenizer.state=yn.PLAINTEXT}_getAdjustedCurrentElement(){return this.openElements.stackTop===0&&this.fragmentContext?this.fragmentContext:this.openElements.current}_findFormInFragmentContext(){let t=this.fragmentContext;for(;t;){if(this.treeAdapter.getTagName(t)===W.FORM){this.formElement=t;break}t=this.treeAdapter.getParentNode(t)}}_initTokenizerForFragmentParsing(){if(!(!this.fragmentContext||this.treeAdapter.getNamespaceURI(this.fragmentContext)!==_e.HTML))switch(this.fragmentContextID){case b.TITLE:case b.TEXTAREA:{this.tokenizer.state=yn.RCDATA;break}case b.STYLE:case b.XMP:case b.IFRAME:case b.NOEMBED:case b.NOFRAMES:case b.NOSCRIPT:{this.tokenizer.state=yn.RAWTEXT;break}case b.SCRIPT:{this.tokenizer.state=yn.SCRIPT_DATA;break}case b.PLAINTEXT:{this.tokenizer.state=yn.PLAINTEXT;break}}}_setDocumentType(t){const n=t.name||"",a=t.publicId||"",l=t.systemId||"";if(this.treeAdapter.setDocumentType(this.document,n,a,l),t.location){const o=this.treeAdapter.getChildNodes(this.document).find(d=>this.treeAdapter.isDocumentTypeNode(d));o&&this.treeAdapter.setNodeSourceCodeLocation(o,t.location)}}_attachElementToTree(t,n){if(this.options.sourceCodeLocationInfo){const a=n&&{...n,startTag:n};this.treeAdapter.setNodeSourceCodeLocation(t,a)}if(this._shouldFosterParentOnInsertion())this._fosterParentElement(t);else{const a=this.openElements.currentTmplContentOrNode;this.treeAdapter.appendChild(a??this.document,t)}}_appendElement(t,n){const a=this.treeAdapter.createElement(t.tagName,n,t.attrs);this._attachElementToTree(a,t.location)}_insertElement(t,n){const a=this.treeAdapter.createElement(t.tagName,n,t.attrs);this._attachElementToTree(a,t.location),this.openElements.push(a,t.tagID)}_insertFakeElement(t,n){const a=this.treeAdapter.createElement(t,_e.HTML,[]);this._attachElementToTree(a,null),this.openElements.push(a,n)}_insertTemplate(t){const n=this.treeAdapter.createElement(t.tagName,_e.HTML,t.attrs),a=this.treeAdapter.createDocumentFragment();this.treeAdapter.setTemplateContent(n,a),this._attachElementToTree(n,t.location),this.openElements.push(n,t.tagID),this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(a,null)}_insertFakeRootElement(){const t=this.treeAdapter.createElement(W.HTML,_e.HTML,[]);this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(t,null),this.treeAdapter.appendChild(this.openElements.current,t),this.openElements.push(t,b.HTML)}_appendCommentNode(t,n){const a=this.treeAdapter.createCommentNode(t.data);this.treeAdapter.appendChild(n,a),this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(a,t.location)}_insertCharacters(t){let n,a;if(this._shouldFosterParentOnInsertion()?({parent:n,beforeElement:a}=this._findFosterParentingLocation(),a?this.treeAdapter.insertTextBefore(n,t.chars,a):this.treeAdapter.insertText(n,t.chars)):(n=this.openElements.currentTmplContentOrNode,this.treeAdapter.insertText(n,t.chars)),!t.location)return;const l=this.treeAdapter.getChildNodes(n),s=a?l.lastIndexOf(a):l.length,o=l[s-1];if(this.treeAdapter.getNodeSourceCodeLocation(o)){const{endLine:f,endCol:h,endOffset:p}=t.location;this.treeAdapter.updateNodeSourceCodeLocation(o,{endLine:f,endCol:h,endOffset:p})}else this.options.sourceCodeLocationInfo&&this.treeAdapter.setNodeSourceCodeLocation(o,t.location)}_adoptNodes(t,n){for(let a=this.treeAdapter.getFirstChild(t);a;a=this.treeAdapter.getFirstChild(t))this.treeAdapter.detachNode(a),this.treeAdapter.appendChild(n,a)}_setEndLocation(t,n){if(this.treeAdapter.getNodeSourceCodeLocation(t)&&n.location){const a=n.location,l=this.treeAdapter.getTagName(t),s=n.type===Et.END_TAG&&l===n.tagName?{endTag:{...a},endLine:a.endLine,endCol:a.endCol,endOffset:a.endOffset}:{endLine:a.startLine,endCol:a.startCol,endOffset:a.startOffset};this.treeAdapter.updateNodeSourceCodeLocation(t,s)}}shouldProcessStartTagTokenInForeignContent(t){if(!this.currentNotInHTML)return!1;let n,a;return this.openElements.stackTop===0&&this.fragmentContext?(n=this.fragmentContext,a=this.fragmentContextID):{current:n,currentTagId:a}=this.openElements,t.tagID===b.SVG&&this.treeAdapter.getTagName(n)===W.ANNOTATION_XML&&this.treeAdapter.getNamespaceURI(n)===_e.MATHML?!1:this.tokenizer.inForeignNode||(t.tagID===b.MGLYPH||t.tagID===b.MALIGNMARK)&&a!==void 0&&!this._isIntegrationPoint(a,n,_e.HTML)}_processToken(t){switch(t.type){case Et.CHARACTER:{this.onCharacter(t);break}case Et.NULL_CHARACTER:{this.onNullCharacter(t);break}case Et.COMMENT:{this.onComment(t);break}case Et.DOCTYPE:{this.onDoctype(t);break}case Et.START_TAG:{this._processStartTag(t);break}case Et.END_TAG:{this.onEndTag(t);break}case Et.EOF:{this.onEof(t);break}case Et.WHITESPACE_CHARACTER:{this.onWhitespaceCharacter(t);break}}}_isIntegrationPoint(t,n,a){const l=this.treeAdapter.getNamespaceURI(n),s=this.treeAdapter.getAttrList(n);return pN(t,l,s,a)}_reconstructActiveFormattingElements(){const t=this.activeFormattingElements.entries.length;if(t){const n=this.activeFormattingElements.entries.findIndex(l=>l.type===Aa.Marker||this.openElements.contains(l.element)),a=n===-1?t-1:n-1;for(let l=a;l>=0;l--){const s=this.activeFormattingElements.entries[l];this._insertElement(s.token,this.treeAdapter.getNamespaceURI(s.element)),s.element=this.openElements.current}}}_closeTableCell(){this.openElements.generateImpliedEndTags(),this.openElements.popUntilTableCellPopped(),this.activeFormattingElements.clearToLastMarker(),this.insertionMode=z.IN_ROW}_closePElement(){this.openElements.generateImpliedEndTagsWithExclusion(b.P),this.openElements.popUntilTagNamePopped(b.P)}_resetInsertionMode(){for(let t=this.openElements.stackTop;t>=0;t--)switch(t===0&&this.fragmentContext?this.fragmentContextID:this.openElements.tagIDs[t]){case b.TR:{this.insertionMode=z.IN_ROW;return}case b.TBODY:case b.THEAD:case b.TFOOT:{this.insertionMode=z.IN_TABLE_BODY;return}case b.CAPTION:{this.insertionMode=z.IN_CAPTION;return}case b.COLGROUP:{this.insertionMode=z.IN_COLUMN_GROUP;return}case b.TABLE:{this.insertionMode=z.IN_TABLE;return}case b.BODY:{this.insertionMode=z.IN_BODY;return}case b.FRAMESET:{this.insertionMode=z.IN_FRAMESET;return}case b.SELECT:{this._resetInsertionModeForSelect(t);return}case b.TEMPLATE:{this.insertionMode=this.tmplInsertionModeStack[0];return}case b.HTML:{this.insertionMode=this.headElement?z.AFTER_HEAD:z.BEFORE_HEAD;return}case b.TD:case b.TH:{if(t>0){this.insertionMode=z.IN_CELL;return}break}case b.HEAD:{if(t>0){this.insertionMode=z.IN_HEAD;return}break}}this.insertionMode=z.IN_BODY}_resetInsertionModeForSelect(t){if(t>0)for(let n=t-1;n>0;n--){const a=this.openElements.tagIDs[n];if(a===b.TEMPLATE)break;if(a===b.TABLE){this.insertionMode=z.IN_SELECT_IN_TABLE;return}}this.insertionMode=z.IN_SELECT}_isElementCausesFosterParenting(t){return WE.has(t)}_shouldFosterParentOnInsertion(){return this.fosterParentingEnabled&&this.openElements.currentTagId!==void 0&&this._isElementCausesFosterParenting(this.openElements.currentTagId)}_findFosterParentingLocation(){for(let t=this.openElements.stackTop;t>=0;t--){const n=this.openElements.items[t];switch(this.openElements.tagIDs[t]){case b.TEMPLATE:{if(this.treeAdapter.getNamespaceURI(n)===_e.HTML)return{parent:this.treeAdapter.getTemplateContent(n),beforeElement:null};break}case b.TABLE:{const a=this.treeAdapter.getParentNode(n);return a?{parent:a,beforeElement:n}:{parent:this.openElements.items[t-1],beforeElement:null}}}}return{parent:this.openElements.items[0],beforeElement:null}}_fosterParentElement(t){const n=this._findFosterParentingLocation();n.beforeElement?this.treeAdapter.insertBefore(n.parent,t,n.beforeElement):this.treeAdapter.appendChild(n.parent,t)}_isSpecialElement(t,n){const a=this.treeAdapter.getNamespaceURI(t);return zk[a].has(n)}onCharacter(t){if(this.skipNextNewLine=!1,this.tokenizer.inForeignNode){$w(this,t);return}switch(this.insertionMode){case z.INITIAL:{$u(this,t);break}case z.BEFORE_HTML:{ro(this,t);break}case z.BEFORE_HEAD:{ao(this,t);break}case z.IN_HEAD:{io(this,t);break}case z.IN_HEAD_NO_SCRIPT:{lo(this,t);break}case z.AFTER_HEAD:{so(this,t);break}case z.IN_BODY:case z.IN_CAPTION:case z.IN_CELL:case z.IN_TEMPLATE:{ZE(this,t);break}case z.TEXT:case z.IN_SELECT:case z.IN_SELECT_IN_TABLE:{this._insertCharacters(t);break}case z.IN_TABLE:case z.IN_TABLE_BODY:case z.IN_ROW:{Ph(this,t);break}case z.IN_TABLE_TEXT:{a5(this,t);break}case z.IN_COLUMN_GROUP:{Cc(this,t);break}case z.AFTER_BODY:{Oc(this,t);break}case z.AFTER_AFTER_BODY:{vc(this,t);break}}}onNullCharacter(t){if(this.skipNextNewLine=!1,this.tokenizer.inForeignNode){Xw(this,t);return}switch(this.insertionMode){case z.INITIAL:{$u(this,t);break}case z.BEFORE_HTML:{ro(this,t);break}case z.BEFORE_HEAD:{ao(this,t);break}case z.IN_HEAD:{io(this,t);break}case z.IN_HEAD_NO_SCRIPT:{lo(this,t);break}case z.AFTER_HEAD:{so(this,t);break}case z.TEXT:{this._insertCharacters(t);break}case z.IN_TABLE:case z.IN_TABLE_BODY:case z.IN_ROW:{Ph(this,t);break}case z.IN_COLUMN_GROUP:{Cc(this,t);break}case z.AFTER_BODY:{Oc(this,t);break}case z.AFTER_AFTER_BODY:{vc(this,t);break}}}onComment(t){if(this.skipNextNewLine=!1,this.currentNotInHTML){I1(this,t);return}switch(this.insertionMode){case z.INITIAL:case z.BEFORE_HTML:case z.BEFORE_HEAD:case z.IN_HEAD:case z.IN_HEAD_NO_SCRIPT:case z.AFTER_HEAD:case z.IN_BODY:case z.IN_TABLE:case z.IN_CAPTION:case z.IN_COLUMN_GROUP:case z.IN_TABLE_BODY:case z.IN_ROW:case z.IN_CELL:case z.IN_SELECT:case z.IN_SELECT_IN_TABLE:case z.IN_TEMPLATE:case z.IN_FRAMESET:case z.AFTER_FRAMESET:{I1(this,t);break}case z.IN_TABLE_TEXT:{Wu(this,t);break}case z.AFTER_BODY:{kN(this,t);break}case z.AFTER_AFTER_BODY:case z.AFTER_AFTER_FRAMESET:{NN(this,t);break}}}onDoctype(t){switch(this.skipNextNewLine=!1,this.insertionMode){case z.INITIAL:{wN(this,t);break}case z.BEFORE_HEAD:case z.IN_HEAD:case z.IN_HEAD_NO_SCRIPT:case z.AFTER_HEAD:{this._err(t,ie.misplacedDoctype);break}case z.IN_TABLE_TEXT:{Wu(this,t);break}}}onStartTag(t){this.skipNextNewLine=!1,this.currentToken=t,this._processStartTag(t),t.selfClosing&&!t.ackSelfClosing&&this._err(t,ie.nonVoidHtmlElementStartTagWithTrailingSolidus)}_processStartTag(t){this.shouldProcessStartTagTokenInForeignContent(t)?Ww(this,t):this._startTagOutsideForeignContent(t)}_startTagOutsideForeignContent(t){switch(this.insertionMode){case z.INITIAL:{$u(this,t);break}case z.BEFORE_HTML:{CN(this,t);break}case z.BEFORE_HEAD:{RN(this,t);break}case z.IN_HEAD:{ma(this,t);break}case z.IN_HEAD_NO_SCRIPT:{IN(this,t);break}case z.AFTER_HEAD:{BN(this,t);break}case z.IN_BODY:{Qn(this,t);break}case z.IN_TABLE:{Rs(this,t);break}case z.IN_TABLE_TEXT:{Wu(this,t);break}case z.IN_CAPTION:{Mw(this,t);break}case z.IN_COLUMN_GROUP:{Cm(this,t);break}case z.IN_TABLE_BODY:{$c(this,t);break}case z.IN_ROW:{Wc(this,t);break}case z.IN_CELL:{Lw(this,t);break}case z.IN_SELECT:{s5(this,t);break}case z.IN_SELECT_IN_TABLE:{Pw(this,t);break}case z.IN_TEMPLATE:{zw(this,t);break}case z.AFTER_BODY:{Fw(this,t);break}case z.IN_FRAMESET:{qw(this,t);break}case z.AFTER_FRAMESET:{Gw(this,t);break}case z.AFTER_AFTER_BODY:{Kw(this,t);break}case z.AFTER_AFTER_FRAMESET:{jw(this,t);break}}}onEndTag(t){this.skipNextNewLine=!1,this.currentToken=t,this.currentNotInHTML?Qw(this,t):this._endTagOutsideForeignContent(t)}_endTagOutsideForeignContent(t){switch(this.insertionMode){case z.INITIAL:{$u(this,t);break}case z.BEFORE_HTML:{ON(this,t);break}case z.BEFORE_HEAD:{MN(this,t);break}case z.IN_HEAD:{DN(this,t);break}case z.IN_HEAD_NO_SCRIPT:{LN(this,t);break}case z.AFTER_HEAD:{PN(this,t);break}case z.IN_BODY:{Xc(this,t);break}case z.TEXT:{_w(this,t);break}case z.IN_TABLE:{go(this,t);break}case z.IN_TABLE_TEXT:{Wu(this,t);break}case z.IN_CAPTION:{Dw(this,t);break}case z.IN_COLUMN_GROUP:{Iw(this,t);break}case z.IN_TABLE_BODY:{L1(this,t);break}case z.IN_ROW:{l5(this,t);break}case z.IN_CELL:{Bw(this,t);break}case z.IN_SELECT:{u5(this,t);break}case z.IN_SELECT_IN_TABLE:{Uw(this,t);break}case z.IN_TEMPLATE:{Hw(this,t);break}case z.AFTER_BODY:{c5(this,t);break}case z.IN_FRAMESET:{Yw(this,t);break}case z.AFTER_FRAMESET:{Vw(this,t);break}case z.AFTER_AFTER_BODY:{vc(this,t);break}}}onEof(t){switch(this.insertionMode){case z.INITIAL:{$u(this,t);break}case z.BEFORE_HTML:{ro(this,t);break}case z.BEFORE_HEAD:{ao(this,t);break}case z.IN_HEAD:{io(this,t);break}case z.IN_HEAD_NO_SCRIPT:{lo(this,t);break}case z.AFTER_HEAD:{so(this,t);break}case z.IN_BODY:case z.IN_TABLE:case z.IN_CAPTION:case z.IN_COLUMN_GROUP:case z.IN_TABLE_BODY:case z.IN_ROW:case z.IN_CELL:case z.IN_SELECT:case z.IN_SELECT_IN_TABLE:{n5(this,t);break}case z.TEXT:{Sw(this,t);break}case z.IN_TABLE_TEXT:{Wu(this,t);break}case z.IN_TEMPLATE:{o5(this,t);break}case z.AFTER_BODY:case z.IN_FRAMESET:case z.AFTER_FRAMESET:case z.AFTER_AFTER_BODY:case z.AFTER_AFTER_FRAMESET:{wm(this,t);break}}}onWhitespaceCharacter(t){if(this.skipNextNewLine&&(this.skipNextNewLine=!1,t.chars.charCodeAt(0)===M.LINE_FEED)){if(t.chars.length===1)return;t.chars=t.chars.substr(1)}if(this.tokenizer.inForeignNode){this._insertCharacters(t);return}switch(this.insertionMode){case z.IN_HEAD:case z.IN_HEAD_NO_SCRIPT:case z.AFTER_HEAD:case z.TEXT:case z.IN_COLUMN_GROUP:case z.IN_SELECT:case z.IN_SELECT_IN_TABLE:case z.IN_FRAMESET:case z.AFTER_FRAMESET:{this._insertCharacters(t);break}case z.IN_BODY:case z.IN_CAPTION:case z.IN_CELL:case z.IN_TEMPLATE:case z.AFTER_BODY:case z.AFTER_AFTER_BODY:case z.AFTER_AFTER_FRAMESET:{QE(this,t);break}case z.IN_TABLE:case z.IN_TABLE_BODY:case z.IN_ROW:{Ph(this,t);break}case z.IN_TABLE_TEXT:{r5(this,t);break}}}};function vN(e,t){let n=e.activeFormattingElements.getElementEntryInScopeWithTagName(t.tagName);return n?e.openElements.contains(n.element)?e.openElements.hasInScope(t.tagID)||(n=null):(e.activeFormattingElements.removeEntry(n),n=null):t5(e,t),n}function TN(e,t){let n=null,a=e.openElements.stackTop;for(;a>=0;a--){const l=e.openElements.items[a];if(l===t.element)break;e._isSpecialElement(l,e.openElements.tagIDs[a])&&(n=l)}return n||(e.openElements.shortenToLength(Math.max(a,0)),e.activeFormattingElements.removeEntry(t)),n}function _N(e,t,n){let a=t,l=e.openElements.getCommonAncestor(t);for(let s=0,o=l;o!==n;s++,o=l){l=e.openElements.getCommonAncestor(o);const d=e.activeFormattingElements.getElementEntry(o),f=d&&s>=EN;!d||f?(f&&e.activeFormattingElements.removeEntry(d),e.openElements.remove(o)):(o=SN(e,d),a===t&&(e.activeFormattingElements.bookmark=d),e.treeAdapter.detachNode(a),e.treeAdapter.appendChild(o,a),a=o)}return a}function SN(e,t){const n=e.treeAdapter.getNamespaceURI(t.element),a=e.treeAdapter.createElement(t.token.tagName,n,t.token.attrs);return e.openElements.replace(t.element,a),t.element=a,a}function AN(e,t,n){const a=e.treeAdapter.getTagName(t),l=zs(a);if(e._isElementCausesFosterParenting(l))e._fosterParentElement(n);else{const s=e.treeAdapter.getNamespaceURI(t);l===b.TEMPLATE&&s===_e.HTML&&(t=e.treeAdapter.getTemplateContent(t)),e.treeAdapter.appendChild(t,n)}}function xN(e,t,n){const a=e.treeAdapter.getNamespaceURI(n.element),{token:l}=n,s=e.treeAdapter.createElement(l.tagName,a,l.attrs);e._adoptNodes(t,s),e.treeAdapter.appendChild(t,s),e.activeFormattingElements.insertElementAfterBookmark(s,l),e.activeFormattingElements.removeEntry(n),e.openElements.remove(n.element),e.openElements.insertAfter(t,s,l.tagID)}function Nm(e,t){for(let n=0;n<bN;n++){const a=vN(e,t);if(!a)break;const l=TN(e,a);if(!l)break;e.activeFormattingElements.bookmark=a;const s=_N(e,l,a.element),o=e.openElements.getCommonAncestor(a.element);e.treeAdapter.detachNode(s),o&&AN(e,o,s),xN(e,l,a)}}function I1(e,t){e._appendCommentNode(t,e.openElements.currentTmplContentOrNode)}function kN(e,t){e._appendCommentNode(t,e.openElements.items[0])}function NN(e,t){e._appendCommentNode(t,e.document)}function wm(e,t){if(e.stopped=!0,t.location){const n=e.fragmentContext?0:2;for(let a=e.openElements.stackTop;a>=n;a--)e._setEndLocation(e.openElements.items[a],t);if(!e.fragmentContext&&e.openElements.stackTop>=0){const a=e.openElements.items[0],l=e.treeAdapter.getNodeSourceCodeLocation(a);if(l&&!l.endTag&&(e._setEndLocation(a,t),e.openElements.stackTop>=1)){const s=e.openElements.items[1],o=e.treeAdapter.getNodeSourceCodeLocation(s);o&&!o.endTag&&e._setEndLocation(s,t)}}}}function wN(e,t){e._setDocumentType(t);const n=t.forceQuirks?Wr.QUIRKS:aN(t);rN(t)||e._err(t,ie.nonConformingDoctype),e.treeAdapter.setDocumentMode(e.document,n),e.insertionMode=z.BEFORE_HTML}function $u(e,t){e._err(t,ie.missingDoctype,!0),e.treeAdapter.setDocumentMode(e.document,Wr.QUIRKS),e.insertionMode=z.BEFORE_HTML,e._processToken(t)}function CN(e,t){t.tagID===b.HTML?(e._insertElement(t,_e.HTML),e.insertionMode=z.BEFORE_HEAD):ro(e,t)}function ON(e,t){const n=t.tagID;(n===b.HTML||n===b.HEAD||n===b.BODY||n===b.BR)&&ro(e,t)}function ro(e,t){e._insertFakeRootElement(),e.insertionMode=z.BEFORE_HEAD,e._processToken(t)}function RN(e,t){switch(t.tagID){case b.HTML:{Qn(e,t);break}case b.HEAD:{e._insertElement(t,_e.HTML),e.headElement=e.openElements.current,e.insertionMode=z.IN_HEAD;break}default:ao(e,t)}}function MN(e,t){const n=t.tagID;n===b.HEAD||n===b.BODY||n===b.HTML||n===b.BR?ao(e,t):e._err(t,ie.endTagWithoutMatchingOpenElement)}function ao(e,t){e._insertFakeElement(W.HEAD,b.HEAD),e.headElement=e.openElements.current,e.insertionMode=z.IN_HEAD,e._processToken(t)}function ma(e,t){switch(t.tagID){case b.HTML:{Qn(e,t);break}case b.BASE:case b.BASEFONT:case b.BGSOUND:case b.LINK:case b.META:{e._appendElement(t,_e.HTML),t.ackSelfClosing=!0;break}case b.TITLE:{e._switchToTextParsing(t,yn.RCDATA);break}case b.NOSCRIPT:{e.options.scriptingEnabled?e._switchToTextParsing(t,yn.RAWTEXT):(e._insertElement(t,_e.HTML),e.insertionMode=z.IN_HEAD_NO_SCRIPT);break}case b.NOFRAMES:case b.STYLE:{e._switchToTextParsing(t,yn.RAWTEXT);break}case b.SCRIPT:{e._switchToTextParsing(t,yn.SCRIPT_DATA);break}case b.TEMPLATE:{e._insertTemplate(t),e.activeFormattingElements.insertMarker(),e.framesetOk=!1,e.insertionMode=z.IN_TEMPLATE,e.tmplInsertionModeStack.unshift(z.IN_TEMPLATE);break}case b.HEAD:{e._err(t,ie.misplacedStartTagForHeadElement);break}default:io(e,t)}}function DN(e,t){switch(t.tagID){case b.HEAD:{e.openElements.pop(),e.insertionMode=z.AFTER_HEAD;break}case b.BODY:case b.BR:case b.HTML:{io(e,t);break}case b.TEMPLATE:{Il(e,t);break}default:e._err(t,ie.endTagWithoutMatchingOpenElement)}}function Il(e,t){e.openElements.tmplCount>0?(e.openElements.generateImpliedEndTagsThoroughly(),e.openElements.currentTagId!==b.TEMPLATE&&e._err(t,ie.closingOfElementWithOpenChildElements),e.openElements.popUntilTagNamePopped(b.TEMPLATE),e.activeFormattingElements.clearToLastMarker(),e.tmplInsertionModeStack.shift(),e._resetInsertionMode()):e._err(t,ie.endTagWithoutMatchingOpenElement)}function io(e,t){e.openElements.pop(),e.insertionMode=z.AFTER_HEAD,e._processToken(t)}function IN(e,t){switch(t.tagID){case b.HTML:{Qn(e,t);break}case b.BASEFONT:case b.BGSOUND:case b.HEAD:case b.LINK:case b.META:case b.NOFRAMES:case b.STYLE:{ma(e,t);break}case b.NOSCRIPT:{e._err(t,ie.nestedNoscriptInHead);break}default:lo(e,t)}}function LN(e,t){switch(t.tagID){case b.NOSCRIPT:{e.openElements.pop(),e.insertionMode=z.IN_HEAD;break}case b.BR:{lo(e,t);break}default:e._err(t,ie.endTagWithoutMatchingOpenElement)}}function lo(e,t){const n=t.type===Et.EOF?ie.openElementsLeftAfterEof:ie.disallowedContentInNoscriptInHead;e._err(t,n),e.openElements.pop(),e.insertionMode=z.IN_HEAD,e._processToken(t)}function BN(e,t){switch(t.tagID){case b.HTML:{Qn(e,t);break}case b.BODY:{e._insertElement(t,_e.HTML),e.framesetOk=!1,e.insertionMode=z.IN_BODY;break}case b.FRAMESET:{e._insertElement(t,_e.HTML),e.insertionMode=z.IN_FRAMESET;break}case b.BASE:case b.BASEFONT:case b.BGSOUND:case b.LINK:case b.META:case b.NOFRAMES:case b.SCRIPT:case b.STYLE:case b.TEMPLATE:case b.TITLE:{e._err(t,ie.abandonedHeadElementChild),e.openElements.push(e.headElement,b.HEAD),ma(e,t),e.openElements.remove(e.headElement);break}case b.HEAD:{e._err(t,ie.misplacedStartTagForHeadElement);break}default:so(e,t)}}function PN(e,t){switch(t.tagID){case b.BODY:case b.HTML:case b.BR:{so(e,t);break}case b.TEMPLATE:{Il(e,t);break}default:e._err(t,ie.endTagWithoutMatchingOpenElement)}}function so(e,t){e._insertFakeElement(W.BODY,b.BODY),e.insertionMode=z.IN_BODY,jc(e,t)}function jc(e,t){switch(t.type){case Et.CHARACTER:{ZE(e,t);break}case Et.WHITESPACE_CHARACTER:{QE(e,t);break}case Et.COMMENT:{I1(e,t);break}case Et.START_TAG:{Qn(e,t);break}case Et.END_TAG:{Xc(e,t);break}case Et.EOF:{n5(e,t);break}}}function QE(e,t){e._reconstructActiveFormattingElements(),e._insertCharacters(t)}function ZE(e,t){e._reconstructActiveFormattingElements(),e._insertCharacters(t),e.framesetOk=!1}function UN(e,t){e.openElements.tmplCount===0&&e.treeAdapter.adoptAttributes(e.openElements.items[0],t.attrs)}function zN(e,t){const n=e.openElements.tryPeekProperlyNestedBodyElement();n&&e.openElements.tmplCount===0&&(e.framesetOk=!1,e.treeAdapter.adoptAttributes(n,t.attrs))}function HN(e,t){const n=e.openElements.tryPeekProperlyNestedBodyElement();e.framesetOk&&n&&(e.treeAdapter.detachNode(n),e.openElements.popAllUpToHtmlElement(),e._insertElement(t,_e.HTML),e.insertionMode=z.IN_FRAMESET)}function FN(e,t){e.openElements.hasInButtonScope(b.P)&&e._closePElement(),e._insertElement(t,_e.HTML)}function qN(e,t){e.openElements.hasInButtonScope(b.P)&&e._closePElement(),e.openElements.currentTagId!==void 0&&D1.has(e.openElements.currentTagId)&&e.openElements.pop(),e._insertElement(t,_e.HTML)}function YN(e,t){e.openElements.hasInButtonScope(b.P)&&e._closePElement(),e._insertElement(t,_e.HTML),e.skipNextNewLine=!0,e.framesetOk=!1}function GN(e,t){const n=e.openElements.tmplCount>0;(!e.formElement||n)&&(e.openElements.hasInButtonScope(b.P)&&e._closePElement(),e._insertElement(t,_e.HTML),n||(e.formElement=e.openElements.current))}function VN(e,t){e.framesetOk=!1;const n=t.tagID;for(let a=e.openElements.stackTop;a>=0;a--){const l=e.openElements.tagIDs[a];if(n===b.LI&&l===b.LI||(n===b.DD||n===b.DT)&&(l===b.DD||l===b.DT)){e.openElements.generateImpliedEndTagsWithExclusion(l),e.openElements.popUntilTagNamePopped(l);break}if(l!==b.ADDRESS&&l!==b.DIV&&l!==b.P&&e._isSpecialElement(e.openElements.items[a],l))break}e.openElements.hasInButtonScope(b.P)&&e._closePElement(),e._insertElement(t,_e.HTML)}function KN(e,t){e.openElements.hasInButtonScope(b.P)&&e._closePElement(),e._insertElement(t,_e.HTML),e.tokenizer.state=yn.PLAINTEXT}function jN(e,t){e.openElements.hasInScope(b.BUTTON)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(b.BUTTON)),e._reconstructActiveFormattingElements(),e._insertElement(t,_e.HTML),e.framesetOk=!1}function XN(e,t){const n=e.activeFormattingElements.getElementEntryInScopeWithTagName(W.A);n&&(Nm(e,t),e.openElements.remove(n.element),e.activeFormattingElements.removeEntry(n)),e._reconstructActiveFormattingElements(),e._insertElement(t,_e.HTML),e.activeFormattingElements.pushElement(e.openElements.current,t)}function $N(e,t){e._reconstructActiveFormattingElements(),e._insertElement(t,_e.HTML),e.activeFormattingElements.pushElement(e.openElements.current,t)}function WN(e,t){e._reconstructActiveFormattingElements(),e.openElements.hasInScope(b.NOBR)&&(Nm(e,t),e._reconstructActiveFormattingElements()),e._insertElement(t,_e.HTML),e.activeFormattingElements.pushElement(e.openElements.current,t)}function QN(e,t){e._reconstructActiveFormattingElements(),e._insertElement(t,_e.HTML),e.activeFormattingElements.insertMarker(),e.framesetOk=!1}function ZN(e,t){e.treeAdapter.getDocumentMode(e.document)!==Wr.QUIRKS&&e.openElements.hasInButtonScope(b.P)&&e._closePElement(),e._insertElement(t,_e.HTML),e.framesetOk=!1,e.insertionMode=z.IN_TABLE}function JE(e,t){e._reconstructActiveFormattingElements(),e._appendElement(t,_e.HTML),e.framesetOk=!1,t.ackSelfClosing=!0}function e5(e){const t=qE(e,Ol.TYPE);return t!=null&&t.toLowerCase()===gN}function JN(e,t){e._reconstructActiveFormattingElements(),e._appendElement(t,_e.HTML),e5(t)||(e.framesetOk=!1),t.ackSelfClosing=!0}function ew(e,t){e._appendElement(t,_e.HTML),t.ackSelfClosing=!0}function tw(e,t){e.openElements.hasInButtonScope(b.P)&&e._closePElement(),e._appendElement(t,_e.HTML),e.framesetOk=!1,t.ackSelfClosing=!0}function nw(e,t){t.tagName=W.IMG,t.tagID=b.IMG,JE(e,t)}function rw(e,t){e._insertElement(t,_e.HTML),e.skipNextNewLine=!0,e.tokenizer.state=yn.RCDATA,e.originalInsertionMode=e.insertionMode,e.framesetOk=!1,e.insertionMode=z.TEXT}function aw(e,t){e.openElements.hasInButtonScope(b.P)&&e._closePElement(),e._reconstructActiveFormattingElements(),e.framesetOk=!1,e._switchToTextParsing(t,yn.RAWTEXT)}function iw(e,t){e.framesetOk=!1,e._switchToTextParsing(t,yn.RAWTEXT)}function Yb(e,t){e._switchToTextParsing(t,yn.RAWTEXT)}function lw(e,t){e._reconstructActiveFormattingElements(),e._insertElement(t,_e.HTML),e.framesetOk=!1,e.insertionMode=e.insertionMode===z.IN_TABLE||e.insertionMode===z.IN_CAPTION||e.insertionMode===z.IN_TABLE_BODY||e.insertionMode===z.IN_ROW||e.insertionMode===z.IN_CELL?z.IN_SELECT_IN_TABLE:z.IN_SELECT}function sw(e,t){e.openElements.currentTagId===b.OPTION&&e.openElements.pop(),e._reconstructActiveFormattingElements(),e._insertElement(t,_e.HTML)}function uw(e,t){e.openElements.hasInScope(b.RUBY)&&e.openElements.generateImpliedEndTags(),e._insertElement(t,_e.HTML)}function ow(e,t){e.openElements.hasInScope(b.RUBY)&&e.openElements.generateImpliedEndTagsWithExclusion(b.RTC),e._insertElement(t,_e.HTML)}function cw(e,t){e._reconstructActiveFormattingElements(),XE(t),km(t),t.selfClosing?e._appendElement(t,_e.MATHML):e._insertElement(t,_e.MATHML),t.ackSelfClosing=!0}function dw(e,t){e._reconstructActiveFormattingElements(),$E(t),km(t),t.selfClosing?e._appendElement(t,_e.SVG):e._insertElement(t,_e.SVG),t.ackSelfClosing=!0}function Gb(e,t){e._reconstructActiveFormattingElements(),e._insertElement(t,_e.HTML)}function Qn(e,t){switch(t.tagID){case b.I:case b.S:case b.B:case b.U:case b.EM:case b.TT:case b.BIG:case b.CODE:case b.FONT:case b.SMALL:case b.STRIKE:case b.STRONG:{$N(e,t);break}case b.A:{XN(e,t);break}case b.H1:case b.H2:case b.H3:case b.H4:case b.H5:case b.H6:{qN(e,t);break}case b.P:case b.DL:case b.OL:case b.UL:case b.DIV:case b.DIR:case b.NAV:case b.MAIN:case b.MENU:case b.ASIDE:case b.CENTER:case b.FIGURE:case b.FOOTER:case b.HEADER:case b.HGROUP:case b.DIALOG:case b.DETAILS:case b.ADDRESS:case b.ARTICLE:case b.SEARCH:case b.SECTION:case b.SUMMARY:case b.FIELDSET:case b.BLOCKQUOTE:case b.FIGCAPTION:{FN(e,t);break}case b.LI:case b.DD:case b.DT:{VN(e,t);break}case b.BR:case b.IMG:case b.WBR:case b.AREA:case b.EMBED:case b.KEYGEN:{JE(e,t);break}case b.HR:{tw(e,t);break}case b.RB:case b.RTC:{uw(e,t);break}case b.RT:case b.RP:{ow(e,t);break}case b.PRE:case b.LISTING:{YN(e,t);break}case b.XMP:{aw(e,t);break}case b.SVG:{dw(e,t);break}case b.HTML:{UN(e,t);break}case b.BASE:case b.LINK:case b.META:case b.STYLE:case b.TITLE:case b.SCRIPT:case b.BGSOUND:case b.BASEFONT:case b.TEMPLATE:{ma(e,t);break}case b.BODY:{zN(e,t);break}case b.FORM:{GN(e,t);break}case b.NOBR:{WN(e,t);break}case b.MATH:{cw(e,t);break}case b.TABLE:{ZN(e,t);break}case b.INPUT:{JN(e,t);break}case b.PARAM:case b.TRACK:case b.SOURCE:{ew(e,t);break}case b.IMAGE:{nw(e,t);break}case b.BUTTON:{jN(e,t);break}case b.APPLET:case b.OBJECT:case b.MARQUEE:{QN(e,t);break}case b.IFRAME:{iw(e,t);break}case b.SELECT:{lw(e,t);break}case b.OPTION:case b.OPTGROUP:{sw(e,t);break}case b.NOEMBED:case b.NOFRAMES:{Yb(e,t);break}case b.FRAMESET:{HN(e,t);break}case b.TEXTAREA:{rw(e,t);break}case b.NOSCRIPT:{e.options.scriptingEnabled?Yb(e,t):Gb(e,t);break}case b.PLAINTEXT:{KN(e,t);break}case b.COL:case b.TH:case b.TD:case b.TR:case b.HEAD:case b.FRAME:case b.TBODY:case b.TFOOT:case b.THEAD:case b.CAPTION:case b.COLGROUP:break;default:Gb(e,t)}}function fw(e,t){if(e.openElements.hasInScope(b.BODY)&&(e.insertionMode=z.AFTER_BODY,e.options.sourceCodeLocationInfo)){const n=e.openElements.tryPeekProperlyNestedBodyElement();n&&e._setEndLocation(n,t)}}function hw(e,t){e.openElements.hasInScope(b.BODY)&&(e.insertionMode=z.AFTER_BODY,c5(e,t))}function mw(e,t){const n=t.tagID;e.openElements.hasInScope(n)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(n))}function pw(e){const t=e.openElements.tmplCount>0,{formElement:n}=e;t||(e.formElement=null),(n||t)&&e.openElements.hasInScope(b.FORM)&&(e.openElements.generateImpliedEndTags(),t?e.openElements.popUntilTagNamePopped(b.FORM):n&&e.openElements.remove(n))}function gw(e){e.openElements.hasInButtonScope(b.P)||e._insertFakeElement(W.P,b.P),e._closePElement()}function bw(e){e.openElements.hasInListItemScope(b.LI)&&(e.openElements.generateImpliedEndTagsWithExclusion(b.LI),e.openElements.popUntilTagNamePopped(b.LI))}function Ew(e,t){const n=t.tagID;e.openElements.hasInScope(n)&&(e.openElements.generateImpliedEndTagsWithExclusion(n),e.openElements.popUntilTagNamePopped(n))}function yw(e){e.openElements.hasNumberedHeaderInScope()&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilNumberedHeaderPopped())}function vw(e,t){const n=t.tagID;e.openElements.hasInScope(n)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(n),e.activeFormattingElements.clearToLastMarker())}function Tw(e){e._reconstructActiveFormattingElements(),e._insertFakeElement(W.BR,b.BR),e.openElements.pop(),e.framesetOk=!1}function t5(e,t){const n=t.tagName,a=t.tagID;for(let l=e.openElements.stackTop;l>0;l--){const s=e.openElements.items[l],o=e.openElements.tagIDs[l];if(a===o&&(a!==b.UNKNOWN||e.treeAdapter.getTagName(s)===n)){e.openElements.generateImpliedEndTagsWithExclusion(a),e.openElements.stackTop>=l&&e.openElements.shortenToLength(l);break}if(e._isSpecialElement(s,o))break}}function Xc(e,t){switch(t.tagID){case b.A:case b.B:case b.I:case b.S:case b.U:case b.EM:case b.TT:case b.BIG:case b.CODE:case b.FONT:case b.NOBR:case b.SMALL:case b.STRIKE:case b.STRONG:{Nm(e,t);break}case b.P:{gw(e);break}case b.DL:case b.UL:case b.OL:case b.DIR:case b.DIV:case b.NAV:case b.PRE:case b.MAIN:case b.MENU:case b.ASIDE:case b.BUTTON:case b.CENTER:case b.FIGURE:case b.FOOTER:case b.HEADER:case b.HGROUP:case b.DIALOG:case b.ADDRESS:case b.ARTICLE:case b.DETAILS:case b.SEARCH:case b.SECTION:case b.SUMMARY:case b.LISTING:case b.FIELDSET:case b.BLOCKQUOTE:case b.FIGCAPTION:{mw(e,t);break}case b.LI:{bw(e);break}case b.DD:case b.DT:{Ew(e,t);break}case b.H1:case b.H2:case b.H3:case b.H4:case b.H5:case b.H6:{yw(e);break}case b.BR:{Tw(e);break}case b.BODY:{fw(e,t);break}case b.HTML:{hw(e,t);break}case b.FORM:{pw(e);break}case b.APPLET:case b.OBJECT:case b.MARQUEE:{vw(e,t);break}case b.TEMPLATE:{Il(e,t);break}default:t5(e,t)}}function n5(e,t){e.tmplInsertionModeStack.length>0?o5(e,t):wm(e,t)}function _w(e,t){var n;t.tagID===b.SCRIPT&&((n=e.scriptHandler)===null||n===void 0||n.call(e,e.openElements.current)),e.openElements.pop(),e.insertionMode=e.originalInsertionMode}function Sw(e,t){e._err(t,ie.eofInElementThatCanContainOnlyText),e.openElements.pop(),e.insertionMode=e.originalInsertionMode,e.onEof(t)}function Ph(e,t){if(e.openElements.currentTagId!==void 0&&WE.has(e.openElements.currentTagId))switch(e.pendingCharacterTokens.length=0,e.hasNonWhitespacePendingCharacterToken=!1,e.originalInsertionMode=e.insertionMode,e.insertionMode=z.IN_TABLE_TEXT,t.type){case Et.CHARACTER:{a5(e,t);break}case Et.WHITESPACE_CHARACTER:{r5(e,t);break}}else ko(e,t)}function Aw(e,t){e.openElements.clearBackToTableContext(),e.activeFormattingElements.insertMarker(),e._insertElement(t,_e.HTML),e.insertionMode=z.IN_CAPTION}function xw(e,t){e.openElements.clearBackToTableContext(),e._insertElement(t,_e.HTML),e.insertionMode=z.IN_COLUMN_GROUP}function kw(e,t){e.openElements.clearBackToTableContext(),e._insertFakeElement(W.COLGROUP,b.COLGROUP),e.insertionMode=z.IN_COLUMN_GROUP,Cm(e,t)}function Nw(e,t){e.openElements.clearBackToTableContext(),e._insertElement(t,_e.HTML),e.insertionMode=z.IN_TABLE_BODY}function ww(e,t){e.openElements.clearBackToTableContext(),e._insertFakeElement(W.TBODY,b.TBODY),e.insertionMode=z.IN_TABLE_BODY,$c(e,t)}function Cw(e,t){e.openElements.hasInTableScope(b.TABLE)&&(e.openElements.popUntilTagNamePopped(b.TABLE),e._resetInsertionMode(),e._processStartTag(t))}function Ow(e,t){e5(t)?e._appendElement(t,_e.HTML):ko(e,t),t.ackSelfClosing=!0}function Rw(e,t){!e.formElement&&e.openElements.tmplCount===0&&(e._insertElement(t,_e.HTML),e.formElement=e.openElements.current,e.openElements.pop())}function Rs(e,t){switch(t.tagID){case b.TD:case b.TH:case b.TR:{ww(e,t);break}case b.STYLE:case b.SCRIPT:case b.TEMPLATE:{ma(e,t);break}case b.COL:{kw(e,t);break}case b.FORM:{Rw(e,t);break}case b.TABLE:{Cw(e,t);break}case b.TBODY:case b.TFOOT:case b.THEAD:{Nw(e,t);break}case b.INPUT:{Ow(e,t);break}case b.CAPTION:{Aw(e,t);break}case b.COLGROUP:{xw(e,t);break}default:ko(e,t)}}function go(e,t){switch(t.tagID){case b.TABLE:{e.openElements.hasInTableScope(b.TABLE)&&(e.openElements.popUntilTagNamePopped(b.TABLE),e._resetInsertionMode());break}case b.TEMPLATE:{Il(e,t);break}case b.BODY:case b.CAPTION:case b.COL:case b.COLGROUP:case b.HTML:case b.TBODY:case b.TD:case b.TFOOT:case b.TH:case b.THEAD:case b.TR:break;default:ko(e,t)}}function ko(e,t){const n=e.fosterParentingEnabled;e.fosterParentingEnabled=!0,jc(e,t),e.fosterParentingEnabled=n}function r5(e,t){e.pendingCharacterTokens.push(t)}function a5(e,t){e.pendingCharacterTokens.push(t),e.hasNonWhitespacePendingCharacterToken=!0}function Wu(e,t){let n=0;if(e.hasNonWhitespacePendingCharacterToken)for(;n<e.pendingCharacterTokens.length;n++)ko(e,e.pendingCharacterTokens[n]);else for(;n<e.pendingCharacterTokens.length;n++)e._insertCharacters(e.pendingCharacterTokens[n]);e.insertionMode=e.originalInsertionMode,e._processToken(t)}const i5=new Set([b.CAPTION,b.COL,b.COLGROUP,b.TBODY,b.TD,b.TFOOT,b.TH,b.THEAD,b.TR]);function Mw(e,t){const n=t.tagID;i5.has(n)?e.openElements.hasInTableScope(b.CAPTION)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(b.CAPTION),e.activeFormattingElements.clearToLastMarker(),e.insertionMode=z.IN_TABLE,Rs(e,t)):Qn(e,t)}function Dw(e,t){const n=t.tagID;switch(n){case b.CAPTION:case b.TABLE:{e.openElements.hasInTableScope(b.CAPTION)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(b.CAPTION),e.activeFormattingElements.clearToLastMarker(),e.insertionMode=z.IN_TABLE,n===b.TABLE&&go(e,t));break}case b.BODY:case b.COL:case b.COLGROUP:case b.HTML:case b.TBODY:case b.TD:case b.TFOOT:case b.TH:case b.THEAD:case b.TR:break;default:Xc(e,t)}}function Cm(e,t){switch(t.tagID){case b.HTML:{Qn(e,t);break}case b.COL:{e._appendElement(t,_e.HTML),t.ackSelfClosing=!0;break}case b.TEMPLATE:{ma(e,t);break}default:Cc(e,t)}}function Iw(e,t){switch(t.tagID){case b.COLGROUP:{e.openElements.currentTagId===b.COLGROUP&&(e.openElements.pop(),e.insertionMode=z.IN_TABLE);break}case b.TEMPLATE:{Il(e,t);break}case b.COL:break;default:Cc(e,t)}}function Cc(e,t){e.openElements.currentTagId===b.COLGROUP&&(e.openElements.pop(),e.insertionMode=z.IN_TABLE,e._processToken(t))}function $c(e,t){switch(t.tagID){case b.TR:{e.openElements.clearBackToTableBodyContext(),e._insertElement(t,_e.HTML),e.insertionMode=z.IN_ROW;break}case b.TH:case b.TD:{e.openElements.clearBackToTableBodyContext(),e._insertFakeElement(W.TR,b.TR),e.insertionMode=z.IN_ROW,Wc(e,t);break}case b.CAPTION:case b.COL:case b.COLGROUP:case b.TBODY:case b.TFOOT:case b.THEAD:{e.openElements.hasTableBodyContextInTableScope()&&(e.openElements.clearBackToTableBodyContext(),e.openElements.pop(),e.insertionMode=z.IN_TABLE,Rs(e,t));break}default:Rs(e,t)}}function L1(e,t){const n=t.tagID;switch(t.tagID){case b.TBODY:case b.TFOOT:case b.THEAD:{e.openElements.hasInTableScope(n)&&(e.openElements.clearBackToTableBodyContext(),e.openElements.pop(),e.insertionMode=z.IN_TABLE);break}case b.TABLE:{e.openElements.hasTableBodyContextInTableScope()&&(e.openElements.clearBackToTableBodyContext(),e.openElements.pop(),e.insertionMode=z.IN_TABLE,go(e,t));break}case b.BODY:case b.CAPTION:case b.COL:case b.COLGROUP:case b.HTML:case b.TD:case b.TH:case b.TR:break;default:go(e,t)}}function Wc(e,t){switch(t.tagID){case b.TH:case b.TD:{e.openElements.clearBackToTableRowContext(),e._insertElement(t,_e.HTML),e.insertionMode=z.IN_CELL,e.activeFormattingElements.insertMarker();break}case b.CAPTION:case b.COL:case b.COLGROUP:case b.TBODY:case b.TFOOT:case b.THEAD:case b.TR:{e.openElements.hasInTableScope(b.TR)&&(e.openElements.clearBackToTableRowContext(),e.openElements.pop(),e.insertionMode=z.IN_TABLE_BODY,$c(e,t));break}default:Rs(e,t)}}function l5(e,t){switch(t.tagID){case b.TR:{e.openElements.hasInTableScope(b.TR)&&(e.openElements.clearBackToTableRowContext(),e.openElements.pop(),e.insertionMode=z.IN_TABLE_BODY);break}case b.TABLE:{e.openElements.hasInTableScope(b.TR)&&(e.openElements.clearBackToTableRowContext(),e.openElements.pop(),e.insertionMode=z.IN_TABLE_BODY,L1(e,t));break}case b.TBODY:case b.TFOOT:case b.THEAD:{(e.openElements.hasInTableScope(t.tagID)||e.openElements.hasInTableScope(b.TR))&&(e.openElements.clearBackToTableRowContext(),e.openElements.pop(),e.insertionMode=z.IN_TABLE_BODY,L1(e,t));break}case b.BODY:case b.CAPTION:case b.COL:case b.COLGROUP:case b.HTML:case b.TD:case b.TH:break;default:go(e,t)}}function Lw(e,t){const n=t.tagID;i5.has(n)?(e.openElements.hasInTableScope(b.TD)||e.openElements.hasInTableScope(b.TH))&&(e._closeTableCell(),Wc(e,t)):Qn(e,t)}function Bw(e,t){const n=t.tagID;switch(n){case b.TD:case b.TH:{e.openElements.hasInTableScope(n)&&(e.openElements.generateImpliedEndTags(),e.openElements.popUntilTagNamePopped(n),e.activeFormattingElements.clearToLastMarker(),e.insertionMode=z.IN_ROW);break}case b.TABLE:case b.TBODY:case b.TFOOT:case b.THEAD:case b.TR:{e.openElements.hasInTableScope(n)&&(e._closeTableCell(),l5(e,t));break}case b.BODY:case b.CAPTION:case b.COL:case b.COLGROUP:case b.HTML:break;default:Xc(e,t)}}function s5(e,t){switch(t.tagID){case b.HTML:{Qn(e,t);break}case b.OPTION:{e.openElements.currentTagId===b.OPTION&&e.openElements.pop(),e._insertElement(t,_e.HTML);break}case b.OPTGROUP:{e.openElements.currentTagId===b.OPTION&&e.openElements.pop(),e.openElements.currentTagId===b.OPTGROUP&&e.openElements.pop(),e._insertElement(t,_e.HTML);break}case b.HR:{e.openElements.currentTagId===b.OPTION&&e.openElements.pop(),e.openElements.currentTagId===b.OPTGROUP&&e.openElements.pop(),e._appendElement(t,_e.HTML),t.ackSelfClosing=!0;break}case b.INPUT:case b.KEYGEN:case b.TEXTAREA:case b.SELECT:{e.openElements.hasInSelectScope(b.SELECT)&&(e.openElements.popUntilTagNamePopped(b.SELECT),e._resetInsertionMode(),t.tagID!==b.SELECT&&e._processStartTag(t));break}case b.SCRIPT:case b.TEMPLATE:{ma(e,t);break}}}function u5(e,t){switch(t.tagID){case b.OPTGROUP:{e.openElements.stackTop>0&&e.openElements.currentTagId===b.OPTION&&e.openElements.tagIDs[e.openElements.stackTop-1]===b.OPTGROUP&&e.openElements.pop(),e.openElements.currentTagId===b.OPTGROUP&&e.openElements.pop();break}case b.OPTION:{e.openElements.currentTagId===b.OPTION&&e.openElements.pop();break}case b.SELECT:{e.openElements.hasInSelectScope(b.SELECT)&&(e.openElements.popUntilTagNamePopped(b.SELECT),e._resetInsertionMode());break}case b.TEMPLATE:{Il(e,t);break}}}function Pw(e,t){const n=t.tagID;n===b.CAPTION||n===b.TABLE||n===b.TBODY||n===b.TFOOT||n===b.THEAD||n===b.TR||n===b.TD||n===b.TH?(e.openElements.popUntilTagNamePopped(b.SELECT),e._resetInsertionMode(),e._processStartTag(t)):s5(e,t)}function Uw(e,t){const n=t.tagID;n===b.CAPTION||n===b.TABLE||n===b.TBODY||n===b.TFOOT||n===b.THEAD||n===b.TR||n===b.TD||n===b.TH?e.openElements.hasInTableScope(n)&&(e.openElements.popUntilTagNamePopped(b.SELECT),e._resetInsertionMode(),e.onEndTag(t)):u5(e,t)}function zw(e,t){switch(t.tagID){case b.BASE:case b.BASEFONT:case b.BGSOUND:case b.LINK:case b.META:case b.NOFRAMES:case b.SCRIPT:case b.STYLE:case b.TEMPLATE:case b.TITLE:{ma(e,t);break}case b.CAPTION:case b.COLGROUP:case b.TBODY:case b.TFOOT:case b.THEAD:{e.tmplInsertionModeStack[0]=z.IN_TABLE,e.insertionMode=z.IN_TABLE,Rs(e,t);break}case b.COL:{e.tmplInsertionModeStack[0]=z.IN_COLUMN_GROUP,e.insertionMode=z.IN_COLUMN_GROUP,Cm(e,t);break}case b.TR:{e.tmplInsertionModeStack[0]=z.IN_TABLE_BODY,e.insertionMode=z.IN_TABLE_BODY,$c(e,t);break}case b.TD:case b.TH:{e.tmplInsertionModeStack[0]=z.IN_ROW,e.insertionMode=z.IN_ROW,Wc(e,t);break}default:e.tmplInsertionModeStack[0]=z.IN_BODY,e.insertionMode=z.IN_BODY,Qn(e,t)}}function Hw(e,t){t.tagID===b.TEMPLATE&&Il(e,t)}function o5(e,t){e.openElements.tmplCount>0?(e.openElements.popUntilTagNamePopped(b.TEMPLATE),e.activeFormattingElements.clearToLastMarker(),e.tmplInsertionModeStack.shift(),e._resetInsertionMode(),e.onEof(t)):wm(e,t)}function Fw(e,t){t.tagID===b.HTML?Qn(e,t):Oc(e,t)}function c5(e,t){var n;if(t.tagID===b.HTML){if(e.fragmentContext||(e.insertionMode=z.AFTER_AFTER_BODY),e.options.sourceCodeLocationInfo&&e.openElements.tagIDs[0]===b.HTML){e._setEndLocation(e.openElements.items[0],t);const a=e.openElements.items[1];a&&!(!((n=e.treeAdapter.getNodeSourceCodeLocation(a))===null||n===void 0)&&n.endTag)&&e._setEndLocation(a,t)}}else Oc(e,t)}function Oc(e,t){e.insertionMode=z.IN_BODY,jc(e,t)}function qw(e,t){switch(t.tagID){case b.HTML:{Qn(e,t);break}case b.FRAMESET:{e._insertElement(t,_e.HTML);break}case b.FRAME:{e._appendElement(t,_e.HTML),t.ackSelfClosing=!0;break}case b.NOFRAMES:{ma(e,t);break}}}function Yw(e,t){t.tagID===b.FRAMESET&&!e.openElements.isRootHtmlElementCurrent()&&(e.openElements.pop(),!e.fragmentContext&&e.openElements.currentTagId!==b.FRAMESET&&(e.insertionMode=z.AFTER_FRAMESET))}function Gw(e,t){switch(t.tagID){case b.HTML:{Qn(e,t);break}case b.NOFRAMES:{ma(e,t);break}}}function Vw(e,t){t.tagID===b.HTML&&(e.insertionMode=z.AFTER_AFTER_FRAMESET)}function Kw(e,t){t.tagID===b.HTML?Qn(e,t):vc(e,t)}function vc(e,t){e.insertionMode=z.IN_BODY,jc(e,t)}function jw(e,t){switch(t.tagID){case b.HTML:{Qn(e,t);break}case b.NOFRAMES:{ma(e,t);break}}}function Xw(e,t){t.chars=nn,e._insertCharacters(t)}function $w(e,t){e._insertCharacters(t),e.framesetOk=!1}function d5(e){for(;e.treeAdapter.getNamespaceURI(e.openElements.current)!==_e.HTML&&e.openElements.currentTagId!==void 0&&!e._isIntegrationPoint(e.openElements.currentTagId,e.openElements.current);)e.openElements.pop()}function Ww(e,t){if(dN(t))d5(e),e._startTagOutsideForeignContent(t);else{const n=e._getAdjustedCurrentElement(),a=e.treeAdapter.getNamespaceURI(n);a===_e.MATHML?XE(t):a===_e.SVG&&(fN(t),$E(t)),km(t),t.selfClosing?e._appendElement(t,a):e._insertElement(t,a),t.ackSelfClosing=!0}}function Qw(e,t){if(t.tagID===b.P||t.tagID===b.BR){d5(e),e._endTagOutsideForeignContent(t);return}for(let n=e.openElements.stackTop;n>0;n--){const a=e.openElements.items[n];if(e.treeAdapter.getNamespaceURI(a)===_e.HTML){e._endTagOutsideForeignContent(t);break}const l=e.treeAdapter.getTagName(a);if(l.toLowerCase()===t.tagName){t.tagName=l,e.openElements.shortenToLength(n);break}}}W.AREA,W.BASE,W.BASEFONT,W.BGSOUND,W.BR,W.COL,W.EMBED,W.FRAME,W.HR,W.IMG,W.INPUT,W.KEYGEN,W.LINK,W.META,W.PARAM,W.SOURCE,W.TRACK,W.WBR;const Zw=/<(\/?)(iframe|noembed|noframes|plaintext|script|style|textarea|title|xmp)(?=[\t\n\f\r />])/gi,Jw=new Set(["mdxFlowExpression","mdxJsxFlowElement","mdxJsxTextElement","mdxTextExpression","mdxjsEsm"]),Vb={sourceCodeLocationInfo:!0,scriptingEnabled:!1};function f5(e,t){const n=oC(e),a=rE("type",{handlers:{root:eC,element:tC,text:nC,comment:m5,doctype:rC,raw:iC},unknown:lC}),l={parser:n?new qb(Vb):qb.getFragmentParser(void 0,Vb),handle(d){a(d,l)},stitches:!1,options:t||{}};a(e,l),Hs(l,Oa());const s=n?l.parser.document:l.parser.getFragment(),o=ek(s,{file:l.options.file});return l.stitches&&So(o,"comment",function(d,f,h){const p=d;if(p.value.stitch&&h&&f!==void 0){const E=h.children;return E[f]=p.value.stitch,f}}),o.type==="root"&&o.children.length===1&&o.children[0].type===e.type?o.children[0]:o}function h5(e,t){let n=-1;if(e)for(;++n<e.length;)t.handle(e[n])}function eC(e,t){h5(e.children,t)}function tC(e,t){sC(e,t),h5(e.children,t),uC(e,t)}function nC(e,t){t.parser.tokenizer.state>4&&(t.parser.tokenizer.state=0);const n={type:Et.CHARACTER,chars:e.value,location:No(e)};Hs(t,Oa(e)),t.parser.currentToken=n,t.parser._processToken(t.parser.currentToken)}function rC(e,t){const n={type:Et.DOCTYPE,name:"html",forceQuirks:!1,publicId:"",systemId:"",location:No(e)};Hs(t,Oa(e)),t.parser.currentToken=n,t.parser._processToken(t.parser.currentToken)}function aC(e,t){t.stitches=!0;const n=cC(e);if("children"in e&&"children"in n){const a=f5({type:"root",children:e.children},t.options);n.children=a.children}m5({type:"comment",value:{stitch:n}},t)}function m5(e,t){const n=e.value,a={type:Et.COMMENT,data:n,location:No(e)};Hs(t,Oa(e)),t.parser.currentToken=a,t.parser._processToken(t.parser.currentToken)}function iC(e,t){if(t.parser.tokenizer.preprocessor.html="",t.parser.tokenizer.preprocessor.pos=-1,t.parser.tokenizer.preprocessor.lastGapPos=-2,t.parser.tokenizer.preprocessor.gapStack=[],t.parser.tokenizer.preprocessor.skipNextNewLine=!1,t.parser.tokenizer.preprocessor.lastChunkWritten=!1,t.parser.tokenizer.preprocessor.endOfChunkHit=!1,t.parser.tokenizer.preprocessor.isEol=!1,p5(t,Oa(e)),t.parser.tokenizer.write(t.options.tagfilter?e.value.replace(Zw,"&lt;$1$2"):e.value,!1),t.parser.tokenizer._runParsingLoop(),t.parser.tokenizer.state===72||t.parser.tokenizer.state===78){t.parser.tokenizer.preprocessor.lastChunkWritten=!0;const n=t.parser.tokenizer._consume();t.parser.tokenizer._callState(n)}}function lC(e,t){const n=e;if(t.options.passThrough&&t.options.passThrough.includes(n.type))aC(n,t);else{let a="";throw Jw.has(n.type)&&(a=". It looks like you are using MDX nodes with `hast-util-raw` (or `rehype-raw`). If you use this because you are using remark or rehype plugins that inject `'html'` nodes, then please raise an issue with that plugin, as its a bad and slow idea. If you use this because you are using markdown syntax, then you have to configure this utility (or plugin) to pass through these nodes (see `passThrough` in docs), but you can also migrate to use the MDX syntax"),new Error("Cannot compile `"+n.type+"` node"+a)}}function Hs(e,t){p5(e,t);const n=e.parser.tokenizer.currentCharacterToken;n&&n.location&&(n.location.endLine=e.parser.tokenizer.preprocessor.line,n.location.endCol=e.parser.tokenizer.preprocessor.col+1,n.location.endOffset=e.parser.tokenizer.preprocessor.offset+1,e.parser.currentToken=n,e.parser._processToken(e.parser.currentToken)),e.parser.tokenizer.paused=!1,e.parser.tokenizer.inLoop=!1,e.parser.tokenizer.active=!1,e.parser.tokenizer.returnState=yn.DATA,e.parser.tokenizer.charRefCode=-1,e.parser.tokenizer.consumedAfterSnapshot=-1,e.parser.tokenizer.currentLocation=null,e.parser.tokenizer.currentCharacterToken=null,e.parser.tokenizer.currentToken=null,e.parser.tokenizer.currentAttr={name:"",value:""}}function p5(e,t){if(t&&t.offset!==void 0){const n={startLine:t.line,startCol:t.column,startOffset:t.offset,endLine:-1,endCol:-1,endOffset:-1};e.parser.tokenizer.preprocessor.lineStartPos=-t.column+1,e.parser.tokenizer.preprocessor.droppedBufferSize=t.offset,e.parser.tokenizer.preprocessor.line=t.line,e.parser.tokenizer.currentLocation=n}}function sC(e,t){const n=e.tagName.toLowerCase();if(t.parser.tokenizer.state===yn.PLAINTEXT)return;Hs(t,Oa(e));const a=t.parser.openElements.current;let l="namespaceURI"in a?a.namespaceURI:ka.html;l===ka.html&&n==="svg"&&(l=ka.svg);const s=pk({...e,children:[]},{space:l===ka.svg?"svg":"html"}),o={type:Et.START_TAG,tagName:n,tagID:zs(n),selfClosing:!1,ackSelfClosing:!1,attrs:"attrs"in s?s.attrs:[],location:No(e)};t.parser.currentToken=o,t.parser._processToken(t.parser.currentToken),t.parser.tokenizer.lastStartTagName=n}function uC(e,t){const n=e.tagName.toLowerCase();if(!t.parser.tokenizer.inForeignNode&&Sk.includes(n)||t.parser.tokenizer.state===yn.PLAINTEXT)return;Hs(t,qc(e));const a={type:Et.END_TAG,tagName:n,tagID:zs(n),selfClosing:!1,ackSelfClosing:!1,attrs:[],location:No(e)};t.parser.currentToken=a,t.parser._processToken(t.parser.currentToken),n===t.parser.tokenizer.lastStartTagName&&(t.parser.tokenizer.state===yn.RCDATA||t.parser.tokenizer.state===yn.RAWTEXT||t.parser.tokenizer.state===yn.SCRIPT_DATA)&&(t.parser.tokenizer.state=yn.DATA)}function oC(e){const t=e.type==="root"?e.children[0]:e;return!!(t&&(t.type==="doctype"||t.type==="element"&&t.tagName.toLowerCase()==="html"))}function No(e){const t=Oa(e)||{line:void 0,column:void 0,offset:void 0},n=qc(e)||{line:void 0,column:void 0,offset:void 0};return{startLine:t.line,startCol:t.column,startOffset:t.offset,endLine:n.line,endCol:n.column,endOffset:n.offset}}function cC(e){return"children"in e?Os({...e,children:[]}):Os(e)}function dC(e){return function(t,n){return f5(t,{...e,file:n})}}const Kb=function(e,t,n){const a=_o(n);if(!e||!e.type||!e.children)throw new Error("Expected parent node");if(typeof t=="number"){if(t<0||t===Number.POSITIVE_INFINITY)throw new Error("Expected positive finite number as index")}else if(t=e.children.indexOf(t),t<0)throw new Error("Expected child node or index");for(;++t<e.children.length;)if(a(e.children[t],t,e))return e.children[t]},Ll=function(e){if(e==null)return mC;if(typeof e=="string")return hC(e);if(typeof e=="object")return fC(e);if(typeof e=="function")return Om(e);throw new Error("Expected function, string, or array as `test`")};function fC(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=Ll(e[n]);return Om(a);function a(...l){let s=-1;for(;++s<t.length;)if(t[s].apply(this,l))return!0;return!1}}function hC(e){return Om(t);function t(n){return n.tagName===e}}function Om(e){return t;function t(n,a,l){return!!(pC(n)&&e.call(this,n,typeof a=="number"?a:void 0,l||void 0))}}function mC(e){return!!(e&&typeof e=="object"&&"type"in e&&e.type==="element"&&"tagName"in e&&typeof e.tagName=="string")}function pC(e){return e!==null&&typeof e=="object"&&"type"in e&&"tagName"in e}const jb=/\n/g,Xb=/[\t ]+/g,B1=Ll("br"),$b=Ll(_C),gC=Ll("p"),Wb=Ll("tr"),bC=Ll(["datalist","head","noembed","noframes","noscript","rp","script","style","template","title",TC,SC]),g5=Ll(["address","article","aside","blockquote","body","caption","center","dd","dialog","dir","dl","dt","div","figure","figcaption","footer","form,","h1","h2","h3","h4","h5","h6","header","hgroup","hr","html","legend","li","listing","main","menu","nav","ol","p","plaintext","pre","section","ul","xmp"]);function b5(e,t){const n=t||{},a="children"in e?e.children:[],l=g5(e),s=v5(e,{whitespace:n.whitespace||"normal"}),o=[];(e.type==="text"||e.type==="comment")&&o.push(...y5(e,{breakBefore:!0,breakAfter:!0}));let d=-1;for(;++d<a.length;)o.push(...E5(a[d],e,{whitespace:s,breakBefore:d?void 0:l,breakAfter:d<a.length-1?B1(a[d+1]):l}));const f=[];let h;for(d=-1;++d<o.length;){const p=o[d];typeof p=="number"?h!==void 0&&p>h&&(h=p):p&&(h!==void 0&&h>-1&&f.push(`
`.repeat(h)||" "),h=-1,f.push(p))}return f.join("")}function E5(e,t,n){return e.type==="element"?EC(e,t,n):e.type==="text"?n.whitespace==="normal"?y5(e,n):yC(e):[]}function EC(e,t,n){const a=v5(e,n),l=e.children||[];let s=-1,o=[];if(bC(e))return o;let d,f;for(B1(e)||Wb(e)&&Kb(t,e,Wb)?f=`
`:gC(e)?(d=2,f=2):g5(e)&&(d=1,f=1);++s<l.length;)o=o.concat(E5(l[s],e,{whitespace:a,breakBefore:s?void 0:d,breakAfter:s<l.length-1?B1(l[s+1]):f}));return $b(e)&&Kb(t,e,$b)&&o.push("	"),d&&o.unshift(d),f&&o.push(f),o}function y5(e,t){const n=String(e.value),a=[],l=[];let s=0;for(;s<=n.length;){jb.lastIndex=s;const f=jb.exec(n),h=f&&"index"in f?f.index:n.length;a.push(vC(n.slice(s,h).replace(/[\u061C\u200E\u200F\u202A-\u202E\u2066-\u2069]/g,""),s===0?t.breakBefore:!0,h===n.length?t.breakAfter:!0)),s=h+1}let o=-1,d;for(;++o<a.length;)a[o].charCodeAt(a[o].length-1)===8203||o<a.length-1&&a[o+1].charCodeAt(0)===8203?(l.push(a[o]),d=void 0):a[o]?(typeof d=="number"&&l.push(d),l.push(a[o]),d=0):(o===0||o===a.length-1)&&l.push(0);return l}function yC(e){return[String(e.value)]}function vC(e,t,n){const a=[];let l=0,s;for(;l<e.length;){Xb.lastIndex=l;const o=Xb.exec(e);s=o?o.index:e.length,!l&&!s&&o&&!t&&a.push(""),l!==s&&a.push(e.slice(l,s)),l=o?s+o[0].length:s}return l!==s&&!n&&a.push(""),a.join(" ")}function v5(e,t){if(e.type==="element"){const n=e.properties||{};switch(e.tagName){case"listing":case"plaintext":case"xmp":return"pre";case"nobr":return"nowrap";case"pre":return n.wrap?"pre-wrap":"pre";case"td":case"th":return n.noWrap?"nowrap":t.whitespace;case"textarea":return"pre-wrap"}}return t.whitespace}function TC(e){return!!(e.properties||{}).hidden}function _C(e){return e.tagName==="td"||e.tagName==="th"}function SC(e){return e.tagName==="dialog"&&!(e.properties||{}).open}function AC(e){const t=e.regex,n=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),a="decltype\\(auto\\)",l="[a-zA-Z_]\\w*::",o="(?!struct)("+a+"|"+t.optional(l)+"[a-zA-Z_]\\w*"+t.optional("<[^<>]+>")+")",d={className:"type",begin:"\\b[a-z\\d_]*_t\\b"},h={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+"\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)"+"|.)",end:"'",illegal:"."},e.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},p={className:"number",variants:[{begin:"[+-]?(?:(?:[0-9](?:'?[0-9])*\\.(?:[0-9](?:'?[0-9])*)?|\\.[0-9](?:'?[0-9])*)(?:[Ee][+-]?[0-9](?:'?[0-9])*)?|[0-9](?:'?[0-9])*[Ee][+-]?[0-9](?:'?[0-9])*|0[Xx](?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*(?:\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)?)?|\\.[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)[Pp][+-]?[0-9](?:'?[0-9])*)(?:[Ff](?:16|32|64|128)?|(BF|bf)16|[Ll]|)"},{begin:"[+-]?\\b(?:0[Bb][01](?:'?[01])*|0[Xx][0-9A-Fa-f](?:'?[0-9A-Fa-f])*|0(?:'?[0-7])*|[1-9](?:'?[0-9])*)(?:[Uu](?:LL?|ll?)|[Uu][Zz]?|(?:LL?|ll?)[Uu]?|[Zz][Uu]|)"}],relevance:0},E={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(h,{className:"string"}),{className:"string",begin:/<.*?>/},n,e.C_BLOCK_COMMENT_MODE]},T={className:"title",begin:t.optional(l)+e.IDENT_RE,relevance:0},v=t.optional(l)+e.IDENT_RE+"\\s*\\(",x=["alignas","alignof","and","and_eq","asm","atomic_cancel","atomic_commit","atomic_noexcept","auto","bitand","bitor","break","case","catch","class","co_await","co_return","co_yield","compl","concept","const_cast|10","consteval","constexpr","constinit","continue","decltype","default","delete","do","dynamic_cast|10","else","enum","explicit","export","extern","false","final","for","friend","goto","if","import","inline","module","mutable","namespace","new","noexcept","not","not_eq","nullptr","operator","or","or_eq","override","private","protected","public","reflexpr","register","reinterpret_cast|10","requires","return","sizeof","static_assert","static_cast|10","struct","switch","synchronized","template","this","thread_local","throw","transaction_safe","transaction_safe_dynamic","true","try","typedef","typeid","typename","union","using","virtual","volatile","while","xor","xor_eq"],N=["bool","char","char16_t","char32_t","char8_t","double","float","int","long","short","void","wchar_t","unsigned","signed","const","static"],D=["any","auto_ptr","barrier","binary_semaphore","bitset","complex","condition_variable","condition_variable_any","counting_semaphore","deque","false_type","flat_map","flat_set","future","imaginary","initializer_list","istringstream","jthread","latch","lock_guard","multimap","multiset","mutex","optional","ostringstream","packaged_task","pair","promise","priority_queue","queue","recursive_mutex","recursive_timed_mutex","scoped_lock","set","shared_future","shared_lock","shared_mutex","shared_timed_mutex","shared_ptr","stack","string_view","stringstream","timed_mutex","thread","true_type","tuple","unique_lock","unique_ptr","unordered_map","unordered_multimap","unordered_multiset","unordered_set","variant","vector","weak_ptr","wstring","wstring_view"],C=["abort","abs","acos","apply","as_const","asin","atan","atan2","calloc","ceil","cerr","cin","clog","cos","cosh","cout","declval","endl","exchange","exit","exp","fabs","floor","fmod","forward","fprintf","fputs","free","frexp","fscanf","future","invoke","isalnum","isalpha","iscntrl","isdigit","isgraph","islower","isprint","ispunct","isspace","isupper","isxdigit","labs","launder","ldexp","log","log10","make_pair","make_shared","make_shared_for_overwrite","make_tuple","make_unique","malloc","memchr","memcmp","memcpy","memset","modf","move","pow","printf","putchar","puts","realloc","scanf","sin","sinh","snprintf","sprintf","sqrt","sscanf","std","stderr","stdin","stdout","strcat","strchr","strcmp","strcpy","strcspn","strlen","strncat","strncmp","strncpy","strpbrk","strrchr","strspn","strstr","swap","tan","tanh","terminate","to_underlying","tolower","toupper","vfprintf","visit","vprintf","vsprintf"],J={type:N,keyword:x,literal:["NULL","false","nullopt","nullptr","true"],built_in:["_Pragma"],_type_hints:D},K={className:"function.dispatch",relevance:0,keywords:{_hint:C},begin:t.concat(/\b/,/(?!decltype)/,/(?!if)/,/(?!for)/,/(?!switch)/,/(?!while)/,e.IDENT_RE,t.lookahead(/(<[^<>]+>|)\s*\(/))},U=[K,E,d,n,e.C_BLOCK_COMMENT_MODE,p,h],le={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:J,contains:U.concat([{begin:/\(/,end:/\)/,keywords:J,contains:U.concat(["self"]),relevance:0}]),relevance:0},ae={className:"function",begin:"("+o+"[\\*&\\s]+)+"+v,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:J,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:a,keywords:J,relevance:0},{begin:v,returnBegin:!0,contains:[T],relevance:0},{begin:/::/,relevance:0},{begin:/:/,endsWithParent:!0,contains:[h,p]},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,keywords:J,relevance:0,contains:[n,e.C_BLOCK_COMMENT_MODE,h,p,d,{begin:/\(/,end:/\)/,keywords:J,relevance:0,contains:["self",n,e.C_BLOCK_COMMENT_MODE,h,p,d]}]},d,n,e.C_BLOCK_COMMENT_MODE,E]};return{name:"C++",aliases:["cc","c++","h++","hpp","hh","hxx","cxx"],keywords:J,illegal:"</",classNameAliases:{"function.dispatch":"built_in"},contains:[].concat(le,ae,K,U,[E,{begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function|flat_map|flat_set)\\s*<(?!<)",end:">",keywords:J,contains:["self",d]},{begin:e.IDENT_RE+"::",keywords:J},{match:[/\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,/\s+/,/\w+/],className:{1:"keyword",3:"title.class"}}])}}function xC(e){const t={type:["boolean","byte","word","String"],built_in:["KeyboardController","MouseController","SoftwareSerial","EthernetServer","EthernetClient","LiquidCrystal","RobotControl","GSMVoiceCall","EthernetUDP","EsploraTFT","HttpClient","RobotMotor","WiFiClient","GSMScanner","FileSystem","Scheduler","GSMServer","YunClient","YunServer","IPAddress","GSMClient","GSMModem","Keyboard","Ethernet","Console","GSMBand","Esplora","Stepper","Process","WiFiUDP","GSM_SMS","Mailbox","USBHost","Firmata","PImage","Client","Server","GSMPIN","FileIO","Bridge","Serial","EEPROM","Stream","Mouse","Audio","Servo","File","Task","GPRS","WiFi","Wire","TFT","GSM","SPI","SD"],_hints:["setup","loop","runShellCommandAsynchronously","analogWriteResolution","retrieveCallingNumber","printFirmwareVersion","analogReadResolution","sendDigitalPortPair","noListenOnLocalhost","readJoystickButton","setFirmwareVersion","readJoystickSwitch","scrollDisplayRight","getVoiceCallStatus","scrollDisplayLeft","writeMicroseconds","delayMicroseconds","beginTransmission","getSignalStrength","runAsynchronously","getAsynchronously","listenOnLocalhost","getCurrentCarrier","readAccelerometer","messageAvailable","sendDigitalPorts","lineFollowConfig","countryNameWrite","runShellCommand","readStringUntil","rewindDirectory","readTemperature","setClockDivider","readLightSensor","endTransmission","analogReference","detachInterrupt","countryNameRead","attachInterrupt","encryptionType","readBytesUntil","robotNameWrite","readMicrophone","robotNameRead","cityNameWrite","userNameWrite","readJoystickY","readJoystickX","mouseReleased","openNextFile","scanNetworks","noInterrupts","digitalWrite","beginSpeaker","mousePressed","isActionDone","mouseDragged","displayLogos","noAutoscroll","addParameter","remoteNumber","getModifiers","keyboardRead","userNameRead","waitContinue","processInput","parseCommand","printVersion","readNetworks","writeMessage","blinkVersion","cityNameRead","readMessage","setDataMode","parsePacket","isListening","setBitOrder","beginPacket","isDirectory","motorsWrite","drawCompass","digitalRead","clearScreen","serialEvent","rightToLeft","setTextSize","leftToRight","requestFrom","keyReleased","compassRead","analogWrite","interrupts","WiFiServer","disconnect","playMelody","parseFloat","autoscroll","getPINUsed","setPINUsed","setTimeout","sendAnalog","readSlider","analogRead","beginWrite","createChar","motorsStop","keyPressed","tempoWrite","readButton","subnetMask","debugPrint","macAddress","writeGreen","randomSeed","attachGPRS","readString","sendString","remotePort","releaseAll","mouseMoved","background","getXChange","getYChange","answerCall","getResult","voiceCall","endPacket","constrain","getSocket","writeJSON","getButton","available","connected","findUntil","readBytes","exitValue","readGreen","writeBlue","startLoop","IPAddress","isPressed","sendSysex","pauseMode","gatewayIP","setCursor","getOemKey","tuneWrite","noDisplay","loadImage","switchPIN","onRequest","onReceive","changePIN","playFile","noBuffer","parseInt","overflow","checkPIN","knobRead","beginTFT","bitClear","updateIR","bitWrite","position","writeRGB","highByte","writeRed","setSpeed","readBlue","noStroke","remoteIP","transfer","shutdown","hangCall","beginSMS","endWrite","attached","maintain","noCursor","checkReg","checkPUK","shiftOut","isValid","shiftIn","pulseIn","connect","println","localIP","pinMode","getIMEI","display","noBlink","process","getBand","running","beginSD","drawBMP","lowByte","setBand","release","bitRead","prepare","pointTo","readRed","setMode","noFill","remove","listen","stroke","detach","attach","noTone","exists","buffer","height","bitSet","circle","config","cursor","random","IRread","setDNS","endSMS","getKey","micros","millis","begin","print","write","ready","flush","width","isPIN","blink","clear","press","mkdir","rmdir","close","point","yield","image","BSSID","click","delay","read","text","move","peek","beep","rect","line","open","seek","fill","size","turn","stop","home","find","step","tone","sqrt","RSSI","SSID","end","bit","tan","cos","sin","pow","map","abs","max","min","get","run","put"],literal:["DIGITAL_MESSAGE","FIRMATA_STRING","ANALOG_MESSAGE","REPORT_DIGITAL","REPORT_ANALOG","INPUT_PULLUP","SET_PIN_MODE","INTERNAL2V56","SYSTEM_RESET","LED_BUILTIN","INTERNAL1V1","SYSEX_START","INTERNAL","EXTERNAL","DEFAULT","OUTPUT","INPUT","HIGH","LOW"]},n=AC(e),a=n.keywords;return a.type=[...a.type,...t.type],a.literal=[...a.literal,...t.literal],a.built_in=[...a.built_in,...t.built_in],a._hints=t._hints,n.name="Arduino",n.aliases=["ino"],n.supersetOf="cpp",n}function kC(e){const t=e.regex,n={},a={begin:/\$\{/,end:/\}/,contains:["self",{begin:/:-/,contains:[n]}]};Object.assign(n,{className:"variable",variants:[{begin:t.concat(/\$[\w\d#@][\w\d_]*/,"(?![\\w\\d])(?![$])")},a]});const l={className:"subst",begin:/\$\(/,end:/\)/,contains:[e.BACKSLASH_ESCAPE]},s=e.inherit(e.COMMENT(),{match:[/(^|\s)/,/#.*$/],scope:{2:"comment"}}),o={begin:/<<-?\s*(?=\w+)/,starts:{contains:[e.END_SAME_AS_BEGIN({begin:/(\w+)/,end:/(\w+)/,className:"string"})]}},d={className:"string",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,n,l]};l.contains.push(d);const f={match:/\\"/},h={className:"string",begin:/'/,end:/'/},p={match:/\\'/},E={begin:/\$?\(\(/,end:/\)\)/,contains:[{begin:/\d+#[0-9a-f]+/,className:"number"},e.NUMBER_MODE,n]},T=["fish","bash","zsh","sh","csh","ksh","tcsh","dash","scsh"],v=e.SHEBANG({binary:`(${T.join("|")})`,relevance:10}),x={className:"function",begin:/\w[\w\d_]*\s*\(\s*\)\s*\{/,returnBegin:!0,contains:[e.inherit(e.TITLE_MODE,{begin:/\w[\w\d_]*/})],relevance:0},N=["if","then","else","elif","fi","time","for","while","until","in","do","done","case","esac","coproc","function","select"],D=["true","false"],C={match:/(\/[a-z._-]+)+/},I=["break","cd","continue","eval","exec","exit","export","getopts","hash","pwd","readonly","return","shift","test","times","trap","umask","unset"],F=["alias","bind","builtin","caller","command","declare","echo","enable","help","let","local","logout","mapfile","printf","read","readarray","source","sudo","type","typeset","ulimit","unalias"],J=["autoload","bg","bindkey","bye","cap","chdir","clone","comparguments","compcall","compctl","compdescribe","compfiles","compgroups","compquote","comptags","comptry","compvalues","dirs","disable","disown","echotc","echoti","emulate","fc","fg","float","functions","getcap","getln","history","integer","jobs","kill","limit","log","noglob","popd","print","pushd","pushln","rehash","sched","setcap","setopt","stat","suspend","ttyctl","unfunction","unhash","unlimit","unsetopt","vared","wait","whence","where","which","zcompile","zformat","zftp","zle","zmodload","zparseopts","zprof","zpty","zregexparse","zsocket","zstyle","ztcp"],K=["chcon","chgrp","chown","chmod","cp","dd","df","dir","dircolors","ln","ls","mkdir","mkfifo","mknod","mktemp","mv","realpath","rm","rmdir","shred","sync","touch","truncate","vdir","b2sum","base32","base64","cat","cksum","comm","csplit","cut","expand","fmt","fold","head","join","md5sum","nl","numfmt","od","paste","ptx","pr","sha1sum","sha224sum","sha256sum","sha384sum","sha512sum","shuf","sort","split","sum","tac","tail","tr","tsort","unexpand","uniq","wc","arch","basename","chroot","date","dirname","du","echo","env","expr","factor","groups","hostid","id","link","logname","nice","nohup","nproc","pathchk","pinky","printenv","printf","pwd","readlink","runcon","seq","sleep","stat","stdbuf","stty","tee","test","timeout","tty","uname","unlink","uptime","users","who","whoami","yes"];return{name:"Bash",aliases:["sh","zsh"],keywords:{$pattern:/\b[a-z][a-z0-9._-]+\b/,keyword:N,literal:D,built_in:[...I,...F,"set","shopt",...J,...K]},contains:[v,e.SHEBANG(),x,E,s,o,C,d,f,h,p,n]}}function NC(e){const t=e.regex,n=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),a="decltype\\(auto\\)",l="[a-zA-Z_]\\w*::",o="("+a+"|"+t.optional(l)+"[a-zA-Z_]\\w*"+t.optional("<[^<>]+>")+")",d={className:"type",variants:[{begin:"\\b[a-z\\d_]*_t\\b"},{match:/\batomic_[a-z]{3,6}\b/}]},h={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+"\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)"+"|.)",end:"'",illegal:"."},e.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},p={className:"number",variants:[{match:/\b(0b[01']+)/},{match:/(-?)\b([\d']+(\.[\d']*)?|\.[\d']+)((ll|LL|l|L)(u|U)?|(u|U)(ll|LL|l|L)?|f|F|b|B)/},{match:/(-?)\b(0[xX][a-fA-F0-9]+(?:'[a-fA-F0-9]+)*(?:\.[a-fA-F0-9]*(?:'[a-fA-F0-9]*)*)?(?:[pP][-+]?[0-9]+)?(l|L)?(u|U)?)/},{match:/(-?)\b\d+(?:'\d+)*(?:\.\d*(?:'\d*)*)?(?:[eE][-+]?\d+)?/}],relevance:0},E={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef elifdef elifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(h,{className:"string"}),{className:"string",begin:/<.*?>/},n,e.C_BLOCK_COMMENT_MODE]},T={className:"title",begin:t.optional(l)+e.IDENT_RE,relevance:0},v=t.optional(l)+e.IDENT_RE+"\\s*\\(",D={keyword:["asm","auto","break","case","continue","default","do","else","enum","extern","for","fortran","goto","if","inline","register","restrict","return","sizeof","typeof","typeof_unqual","struct","switch","typedef","union","volatile","while","_Alignas","_Alignof","_Atomic","_Generic","_Noreturn","_Static_assert","_Thread_local","alignas","alignof","noreturn","static_assert","thread_local","_Pragma"],type:["float","double","signed","unsigned","int","short","long","char","void","_Bool","_BitInt","_Complex","_Imaginary","_Decimal32","_Decimal64","_Decimal96","_Decimal128","_Decimal64x","_Decimal128x","_Float16","_Float32","_Float64","_Float128","_Float32x","_Float64x","_Float128x","const","static","constexpr","complex","bool","imaginary"],literal:"true false NULL",built_in:"std string wstring cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream auto_ptr deque list queue stack vector map set pair bitset multiset multimap unordered_set unordered_map unordered_multiset unordered_multimap priority_queue make_pair array shared_ptr abort terminate abs acos asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp fscanf future isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan vfprintf vprintf vsprintf endl initializer_list unique_ptr"},C=[E,d,n,e.C_BLOCK_COMMENT_MODE,p,h],I={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:D,contains:C.concat([{begin:/\(/,end:/\)/,keywords:D,contains:C.concat(["self"]),relevance:0}]),relevance:0},F={begin:"("+o+"[\\*&\\s]+)+"+v,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:D,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:a,keywords:D,relevance:0},{begin:v,returnBegin:!0,contains:[e.inherit(T,{className:"title.function"})],relevance:0},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,keywords:D,relevance:0,contains:[n,e.C_BLOCK_COMMENT_MODE,h,p,d,{begin:/\(/,end:/\)/,keywords:D,relevance:0,contains:["self",n,e.C_BLOCK_COMMENT_MODE,h,p,d]}]},d,n,e.C_BLOCK_COMMENT_MODE,E]};return{name:"C",aliases:["h"],keywords:D,disableAutodetect:!0,illegal:"</",contains:[].concat(I,F,C,[E,{begin:e.IDENT_RE+"::",keywords:D},{className:"class",beginKeywords:"enum class struct union",end:/[{;:<>=]/,contains:[{beginKeywords:"final class struct"},e.TITLE_MODE]}]),exports:{preprocessor:E,strings:h,keywords:D}}}function wC(e){const t=e.regex,n=e.COMMENT("//","$",{contains:[{begin:/\\\n/}]}),a="decltype\\(auto\\)",l="[a-zA-Z_]\\w*::",o="(?!struct)("+a+"|"+t.optional(l)+"[a-zA-Z_]\\w*"+t.optional("<[^<>]+>")+")",d={className:"type",begin:"\\b[a-z\\d_]*_t\\b"},h={className:"string",variants:[{begin:'(u8?|U|L)?"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]},{begin:"(u8?|U|L)?'("+"\\\\(x[0-9A-Fa-f]{2}|u[0-9A-Fa-f]{4,8}|[0-7]{3}|\\S)"+"|.)",end:"'",illegal:"."},e.END_SAME_AS_BEGIN({begin:/(?:u8?|U|L)?R"([^()\\ ]{0,16})\(/,end:/\)([^()\\ ]{0,16})"/})]},p={className:"number",variants:[{begin:"[+-]?(?:(?:[0-9](?:'?[0-9])*\\.(?:[0-9](?:'?[0-9])*)?|\\.[0-9](?:'?[0-9])*)(?:[Ee][+-]?[0-9](?:'?[0-9])*)?|[0-9](?:'?[0-9])*[Ee][+-]?[0-9](?:'?[0-9])*|0[Xx](?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*(?:\\.(?:[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)?)?|\\.[0-9A-Fa-f](?:'?[0-9A-Fa-f])*)[Pp][+-]?[0-9](?:'?[0-9])*)(?:[Ff](?:16|32|64|128)?|(BF|bf)16|[Ll]|)"},{begin:"[+-]?\\b(?:0[Bb][01](?:'?[01])*|0[Xx][0-9A-Fa-f](?:'?[0-9A-Fa-f])*|0(?:'?[0-7])*|[1-9](?:'?[0-9])*)(?:[Uu](?:LL?|ll?)|[Uu][Zz]?|(?:LL?|ll?)[Uu]?|[Zz][Uu]|)"}],relevance:0},E={className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma _Pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(h,{className:"string"}),{className:"string",begin:/<.*?>/},n,e.C_BLOCK_COMMENT_MODE]},T={className:"title",begin:t.optional(l)+e.IDENT_RE,relevance:0},v=t.optional(l)+e.IDENT_RE+"\\s*\\(",x=["alignas","alignof","and","and_eq","asm","atomic_cancel","atomic_commit","atomic_noexcept","auto","bitand","bitor","break","case","catch","class","co_await","co_return","co_yield","compl","concept","const_cast|10","consteval","constexpr","constinit","continue","decltype","default","delete","do","dynamic_cast|10","else","enum","explicit","export","extern","false","final","for","friend","goto","if","import","inline","module","mutable","namespace","new","noexcept","not","not_eq","nullptr","operator","or","or_eq","override","private","protected","public","reflexpr","register","reinterpret_cast|10","requires","return","sizeof","static_assert","static_cast|10","struct","switch","synchronized","template","this","thread_local","throw","transaction_safe","transaction_safe_dynamic","true","try","typedef","typeid","typename","union","using","virtual","volatile","while","xor","xor_eq"],N=["bool","char","char16_t","char32_t","char8_t","double","float","int","long","short","void","wchar_t","unsigned","signed","const","static"],D=["any","auto_ptr","barrier","binary_semaphore","bitset","complex","condition_variable","condition_variable_any","counting_semaphore","deque","false_type","flat_map","flat_set","future","imaginary","initializer_list","istringstream","jthread","latch","lock_guard","multimap","multiset","mutex","optional","ostringstream","packaged_task","pair","promise","priority_queue","queue","recursive_mutex","recursive_timed_mutex","scoped_lock","set","shared_future","shared_lock","shared_mutex","shared_timed_mutex","shared_ptr","stack","string_view","stringstream","timed_mutex","thread","true_type","tuple","unique_lock","unique_ptr","unordered_map","unordered_multimap","unordered_multiset","unordered_set","variant","vector","weak_ptr","wstring","wstring_view"],C=["abort","abs","acos","apply","as_const","asin","atan","atan2","calloc","ceil","cerr","cin","clog","cos","cosh","cout","declval","endl","exchange","exit","exp","fabs","floor","fmod","forward","fprintf","fputs","free","frexp","fscanf","future","invoke","isalnum","isalpha","iscntrl","isdigit","isgraph","islower","isprint","ispunct","isspace","isupper","isxdigit","labs","launder","ldexp","log","log10","make_pair","make_shared","make_shared_for_overwrite","make_tuple","make_unique","malloc","memchr","memcmp","memcpy","memset","modf","move","pow","printf","putchar","puts","realloc","scanf","sin","sinh","snprintf","sprintf","sqrt","sscanf","std","stderr","stdin","stdout","strcat","strchr","strcmp","strcpy","strcspn","strlen","strncat","strncmp","strncpy","strpbrk","strrchr","strspn","strstr","swap","tan","tanh","terminate","to_underlying","tolower","toupper","vfprintf","visit","vprintf","vsprintf"],J={type:N,keyword:x,literal:["NULL","false","nullopt","nullptr","true"],built_in:["_Pragma"],_type_hints:D},K={className:"function.dispatch",relevance:0,keywords:{_hint:C},begin:t.concat(/\b/,/(?!decltype)/,/(?!if)/,/(?!for)/,/(?!switch)/,/(?!while)/,e.IDENT_RE,t.lookahead(/(<[^<>]+>|)\s*\(/))},U=[K,E,d,n,e.C_BLOCK_COMMENT_MODE,p,h],le={variants:[{begin:/=/,end:/;/},{begin:/\(/,end:/\)/},{beginKeywords:"new throw return else",end:/;/}],keywords:J,contains:U.concat([{begin:/\(/,end:/\)/,keywords:J,contains:U.concat(["self"]),relevance:0}]),relevance:0},ae={className:"function",begin:"("+o+"[\\*&\\s]+)+"+v,returnBegin:!0,end:/[{;=]/,excludeEnd:!0,keywords:J,illegal:/[^\w\s\*&:<>.]/,contains:[{begin:a,keywords:J,relevance:0},{begin:v,returnBegin:!0,contains:[T],relevance:0},{begin:/::/,relevance:0},{begin:/:/,endsWithParent:!0,contains:[h,p]},{relevance:0,match:/,/},{className:"params",begin:/\(/,end:/\)/,keywords:J,relevance:0,contains:[n,e.C_BLOCK_COMMENT_MODE,h,p,d,{begin:/\(/,end:/\)/,keywords:J,relevance:0,contains:["self",n,e.C_BLOCK_COMMENT_MODE,h,p,d]}]},d,n,e.C_BLOCK_COMMENT_MODE,E]};return{name:"C++",aliases:["cc","c++","h++","hpp","hh","hxx","cxx"],keywords:J,illegal:"</",classNameAliases:{"function.dispatch":"built_in"},contains:[].concat(le,ae,K,U,[E,{begin:"\\b(deque|list|queue|priority_queue|pair|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array|tuple|optional|variant|function|flat_map|flat_set)\\s*<(?!<)",end:">",keywords:J,contains:["self",d]},{begin:e.IDENT_RE+"::",keywords:J},{match:[/\b(?:enum(?:\s+(?:class|struct))?|class|struct|union)/,/\s+/,/\w+/],className:{1:"keyword",3:"title.class"}}])}}function CC(e){const t=["bool","byte","char","decimal","delegate","double","dynamic","enum","float","int","long","nint","nuint","object","sbyte","short","string","ulong","uint","ushort"],n=["public","private","protected","static","internal","protected","abstract","async","extern","override","unsafe","virtual","new","sealed","partial"],a=["default","false","null","true"],l=["abstract","as","base","break","case","catch","class","const","continue","do","else","event","explicit","extern","finally","fixed","for","foreach","goto","if","implicit","in","interface","internal","is","lock","namespace","new","operator","out","override","params","private","protected","public","readonly","record","ref","return","scoped","sealed","sizeof","stackalloc","static","struct","switch","this","throw","try","typeof","unchecked","unsafe","using","virtual","void","volatile","while"],s=["add","alias","and","ascending","args","async","await","by","descending","dynamic","equals","file","from","get","global","group","init","into","join","let","nameof","not","notnull","on","or","orderby","partial","record","remove","required","scoped","select","set","unmanaged","value|0","var","when","where","with","yield"],o={keyword:l.concat(s),built_in:t,literal:a},d=e.inherit(e.TITLE_MODE,{begin:"[a-zA-Z](\\.?\\w)*"}),f={className:"number",variants:[{begin:"\\b(0b[01']+)"},{begin:"(-?)\\b([\\d']+(\\.[\\d']*)?|\\.[\\d']+)(u|U|l|L|ul|UL|f|F|b|B)"},{begin:"(-?)(\\b0[xX][a-fA-F0-9']+|(\\b[\\d']+(\\.[\\d']*)?|\\.[\\d']+)([eE][-+]?[\\d']+)?)"}],relevance:0},h={className:"string",begin:/"""("*)(?!")(.|\n)*?"""\1/,relevance:1},p={className:"string",begin:'@"',end:'"',contains:[{begin:'""'}]},E=e.inherit(p,{illegal:/\n/}),T={className:"subst",begin:/\{/,end:/\}/,keywords:o},v=e.inherit(T,{illegal:/\n/}),x={className:"string",begin:/\$"/,end:'"',illegal:/\n/,contains:[{begin:/\{\{/},{begin:/\}\}/},e.BACKSLASH_ESCAPE,v]},N={className:"string",begin:/\$@"/,end:'"',contains:[{begin:/\{\{/},{begin:/\}\}/},{begin:'""'},T]},D=e.inherit(N,{illegal:/\n/,contains:[{begin:/\{\{/},{begin:/\}\}/},{begin:'""'},v]});T.contains=[N,x,p,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,f,e.C_BLOCK_COMMENT_MODE],v.contains=[D,x,E,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,f,e.inherit(e.C_BLOCK_COMMENT_MODE,{illegal:/\n/})];const C={variants:[h,N,x,p,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},I={begin:"<",end:">",contains:[{beginKeywords:"in out"},d]},F=e.IDENT_RE+"(<"+e.IDENT_RE+"(\\s*,\\s*"+e.IDENT_RE+")*>)?(\\[\\])?",J={begin:"@"+e.IDENT_RE,relevance:0};return{name:"C#",aliases:["cs","c#"],keywords:o,illegal:/::/,contains:[e.COMMENT("///","$",{returnBegin:!0,contains:[{className:"doctag",variants:[{begin:"///",relevance:0},{begin:"<!--|-->"},{begin:"</?",end:">"}]}]}),e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{className:"meta",begin:"#",end:"$",keywords:{keyword:"if else elif endif define undef warning error line region endregion pragma checksum"}},C,f,{beginKeywords:"class interface",relevance:0,end:/[{;=]/,illegal:/[^\s:,]/,contains:[{beginKeywords:"where class"},d,I,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{beginKeywords:"namespace",relevance:0,end:/[{;=]/,illegal:/[^\s:]/,contains:[d,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{beginKeywords:"record",relevance:0,end:/[{;=]/,illegal:/[^\s:]/,contains:[d,I,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"meta",begin:"^\\s*\\[(?=[\\w])",excludeBegin:!0,end:"\\]",excludeEnd:!0,contains:[{className:"string",begin:/"/,end:/"/}]},{beginKeywords:"new return throw await else",relevance:0},{className:"function",begin:"("+F+"\\s+)+"+e.IDENT_RE+"\\s*(<[^=]+>\\s*)?\\(",returnBegin:!0,end:/\s*[{;=]/,excludeEnd:!0,keywords:o,contains:[{beginKeywords:n.join(" "),relevance:0},{begin:e.IDENT_RE+"\\s*(<[^=]+>\\s*)?\\(",returnBegin:!0,contains:[e.TITLE_MODE,I],relevance:0},{match:/\(\)/},{className:"params",begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:o,relevance:0,contains:[C,f,e.C_BLOCK_COMMENT_MODE]},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},J]}}const OC=e=>({IMPORTANT:{scope:"meta",begin:"!important"},BLOCK_COMMENT:e.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{scope:"number",begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}}),RC=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],MC=["defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],DC=[...RC,...MC],IC=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),LC=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),BC=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),PC=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse();function UC(e){const t=e.regex,n=OC(e),a={begin:/-(webkit|moz|ms|o)-(?=[a-z])/},l="and or not only",s=/@-?\w[\w]*(-\w+)*/,o="[a-zA-Z-][a-zA-Z0-9_-]*",d=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE];return{name:"CSS",case_insensitive:!0,illegal:/[=|'\$]/,keywords:{keyframePosition:"from to"},classNameAliases:{keyframePosition:"selector-tag"},contains:[n.BLOCK_COMMENT,a,n.CSS_NUMBER_MODE,{className:"selector-id",begin:/#[A-Za-z0-9_-]+/,relevance:0},{className:"selector-class",begin:"\\."+o,relevance:0},n.ATTRIBUTE_SELECTOR_MODE,{className:"selector-pseudo",variants:[{begin:":("+LC.join("|")+")"},{begin:":(:)?("+BC.join("|")+")"}]},n.CSS_VARIABLE,{className:"attribute",begin:"\\b("+PC.join("|")+")\\b"},{begin:/:/,end:/[;}{]/,contains:[n.BLOCK_COMMENT,n.HEXCOLOR,n.IMPORTANT,n.CSS_NUMBER_MODE,...d,{begin:/(url|data-uri)\(/,end:/\)/,relevance:0,keywords:{built_in:"url data-uri"},contains:[...d,{className:"string",begin:/[^)]/,endsWithParent:!0,excludeEnd:!0}]},n.FUNCTION_DISPATCH]},{begin:t.lookahead(/@/),end:"[{;]",relevance:0,illegal:/:/,contains:[{className:"keyword",begin:s},{begin:/\s/,endsWithParent:!0,excludeEnd:!0,relevance:0,keywords:{$pattern:/[a-z-]+/,keyword:l,attribute:IC.join(" ")},contains:[{begin:/[a-z-]+(?=:)/,className:"attribute"},...d,n.CSS_NUMBER_MODE]}]},{className:"selector-tag",begin:"\\b("+DC.join("|")+")\\b"}]}}function zC(e){const t=e.regex;return{name:"Diff",aliases:["patch"],contains:[{className:"meta",relevance:10,match:t.either(/^@@ +-\d+,\d+ +\+\d+,\d+ +@@/,/^\*\*\* +\d+,\d+ +\*\*\*\*$/,/^--- +\d+,\d+ +----$/)},{className:"comment",variants:[{begin:t.either(/Index: /,/^index/,/={3,}/,/^-{3}/,/^\*{3} /,/^\+{3}/,/^diff --git/),end:/$/},{match:/^\*{15}$/}]},{className:"addition",begin:/^\+/,end:/$/},{className:"deletion",begin:/^-/,end:/$/},{className:"addition",begin:/^!/,end:/$/}]}}function HC(e){const s={keyword:["break","case","chan","const","continue","default","defer","else","fallthrough","for","func","go","goto","if","import","interface","map","package","range","return","select","struct","switch","type","var"],type:["bool","byte","complex64","complex128","error","float32","float64","int8","int16","int32","int64","string","uint8","uint16","uint32","uint64","int","uint","uintptr","rune"],literal:["true","false","iota","nil"],built_in:["append","cap","close","complex","copy","imag","len","make","new","panic","print","println","real","recover","delete"]};return{name:"Go",aliases:["golang"],keywords:s,illegal:"</",contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{className:"string",variants:[e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,{begin:"`",end:"`"}]},{className:"number",variants:[{match:/-?\b0[xX]\.[a-fA-F0-9](_?[a-fA-F0-9])*[pP][+-]?\d(_?\d)*i?/,relevance:0},{match:/-?\b0[xX](_?[a-fA-F0-9])+((\.([a-fA-F0-9](_?[a-fA-F0-9])*)?)?[pP][+-]?\d(_?\d)*)?i?/,relevance:0},{match:/-?\b0[oO](_?[0-7])*i?/,relevance:0},{match:/-?\.\d(_?\d)*([eE][+-]?\d(_?\d)*)?i?/,relevance:0},{match:/-?\b\d(_?\d)*(\.(\d(_?\d)*)?)?([eE][+-]?\d(_?\d)*)?i?/,relevance:0}]},{begin:/:=/},{className:"function",beginKeywords:"func",end:"\\s*(\\{|$)",excludeEnd:!0,contains:[e.TITLE_MODE,{className:"params",begin:/\(/,end:/\)/,endsParent:!0,keywords:s,illegal:/["']/}]}]}}function FC(e){const t=e.regex,n=/[_A-Za-z][_0-9A-Za-z]*/;return{name:"GraphQL",aliases:["gql"],case_insensitive:!0,disableAutodetect:!1,keywords:{keyword:["query","mutation","subscription","type","input","schema","directive","interface","union","scalar","fragment","enum","on"],literal:["true","false","null"]},contains:[e.HASH_COMMENT_MODE,e.QUOTE_STRING_MODE,e.NUMBER_MODE,{scope:"punctuation",match:/[.]{3}/,relevance:0},{scope:"punctuation",begin:/[\!\(\)\:\=\[\]\{\|\}]{1}/,relevance:0},{scope:"variable",begin:/\$/,end:/\W/,excludeEnd:!0,relevance:0},{scope:"meta",match:/@\w+/,excludeEnd:!0},{scope:"symbol",begin:t.concat(n,t.lookahead(/\s*:/)),relevance:0}],illegal:[/[;<']/,/BEGIN/]}}function qC(e){const t=e.regex,n={className:"number",relevance:0,variants:[{begin:/([+-]+)?[\d]+_[\d_]+/},{begin:e.NUMBER_RE}]},a=e.COMMENT();a.variants=[{begin:/;/,end:/$/},{begin:/#/,end:/$/}];const l={className:"variable",variants:[{begin:/\$[\w\d"][\w\d_]*/},{begin:/\$\{(.*?)\}/}]},s={className:"literal",begin:/\bon|off|true|false|yes|no\b/},o={className:"string",contains:[e.BACKSLASH_ESCAPE],variants:[{begin:"'''",end:"'''",relevance:10},{begin:'"""',end:'"""',relevance:10},{begin:'"',end:'"'},{begin:"'",end:"'"}]},d={begin:/\[/,end:/\]/,contains:[a,s,l,o,n,"self"],relevance:0},f=/[A-Za-z0-9_-]+/,h=/"(\\"|[^"])*"/,p=/'[^']*'/,E=t.either(f,h,p),T=t.concat(E,"(\\s*\\.\\s*",E,")*",t.lookahead(/\s*=\s*[^#\s]/));return{name:"TOML, also INI",aliases:["toml"],case_insensitive:!0,illegal:/\S/,contains:[a,{className:"section",begin:/\[+/,end:/\]+/},{begin:T,className:"attr",starts:{end:/$/,contains:[a,d,s,l,o,n]}}]}}var vs="[0-9](_*[0-9])*",Q0=`\\.(${vs})`,Z0="[0-9a-fA-F](_*[0-9a-fA-F])*",Qb={className:"number",variants:[{begin:`(\\b(${vs})((${Q0})|\\.)?|(${Q0}))[eE][+-]?(${vs})[fFdD]?\\b`},{begin:`\\b(${vs})((${Q0})[fFdD]?\\b|\\.([fFdD]\\b)?)`},{begin:`(${Q0})[fFdD]?\\b`},{begin:`\\b(${vs})[fFdD]\\b`},{begin:`\\b0[xX]((${Z0})\\.?|(${Z0})?\\.(${Z0}))[pP][+-]?(${vs})[fFdD]?\\b`},{begin:"\\b(0|[1-9](_*[0-9])*)[lL]?\\b"},{begin:`\\b0[xX](${Z0})[lL]?\\b`},{begin:"\\b0(_*[0-7])*[lL]?\\b"},{begin:"\\b0[bB][01](_*[01])*[lL]?\\b"}],relevance:0};function T5(e,t,n){return n===-1?"":e.replace(t,a=>T5(e,t,n-1))}function YC(e){const t=e.regex,n="[À-ʸa-zA-Z_$][À-ʸa-zA-Z_$0-9]*",a=n+T5("(?:<"+n+"~~~(?:\\s*,\\s*"+n+"~~~)*>)?",/~~~/g,2),f={keyword:["synchronized","abstract","private","var","static","if","const ","for","while","strictfp","finally","protected","import","native","final","void","enum","else","break","transient","catch","instanceof","volatile","case","assert","package","default","public","try","switch","continue","throws","protected","public","private","module","requires","exports","do","sealed","yield","permits","goto","when"],literal:["false","true","null"],type:["char","boolean","long","float","int","byte","short","double"],built_in:["super","this"]},h={className:"meta",begin:"@"+n,contains:[{begin:/\(/,end:/\)/,contains:["self"]}]},p={className:"params",begin:/\(/,end:/\)/,keywords:f,relevance:0,contains:[e.C_BLOCK_COMMENT_MODE],endsParent:!0};return{name:"Java",aliases:["jsp"],keywords:f,illegal:/<\/|#/,contains:[e.COMMENT("/\\*\\*","\\*/",{relevance:0,contains:[{begin:/\w+@/,relevance:0},{className:"doctag",begin:"@[A-Za-z]+"}]}),{begin:/import java\.[a-z]+\./,keywords:"import",relevance:2},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,{begin:/"""/,end:/"""/,className:"string",contains:[e.BACKSLASH_ESCAPE]},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,{match:[/\b(?:class|interface|enum|extends|implements|new)/,/\s+/,n],className:{1:"keyword",3:"title.class"}},{match:/non-sealed/,scope:"keyword"},{begin:[t.concat(/(?!else)/,n),/\s+/,n,/\s+/,/=(?!=)/],className:{1:"type",3:"variable",5:"operator"}},{begin:[/record/,/\s+/,n],className:{1:"keyword",3:"title.class"},contains:[p,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{beginKeywords:"new throw return else",relevance:0},{begin:["(?:"+a+"\\s+)",e.UNDERSCORE_IDENT_RE,/\s*(?=\()/],className:{2:"title.function"},keywords:f,contains:[{className:"params",begin:/\(/,end:/\)/,keywords:f,relevance:0,contains:[h,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,Qb,e.C_BLOCK_COMMENT_MODE]},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},Qb,h]}}const Zb="[A-Za-z$_][0-9A-Za-z$_]*",GC=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends","using"],VC=["true","false","null","undefined","NaN","Infinity"],_5=["Object","Function","Boolean","Symbol","Math","Date","Number","BigInt","String","RegExp","Array","Float32Array","Float64Array","Int8Array","Uint8Array","Uint8ClampedArray","Int16Array","Int32Array","Uint16Array","Uint32Array","BigInt64Array","BigUint64Array","Set","Map","WeakSet","WeakMap","ArrayBuffer","SharedArrayBuffer","Atomics","DataView","JSON","Promise","Generator","GeneratorFunction","AsyncFunction","Reflect","Proxy","Intl","WebAssembly"],S5=["Error","EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],A5=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],KC=["arguments","this","super","console","window","document","localStorage","sessionStorage","module","global"],jC=[].concat(A5,_5,S5);function XC(e){const t=e.regex,n=(be,{after:ze})=>{const A="</"+be[0].slice(1);return be.input.indexOf(A,ze)!==-1},a=Zb,l={begin:"<>",end:"</>"},s=/<[A-Za-z0-9\\._:-]+\s*\/>/,o={begin:/<[A-Za-z0-9\\._:-]+/,end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(be,ze)=>{const A=be[0].length+be.index,te=be.input[A];if(te==="<"||te===","){ze.ignoreMatch();return}te===">"&&(n(be,{after:A})||ze.ignoreMatch());let ue;const R=be.input.substring(A);if(ue=R.match(/^\s*=/)){ze.ignoreMatch();return}if((ue=R.match(/^\s+extends\s+/))&&ue.index===0){ze.ignoreMatch();return}}},d={$pattern:Zb,keyword:GC,literal:VC,built_in:jC,"variable.language":KC},f="[0-9](_?[0-9])*",h=`\\.(${f})`,p="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",E={className:"number",variants:[{begin:`(\\b(${p})((${h})|\\.)?|(${h}))[eE][+-]?(${f})\\b`},{begin:`\\b(${p})\\b((${h})\\b|\\.)?|(${h})\\b`},{begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{begin:"\\b0[0-7]+n?\\b"}],relevance:0},T={className:"subst",begin:"\\$\\{",end:"\\}",keywords:d,contains:[]},v={begin:".?html`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,T],subLanguage:"xml"}},x={begin:".?css`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,T],subLanguage:"css"}},N={begin:".?gql`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,T],subLanguage:"graphql"}},D={className:"string",begin:"`",end:"`",contains:[e.BACKSLASH_ESCAPE,T]},I={className:"comment",variants:[e.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{begin:"(?=@[A-Za-z]+)",relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+"},{className:"type",begin:"\\{",end:"\\}",excludeEnd:!0,excludeBegin:!0,relevance:0},{className:"variable",begin:a+"(?=\\s*(-)|$)",endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]}),e.C_BLOCK_COMMENT_MODE,e.C_LINE_COMMENT_MODE]},F=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,v,x,N,D,{match:/\$\d+/},E];T.contains=F.concat({begin:/\{/,end:/\}/,keywords:d,contains:["self"].concat(F)});const J=[].concat(I,T.contains),K=J.concat([{begin:/(\s*)\(/,end:/\)/,keywords:d,contains:["self"].concat(J)}]),U={className:"params",begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:d,contains:K},le={variants:[{match:[/class/,/\s+/,a,/\s+/,/extends/,/\s+/,t.concat(a,"(",t.concat(/\./,a),")*")],scope:{1:"keyword",3:"title.class",5:"keyword",7:"title.class.inherited"}},{match:[/class/,/\s+/,a],scope:{1:"keyword",3:"title.class"}}]},ae={relevance:0,match:t.either(/\bJSON/,/\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,/\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,/\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/),className:"title.class",keywords:{_:[..._5,...S5]}},se={label:"use_strict",className:"meta",relevance:10,begin:/^\s*['"]use (strict|asm)['"]/},G={variants:[{match:[/function/,/\s+/,a,/(?=\s*\()/]},{match:[/function/,/\s*(?=\()/]}],className:{1:"keyword",3:"title.function"},label:"func.def",contains:[U],illegal:/%/},ge={relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,className:"variable.constant"};function ce(be){return t.concat("(?!",be.join("|"),")")}const Se={match:t.concat(/\b/,ce([...A5,"super","import"].map(be=>`${be}\\s*\\(`)),a,t.lookahead(/\s*\(/)),className:"title.function",relevance:0},fe={begin:t.concat(/\./,t.lookahead(t.concat(a,/(?![0-9A-Za-z$_(])/))),end:a,excludeBegin:!0,keywords:"prototype",className:"property",relevance:0},ye={match:[/get|set/,/\s+/,a,/(?=\()/],className:{1:"keyword",3:"title.function"},contains:[{begin:/\(\)/},U]},X="(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+e.UNDERSCORE_IDENT_RE+")\\s*=>",oe={match:[/const|var|let/,/\s+/,a,/\s*/,/=\s*/,/(async\s*)?/,t.lookahead(X)],keywords:"async",className:{1:"keyword",3:"title.function"},contains:[U]};return{name:"JavaScript",aliases:["js","jsx","mjs","cjs"],keywords:d,exports:{PARAMS_CONTAINS:K,CLASS_REFERENCE:ae},illegal:/#(?![$_A-z])/,contains:[e.SHEBANG({label:"shebang",binary:"node",relevance:5}),se,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,v,x,N,D,I,{match:/\$\d+/},E,ae,{scope:"attr",match:a+t.lookahead(":"),relevance:0},oe,{begin:"("+e.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",keywords:"return throw case",relevance:0,contains:[I,e.REGEXP_MODE,{className:"function",begin:X,returnBegin:!0,end:"\\s*=>",contains:[{className:"params",variants:[{begin:e.UNDERSCORE_IDENT_RE,relevance:0},{className:null,begin:/\(\s*\)/,skip:!0},{begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:d,contains:K}]}]},{begin:/,/,relevance:0},{match:/\s+/,relevance:0},{variants:[{begin:l.begin,end:l.end},{match:s},{begin:o.begin,"on:begin":o.isTrulyOpeningTag,end:o.end}],subLanguage:"xml",contains:[{begin:o.begin,end:o.end,skip:!0,contains:["self"]}]}]},G,{beginKeywords:"while if switch catch for"},{begin:"\\b(?!function)"+e.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",returnBegin:!0,label:"func.def",contains:[U,e.inherit(e.TITLE_MODE,{begin:a,className:"title.function"})]},{match:/\.\.\./,relevance:0},fe,{match:"\\$"+a,relevance:0},{match:[/\bconstructor(?=\s*\()/],className:{1:"title.function"},contains:[U]},Se,ge,le,ye,{match:/\$[(.]/}]}}function $C(e){const t={className:"attr",begin:/"(\\.|[^\\"\r\n])*"(?=\s*:)/,relevance:1.01},n={match:/[{}[\],:]/,className:"punctuation",relevance:0},a=["true","false","null"],l={scope:"literal",beginKeywords:a.join(" ")};return{name:"JSON",aliases:["jsonc"],keywords:{literal:a},contains:[t,n,e.QUOTE_STRING_MODE,l,e.C_NUMBER_MODE,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE],illegal:"\\S"}}var Ts="[0-9](_*[0-9])*",J0=`\\.(${Ts})`,ec="[0-9a-fA-F](_*[0-9a-fA-F])*",WC={className:"number",variants:[{begin:`(\\b(${Ts})((${J0})|\\.)?|(${J0}))[eE][+-]?(${Ts})[fFdD]?\\b`},{begin:`\\b(${Ts})((${J0})[fFdD]?\\b|\\.([fFdD]\\b)?)`},{begin:`(${J0})[fFdD]?\\b`},{begin:`\\b(${Ts})[fFdD]\\b`},{begin:`\\b0[xX]((${ec})\\.?|(${ec})?\\.(${ec}))[pP][+-]?(${Ts})[fFdD]?\\b`},{begin:"\\b(0|[1-9](_*[0-9])*)[lL]?\\b"},{begin:`\\b0[xX](${ec})[lL]?\\b`},{begin:"\\b0(_*[0-7])*[lL]?\\b"},{begin:"\\b0[bB][01](_*[01])*[lL]?\\b"}],relevance:0};function QC(e){const t={keyword:"abstract as val var vararg get set class object open private protected public noinline crossinline dynamic final enum if else do while for when throw try catch finally import package is in fun override companion reified inline lateinit init interface annotation data sealed internal infix operator out by constructor super tailrec where const inner suspend typealias external expect actual",built_in:"Byte Short Char Int Long Boolean Float Double Void Unit Nothing",literal:"true false null"},n={className:"keyword",begin:/\b(break|continue|return|this)\b/,starts:{contains:[{className:"symbol",begin:/@\w+/}]}},a={className:"symbol",begin:e.UNDERSCORE_IDENT_RE+"@"},l={className:"subst",begin:/\$\{/,end:/\}/,contains:[e.C_NUMBER_MODE]},s={className:"variable",begin:"\\$"+e.UNDERSCORE_IDENT_RE},o={className:"string",variants:[{begin:'"""',end:'"""(?=[^"])',contains:[s,l]},{begin:"'",end:"'",illegal:/\n/,contains:[e.BACKSLASH_ESCAPE]},{begin:'"',end:'"',illegal:/\n/,contains:[e.BACKSLASH_ESCAPE,s,l]}]};l.contains.push(o);const d={className:"meta",begin:"@(?:file|property|field|get|set|receiver|param|setparam|delegate)\\s*:(?:\\s*"+e.UNDERSCORE_IDENT_RE+")?"},f={className:"meta",begin:"@"+e.UNDERSCORE_IDENT_RE,contains:[{begin:/\(/,end:/\)/,contains:[e.inherit(o,{className:"string"}),"self"]}]},h=WC,p=e.COMMENT("/\\*","\\*/",{contains:[e.C_BLOCK_COMMENT_MODE]}),E={variants:[{className:"type",begin:e.UNDERSCORE_IDENT_RE},{begin:/\(/,end:/\)/,contains:[]}]},T=E;return T.variants[1].contains=[E],E.variants[1].contains=[T],{name:"Kotlin",aliases:["kt","kts"],keywords:t,contains:[e.COMMENT("/\\*\\*","\\*/",{relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+"}]}),e.C_LINE_COMMENT_MODE,p,n,a,d,f,{className:"function",beginKeywords:"fun",end:"[(]|$",returnBegin:!0,excludeEnd:!0,keywords:t,relevance:5,contains:[{begin:e.UNDERSCORE_IDENT_RE+"\\s*\\(",returnBegin:!0,relevance:0,contains:[e.UNDERSCORE_TITLE_MODE]},{className:"type",begin:/</,end:/>/,keywords:"reified",relevance:0},{className:"params",begin:/\(/,end:/\)/,endsParent:!0,keywords:t,relevance:0,contains:[{begin:/:/,end:/[=,\/]/,endsWithParent:!0,contains:[E,e.C_LINE_COMMENT_MODE,p],relevance:0},e.C_LINE_COMMENT_MODE,p,d,f,o,e.C_NUMBER_MODE]},p]},{begin:[/class|interface|trait/,/\s+/,e.UNDERSCORE_IDENT_RE],beginScope:{3:"title.class"},keywords:"class interface trait",end:/[:\{(]|$/,excludeEnd:!0,illegal:"extends implements",contains:[{beginKeywords:"public protected internal private constructor"},e.UNDERSCORE_TITLE_MODE,{className:"type",begin:/</,end:/>/,excludeBegin:!0,excludeEnd:!0,relevance:0},{className:"type",begin:/[,:]\s*/,end:/[<\(,){\s]|$/,excludeBegin:!0,returnEnd:!0},d,f]},o,{className:"meta",begin:"^#!/usr/bin/env",end:"$",illegal:`
`},h]}}const ZC=e=>({IMPORTANT:{scope:"meta",begin:"!important"},BLOCK_COMMENT:e.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{scope:"number",begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}}),JC=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],eO=["defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],tO=[...JC,...eO],nO=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),x5=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),k5=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),rO=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse(),aO=x5.concat(k5).sort().reverse();function iO(e){const t=ZC(e),n=aO,a="and or not only",l="[\\w-]+",s="("+l+"|@\\{"+l+"\\})",o=[],d=[],f=function(F){return{className:"string",begin:"~?"+F+".*?"+F}},h=function(F,J,K){return{className:F,begin:J,relevance:K}},p={$pattern:/[a-z-]+/,keyword:a,attribute:nO.join(" ")},E={begin:"\\(",end:"\\)",contains:d,keywords:p,relevance:0};d.push(e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,f("'"),f('"'),t.CSS_NUMBER_MODE,{begin:"(url|data-uri)\\(",starts:{className:"string",end:"[\\)\\n]",excludeEnd:!0}},t.HEXCOLOR,E,h("variable","@@?"+l,10),h("variable","@\\{"+l+"\\}"),h("built_in","~?`[^`]*?`"),{className:"attribute",begin:l+"\\s*:",end:":",returnBegin:!0,excludeEnd:!0},t.IMPORTANT,{beginKeywords:"and not"},t.FUNCTION_DISPATCH);const T=d.concat({begin:/\{/,end:/\}/,contains:o}),v={beginKeywords:"when",endsWithParent:!0,contains:[{beginKeywords:"and not"}].concat(d)},x={begin:s+"\\s*:",returnBegin:!0,end:/[;}]/,relevance:0,contains:[{begin:/-(webkit|moz|ms|o)-/},t.CSS_VARIABLE,{className:"attribute",begin:"\\b("+rO.join("|")+")\\b",end:/(?=:)/,starts:{endsWithParent:!0,illegal:"[<=$]",relevance:0,contains:d}}]},N={className:"keyword",begin:"@(import|media|charset|font-face|(-[a-z]+-)?keyframes|supports|document|namespace|page|viewport|host)\\b",starts:{end:"[;{}]",keywords:p,returnEnd:!0,contains:d,relevance:0}},D={className:"variable",variants:[{begin:"@"+l+"\\s*:",relevance:15},{begin:"@"+l}],starts:{end:"[;}]",returnEnd:!0,contains:T}},C={variants:[{begin:"[\\.#:&\\[>]",end:"[;{}]"},{begin:s,end:/\{/}],returnBegin:!0,returnEnd:!0,illegal:`[<='$"]`,relevance:0,contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,v,h("keyword","all\\b"),h("variable","@\\{"+l+"\\}"),{begin:"\\b("+tO.join("|")+")\\b",className:"selector-tag"},t.CSS_NUMBER_MODE,h("selector-tag",s,0),h("selector-id","#"+s),h("selector-class","\\."+s,0),h("selector-tag","&",0),t.ATTRIBUTE_SELECTOR_MODE,{className:"selector-pseudo",begin:":("+x5.join("|")+")"},{className:"selector-pseudo",begin:":(:)?("+k5.join("|")+")"},{begin:/\(/,end:/\)/,relevance:0,contains:T},{begin:"!important"},t.FUNCTION_DISPATCH]},I={begin:l+`:(:)?(${n.join("|")})`,returnBegin:!0,contains:[C]};return o.push(e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,N,D,I,x,C,v,t.FUNCTION_DISPATCH),{name:"Less",case_insensitive:!0,illegal:`[=>'/<($"]`,contains:o}}function lO(e){const t="\\[=*\\[",n="\\]=*\\]",a={begin:t,end:n,contains:["self"]},l=[e.COMMENT("--(?!"+t+")","$"),e.COMMENT("--"+t,n,{contains:[a],relevance:10})];return{name:"Lua",aliases:["pluto"],keywords:{$pattern:e.UNDERSCORE_IDENT_RE,literal:"true false nil",keyword:"and break do else elseif end for goto if in local not or repeat return then until while",built_in:"_G _ENV _VERSION __index __newindex __mode __call __metatable __tostring __len __gc __add __sub __mul __div __mod __pow __concat __unm __eq __lt __le assert collectgarbage dofile error getfenv getmetatable ipairs load loadfile loadstring module next pairs pcall print rawequal rawget rawset require select setfenv setmetatable tonumber tostring type unpack xpcall arg self coroutine resume yield status wrap create running debug getupvalue debug sethook getmetatable gethook setmetatable setlocal traceback setfenv getinfo setupvalue getlocal getregistry getfenv io lines write close flush open output type read stderr stdin input stdout popen tmpfile math log max acos huge ldexp pi cos tanh pow deg tan cosh sinh random randomseed frexp ceil floor rad abs sqrt modf asin min mod fmod log10 atan2 exp sin atan os exit setlocale date getenv difftime remove time clock tmpname rename execute package preload loadlib loaded loaders cpath config path seeall string sub upper len gfind rep find match char dump gmatch reverse byte format gsub lower table setn insert getn foreachi maxn foreach concat sort remove"},contains:l.concat([{className:"function",beginKeywords:"function",end:"\\)",contains:[e.inherit(e.TITLE_MODE,{begin:"([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*"}),{className:"params",begin:"\\(",endsWithParent:!0,contains:l}].concat(l)},e.C_NUMBER_MODE,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,{className:"string",begin:t,end:n,contains:[a],relevance:5}])}}function sO(e){const t={className:"variable",variants:[{begin:"\\$\\("+e.UNDERSCORE_IDENT_RE+"\\)",contains:[e.BACKSLASH_ESCAPE]},{begin:/\$[@%<?\^\+\*]/}]},n={className:"string",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,t]},a={className:"variable",begin:/\$\([\w-]+\s/,end:/\)/,keywords:{built_in:"subst patsubst strip findstring filter filter-out sort word wordlist firstword lastword dir notdir suffix basename addsuffix addprefix join wildcard realpath abspath error warning shell origin flavor foreach if or and call eval file value"},contains:[t,n]},l={begin:"^"+e.UNDERSCORE_IDENT_RE+"\\s*(?=[:+?]?=)"},s={className:"meta",begin:/^\.PHONY:/,end:/$/,keywords:{$pattern:/[\.\w]+/,keyword:".PHONY"}},o={className:"section",begin:/^[^\s]+:/,end:/$/,contains:[t]};return{name:"Makefile",aliases:["mk","mak","make"],keywords:{$pattern:/[\w-]+/,keyword:"define endef undefine ifdef ifndef ifeq ifneq else endif include -include sinclude override export unexport private vpath"},contains:[e.HASH_COMMENT_MODE,t,n,a,l,s,o]}}function uO(e){const t=e.regex,n={begin:/<\/?[A-Za-z_]/,end:">",subLanguage:"xml",relevance:0},a={begin:"^[-\\*]{3,}",end:"$"},l={className:"code",variants:[{begin:"(`{3,})[^`](.|\\n)*?\\1`*[ ]*"},{begin:"(~{3,})[^~](.|\\n)*?\\1~*[ ]*"},{begin:"```",end:"```+[ ]*$"},{begin:"~~~",end:"~~~+[ ]*$"},{begin:"`.+?`"},{begin:"(?=^( {4}|\\t))",contains:[{begin:"^( {4}|\\t)",end:"(\\n)$"}],relevance:0}]},s={className:"bullet",begin:"^[ 	]*([*+-]|(\\d+\\.))(?=\\s+)",end:"\\s+",excludeEnd:!0},o={begin:/^\[[^\n]+\]:/,returnBegin:!0,contains:[{className:"symbol",begin:/\[/,end:/\]/,excludeBegin:!0,excludeEnd:!0},{className:"link",begin:/:\s*/,end:/$/,excludeBegin:!0}]},d=/[A-Za-z][A-Za-z0-9+.-]*/,f={variants:[{begin:/\[.+?\]\[.*?\]/,relevance:0},{begin:/\[.+?\]\(((data|javascript|mailto):|(?:http|ftp)s?:\/\/).*?\)/,relevance:2},{begin:t.concat(/\[.+?\]\(/,d,/:\/\/.*?\)/),relevance:2},{begin:/\[.+?\]\([./?&#].*?\)/,relevance:1},{begin:/\[.*?\]\(.*?\)/,relevance:0}],returnBegin:!0,contains:[{match:/\[(?=\])/},{className:"string",relevance:0,begin:"\\[",end:"\\]",excludeBegin:!0,returnEnd:!0},{className:"link",relevance:0,begin:"\\]\\(",end:"\\)",excludeBegin:!0,excludeEnd:!0},{className:"symbol",relevance:0,begin:"\\]\\[",end:"\\]",excludeBegin:!0,excludeEnd:!0}]},h={className:"strong",contains:[],variants:[{begin:/_{2}(?!\s)/,end:/_{2}/},{begin:/\*{2}(?!\s)/,end:/\*{2}/}]},p={className:"emphasis",contains:[],variants:[{begin:/\*(?![*\s])/,end:/\*/},{begin:/_(?![_\s])/,end:/_/,relevance:0}]},E=e.inherit(h,{contains:[]}),T=e.inherit(p,{contains:[]});h.contains.push(T),p.contains.push(E);let v=[n,f];return[h,p,E,T].forEach(C=>{C.contains=C.contains.concat(v)}),v=v.concat(h,p),{name:"Markdown",aliases:["md","mkdown","mkd"],contains:[{className:"section",variants:[{begin:"^#{1,6}",end:"$",contains:v},{begin:"(?=^.+?\\n[=-]{2,}$)",contains:[{begin:"^[=-]*$"},{begin:"^",end:"\\n",contains:v}]}]},n,s,h,p,{className:"quote",begin:"^>\\s+",contains:v,end:"$"},l,a,f,o,{scope:"literal",match:/&([a-zA-Z0-9]+|#[0-9]{1,7}|#[Xx][0-9a-fA-F]{1,6});/}]}}function oO(e){const t={className:"built_in",begin:"\\b(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)\\w+"},n=/[a-zA-Z@][a-zA-Z0-9_]*/,d={"variable.language":["this","super"],$pattern:n,keyword:["while","export","sizeof","typedef","const","struct","for","union","volatile","static","mutable","if","do","return","goto","enum","else","break","extern","asm","case","default","register","explicit","typename","switch","continue","inline","readonly","assign","readwrite","self","@synchronized","id","typeof","nonatomic","IBOutlet","IBAction","strong","weak","copy","in","out","inout","bycopy","byref","oneway","__strong","__weak","__block","__autoreleasing","@private","@protected","@public","@try","@property","@end","@throw","@catch","@finally","@autoreleasepool","@synthesize","@dynamic","@selector","@optional","@required","@encode","@package","@import","@defs","@compatibility_alias","__bridge","__bridge_transfer","__bridge_retained","__bridge_retain","__covariant","__contravariant","__kindof","_Nonnull","_Nullable","_Null_unspecified","__FUNCTION__","__PRETTY_FUNCTION__","__attribute__","getter","setter","retain","unsafe_unretained","nonnull","nullable","null_unspecified","null_resettable","class","instancetype","NS_DESIGNATED_INITIALIZER","NS_UNAVAILABLE","NS_REQUIRES_SUPER","NS_RETURNS_INNER_POINTER","NS_INLINE","NS_AVAILABLE","NS_DEPRECATED","NS_ENUM","NS_OPTIONS","NS_SWIFT_UNAVAILABLE","NS_ASSUME_NONNULL_BEGIN","NS_ASSUME_NONNULL_END","NS_REFINED_FOR_SWIFT","NS_SWIFT_NAME","NS_SWIFT_NOTHROW","NS_DURING","NS_HANDLER","NS_ENDHANDLER","NS_VALUERETURN","NS_VOIDRETURN"],literal:["false","true","FALSE","TRUE","nil","YES","NO","NULL"],built_in:["dispatch_once_t","dispatch_queue_t","dispatch_sync","dispatch_async","dispatch_once"],type:["int","float","char","unsigned","signed","short","long","double","wchar_t","unichar","void","bool","BOOL","id|0","_Bool"]},f={$pattern:n,keyword:["@interface","@class","@protocol","@implementation"]};return{name:"Objective-C",aliases:["mm","objc","obj-c","obj-c++","objective-c++"],keywords:d,illegal:"</",contains:[t,e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,e.C_NUMBER_MODE,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,{className:"string",variants:[{begin:'@"',end:'"',illegal:"\\n",contains:[e.BACKSLASH_ESCAPE]}]},{className:"meta",begin:/#\s*[a-z]+\b/,end:/$/,keywords:{keyword:"if else elif endif define undef warning error line pragma ifdef ifndef include"},contains:[{begin:/\\\n/,relevance:0},e.inherit(e.QUOTE_STRING_MODE,{className:"string"}),{className:"string",begin:/<.*?>/,end:/$/,illegal:"\\n"},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE]},{className:"class",begin:"("+f.keyword.join("|")+")\\b",end:/(\{|$)/,excludeEnd:!0,keywords:f,contains:[e.UNDERSCORE_TITLE_MODE]},{begin:"\\."+e.UNDERSCORE_IDENT_RE,relevance:0}]}}function cO(e){const t=e.regex,n=["abs","accept","alarm","and","atan2","bind","binmode","bless","break","caller","chdir","chmod","chomp","chop","chown","chr","chroot","class","close","closedir","connect","continue","cos","crypt","dbmclose","dbmopen","defined","delete","die","do","dump","each","else","elsif","endgrent","endhostent","endnetent","endprotoent","endpwent","endservent","eof","eval","exec","exists","exit","exp","fcntl","field","fileno","flock","for","foreach","fork","format","formline","getc","getgrent","getgrgid","getgrnam","gethostbyaddr","gethostbyname","gethostent","getlogin","getnetbyaddr","getnetbyname","getnetent","getpeername","getpgrp","getpriority","getprotobyname","getprotobynumber","getprotoent","getpwent","getpwnam","getpwuid","getservbyname","getservbyport","getservent","getsockname","getsockopt","given","glob","gmtime","goto","grep","gt","hex","if","index","int","ioctl","join","keys","kill","last","lc","lcfirst","length","link","listen","local","localtime","log","lstat","lt","ma","map","method","mkdir","msgctl","msgget","msgrcv","msgsnd","my","ne","next","no","not","oct","open","opendir","or","ord","our","pack","package","pipe","pop","pos","print","printf","prototype","push","q|0","qq","quotemeta","qw","qx","rand","read","readdir","readline","readlink","readpipe","recv","redo","ref","rename","require","reset","return","reverse","rewinddir","rindex","rmdir","say","scalar","seek","seekdir","select","semctl","semget","semop","send","setgrent","sethostent","setnetent","setpgrp","setpriority","setprotoent","setpwent","setservent","setsockopt","shift","shmctl","shmget","shmread","shmwrite","shutdown","sin","sleep","socket","socketpair","sort","splice","split","sprintf","sqrt","srand","stat","state","study","sub","substr","symlink","syscall","sysopen","sysread","sysseek","system","syswrite","tell","telldir","tie","tied","time","times","tr","truncate","uc","ucfirst","umask","undef","unless","unlink","unpack","unshift","untie","until","use","utime","values","vec","wait","waitpid","wantarray","warn","when","while","write","x|0","xor","y|0"],a=/[dualxmsipngr]{0,12}/,l={$pattern:/[\w.]+/,keyword:n.join(" ")},s={className:"subst",begin:"[$@]\\{",end:"\\}",keywords:l},o={begin:/->\{/,end:/\}/},d={scope:"attr",match:/\s+:\s*\w+(\s*\(.*?\))?/},f={scope:"variable",variants:[{begin:/\$\d/},{begin:t.concat(/[$%@](?!")(\^\w\b|#\w+(::\w+)*|\{\w+\}|\w+(::\w*)*)/,"(?![A-Za-z])(?![@$%])")},{begin:/[$%@](?!")[^\s\w{=]|\$=/,relevance:0}],contains:[d]},h={className:"number",variants:[{match:/0?\.[0-9][0-9_]+\b/},{match:/\bv?(0|[1-9][0-9_]*(\.[0-9_]+)?|[1-9][0-9_]*)\b/},{match:/\b0[0-7][0-7_]*\b/},{match:/\b0x[0-9a-fA-F][0-9a-fA-F_]*\b/},{match:/\b0b[0-1][0-1_]*\b/}],relevance:0},p=[e.BACKSLASH_ESCAPE,s,f],E=[/!/,/\//,/\|/,/\?/,/'/,/"/,/#/],T=(N,D,C="\\1")=>{const I=C==="\\1"?C:t.concat(C,D);return t.concat(t.concat("(?:",N,")"),D,/(?:\\.|[^\\\/])*?/,I,/(?:\\.|[^\\\/])*?/,C,a)},v=(N,D,C)=>t.concat(t.concat("(?:",N,")"),D,/(?:\\.|[^\\\/])*?/,C,a),x=[f,e.HASH_COMMENT_MODE,e.COMMENT(/^=\w/,/=cut/,{endsWithParent:!0}),o,{className:"string",contains:p,variants:[{begin:"q[qwxr]?\\s*\\(",end:"\\)",relevance:5},{begin:"q[qwxr]?\\s*\\[",end:"\\]",relevance:5},{begin:"q[qwxr]?\\s*\\{",end:"\\}",relevance:5},{begin:"q[qwxr]?\\s*\\|",end:"\\|",relevance:5},{begin:"q[qwxr]?\\s*<",end:">",relevance:5},{begin:"qw\\s+q",end:"q",relevance:5},{begin:"'",end:"'",contains:[e.BACKSLASH_ESCAPE]},{begin:'"',end:'"'},{begin:"`",end:"`",contains:[e.BACKSLASH_ESCAPE]},{begin:/\{\w+\}/,relevance:0},{begin:"-?\\w+\\s*=>",relevance:0}]},h,{begin:"(\\/\\/|"+e.RE_STARTERS_RE+"|\\b(split|return|print|reverse|grep)\\b)\\s*",keywords:"split return print reverse grep",relevance:0,contains:[e.HASH_COMMENT_MODE,{className:"regexp",variants:[{begin:T("s|tr|y",t.either(...E,{capture:!0}))},{begin:T("s|tr|y","\\(","\\)")},{begin:T("s|tr|y","\\[","\\]")},{begin:T("s|tr|y","\\{","\\}")}],relevance:2},{className:"regexp",variants:[{begin:/(m|qr)\/\//,relevance:0},{begin:v("(?:m|qr)?",/\//,/\//)},{begin:v("m|qr",t.either(...E,{capture:!0}),/\1/)},{begin:v("m|qr",/\(/,/\)/)},{begin:v("m|qr",/\[/,/\]/)},{begin:v("m|qr",/\{/,/\}/)}]}]},{className:"function",beginKeywords:"sub method",end:"(\\s*\\(.*?\\))?[;{]",excludeEnd:!0,relevance:5,contains:[e.TITLE_MODE,d]},{className:"class",beginKeywords:"class",end:"[;{]",excludeEnd:!0,relevance:5,contains:[e.TITLE_MODE,d,h]},{begin:"-\\w\\b",relevance:0},{begin:"^__DATA__$",end:"^__END__$",subLanguage:"mojolicious",contains:[{begin:"^@@.*",end:"$",className:"comment"}]}];return s.contains=x,o.contains=x,{name:"Perl",aliases:["pl","pm"],keywords:l,contains:x}}function dO(e){const t=e.regex,n=/(?![A-Za-z0-9])(?![$])/,a=t.concat(/[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/,n),l=t.concat(/(\\?[A-Z][a-z0-9_\x7f-\xff]+|\\?[A-Z]+(?=[A-Z][a-z0-9_\x7f-\xff])){1,}/,n),s=t.concat(/[A-Z]+/,n),o={scope:"variable",match:"\\$+"+a},d={scope:"meta",variants:[{begin:/<\?php/,relevance:10},{begin:/<\?=/},{begin:/<\?/,relevance:.1},{begin:/\?>/}]},f={scope:"subst",variants:[{begin:/\$\w+/},{begin:/\{\$/,end:/\}/}]},h=e.inherit(e.APOS_STRING_MODE,{illegal:null}),p=e.inherit(e.QUOTE_STRING_MODE,{illegal:null,contains:e.QUOTE_STRING_MODE.contains.concat(f)}),E={begin:/<<<[ \t]*(?:(\w+)|"(\w+)")\n/,end:/[ \t]*(\w+)\b/,contains:e.QUOTE_STRING_MODE.contains.concat(f),"on:begin":(fe,ye)=>{ye.data._beginMatch=fe[1]||fe[2]},"on:end":(fe,ye)=>{ye.data._beginMatch!==fe[1]&&ye.ignoreMatch()}},T=e.END_SAME_AS_BEGIN({begin:/<<<[ \t]*'(\w+)'\n/,end:/[ \t]*(\w+)\b/}),v=`[ 	
]`,x={scope:"string",variants:[p,h,E,T]},N={scope:"number",variants:[{begin:"\\b0[bB][01]+(?:_[01]+)*\\b"},{begin:"\\b0[oO][0-7]+(?:_[0-7]+)*\\b"},{begin:"\\b0[xX][\\da-fA-F]+(?:_[\\da-fA-F]+)*\\b"},{begin:"(?:\\b\\d+(?:_\\d+)*(\\.(?:\\d+(?:_\\d+)*))?|\\B\\.\\d+)(?:[eE][+-]?\\d+)?"}],relevance:0},D=["false","null","true"],C=["__CLASS__","__DIR__","__FILE__","__FUNCTION__","__COMPILER_HALT_OFFSET__","__LINE__","__METHOD__","__NAMESPACE__","__TRAIT__","die","echo","exit","include","include_once","print","require","require_once","array","abstract","and","as","binary","bool","boolean","break","callable","case","catch","class","clone","const","continue","declare","default","do","double","else","elseif","empty","enddeclare","endfor","endforeach","endif","endswitch","endwhile","enum","eval","extends","final","finally","float","for","foreach","from","global","goto","if","implements","instanceof","insteadof","int","integer","interface","isset","iterable","list","match|0","mixed","new","never","object","or","private","protected","public","readonly","real","return","string","switch","throw","trait","try","unset","use","var","void","while","xor","yield"],I=["Error|0","AppendIterator","ArgumentCountError","ArithmeticError","ArrayIterator","ArrayObject","AssertionError","BadFunctionCallException","BadMethodCallException","CachingIterator","CallbackFilterIterator","CompileError","Countable","DirectoryIterator","DivisionByZeroError","DomainException","EmptyIterator","ErrorException","Exception","FilesystemIterator","FilterIterator","GlobIterator","InfiniteIterator","InvalidArgumentException","IteratorIterator","LengthException","LimitIterator","LogicException","MultipleIterator","NoRewindIterator","OutOfBoundsException","OutOfRangeException","OuterIterator","OverflowException","ParentIterator","ParseError","RangeException","RecursiveArrayIterator","RecursiveCachingIterator","RecursiveCallbackFilterIterator","RecursiveDirectoryIterator","RecursiveFilterIterator","RecursiveIterator","RecursiveIteratorIterator","RecursiveRegexIterator","RecursiveTreeIterator","RegexIterator","RuntimeException","SeekableIterator","SplDoublyLinkedList","SplFileInfo","SplFileObject","SplFixedArray","SplHeap","SplMaxHeap","SplMinHeap","SplObjectStorage","SplObserver","SplPriorityQueue","SplQueue","SplStack","SplSubject","SplTempFileObject","TypeError","UnderflowException","UnexpectedValueException","UnhandledMatchError","ArrayAccess","BackedEnum","Closure","Fiber","Generator","Iterator","IteratorAggregate","Serializable","Stringable","Throwable","Traversable","UnitEnum","WeakReference","WeakMap","Directory","__PHP_Incomplete_Class","parent","php_user_filter","self","static","stdClass"],J={keyword:C,literal:(fe=>{const ye=[];return fe.forEach(X=>{ye.push(X),X.toLowerCase()===X?ye.push(X.toUpperCase()):ye.push(X.toLowerCase())}),ye})(D),built_in:I},K=fe=>fe.map(ye=>ye.replace(/\|\d+$/,"")),U={variants:[{match:[/new/,t.concat(v,"+"),t.concat("(?!",K(I).join("\\b|"),"\\b)"),l],scope:{1:"keyword",4:"title.class"}}]},le=t.concat(a,"\\b(?!\\()"),ae={variants:[{match:[t.concat(/::/,t.lookahead(/(?!class\b)/)),le],scope:{2:"variable.constant"}},{match:[/::/,/class/],scope:{2:"variable.language"}},{match:[l,t.concat(/::/,t.lookahead(/(?!class\b)/)),le],scope:{1:"title.class",3:"variable.constant"}},{match:[l,t.concat("::",t.lookahead(/(?!class\b)/))],scope:{1:"title.class"}},{match:[l,/::/,/class/],scope:{1:"title.class",3:"variable.language"}}]},se={scope:"attr",match:t.concat(a,t.lookahead(":"),t.lookahead(/(?!::)/))},G={relevance:0,begin:/\(/,end:/\)/,keywords:J,contains:[se,o,ae,e.C_BLOCK_COMMENT_MODE,x,N,U]},ge={relevance:0,match:[/\b/,t.concat("(?!fn\\b|function\\b|",K(C).join("\\b|"),"|",K(I).join("\\b|"),"\\b)"),a,t.concat(v,"*"),t.lookahead(/(?=\()/)],scope:{3:"title.function.invoke"},contains:[G]};G.contains.push(ge);const ce=[se,ae,e.C_BLOCK_COMMENT_MODE,x,N,U],Se={begin:t.concat(/#\[\s*\\?/,t.either(l,s)),beginScope:"meta",end:/]/,endScope:"meta",keywords:{literal:D,keyword:["new","array"]},contains:[{begin:/\[/,end:/]/,keywords:{literal:D,keyword:["new","array"]},contains:["self",...ce]},...ce,{scope:"meta",variants:[{match:l},{match:s}]}]};return{case_insensitive:!1,keywords:J,contains:[Se,e.HASH_COMMENT_MODE,e.COMMENT("//","$"),e.COMMENT("/\\*","\\*/",{contains:[{scope:"doctag",match:"@[A-Za-z]+"}]}),{match:/__halt_compiler\(\);/,keywords:"__halt_compiler",starts:{scope:"comment",end:e.MATCH_NOTHING_RE,contains:[{match:/\?>/,scope:"meta",endsParent:!0}]}},d,{scope:"variable.language",match:/\$this\b/},o,ge,ae,{match:[/const/,/\s/,a],scope:{1:"keyword",3:"variable.constant"}},U,{scope:"function",relevance:0,beginKeywords:"fn function",end:/[;{]/,excludeEnd:!0,illegal:"[$%\\[]",contains:[{beginKeywords:"use"},e.UNDERSCORE_TITLE_MODE,{begin:"=>",endsParent:!0},{scope:"params",begin:"\\(",end:"\\)",excludeBegin:!0,excludeEnd:!0,keywords:J,contains:["self",Se,o,ae,e.C_BLOCK_COMMENT_MODE,x,N]}]},{scope:"class",variants:[{beginKeywords:"enum",illegal:/[($"]/},{beginKeywords:"class interface trait",illegal:/[:($"]/}],relevance:0,end:/\{/,excludeEnd:!0,contains:[{beginKeywords:"extends implements"},e.UNDERSCORE_TITLE_MODE]},{beginKeywords:"namespace",relevance:0,end:";",illegal:/[.']/,contains:[e.inherit(e.UNDERSCORE_TITLE_MODE,{scope:"title.class"})]},{beginKeywords:"use",relevance:0,end:";",contains:[{match:/\b(as|const|function)\b/,scope:"keyword"},e.UNDERSCORE_TITLE_MODE]},x,N]}}function fO(e){return{name:"PHP template",subLanguage:"xml",contains:[{begin:/<\?(php|=)?/,end:/\?>/,subLanguage:"php",contains:[{begin:"/\\*",end:"\\*/",skip:!0},{begin:'b"',end:'"',skip:!0},{begin:"b'",end:"'",skip:!0},e.inherit(e.APOS_STRING_MODE,{illegal:null,className:null,contains:null,skip:!0}),e.inherit(e.QUOTE_STRING_MODE,{illegal:null,className:null,contains:null,skip:!0})]}]}}function hO(e){return{name:"Plain text",aliases:["text","txt"],disableAutodetect:!0}}function mO(e){const t=e.regex,n=new RegExp("[\\p{XID_Start}_]\\p{XID_Continue}*","u"),a=["and","as","assert","async","await","break","case","class","continue","def","del","elif","else","except","finally","for","from","global","if","import","in","is","lambda","match","nonlocal|10","not","or","pass","raise","return","try","while","with","yield"],d={$pattern:/[A-Za-z]\w+|__\w+__/,keyword:a,built_in:["__import__","abs","all","any","ascii","bin","bool","breakpoint","bytearray","bytes","callable","chr","classmethod","compile","complex","delattr","dict","dir","divmod","enumerate","eval","exec","filter","float","format","frozenset","getattr","globals","hasattr","hash","help","hex","id","input","int","isinstance","issubclass","iter","len","list","locals","map","max","memoryview","min","next","object","oct","open","ord","pow","print","property","range","repr","reversed","round","set","setattr","slice","sorted","staticmethod","str","sum","super","tuple","type","vars","zip"],literal:["__debug__","Ellipsis","False","None","NotImplemented","True"],type:["Any","Callable","Coroutine","Dict","List","Literal","Generic","Optional","Sequence","Set","Tuple","Type","Union"]},f={className:"meta",begin:/^(>>>|\.\.\.) /},h={className:"subst",begin:/\{/,end:/\}/,keywords:d,illegal:/#/},p={begin:/\{\{/,relevance:0},E={className:"string",contains:[e.BACKSLASH_ESCAPE],variants:[{begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?'''/,end:/'''/,contains:[e.BACKSLASH_ESCAPE,f],relevance:10},{begin:/([uU]|[bB]|[rR]|[bB][rR]|[rR][bB])?"""/,end:/"""/,contains:[e.BACKSLASH_ESCAPE,f],relevance:10},{begin:/([fF][rR]|[rR][fF]|[fF])'''/,end:/'''/,contains:[e.BACKSLASH_ESCAPE,f,p,h]},{begin:/([fF][rR]|[rR][fF]|[fF])"""/,end:/"""/,contains:[e.BACKSLASH_ESCAPE,f,p,h]},{begin:/([uU]|[rR])'/,end:/'/,relevance:10},{begin:/([uU]|[rR])"/,end:/"/,relevance:10},{begin:/([bB]|[bB][rR]|[rR][bB])'/,end:/'/},{begin:/([bB]|[bB][rR]|[rR][bB])"/,end:/"/},{begin:/([fF][rR]|[rR][fF]|[fF])'/,end:/'/,contains:[e.BACKSLASH_ESCAPE,p,h]},{begin:/([fF][rR]|[rR][fF]|[fF])"/,end:/"/,contains:[e.BACKSLASH_ESCAPE,p,h]},e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},T="[0-9](_?[0-9])*",v=`(\\b(${T}))?\\.(${T})|\\b(${T})\\.`,x=`\\b|${a.join("|")}`,N={className:"number",relevance:0,variants:[{begin:`(\\b(${T})|(${v}))[eE][+-]?(${T})[jJ]?(?=${x})`},{begin:`(${v})[jJ]?`},{begin:`\\b([1-9](_?[0-9])*|0+(_?0)*)[lLjJ]?(?=${x})`},{begin:`\\b0[bB](_?[01])+[lL]?(?=${x})`},{begin:`\\b0[oO](_?[0-7])+[lL]?(?=${x})`},{begin:`\\b0[xX](_?[0-9a-fA-F])+[lL]?(?=${x})`},{begin:`\\b(${T})[jJ](?=${x})`}]},D={className:"comment",begin:t.lookahead(/# type:/),end:/$/,keywords:d,contains:[{begin:/# type:/},{begin:/#/,end:/\b\B/,endsWithParent:!0}]},C={className:"params",variants:[{className:"",begin:/\(\s*\)/,skip:!0},{begin:/\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:d,contains:["self",f,N,E,e.HASH_COMMENT_MODE]}]};return h.contains=[E,N,f],{name:"Python",aliases:["py","gyp","ipython"],unicodeRegex:!0,keywords:d,illegal:/(<\/|\?)|=>/,contains:[f,N,{scope:"variable.language",match:/\bself\b/},{beginKeywords:"if",relevance:0},{match:/\bor\b/,scope:"keyword"},E,D,e.HASH_COMMENT_MODE,{match:[/\bdef/,/\s+/,n],scope:{1:"keyword",3:"title.function"},contains:[C]},{variants:[{match:[/\bclass/,/\s+/,n,/\s*/,/\(\s*/,n,/\s*\)/]},{match:[/\bclass/,/\s+/,n]}],scope:{1:"keyword",3:"title.class",6:"title.class.inherited"}},{className:"meta",begin:/^[\t ]*@/,end:/(?=#)|$/,contains:[N,C,E]}]}}function pO(e){return{aliases:["pycon"],contains:[{className:"meta.prompt",starts:{end:/ |$/,starts:{end:"$",subLanguage:"python"}},variants:[{begin:/^>>>(?=[ ]|$)/},{begin:/^\.\.\.(?=[ ]|$)/}]}]}}function gO(e){const t=e.regex,n=/(?:(?:[a-zA-Z]|\.[._a-zA-Z])[._a-zA-Z0-9]*)|\.(?!\d)/,a=t.either(/0[xX][0-9a-fA-F]+\.[0-9a-fA-F]*[pP][+-]?\d+i?/,/0[xX][0-9a-fA-F]+(?:[pP][+-]?\d+)?[Li]?/,/(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?[Li]?/),l=/[=!<>:]=|\|\||&&|:::?|<-|<<-|->>|->|\|>|[-+*\/?!$&|:<=>@^~]|\*\*/,s=t.either(/[()]/,/[{}]/,/\[\[/,/[[\]]/,/\\/,/,/);return{name:"R",keywords:{$pattern:n,keyword:"function if in break next repeat else for while",literal:"NULL NA TRUE FALSE Inf NaN NA_integer_|10 NA_real_|10 NA_character_|10 NA_complex_|10",built_in:"LETTERS letters month.abb month.name pi T F abs acos acosh all any anyNA Arg as.call as.character as.complex as.double as.environment as.integer as.logical as.null.default as.numeric as.raw asin asinh atan atanh attr attributes baseenv browser c call ceiling class Conj cos cosh cospi cummax cummin cumprod cumsum digamma dim dimnames emptyenv exp expression floor forceAndCall gamma gc.time globalenv Im interactive invisible is.array is.atomic is.call is.character is.complex is.double is.environment is.expression is.finite is.function is.infinite is.integer is.language is.list is.logical is.matrix is.na is.name is.nan is.null is.numeric is.object is.pairlist is.raw is.recursive is.single is.symbol lazyLoadDBfetch length lgamma list log max min missing Mod names nargs nzchar oldClass on.exit pos.to.env proc.time prod quote range Re rep retracemem return round seq_along seq_len seq.int sign signif sin sinh sinpi sqrt standardGeneric substitute sum switch tan tanh tanpi tracemem trigamma trunc unclass untracemem UseMethod xtfrm"},contains:[e.COMMENT(/#'/,/$/,{contains:[{scope:"doctag",match:/@examples/,starts:{end:t.lookahead(t.either(/\n^#'\s*(?=@[a-zA-Z]+)/,/\n^(?!#')/)),endsParent:!0}},{scope:"doctag",begin:"@param",end:/$/,contains:[{scope:"variable",variants:[{match:n},{match:/`(?:\\.|[^`\\])+`/}],endsParent:!0}]},{scope:"doctag",match:/@[a-zA-Z]+/},{scope:"keyword",match:/\\[a-zA-Z]+/}]}),e.HASH_COMMENT_MODE,{scope:"string",contains:[e.BACKSLASH_ESCAPE],variants:[e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\(/,end:/\)(-*)"/}),e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\{/,end:/\}(-*)"/}),e.END_SAME_AS_BEGIN({begin:/[rR]"(-*)\[/,end:/\](-*)"/}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\(/,end:/\)(-*)'/}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\{/,end:/\}(-*)'/}),e.END_SAME_AS_BEGIN({begin:/[rR]'(-*)\[/,end:/\](-*)'/}),{begin:'"',end:'"',relevance:0},{begin:"'",end:"'",relevance:0}]},{relevance:0,variants:[{scope:{1:"operator",2:"number"},match:[l,a]},{scope:{1:"operator",2:"number"},match:[/%[^%]*%/,a]},{scope:{1:"punctuation",2:"number"},match:[s,a]},{scope:{2:"number"},match:[/[^a-zA-Z0-9._]|^/,a]}]},{scope:{3:"operator"},match:[n,/\s+/,/<-/,/\s+/]},{scope:"operator",relevance:0,variants:[{match:l},{match:/%[^%]*%/}]},{scope:"punctuation",relevance:0,match:s},{begin:"`",end:"`",contains:[{begin:/\\./}]}]}}function bO(e){const t=e.regex,n="([a-zA-Z_]\\w*[!?=]?|[-+~]@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?)",a=t.either(/\b([A-Z]+[a-z0-9]+)+/,/\b([A-Z]+[a-z0-9]+)+[A-Z]+/),l=t.concat(a,/(::\w+)*/),o={"variable.constant":["__FILE__","__LINE__","__ENCODING__"],"variable.language":["self","super"],keyword:["alias","and","begin","BEGIN","break","case","class","defined","do","else","elsif","end","END","ensure","for","if","in","module","next","not","or","redo","require","rescue","retry","return","then","undef","unless","until","when","while","yield",...["include","extend","prepend","public","private","protected","raise","throw"]],built_in:["proc","lambda","attr_accessor","attr_reader","attr_writer","define_method","private_constant","module_function"],literal:["true","false","nil"]},d={className:"doctag",begin:"@[A-Za-z]+"},f={begin:"#<",end:">"},h=[e.COMMENT("#","$",{contains:[d]}),e.COMMENT("^=begin","^=end",{contains:[d],relevance:10}),e.COMMENT("^__END__",e.MATCH_NOTHING_RE)],p={className:"subst",begin:/#\{/,end:/\}/,keywords:o},E={className:"string",contains:[e.BACKSLASH_ESCAPE,p],variants:[{begin:/'/,end:/'/},{begin:/"/,end:/"/},{begin:/`/,end:/`/},{begin:/%[qQwWx]?\(/,end:/\)/},{begin:/%[qQwWx]?\[/,end:/\]/},{begin:/%[qQwWx]?\{/,end:/\}/},{begin:/%[qQwWx]?</,end:/>/},{begin:/%[qQwWx]?\//,end:/\//},{begin:/%[qQwWx]?%/,end:/%/},{begin:/%[qQwWx]?-/,end:/-/},{begin:/%[qQwWx]?\|/,end:/\|/},{begin:/\B\?(\\\d{1,3})/},{begin:/\B\?(\\x[A-Fa-f0-9]{1,2})/},{begin:/\B\?(\\u\{?[A-Fa-f0-9]{1,6}\}?)/},{begin:/\B\?(\\M-\\C-|\\M-\\c|\\c\\M-|\\M-|\\C-\\M-)[\x20-\x7e]/},{begin:/\B\?\\(c|C-)[\x20-\x7e]/},{begin:/\B\?\\?\S/},{begin:t.concat(/<<[-~]?'?/,t.lookahead(/(\w+)(?=\W)[^\n]*\n(?:[^\n]*\n)*?\s*\1\b/)),contains:[e.END_SAME_AS_BEGIN({begin:/(\w+)/,end:/(\w+)/,contains:[e.BACKSLASH_ESCAPE,p]})]}]},T="[1-9](_?[0-9])*|0",v="[0-9](_?[0-9])*",x={className:"number",relevance:0,variants:[{begin:`\\b(${T})(\\.(${v}))?([eE][+-]?(${v})|r)?i?\\b`},{begin:"\\b0[dD][0-9](_?[0-9])*r?i?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*r?i?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*r?i?\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*r?i?\\b"},{begin:"\\b0(_?[0-7])+r?i?\\b"}]},N={variants:[{match:/\(\)/},{className:"params",begin:/\(/,end:/(?=\))/,excludeBegin:!0,endsParent:!0,keywords:o}]},U=[E,{variants:[{match:[/class\s+/,l,/\s+<\s+/,l]},{match:[/\b(class|module)\s+/,l]}],scope:{2:"title.class",4:"title.class.inherited"},keywords:o},{match:[/(include|extend)\s+/,l],scope:{2:"title.class"},keywords:o},{relevance:0,match:[l,/\.new[. (]/],scope:{1:"title.class"}},{relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,className:"variable.constant"},{relevance:0,match:a,scope:"title.class"},{match:[/def/,/\s+/,n],scope:{1:"keyword",3:"title.function"},contains:[N]},{begin:e.IDENT_RE+"::"},{className:"symbol",begin:e.UNDERSCORE_IDENT_RE+"(!|\\?)?:",relevance:0},{className:"symbol",begin:":(?!\\s)",contains:[E,{begin:n}],relevance:0},x,{className:"variable",begin:"(\\$\\W)|((\\$|@@?)(\\w+))(?=[^@$?])(?![A-Za-z])(?![@$?'])"},{className:"params",begin:/\|(?!=)/,end:/\|/,excludeBegin:!0,excludeEnd:!0,relevance:0,keywords:o},{begin:"("+e.RE_STARTERS_RE+"|unless)\\s*",keywords:"unless",contains:[{className:"regexp",contains:[e.BACKSLASH_ESCAPE,p],illegal:/\n/,variants:[{begin:"/",end:"/[a-z]*"},{begin:/%r\{/,end:/\}[a-z]*/},{begin:"%r\\(",end:"\\)[a-z]*"},{begin:"%r!",end:"![a-z]*"},{begin:"%r\\[",end:"\\][a-z]*"}]}].concat(f,h),relevance:0}].concat(f,h);p.contains=U,N.contains=U;const G=[{begin:/^\s*=>/,starts:{end:"$",contains:U}},{className:"meta.prompt",begin:"^("+"[>?]>"+"|"+"[\\w#]+\\(\\w+\\):\\d+:\\d+[>*]"+"|"+"(\\w+-)?\\d+\\.\\d+\\.\\d+(p\\d+)?[^\\d][^>]+>"+")(?=[ ])",starts:{end:"$",keywords:o,contains:U}}];return h.unshift(f),{name:"Ruby",aliases:["rb","gemspec","podspec","thor","irb"],keywords:o,illegal:/\/\*/,contains:[e.SHEBANG({binary:"ruby"})].concat(G).concat(h).concat(U)}}function EO(e){const t=e.regex,n=/(r#)?/,a=t.concat(n,e.UNDERSCORE_IDENT_RE),l=t.concat(n,e.IDENT_RE),s={className:"title.function.invoke",relevance:0,begin:t.concat(/\b/,/(?!let|for|while|if|else|match\b)/,l,t.lookahead(/\s*\(/))},o="([ui](8|16|32|64|128|size)|f(32|64))?",d=["abstract","as","async","await","become","box","break","const","continue","crate","do","dyn","else","enum","extern","false","final","fn","for","if","impl","in","let","loop","macro","match","mod","move","mut","override","priv","pub","ref","return","self","Self","static","struct","super","trait","true","try","type","typeof","union","unsafe","unsized","use","virtual","where","while","yield"],f=["true","false","Some","None","Ok","Err"],h=["drop ","Copy","Send","Sized","Sync","Drop","Fn","FnMut","FnOnce","ToOwned","Clone","Debug","PartialEq","PartialOrd","Eq","Ord","AsRef","AsMut","Into","From","Default","Iterator","Extend","IntoIterator","DoubleEndedIterator","ExactSizeIterator","SliceConcatExt","ToString","assert!","assert_eq!","bitflags!","bytes!","cfg!","col!","concat!","concat_idents!","debug_assert!","debug_assert_eq!","env!","eprintln!","panic!","file!","format!","format_args!","include_bytes!","include_str!","line!","local_data_key!","module_path!","option_env!","print!","println!","select!","stringify!","try!","unimplemented!","unreachable!","vec!","write!","writeln!","macro_rules!","assert_ne!","debug_assert_ne!"],p=["i8","i16","i32","i64","i128","isize","u8","u16","u32","u64","u128","usize","f32","f64","str","char","bool","Box","Option","Result","String","Vec"];return{name:"Rust",aliases:["rs"],keywords:{$pattern:e.IDENT_RE+"!?",type:p,keyword:d,literal:f,built_in:h},illegal:"</",contains:[e.C_LINE_COMMENT_MODE,e.COMMENT("/\\*","\\*/",{contains:["self"]}),e.inherit(e.QUOTE_STRING_MODE,{begin:/b?"/,illegal:null}),{className:"symbol",begin:/'[a-zA-Z_][a-zA-Z0-9_]*(?!')/},{scope:"string",variants:[{begin:/b?r(#*)"(.|\n)*?"\1(?!#)/},{begin:/b?'/,end:/'/,contains:[{scope:"char.escape",match:/\\('|\w|x\w{2}|u\w{4}|U\w{8})/}]}]},{className:"number",variants:[{begin:"\\b0b([01_]+)"+o},{begin:"\\b0o([0-7_]+)"+o},{begin:"\\b0x([A-Fa-f0-9_]+)"+o},{begin:"\\b(\\d[\\d_]*(\\.[0-9_]+)?([eE][+-]?[0-9_]+)?)"+o}],relevance:0},{begin:[/fn/,/\s+/,a],className:{1:"keyword",3:"title.function"}},{className:"meta",begin:"#!?\\[",end:"\\]",contains:[{className:"string",begin:/"/,end:/"/,contains:[e.BACKSLASH_ESCAPE]}]},{begin:[/let/,/\s+/,/(?:mut\s+)?/,a],className:{1:"keyword",3:"keyword",4:"variable"}},{begin:[/for/,/\s+/,a,/\s+/,/in/],className:{1:"keyword",3:"variable",5:"keyword"}},{begin:[/type/,/\s+/,a],className:{1:"keyword",3:"title.class"}},{begin:[/(?:trait|enum|struct|union|impl|for)/,/\s+/,a],className:{1:"keyword",3:"title.class"}},{begin:e.IDENT_RE+"::",keywords:{keyword:"Self",built_in:h,type:p}},{className:"punctuation",begin:"->"},s]}}const yO=e=>({IMPORTANT:{scope:"meta",begin:"!important"},BLOCK_COMMENT:e.C_BLOCK_COMMENT_MODE,HEXCOLOR:{scope:"number",begin:/#(([0-9a-fA-F]{3,4})|(([0-9a-fA-F]{2}){3,4}))\b/},FUNCTION_DISPATCH:{className:"built_in",begin:/[\w-]+(?=\()/},ATTRIBUTE_SELECTOR_MODE:{scope:"selector-attr",begin:/\[/,end:/\]/,illegal:"$",contains:[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]},CSS_NUMBER_MODE:{scope:"number",begin:e.NUMBER_RE+"(%|em|ex|ch|rem|vw|vh|vmin|vmax|cm|mm|in|pt|pc|px|deg|grad|rad|turn|s|ms|Hz|kHz|dpi|dpcm|dppx)?",relevance:0},CSS_VARIABLE:{className:"attr",begin:/--[A-Za-z_][A-Za-z0-9_-]*/}}),vO=["a","abbr","address","article","aside","audio","b","blockquote","body","button","canvas","caption","cite","code","dd","del","details","dfn","div","dl","dt","em","fieldset","figcaption","figure","footer","form","h1","h2","h3","h4","h5","h6","header","hgroup","html","i","iframe","img","input","ins","kbd","label","legend","li","main","mark","menu","nav","object","ol","optgroup","option","p","picture","q","quote","samp","section","select","source","span","strong","summary","sup","table","tbody","td","textarea","tfoot","th","thead","time","tr","ul","var","video"],TO=["defs","g","marker","mask","pattern","svg","switch","symbol","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feFlood","feGaussianBlur","feImage","feMerge","feMorphology","feOffset","feSpecularLighting","feTile","feTurbulence","linearGradient","radialGradient","stop","circle","ellipse","image","line","path","polygon","polyline","rect","text","use","textPath","tspan","foreignObject","clipPath"],_O=[...vO,...TO],SO=["any-hover","any-pointer","aspect-ratio","color","color-gamut","color-index","device-aspect-ratio","device-height","device-width","display-mode","forced-colors","grid","height","hover","inverted-colors","monochrome","orientation","overflow-block","overflow-inline","pointer","prefers-color-scheme","prefers-contrast","prefers-reduced-motion","prefers-reduced-transparency","resolution","scan","scripting","update","width","min-width","max-width","min-height","max-height"].sort().reverse(),AO=["active","any-link","blank","checked","current","default","defined","dir","disabled","drop","empty","enabled","first","first-child","first-of-type","fullscreen","future","focus","focus-visible","focus-within","has","host","host-context","hover","indeterminate","in-range","invalid","is","lang","last-child","last-of-type","left","link","local-link","not","nth-child","nth-col","nth-last-child","nth-last-col","nth-last-of-type","nth-of-type","only-child","only-of-type","optional","out-of-range","past","placeholder-shown","read-only","read-write","required","right","root","scope","target","target-within","user-invalid","valid","visited","where"].sort().reverse(),xO=["after","backdrop","before","cue","cue-region","first-letter","first-line","grammar-error","marker","part","placeholder","selection","slotted","spelling-error"].sort().reverse(),kO=["accent-color","align-content","align-items","align-self","alignment-baseline","all","anchor-name","animation","animation-composition","animation-delay","animation-direction","animation-duration","animation-fill-mode","animation-iteration-count","animation-name","animation-play-state","animation-range","animation-range-end","animation-range-start","animation-timeline","animation-timing-function","appearance","aspect-ratio","backdrop-filter","backface-visibility","background","background-attachment","background-blend-mode","background-clip","background-color","background-image","background-origin","background-position","background-position-x","background-position-y","background-repeat","background-size","baseline-shift","block-size","border","border-block","border-block-color","border-block-end","border-block-end-color","border-block-end-style","border-block-end-width","border-block-start","border-block-start-color","border-block-start-style","border-block-start-width","border-block-style","border-block-width","border-bottom","border-bottom-color","border-bottom-left-radius","border-bottom-right-radius","border-bottom-style","border-bottom-width","border-collapse","border-color","border-end-end-radius","border-end-start-radius","border-image","border-image-outset","border-image-repeat","border-image-slice","border-image-source","border-image-width","border-inline","border-inline-color","border-inline-end","border-inline-end-color","border-inline-end-style","border-inline-end-width","border-inline-start","border-inline-start-color","border-inline-start-style","border-inline-start-width","border-inline-style","border-inline-width","border-left","border-left-color","border-left-style","border-left-width","border-radius","border-right","border-right-color","border-right-style","border-right-width","border-spacing","border-start-end-radius","border-start-start-radius","border-style","border-top","border-top-color","border-top-left-radius","border-top-right-radius","border-top-style","border-top-width","border-width","bottom","box-align","box-decoration-break","box-direction","box-flex","box-flex-group","box-lines","box-ordinal-group","box-orient","box-pack","box-shadow","box-sizing","break-after","break-before","break-inside","caption-side","caret-color","clear","clip","clip-path","clip-rule","color","color-interpolation","color-interpolation-filters","color-profile","color-rendering","color-scheme","column-count","column-fill","column-gap","column-rule","column-rule-color","column-rule-style","column-rule-width","column-span","column-width","columns","contain","contain-intrinsic-block-size","contain-intrinsic-height","contain-intrinsic-inline-size","contain-intrinsic-size","contain-intrinsic-width","container","container-name","container-type","content","content-visibility","counter-increment","counter-reset","counter-set","cue","cue-after","cue-before","cursor","cx","cy","direction","display","dominant-baseline","empty-cells","enable-background","field-sizing","fill","fill-opacity","fill-rule","filter","flex","flex-basis","flex-direction","flex-flow","flex-grow","flex-shrink","flex-wrap","float","flood-color","flood-opacity","flow","font","font-display","font-family","font-feature-settings","font-kerning","font-language-override","font-optical-sizing","font-palette","font-size","font-size-adjust","font-smooth","font-smoothing","font-stretch","font-style","font-synthesis","font-synthesis-position","font-synthesis-small-caps","font-synthesis-style","font-synthesis-weight","font-variant","font-variant-alternates","font-variant-caps","font-variant-east-asian","font-variant-emoji","font-variant-ligatures","font-variant-numeric","font-variant-position","font-variation-settings","font-weight","forced-color-adjust","gap","glyph-orientation-horizontal","glyph-orientation-vertical","grid","grid-area","grid-auto-columns","grid-auto-flow","grid-auto-rows","grid-column","grid-column-end","grid-column-start","grid-gap","grid-row","grid-row-end","grid-row-start","grid-template","grid-template-areas","grid-template-columns","grid-template-rows","hanging-punctuation","height","hyphenate-character","hyphenate-limit-chars","hyphens","icon","image-orientation","image-rendering","image-resolution","ime-mode","initial-letter","initial-letter-align","inline-size","inset","inset-area","inset-block","inset-block-end","inset-block-start","inset-inline","inset-inline-end","inset-inline-start","isolation","justify-content","justify-items","justify-self","kerning","left","letter-spacing","lighting-color","line-break","line-height","line-height-step","list-style","list-style-image","list-style-position","list-style-type","margin","margin-block","margin-block-end","margin-block-start","margin-bottom","margin-inline","margin-inline-end","margin-inline-start","margin-left","margin-right","margin-top","margin-trim","marker","marker-end","marker-mid","marker-start","marks","mask","mask-border","mask-border-mode","mask-border-outset","mask-border-repeat","mask-border-slice","mask-border-source","mask-border-width","mask-clip","mask-composite","mask-image","mask-mode","mask-origin","mask-position","mask-repeat","mask-size","mask-type","masonry-auto-flow","math-depth","math-shift","math-style","max-block-size","max-height","max-inline-size","max-width","min-block-size","min-height","min-inline-size","min-width","mix-blend-mode","nav-down","nav-index","nav-left","nav-right","nav-up","none","normal","object-fit","object-position","offset","offset-anchor","offset-distance","offset-path","offset-position","offset-rotate","opacity","order","orphans","outline","outline-color","outline-offset","outline-style","outline-width","overflow","overflow-anchor","overflow-block","overflow-clip-margin","overflow-inline","overflow-wrap","overflow-x","overflow-y","overlay","overscroll-behavior","overscroll-behavior-block","overscroll-behavior-inline","overscroll-behavior-x","overscroll-behavior-y","padding","padding-block","padding-block-end","padding-block-start","padding-bottom","padding-inline","padding-inline-end","padding-inline-start","padding-left","padding-right","padding-top","page","page-break-after","page-break-before","page-break-inside","paint-order","pause","pause-after","pause-before","perspective","perspective-origin","place-content","place-items","place-self","pointer-events","position","position-anchor","position-visibility","print-color-adjust","quotes","r","resize","rest","rest-after","rest-before","right","rotate","row-gap","ruby-align","ruby-position","scale","scroll-behavior","scroll-margin","scroll-margin-block","scroll-margin-block-end","scroll-margin-block-start","scroll-margin-bottom","scroll-margin-inline","scroll-margin-inline-end","scroll-margin-inline-start","scroll-margin-left","scroll-margin-right","scroll-margin-top","scroll-padding","scroll-padding-block","scroll-padding-block-end","scroll-padding-block-start","scroll-padding-bottom","scroll-padding-inline","scroll-padding-inline-end","scroll-padding-inline-start","scroll-padding-left","scroll-padding-right","scroll-padding-top","scroll-snap-align","scroll-snap-stop","scroll-snap-type","scroll-timeline","scroll-timeline-axis","scroll-timeline-name","scrollbar-color","scrollbar-gutter","scrollbar-width","shape-image-threshold","shape-margin","shape-outside","shape-rendering","speak","speak-as","src","stop-color","stop-opacity","stroke","stroke-dasharray","stroke-dashoffset","stroke-linecap","stroke-linejoin","stroke-miterlimit","stroke-opacity","stroke-width","tab-size","table-layout","text-align","text-align-all","text-align-last","text-anchor","text-combine-upright","text-decoration","text-decoration-color","text-decoration-line","text-decoration-skip","text-decoration-skip-ink","text-decoration-style","text-decoration-thickness","text-emphasis","text-emphasis-color","text-emphasis-position","text-emphasis-style","text-indent","text-justify","text-orientation","text-overflow","text-rendering","text-shadow","text-size-adjust","text-transform","text-underline-offset","text-underline-position","text-wrap","text-wrap-mode","text-wrap-style","timeline-scope","top","touch-action","transform","transform-box","transform-origin","transform-style","transition","transition-behavior","transition-delay","transition-duration","transition-property","transition-timing-function","translate","unicode-bidi","user-modify","user-select","vector-effect","vertical-align","view-timeline","view-timeline-axis","view-timeline-inset","view-timeline-name","view-transition-name","visibility","voice-balance","voice-duration","voice-family","voice-pitch","voice-range","voice-rate","voice-stress","voice-volume","white-space","white-space-collapse","widows","width","will-change","word-break","word-spacing","word-wrap","writing-mode","x","y","z-index","zoom"].sort().reverse();function NO(e){const t=yO(e),n=xO,a=AO,l="@[a-z-]+",s="and or not only",d={className:"variable",begin:"(\\$"+"[a-zA-Z-][a-zA-Z0-9_-]*"+")\\b",relevance:0};return{name:"SCSS",case_insensitive:!0,illegal:"[=/|']",contains:[e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,t.CSS_NUMBER_MODE,{className:"selector-id",begin:"#[A-Za-z0-9_-]+",relevance:0},{className:"selector-class",begin:"\\.[A-Za-z0-9_-]+",relevance:0},t.ATTRIBUTE_SELECTOR_MODE,{className:"selector-tag",begin:"\\b("+_O.join("|")+")\\b",relevance:0},{className:"selector-pseudo",begin:":("+a.join("|")+")"},{className:"selector-pseudo",begin:":(:)?("+n.join("|")+")"},d,{begin:/\(/,end:/\)/,contains:[t.CSS_NUMBER_MODE]},t.CSS_VARIABLE,{className:"attribute",begin:"\\b("+kO.join("|")+")\\b"},{begin:"\\b(whitespace|wait|w-resize|visible|vertical-text|vertical-ideographic|uppercase|upper-roman|upper-alpha|underline|transparent|top|thin|thick|text|text-top|text-bottom|tb-rl|table-header-group|table-footer-group|sw-resize|super|strict|static|square|solid|small-caps|separate|se-resize|scroll|s-resize|rtl|row-resize|ridge|right|repeat|repeat-y|repeat-x|relative|progress|pointer|overline|outside|outset|oblique|nowrap|not-allowed|normal|none|nw-resize|no-repeat|no-drop|newspaper|ne-resize|n-resize|move|middle|medium|ltr|lr-tb|lowercase|lower-roman|lower-alpha|loose|list-item|line|line-through|line-edge|lighter|left|keep-all|justify|italic|inter-word|inter-ideograph|inside|inset|inline|inline-block|inherit|inactive|ideograph-space|ideograph-parenthesis|ideograph-numeric|ideograph-alpha|horizontal|hidden|help|hand|groove|fixed|ellipsis|e-resize|double|dotted|distribute|distribute-space|distribute-letter|distribute-all-lines|disc|disabled|default|decimal|dashed|crosshair|collapse|col-resize|circle|char|center|capitalize|break-word|break-all|bottom|both|bolder|bold|block|bidi-override|below|baseline|auto|always|all-scroll|absolute|table|table-cell)\\b"},{begin:/:/,end:/[;}{]/,relevance:0,contains:[t.BLOCK_COMMENT,d,t.HEXCOLOR,t.CSS_NUMBER_MODE,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,t.IMPORTANT,t.FUNCTION_DISPATCH]},{begin:"@(page|font-face)",keywords:{$pattern:l,keyword:"@page @font-face"}},{begin:"@",end:"[{;]",returnBegin:!0,keywords:{$pattern:/[a-z-]+/,keyword:s,attribute:SO.join(" ")},contains:[{begin:l,className:"keyword"},{begin:/[a-z-]+(?=:)/,className:"attribute"},d,e.QUOTE_STRING_MODE,e.APOS_STRING_MODE,t.HEXCOLOR,t.CSS_NUMBER_MODE]},t.FUNCTION_DISPATCH]}}function wO(e){return{name:"Shell Session",aliases:["console","shellsession"],contains:[{className:"meta.prompt",begin:/^\s{0,3}[/~\w\d[\]()@-]*[>%$#][ ]?/,starts:{end:/[^\\](?=\s*$)/,subLanguage:"bash"}}]}}function CO(e){const t=e.regex,n=e.COMMENT("--","$"),a={scope:"string",variants:[{begin:/'/,end:/'/,contains:[{match:/''/}]}]},l={begin:/"/,end:/"/,contains:[{match:/""/}]},s=["true","false","unknown"],o=["double precision","large object","with timezone","without timezone"],d=["bigint","binary","blob","boolean","char","character","clob","date","dec","decfloat","decimal","float","int","integer","interval","nchar","nclob","national","numeric","real","row","smallint","time","timestamp","varchar","varying","varbinary"],f=["add","asc","collation","desc","final","first","last","view"],h=["abs","acos","all","allocate","alter","and","any","are","array","array_agg","array_max_cardinality","as","asensitive","asin","asymmetric","at","atan","atomic","authorization","avg","begin","begin_frame","begin_partition","between","bigint","binary","blob","boolean","both","by","call","called","cardinality","cascaded","case","cast","ceil","ceiling","char","char_length","character","character_length","check","classifier","clob","close","coalesce","collate","collect","column","commit","condition","connect","constraint","contains","convert","copy","corr","corresponding","cos","cosh","count","covar_pop","covar_samp","create","cross","cube","cume_dist","current","current_catalog","current_date","current_default_transform_group","current_path","current_role","current_row","current_schema","current_time","current_timestamp","current_path","current_role","current_transform_group_for_type","current_user","cursor","cycle","date","day","deallocate","dec","decimal","decfloat","declare","default","define","delete","dense_rank","deref","describe","deterministic","disconnect","distinct","double","drop","dynamic","each","element","else","empty","end","end_frame","end_partition","end-exec","equals","escape","every","except","exec","execute","exists","exp","external","extract","false","fetch","filter","first_value","float","floor","for","foreign","frame_row","free","from","full","function","fusion","get","global","grant","group","grouping","groups","having","hold","hour","identity","in","indicator","initial","inner","inout","insensitive","insert","int","integer","intersect","intersection","interval","into","is","join","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","language","large","last_value","lateral","lead","leading","left","like","like_regex","listagg","ln","local","localtime","localtimestamp","log","log10","lower","match","match_number","match_recognize","matches","max","member","merge","method","min","minute","mod","modifies","module","month","multiset","national","natural","nchar","nclob","new","no","none","normalize","not","nth_value","ntile","null","nullif","numeric","octet_length","occurrences_regex","of","offset","old","omit","on","one","only","open","or","order","out","outer","over","overlaps","overlay","parameter","partition","pattern","per","percent","percent_rank","percentile_cont","percentile_disc","period","portion","position","position_regex","power","precedes","precision","prepare","primary","procedure","ptf","range","rank","reads","real","recursive","ref","references","referencing","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","release","result","return","returns","revoke","right","rollback","rollup","row","row_number","rows","running","savepoint","scope","scroll","search","second","seek","select","sensitive","session_user","set","show","similar","sin","sinh","skip","smallint","some","specific","specifictype","sql","sqlexception","sqlstate","sqlwarning","sqrt","start","static","stddev_pop","stddev_samp","submultiset","subset","substring","substring_regex","succeeds","sum","symmetric","system","system_time","system_user","table","tablesample","tan","tanh","then","time","timestamp","timezone_hour","timezone_minute","to","trailing","translate","translate_regex","translation","treat","trigger","trim","trim_array","true","truncate","uescape","union","unique","unknown","unnest","update","upper","user","using","value","values","value_of","var_pop","var_samp","varbinary","varchar","varying","versioning","when","whenever","where","width_bucket","window","with","within","without","year"],p=["abs","acos","array_agg","asin","atan","avg","cast","ceil","ceiling","coalesce","corr","cos","cosh","count","covar_pop","covar_samp","cume_dist","dense_rank","deref","element","exp","extract","first_value","floor","json_array","json_arrayagg","json_exists","json_object","json_objectagg","json_query","json_table","json_table_primitive","json_value","lag","last_value","lead","listagg","ln","log","log10","lower","max","min","mod","nth_value","ntile","nullif","percent_rank","percentile_cont","percentile_disc","position","position_regex","power","rank","regr_avgx","regr_avgy","regr_count","regr_intercept","regr_r2","regr_slope","regr_sxx","regr_sxy","regr_syy","row_number","sin","sinh","sqrt","stddev_pop","stddev_samp","substring","substring_regex","sum","tan","tanh","translate","translate_regex","treat","trim","trim_array","unnest","upper","value_of","var_pop","var_samp","width_bucket"],E=["current_catalog","current_date","current_default_transform_group","current_path","current_role","current_schema","current_transform_group_for_type","current_user","session_user","system_time","system_user","current_time","localtime","current_timestamp","localtimestamp"],T=["create table","insert into","primary key","foreign key","not null","alter table","add constraint","grouping sets","on overflow","character set","respect nulls","ignore nulls","nulls first","nulls last","depth first","breadth first"],v=p,x=[...h,...f].filter(K=>!p.includes(K)),N={scope:"variable",match:/@[a-z0-9][a-z0-9_]*/},D={scope:"operator",match:/[-+*/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?/,relevance:0},C={match:t.concat(/\b/,t.either(...v),/\s*\(/),relevance:0,keywords:{built_in:v}};function I(K){return t.concat(/\b/,t.either(...K.map(U=>U.replace(/\s+/,"\\s+"))),/\b/)}const F={scope:"keyword",match:I(T),relevance:0};function J(K,{exceptions:U,when:le}={}){const ae=le;return U=U||[],K.map(se=>se.match(/\|\d+$/)||U.includes(se)?se:ae(se)?`${se}|0`:se)}return{name:"SQL",case_insensitive:!0,illegal:/[{}]|<\//,keywords:{$pattern:/\b[\w\.]+/,keyword:J(x,{when:K=>K.length<3}),literal:s,type:d,built_in:E},contains:[{scope:"type",match:I(o)},F,C,N,a,l,e.C_NUMBER_MODE,e.C_BLOCK_COMMENT_MODE,n,D]}}function N5(e){return e?typeof e=="string"?e:e.source:null}function Qu(e){return qt("(?=",e,")")}function qt(...e){return e.map(n=>N5(n)).join("")}function OO(e){const t=e[e.length-1];return typeof t=="object"&&t.constructor===Object?(e.splice(e.length-1,1),t):{}}function ar(...e){return"("+(OO(e).capture?"":"?:")+e.map(a=>N5(a)).join("|")+")"}const Rm=e=>qt(/\b/,e,/\w$/.test(e)?/\b/:/\B/),RO=["Protocol","Type"].map(Rm),Jb=["init","self"].map(Rm),MO=["Any","Self"],Uh=["actor","any","associatedtype","async","await",/as\?/,/as!/,"as","borrowing","break","case","catch","class","consume","consuming","continue","convenience","copy","default","defer","deinit","didSet","distributed","do","dynamic","each","else","enum","extension","fallthrough",/fileprivate\(set\)/,"fileprivate","final","for","func","get","guard","if","import","indirect","infix",/init\?/,/init!/,"inout",/internal\(set\)/,"internal","in","is","isolated","nonisolated","lazy","let","macro","mutating","nonmutating",/open\(set\)/,"open","operator","optional","override","package","postfix","precedencegroup","prefix",/private\(set\)/,"private","protocol",/public\(set\)/,"public","repeat","required","rethrows","return","set","some","static","struct","subscript","super","switch","throws","throw",/try\?/,/try!/,"try","typealias",/unowned\(safe\)/,/unowned\(unsafe\)/,"unowned","var","weak","where","while","willSet"],e3=["false","nil","true"],DO=["assignment","associativity","higherThan","left","lowerThan","none","right"],IO=["#colorLiteral","#column","#dsohandle","#else","#elseif","#endif","#error","#file","#fileID","#fileLiteral","#filePath","#function","#if","#imageLiteral","#keyPath","#line","#selector","#sourceLocation","#warning"],t3=["abs","all","any","assert","assertionFailure","debugPrint","dump","fatalError","getVaList","isKnownUniquelyReferenced","max","min","numericCast","pointwiseMax","pointwiseMin","precondition","preconditionFailure","print","readLine","repeatElement","sequence","stride","swap","swift_unboxFromSwiftValueWithType","transcode","type","unsafeBitCast","unsafeDowncast","withExtendedLifetime","withUnsafeMutablePointer","withUnsafePointer","withVaList","withoutActuallyEscaping","zip"],w5=ar(/[/=\-+!*%<>&|^~?]/,/[\u00A1-\u00A7]/,/[\u00A9\u00AB]/,/[\u00AC\u00AE]/,/[\u00B0\u00B1]/,/[\u00B6\u00BB\u00BF\u00D7\u00F7]/,/[\u2016-\u2017]/,/[\u2020-\u2027]/,/[\u2030-\u203E]/,/[\u2041-\u2053]/,/[\u2055-\u205E]/,/[\u2190-\u23FF]/,/[\u2500-\u2775]/,/[\u2794-\u2BFF]/,/[\u2E00-\u2E7F]/,/[\u3001-\u3003]/,/[\u3008-\u3020]/,/[\u3030]/),C5=ar(w5,/[\u0300-\u036F]/,/[\u1DC0-\u1DFF]/,/[\u20D0-\u20FF]/,/[\uFE00-\uFE0F]/,/[\uFE20-\uFE2F]/),zh=qt(w5,C5,"*"),O5=ar(/[a-zA-Z_]/,/[\u00A8\u00AA\u00AD\u00AF\u00B2-\u00B5\u00B7-\u00BA]/,/[\u00BC-\u00BE\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF]/,/[\u0100-\u02FF\u0370-\u167F\u1681-\u180D\u180F-\u1DBF]/,/[\u1E00-\u1FFF]/,/[\u200B-\u200D\u202A-\u202E\u203F-\u2040\u2054\u2060-\u206F]/,/[\u2070-\u20CF\u2100-\u218F\u2460-\u24FF\u2776-\u2793]/,/[\u2C00-\u2DFF\u2E80-\u2FFF]/,/[\u3004-\u3007\u3021-\u302F\u3031-\u303F\u3040-\uD7FF]/,/[\uF900-\uFD3D\uFD40-\uFDCF\uFDF0-\uFE1F\uFE30-\uFE44]/,/[\uFE47-\uFEFE\uFF00-\uFFFD]/),Rc=ar(O5,/\d/,/[\u0300-\u036F\u1DC0-\u1DFF\u20D0-\u20FF\uFE20-\uFE2F]/),_a=qt(O5,Rc,"*"),tc=qt(/[A-Z]/,Rc,"*"),LO=["attached","autoclosure",qt(/convention\(/,ar("swift","block","c"),/\)/),"discardableResult","dynamicCallable","dynamicMemberLookup","escaping","freestanding","frozen","GKInspectable","IBAction","IBDesignable","IBInspectable","IBOutlet","IBSegueAction","inlinable","main","nonobjc","NSApplicationMain","NSCopying","NSManaged",qt(/objc\(/,_a,/\)/),"objc","objcMembers","propertyWrapper","requires_stored_property_inits","resultBuilder","Sendable","testable","UIApplicationMain","unchecked","unknown","usableFromInline","warn_unqualified_access"],BO=["iOS","iOSApplicationExtension","macOS","macOSApplicationExtension","macCatalyst","macCatalystApplicationExtension","watchOS","watchOSApplicationExtension","tvOS","tvOSApplicationExtension","swift"];function PO(e){const t={match:/\s+/,relevance:0},n=e.COMMENT("/\\*","\\*/",{contains:["self"]}),a=[e.C_LINE_COMMENT_MODE,n],l={match:[/\./,ar(...RO,...Jb)],className:{2:"keyword"}},s={match:qt(/\./,ar(...Uh)),relevance:0},o=Uh.filter(Ve=>typeof Ve=="string").concat(["_|0"]),d=Uh.filter(Ve=>typeof Ve!="string").concat(MO).map(Rm),f={variants:[{className:"keyword",match:ar(...d,...Jb)}]},h={$pattern:ar(/\b\w+/,/#\w+/),keyword:o.concat(IO),literal:e3},p=[l,s,f],E={match:qt(/\./,ar(...t3)),relevance:0},T={className:"built_in",match:qt(/\b/,ar(...t3),/(?=\()/)},v=[E,T],x={match:/->/,relevance:0},N={className:"operator",relevance:0,variants:[{match:zh},{match:`\\.(\\.|${C5})+`}]},D=[x,N],C="([0-9]_*)+",I="([0-9a-fA-F]_*)+",F={className:"number",relevance:0,variants:[{match:`\\b(${C})(\\.(${C}))?([eE][+-]?(${C}))?\\b`},{match:`\\b0x(${I})(\\.(${I}))?([pP][+-]?(${C}))?\\b`},{match:/\b0o([0-7]_*)+\b/},{match:/\b0b([01]_*)+\b/}]},J=(Ve="")=>({className:"subst",variants:[{match:qt(/\\/,Ve,/[0\\tnr"']/)},{match:qt(/\\/,Ve,/u\{[0-9a-fA-F]{1,8}\}/)}]}),K=(Ve="")=>({className:"subst",match:qt(/\\/,Ve,/[\t ]*(?:[\r\n]|\r\n)/)}),U=(Ve="")=>({className:"subst",label:"interpol",begin:qt(/\\/,Ve,/\(/),end:/\)/}),le=(Ve="")=>({begin:qt(Ve,/"""/),end:qt(/"""/,Ve),contains:[J(Ve),K(Ve),U(Ve)]}),ae=(Ve="")=>({begin:qt(Ve,/"/),end:qt(/"/,Ve),contains:[J(Ve),U(Ve)]}),se={className:"string",variants:[le(),le("#"),le("##"),le("###"),ae(),ae("#"),ae("##"),ae("###")]},G=[e.BACKSLASH_ESCAPE,{begin:/\[/,end:/\]/,relevance:0,contains:[e.BACKSLASH_ESCAPE]}],ge={begin:/\/[^\s](?=[^/\n]*\/)/,end:/\//,contains:G},ce=Ve=>{const At=qt(Ve,/\//),an=qt(/\//,Ve);return{begin:At,end:an,contains:[...G,{scope:"comment",begin:`#(?!.*${an})`,end:/$/}]}},Se={scope:"regexp",variants:[ce("###"),ce("##"),ce("#"),ge]},fe={match:qt(/`/,_a,/`/)},ye={className:"variable",match:/\$\d+/},X={className:"variable",match:`\\$${Rc}+`},oe=[fe,ye,X],be={match:/(@|#(un)?)available/,scope:"keyword",starts:{contains:[{begin:/\(/,end:/\)/,keywords:BO,contains:[...D,F,se]}]}},ze={scope:"keyword",match:qt(/@/,ar(...LO),Qu(ar(/\(/,/\s+/)))},A={scope:"meta",match:qt(/@/,_a)},te=[be,ze,A],ue={match:Qu(/\b[A-Z]/),relevance:0,contains:[{className:"type",match:qt(/(AV|CA|CF|CG|CI|CL|CM|CN|CT|MK|MP|MTK|MTL|NS|SCN|SK|UI|WK|XC)/,Rc,"+")},{className:"type",match:tc,relevance:0},{match:/[?!]+/,relevance:0},{match:/\.\.\./,relevance:0},{match:qt(/\s+&\s+/,Qu(tc)),relevance:0}]},R={begin:/</,end:/>/,keywords:h,contains:[...a,...p,...te,x,ue]};ue.contains.push(R);const De={match:qt(_a,/\s*:/),keywords:"_|0",relevance:0},Ge={begin:/\(/,end:/\)/,relevance:0,keywords:h,contains:["self",De,...a,Se,...p,...v,...D,F,se,...oe,...te,ue]},Le={begin:/</,end:/>/,keywords:"repeat each",contains:[...a,ue]},kt={begin:ar(Qu(qt(_a,/\s*:/)),Qu(qt(_a,/\s+/,_a,/\s*:/))),end:/:/,relevance:0,contains:[{className:"keyword",match:/\b_\b/},{className:"params",match:_a}]},it={begin:/\(/,end:/\)/,keywords:h,contains:[kt,...a,...p,...D,F,se,...te,ue,Ge],endsParent:!0,illegal:/["']/},Wt={match:[/(func|macro)/,/\s+/,ar(fe.match,_a,zh)],className:{1:"keyword",3:"title.function"},contains:[Le,it,t],illegal:[/\[/,/%/]},Pt={match:[/\b(?:subscript|init[?!]?)/,/\s*(?=[<(])/],className:{1:"keyword"},contains:[Le,it,t],illegal:/\[|%/},In={match:[/operator/,/\s+/,zh],className:{1:"keyword",3:"title"}},zr={begin:[/precedencegroup/,/\s+/,tc],className:{1:"keyword",3:"title"},contains:[ue],keywords:[...DO,...e3],end:/}/},vt={match:[/class\b/,/\s+/,/func\b/,/\s+/,/\b[A-Za-z_][A-Za-z0-9_]*\b/],scope:{1:"keyword",3:"keyword",5:"title.function"}},ht={match:[/class\b/,/\s+/,/var\b/],scope:{1:"keyword",3:"keyword"}},Ut={begin:[/(struct|protocol|class|extension|enum|actor)/,/\s+/,_a,/\s*/],beginScope:{1:"keyword",3:"title.class"},keywords:h,contains:[Le,...p,{begin:/:/,end:/\{/,keywords:h,contains:[{scope:"title.class.inherited",match:tc},...p],relevance:0}]};for(const Ve of se.variants){const At=Ve.contains.find(wt=>wt.label==="interpol");At.keywords=h;const an=[...p,...v,...D,F,se,...oe];At.contains=[...an,{begin:/\(/,end:/\)/,contains:["self",...an]}]}return{name:"Swift",keywords:h,contains:[...a,Wt,Pt,vt,ht,Ut,In,zr,{beginKeywords:"import",end:/$/,contains:[...a],relevance:0},Se,...p,...v,...D,F,se,...oe,...te,ue,Ge]}}const Mc="[A-Za-z$_][0-9A-Za-z$_]*",R5=["as","in","of","if","for","while","finally","var","new","function","do","return","void","else","break","catch","instanceof","with","throw","case","default","try","switch","continue","typeof","delete","let","yield","const","class","debugger","async","await","static","import","from","export","extends","using"],M5=["true","false","null","undefined","NaN","Infinity"],D5=["Object","Function","Boolean","Symbol","Math","Date","Number","BigInt","String","RegExp","Array","Float32Array","Float64Array","Int8Array","Uint8Array","Uint8ClampedArray","Int16Array","Int32Array","Uint16Array","Uint32Array","BigInt64Array","BigUint64Array","Set","Map","WeakSet","WeakMap","ArrayBuffer","SharedArrayBuffer","Atomics","DataView","JSON","Promise","Generator","GeneratorFunction","AsyncFunction","Reflect","Proxy","Intl","WebAssembly"],I5=["Error","EvalError","InternalError","RangeError","ReferenceError","SyntaxError","TypeError","URIError"],L5=["setInterval","setTimeout","clearInterval","clearTimeout","require","exports","eval","isFinite","isNaN","parseFloat","parseInt","decodeURI","decodeURIComponent","encodeURI","encodeURIComponent","escape","unescape"],B5=["arguments","this","super","console","window","document","localStorage","sessionStorage","module","global"],P5=[].concat(L5,D5,I5);function UO(e){const t=e.regex,n=(be,{after:ze})=>{const A="</"+be[0].slice(1);return be.input.indexOf(A,ze)!==-1},a=Mc,l={begin:"<>",end:"</>"},s=/<[A-Za-z0-9\\._:-]+\s*\/>/,o={begin:/<[A-Za-z0-9\\._:-]+/,end:/\/[A-Za-z0-9\\._:-]+>|\/>/,isTrulyOpeningTag:(be,ze)=>{const A=be[0].length+be.index,te=be.input[A];if(te==="<"||te===","){ze.ignoreMatch();return}te===">"&&(n(be,{after:A})||ze.ignoreMatch());let ue;const R=be.input.substring(A);if(ue=R.match(/^\s*=/)){ze.ignoreMatch();return}if((ue=R.match(/^\s+extends\s+/))&&ue.index===0){ze.ignoreMatch();return}}},d={$pattern:Mc,keyword:R5,literal:M5,built_in:P5,"variable.language":B5},f="[0-9](_?[0-9])*",h=`\\.(${f})`,p="0|[1-9](_?[0-9])*|0[0-7]*[89][0-9]*",E={className:"number",variants:[{begin:`(\\b(${p})((${h})|\\.)?|(${h}))[eE][+-]?(${f})\\b`},{begin:`\\b(${p})\\b((${h})\\b|\\.)?|(${h})\\b`},{begin:"\\b(0|[1-9](_?[0-9])*)n\\b"},{begin:"\\b0[xX][0-9a-fA-F](_?[0-9a-fA-F])*n?\\b"},{begin:"\\b0[bB][0-1](_?[0-1])*n?\\b"},{begin:"\\b0[oO][0-7](_?[0-7])*n?\\b"},{begin:"\\b0[0-7]+n?\\b"}],relevance:0},T={className:"subst",begin:"\\$\\{",end:"\\}",keywords:d,contains:[]},v={begin:".?html`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,T],subLanguage:"xml"}},x={begin:".?css`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,T],subLanguage:"css"}},N={begin:".?gql`",end:"",starts:{end:"`",returnEnd:!1,contains:[e.BACKSLASH_ESCAPE,T],subLanguage:"graphql"}},D={className:"string",begin:"`",end:"`",contains:[e.BACKSLASH_ESCAPE,T]},I={className:"comment",variants:[e.COMMENT(/\/\*\*(?!\/)/,"\\*/",{relevance:0,contains:[{begin:"(?=@[A-Za-z]+)",relevance:0,contains:[{className:"doctag",begin:"@[A-Za-z]+"},{className:"type",begin:"\\{",end:"\\}",excludeEnd:!0,excludeBegin:!0,relevance:0},{className:"variable",begin:a+"(?=\\s*(-)|$)",endsParent:!0,relevance:0},{begin:/(?=[^\n])\s/,relevance:0}]}]}),e.C_BLOCK_COMMENT_MODE,e.C_LINE_COMMENT_MODE]},F=[e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,v,x,N,D,{match:/\$\d+/},E];T.contains=F.concat({begin:/\{/,end:/\}/,keywords:d,contains:["self"].concat(F)});const J=[].concat(I,T.contains),K=J.concat([{begin:/(\s*)\(/,end:/\)/,keywords:d,contains:["self"].concat(J)}]),U={className:"params",begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:d,contains:K},le={variants:[{match:[/class/,/\s+/,a,/\s+/,/extends/,/\s+/,t.concat(a,"(",t.concat(/\./,a),")*")],scope:{1:"keyword",3:"title.class",5:"keyword",7:"title.class.inherited"}},{match:[/class/,/\s+/,a],scope:{1:"keyword",3:"title.class"}}]},ae={relevance:0,match:t.either(/\bJSON/,/\b[A-Z][a-z]+([A-Z][a-z]*|\d)*/,/\b[A-Z]{2,}([A-Z][a-z]+|\d)+([A-Z][a-z]*)*/,/\b[A-Z]{2,}[a-z]+([A-Z][a-z]+|\d)*([A-Z][a-z]*)*/),className:"title.class",keywords:{_:[...D5,...I5]}},se={label:"use_strict",className:"meta",relevance:10,begin:/^\s*['"]use (strict|asm)['"]/},G={variants:[{match:[/function/,/\s+/,a,/(?=\s*\()/]},{match:[/function/,/\s*(?=\()/]}],className:{1:"keyword",3:"title.function"},label:"func.def",contains:[U],illegal:/%/},ge={relevance:0,match:/\b[A-Z][A-Z_0-9]+\b/,className:"variable.constant"};function ce(be){return t.concat("(?!",be.join("|"),")")}const Se={match:t.concat(/\b/,ce([...L5,"super","import"].map(be=>`${be}\\s*\\(`)),a,t.lookahead(/\s*\(/)),className:"title.function",relevance:0},fe={begin:t.concat(/\./,t.lookahead(t.concat(a,/(?![0-9A-Za-z$_(])/))),end:a,excludeBegin:!0,keywords:"prototype",className:"property",relevance:0},ye={match:[/get|set/,/\s+/,a,/(?=\()/],className:{1:"keyword",3:"title.function"},contains:[{begin:/\(\)/},U]},X="(\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)|"+e.UNDERSCORE_IDENT_RE+")\\s*=>",oe={match:[/const|var|let/,/\s+/,a,/\s*/,/=\s*/,/(async\s*)?/,t.lookahead(X)],keywords:"async",className:{1:"keyword",3:"title.function"},contains:[U]};return{name:"JavaScript",aliases:["js","jsx","mjs","cjs"],keywords:d,exports:{PARAMS_CONTAINS:K,CLASS_REFERENCE:ae},illegal:/#(?![$_A-z])/,contains:[e.SHEBANG({label:"shebang",binary:"node",relevance:5}),se,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE,v,x,N,D,I,{match:/\$\d+/},E,ae,{scope:"attr",match:a+t.lookahead(":"),relevance:0},oe,{begin:"("+e.RE_STARTERS_RE+"|\\b(case|return|throw)\\b)\\s*",keywords:"return throw case",relevance:0,contains:[I,e.REGEXP_MODE,{className:"function",begin:X,returnBegin:!0,end:"\\s*=>",contains:[{className:"params",variants:[{begin:e.UNDERSCORE_IDENT_RE,relevance:0},{className:null,begin:/\(\s*\)/,skip:!0},{begin:/(\s*)\(/,end:/\)/,excludeBegin:!0,excludeEnd:!0,keywords:d,contains:K}]}]},{begin:/,/,relevance:0},{match:/\s+/,relevance:0},{variants:[{begin:l.begin,end:l.end},{match:s},{begin:o.begin,"on:begin":o.isTrulyOpeningTag,end:o.end}],subLanguage:"xml",contains:[{begin:o.begin,end:o.end,skip:!0,contains:["self"]}]}]},G,{beginKeywords:"while if switch catch for"},{begin:"\\b(?!function)"+e.UNDERSCORE_IDENT_RE+"\\([^()]*(\\([^()]*(\\([^()]*\\)[^()]*)*\\)[^()]*)*\\)\\s*\\{",returnBegin:!0,label:"func.def",contains:[U,e.inherit(e.TITLE_MODE,{begin:a,className:"title.function"})]},{match:/\.\.\./,relevance:0},fe,{match:"\\$"+a,relevance:0},{match:[/\bconstructor(?=\s*\()/],className:{1:"title.function"},contains:[U]},Se,ge,le,ye,{match:/\$[(.]/}]}}function zO(e){const t=e.regex,n=UO(e),a=Mc,l=["any","void","number","boolean","string","object","never","symbol","bigint","unknown"],s={begin:[/namespace/,/\s+/,e.IDENT_RE],beginScope:{1:"keyword",3:"title.class"}},o={beginKeywords:"interface",end:/\{/,excludeEnd:!0,keywords:{keyword:"interface extends",built_in:l},contains:[n.exports.CLASS_REFERENCE]},d={className:"meta",relevance:10,begin:/^\s*['"]use strict['"]/},f=["type","interface","public","private","protected","implements","declare","abstract","readonly","enum","override","satisfies"],h={$pattern:Mc,keyword:R5.concat(f),literal:M5,built_in:P5.concat(l),"variable.language":B5},p={className:"meta",begin:"@"+a},E=(N,D,C)=>{const I=N.contains.findIndex(F=>F.label===D);if(I===-1)throw new Error("can not find mode to replace");N.contains.splice(I,1,C)};Object.assign(n.keywords,h),n.exports.PARAMS_CONTAINS.push(p);const T=n.contains.find(N=>N.scope==="attr"),v=Object.assign({},T,{match:t.concat(a,t.lookahead(/\s*\?:/))});n.exports.PARAMS_CONTAINS.push([n.exports.CLASS_REFERENCE,T,v]),n.contains=n.contains.concat([p,s,o,v]),E(n,"shebang",e.SHEBANG()),E(n,"use_strict",d);const x=n.contains.find(N=>N.label==="func.def");return x.relevance=0,Object.assign(n,{name:"TypeScript",aliases:["ts","tsx","mts","cts"]}),n}function HO(e){const t=e.regex,n={className:"string",begin:/"(""|[^/n])"C\b/},a={className:"string",begin:/"/,end:/"/,illegal:/\n/,contains:[{begin:/""/}]},l=/\d{1,2}\/\d{1,2}\/\d{4}/,s=/\d{4}-\d{1,2}-\d{1,2}/,o=/(\d|1[012])(:\d+){0,2} *(AM|PM)/,d=/\d{1,2}(:\d{1,2}){1,2}/,f={className:"literal",variants:[{begin:t.concat(/# */,t.either(s,l),/ *#/)},{begin:t.concat(/# */,d,/ *#/)},{begin:t.concat(/# */,o,/ *#/)},{begin:t.concat(/# */,t.either(s,l),/ +/,t.either(o,d),/ *#/)}]},h={className:"number",relevance:0,variants:[{begin:/\b\d[\d_]*((\.[\d_]+(E[+-]?[\d_]+)?)|(E[+-]?[\d_]+))[RFD@!#]?/},{begin:/\b\d[\d_]*((U?[SIL])|[%&])?/},{begin:/&H[\dA-F_]+((U?[SIL])|[%&])?/},{begin:/&O[0-7_]+((U?[SIL])|[%&])?/},{begin:/&B[01_]+((U?[SIL])|[%&])?/}]},p={className:"label",begin:/^\w+:/},E=e.COMMENT(/'''/,/$/,{contains:[{className:"doctag",begin:/<\/?/,end:/>/}]}),T=e.COMMENT(null,/$/,{variants:[{begin:/'/},{begin:/([\t ]|^)REM(?=\s)/}]});return{name:"Visual Basic .NET",aliases:["vb"],case_insensitive:!0,classNameAliases:{label:"symbol"},keywords:{keyword:"addhandler alias aggregate ansi as async assembly auto binary by byref byval call case catch class compare const continue custom declare default delegate dim distinct do each equals else elseif end enum erase error event exit explicit finally for friend from function get global goto group handles if implements imports in inherits interface into iterator join key let lib loop me mid module mustinherit mustoverride mybase myclass namespace narrowing new next notinheritable notoverridable of off on operator option optional order overloads overridable overrides paramarray partial preserve private property protected public raiseevent readonly redim removehandler resume return select set shadows shared skip static step stop structure strict sub synclock take text then throw to try unicode until using when where while widening with withevents writeonly yield",built_in:"addressof and andalso await directcast gettype getxmlnamespace is isfalse isnot istrue like mod nameof new not or orelse trycast typeof xor cbool cbyte cchar cdate cdbl cdec cint clng cobj csbyte cshort csng cstr cuint culng cushort",type:"boolean byte char date decimal double integer long object sbyte short single string uinteger ulong ushort",literal:"true false nothing"},illegal:"//|\\{|\\}|endif|gosub|variant|wend|^\\$ ",contains:[n,a,f,h,p,E,T,{className:"meta",begin:/[\t ]*#(const|disable|else|elseif|enable|end|externalsource|if|region)\b/,end:/$/,keywords:{keyword:"const disable else elseif enable end externalsource if region then"},contains:[T]}]}}function FO(e){e.regex;const t=e.COMMENT(/\(;/,/;\)/);t.contains.push("self");const n=e.COMMENT(/;;/,/$/),a=["anyfunc","block","br","br_if","br_table","call","call_indirect","data","drop","elem","else","end","export","func","global.get","global.set","local.get","local.set","local.tee","get_global","get_local","global","if","import","local","loop","memory","memory.grow","memory.size","module","mut","nop","offset","param","result","return","select","set_global","set_local","start","table","tee_local","then","type","unreachable"],l={begin:[/(?:func|call|call_indirect)/,/\s+/,/\$[^\s)]+/],className:{1:"keyword",3:"title.function"}},s={className:"variable",begin:/\$[\w_]+/},o={match:/(\((?!;)|\))+/,className:"punctuation",relevance:0},d={className:"number",relevance:0,match:/[+-]?\b(?:\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:[eE][+-]?\d(?:_?\d)*)?|0x[\da-fA-F](?:_?[\da-fA-F])*(?:\.[\da-fA-F](?:_?[\da-fA-D])*)?(?:[pP][+-]?\d(?:_?\d)*)?)\b|\binf\b|\bnan(?::0x[\da-fA-F](?:_?[\da-fA-D])*)?\b/},f={match:/(i32|i64|f32|f64)(?!\.)/,className:"type"},h={className:"keyword",match:/\b(f32|f64|i32|i64)(?:\.(?:abs|add|and|ceil|clz|const|convert_[su]\/i(?:32|64)|copysign|ctz|demote\/f64|div(?:_[su])?|eqz?|extend_[su]\/i32|floor|ge(?:_[su])?|gt(?:_[su])?|le(?:_[su])?|load(?:(?:8|16|32)_[su])?|lt(?:_[su])?|max|min|mul|nearest|neg?|or|popcnt|promote\/f32|reinterpret\/[fi](?:32|64)|rem_[su]|rot[lr]|shl|shr_[su]|store(?:8|16|32)?|sqrt|sub|trunc(?:_[su]\/f(?:32|64))?|wrap\/i64|xor))\b/};return{name:"WebAssembly",keywords:{$pattern:/[\w.]+/,keyword:a},contains:[n,t,{match:[/(?:offset|align)/,/\s*/,/=/],className:{1:"keyword",3:"operator"}},s,o,l,e.QUOTE_STRING_MODE,f,h,d]}}function qO(e){const t=e.regex,n=t.concat(/[\p{L}_]/u,t.optional(/[\p{L}0-9_.-]*:/u),/[\p{L}0-9_.-]*/u),a=/[\p{L}0-9._:-]+/u,l={className:"symbol",begin:/&[a-z]+;|&#[0-9]+;|&#x[a-f0-9]+;/},s={begin:/\s/,contains:[{className:"keyword",begin:/#?[a-z_][a-z1-9_-]+/,illegal:/\n/}]},o=e.inherit(s,{begin:/\(/,end:/\)/}),d=e.inherit(e.APOS_STRING_MODE,{className:"string"}),f=e.inherit(e.QUOTE_STRING_MODE,{className:"string"}),h={endsWithParent:!0,illegal:/</,relevance:0,contains:[{className:"attr",begin:a,relevance:0},{begin:/=\s*/,relevance:0,contains:[{className:"string",endsParent:!0,variants:[{begin:/"/,end:/"/,contains:[l]},{begin:/'/,end:/'/,contains:[l]},{begin:/[^\s"'=<>`]+/}]}]}]};return{name:"HTML, XML",aliases:["html","xhtml","rss","atom","xjb","xsd","xsl","plist","wsf","svg"],case_insensitive:!0,unicodeRegex:!0,contains:[{className:"meta",begin:/<![a-z]/,end:/>/,relevance:10,contains:[s,f,d,o,{begin:/\[/,end:/\]/,contains:[{className:"meta",begin:/<![a-z]/,end:/>/,contains:[s,o,f,d]}]}]},e.COMMENT(/<!--/,/-->/,{relevance:10}),{begin:/<!\[CDATA\[/,end:/\]\]>/,relevance:10},l,{className:"meta",end:/\?>/,variants:[{begin:/<\?xml/,relevance:10,contains:[f]},{begin:/<\?[a-z][a-z0-9]+/}]},{className:"tag",begin:/<style(?=\s|>)/,end:/>/,keywords:{name:"style"},contains:[h],starts:{end:/<\/style>/,returnEnd:!0,subLanguage:["css","xml"]}},{className:"tag",begin:/<script(?=\s|>)/,end:/>/,keywords:{name:"script"},contains:[h],starts:{end:/<\/script>/,returnEnd:!0,subLanguage:["javascript","handlebars","xml"]}},{className:"tag",begin:/<>|<\/>/},{className:"tag",begin:t.concat(/</,t.lookahead(t.concat(n,t.either(/\/>/,/>/,/\s/)))),end:/\/?>/,contains:[{className:"name",begin:n,relevance:0,starts:h}]},{className:"tag",begin:t.concat(/<\//,t.lookahead(t.concat(n,/>/))),contains:[{className:"name",begin:n,relevance:0},{begin:/>/,relevance:0,endsParent:!0}]}]}}function YO(e){const t="true false yes no null",n="[\\w#;/?:@&=+$,.~*'()[\\]]+",a={className:"attr",variants:[{begin:/[\w*@][\w*@ :()\./-]*:(?=[ \t]|$)/},{begin:/"[\w*@][\w*@ :()\./-]*":(?=[ \t]|$)/},{begin:/'[\w*@][\w*@ :()\./-]*':(?=[ \t]|$)/}]},l={className:"template-variable",variants:[{begin:/\{\{/,end:/\}\}/},{begin:/%\{/,end:/\}/}]},s={className:"string",relevance:0,begin:/'/,end:/'/,contains:[{match:/''/,scope:"char.escape",relevance:0}]},o={className:"string",relevance:0,variants:[{begin:/"/,end:/"/},{begin:/\S+/}],contains:[e.BACKSLASH_ESCAPE,l]},d=e.inherit(o,{variants:[{begin:/'/,end:/'/,contains:[{begin:/''/,relevance:0}]},{begin:/"/,end:/"/},{begin:/[^\s,{}[\]]+/}]}),T={className:"number",begin:"\\b"+"[0-9]{4}(-[0-9][0-9]){0,2}"+"([Tt \\t][0-9][0-9]?(:[0-9][0-9]){2})?"+"(\\.[0-9]*)?"+"([ \\t])*(Z|[-+][0-9][0-9]?(:[0-9][0-9])?)?"+"\\b"},v={end:",",endsWithParent:!0,excludeEnd:!0,keywords:t,relevance:0},x={begin:/\{/,end:/\}/,contains:[v],illegal:"\\n",relevance:0},N={begin:"\\[",end:"\\]",contains:[v],illegal:"\\n",relevance:0},D=[a,{className:"meta",begin:"^---\\s*$",relevance:10},{className:"string",begin:"[\\|>]([1-9]?[+-])?[ ]*\\n( +)[^ ][^\\n]*\\n(\\2[^\\n]+\\n?)*"},{begin:"<%[%=-]?",end:"[%-]?%>",subLanguage:"ruby",excludeBegin:!0,excludeEnd:!0,relevance:0},{className:"type",begin:"!\\w+!"+n},{className:"type",begin:"!<"+n+">"},{className:"type",begin:"!"+n},{className:"type",begin:"!!"+n},{className:"meta",begin:"&"+e.UNDERSCORE_IDENT_RE+"$"},{className:"meta",begin:"\\*"+e.UNDERSCORE_IDENT_RE+"$"},{className:"bullet",begin:"-(?=[ ]|$)",relevance:0},e.HASH_COMMENT_MODE,{beginKeywords:t,keywords:{literal:t}},T,{className:"number",begin:e.C_NUMBER_RE+"\\b",relevance:0},x,N,s,o],C=[...D];return C.pop(),C.push(d),v.contains=C,{name:"YAML",case_insensitive:!0,aliases:["yml"],contains:D}}const GO={arduino:xC,bash:kC,c:NC,cpp:wC,csharp:CC,css:UC,diff:zC,go:HC,graphql:FC,ini:qC,java:YC,javascript:XC,json:$C,kotlin:QC,less:iO,lua:lO,makefile:sO,markdown:uO,objectivec:oO,perl:cO,php:dO,"php-template":fO,plaintext:hO,python:mO,"python-repl":pO,r:gO,ruby:bO,rust:EO,scss:NO,shell:wO,sql:CO,swift:PO,typescript:zO,vbnet:HO,wasm:FO,xml:qO,yaml:YO};var Hh,n3;function VO(){if(n3)return Hh;n3=1;function e(q){return q instanceof Map?q.clear=q.delete=q.set=function(){throw new Error("map is read-only")}:q instanceof Set&&(q.add=q.clear=q.delete=function(){throw new Error("set is read-only")}),Object.freeze(q),Object.getOwnPropertyNames(q).forEach(me=>{const Me=q[me],nt=typeof Me;(nt==="object"||nt==="function")&&!Object.isFrozen(Me)&&e(Me)}),q}class t{constructor(me){me.data===void 0&&(me.data={}),this.data=me.data,this.isMatchIgnored=!1}ignoreMatch(){this.isMatchIgnored=!0}}function n(q){return q.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/'/g,"&#x27;")}function a(q,...me){const Me=Object.create(null);for(const nt in q)Me[nt]=q[nt];return me.forEach(function(nt){for(const Jt in nt)Me[Jt]=nt[Jt]}),Me}const l="</span>",s=q=>!!q.scope,o=(q,{prefix:me})=>{if(q.startsWith("language:"))return q.replace("language:","language-");if(q.includes(".")){const Me=q.split(".");return[`${me}${Me.shift()}`,...Me.map((nt,Jt)=>`${nt}${"_".repeat(Jt+1)}`)].join(" ")}return`${me}${q}`};class d{constructor(me,Me){this.buffer="",this.classPrefix=Me.classPrefix,me.walk(this)}addText(me){this.buffer+=n(me)}openNode(me){if(!s(me))return;const Me=o(me.scope,{prefix:this.classPrefix});this.span(Me)}closeNode(me){s(me)&&(this.buffer+=l)}value(){return this.buffer}span(me){this.buffer+=`<span class="${me}">`}}const f=(q={})=>{const me={children:[]};return Object.assign(me,q),me};class h{constructor(){this.rootNode=f(),this.stack=[this.rootNode]}get top(){return this.stack[this.stack.length-1]}get root(){return this.rootNode}add(me){this.top.children.push(me)}openNode(me){const Me=f({scope:me});this.add(Me),this.stack.push(Me)}closeNode(){if(this.stack.length>1)return this.stack.pop()}closeAllNodes(){for(;this.closeNode(););}toJSON(){return JSON.stringify(this.rootNode,null,4)}walk(me){return this.constructor._walk(me,this.rootNode)}static _walk(me,Me){return typeof Me=="string"?me.addText(Me):Me.children&&(me.openNode(Me),Me.children.forEach(nt=>this._walk(me,nt)),me.closeNode(Me)),me}static _collapse(me){typeof me!="string"&&me.children&&(me.children.every(Me=>typeof Me=="string")?me.children=[me.children.join("")]:me.children.forEach(Me=>{h._collapse(Me)}))}}class p extends h{constructor(me){super(),this.options=me}addText(me){me!==""&&this.add(me)}startScope(me){this.openNode(me)}endScope(){this.closeNode()}__addSublanguage(me,Me){const nt=me.root;Me&&(nt.scope=`language:${Me}`),this.add(nt)}toHTML(){return new d(this,this.options).value()}finalize(){return this.closeAllNodes(),!0}}function E(q){return q?typeof q=="string"?q:q.source:null}function T(q){return N("(?=",q,")")}function v(q){return N("(?:",q,")*")}function x(q){return N("(?:",q,")?")}function N(...q){return q.map(Me=>E(Me)).join("")}function D(q){const me=q[q.length-1];return typeof me=="object"&&me.constructor===Object?(q.splice(q.length-1,1),me):{}}function C(...q){return"("+(D(q).capture?"":"?:")+q.map(nt=>E(nt)).join("|")+")"}function I(q){return new RegExp(q.toString()+"|").exec("").length-1}function F(q,me){const Me=q&&q.exec(me);return Me&&Me.index===0}const J=/\[(?:[^\\\]]|\\.)*\]|\(\??|\\([1-9][0-9]*)|\\./;function K(q,{joinWith:me}){let Me=0;return q.map(nt=>{Me+=1;const Jt=Me;let ln=E(nt),Pe="";for(;ln.length>0;){const Re=J.exec(ln);if(!Re){Pe+=ln;break}Pe+=ln.substring(0,Re.index),ln=ln.substring(Re.index+Re[0].length),Re[0][0]==="\\"&&Re[1]?Pe+="\\"+String(Number(Re[1])+Jt):(Pe+=Re[0],Re[0]==="("&&Me++)}return Pe}).map(nt=>`(${nt})`).join(me)}const U=/\b\B/,le="[a-zA-Z]\\w*",ae="[a-zA-Z_]\\w*",se="\\b\\d+(\\.\\d+)?",G="(-?)(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)",ge="\\b(0b[01]+)",ce="!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~",Se=(q={})=>{const me=/^#![ ]*\//;return q.binary&&(q.begin=N(me,/.*\b/,q.binary,/\b.*/)),a({scope:"meta",begin:me,end:/$/,relevance:0,"on:begin":(Me,nt)=>{Me.index!==0&&nt.ignoreMatch()}},q)},fe={begin:"\\\\[\\s\\S]",relevance:0},ye={scope:"string",begin:"'",end:"'",illegal:"\\n",contains:[fe]},X={scope:"string",begin:'"',end:'"',illegal:"\\n",contains:[fe]},oe={begin:/\b(a|an|the|are|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|they|like|more)\b/},be=function(q,me,Me={}){const nt=a({scope:"comment",begin:q,end:me,contains:[]},Me);nt.contains.push({scope:"doctag",begin:"[ ]*(?=(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):)",end:/(TODO|FIXME|NOTE|BUG|OPTIMIZE|HACK|XXX):/,excludeBegin:!0,relevance:0});const Jt=C("I","a","is","so","us","to","at","if","in","it","on",/[A-Za-z]+['](d|ve|re|ll|t|s|n)/,/[A-Za-z]+[-][a-z]+/,/[A-Za-z][a-z]{2,}/);return nt.contains.push({begin:N(/[ ]+/,"(",Jt,/[.]?[:]?([.][ ]|[ ])/,"){3}")}),nt},ze=be("//","$"),A=be("/\\*","\\*/"),te=be("#","$"),ue={scope:"number",begin:se,relevance:0},R={scope:"number",begin:G,relevance:0},De={scope:"number",begin:ge,relevance:0},Ge={scope:"regexp",begin:/\/(?=[^/\n]*\/)/,end:/\/[gimuy]*/,contains:[fe,{begin:/\[/,end:/\]/,relevance:0,contains:[fe]}]},Le={scope:"title",begin:le,relevance:0},kt={scope:"title",begin:ae,relevance:0},it={begin:"\\.\\s*"+ae,relevance:0};var Pt=Object.freeze({__proto__:null,APOS_STRING_MODE:ye,BACKSLASH_ESCAPE:fe,BINARY_NUMBER_MODE:De,BINARY_NUMBER_RE:ge,COMMENT:be,C_BLOCK_COMMENT_MODE:A,C_LINE_COMMENT_MODE:ze,C_NUMBER_MODE:R,C_NUMBER_RE:G,END_SAME_AS_BEGIN:function(q){return Object.assign(q,{"on:begin":(me,Me)=>{Me.data._beginMatch=me[1]},"on:end":(me,Me)=>{Me.data._beginMatch!==me[1]&&Me.ignoreMatch()}})},HASH_COMMENT_MODE:te,IDENT_RE:le,MATCH_NOTHING_RE:U,METHOD_GUARD:it,NUMBER_MODE:ue,NUMBER_RE:se,PHRASAL_WORDS_MODE:oe,QUOTE_STRING_MODE:X,REGEXP_MODE:Ge,RE_STARTERS_RE:ce,SHEBANG:Se,TITLE_MODE:Le,UNDERSCORE_IDENT_RE:ae,UNDERSCORE_TITLE_MODE:kt});function In(q,me){q.input[q.index-1]==="."&&me.ignoreMatch()}function zr(q,me){q.className!==void 0&&(q.scope=q.className,delete q.className)}function vt(q,me){me&&q.beginKeywords&&(q.begin="\\b("+q.beginKeywords.split(" ").join("|")+")(?!\\.)(?=\\b|\\s)",q.__beforeBegin=In,q.keywords=q.keywords||q.beginKeywords,delete q.beginKeywords,q.relevance===void 0&&(q.relevance=0))}function ht(q,me){Array.isArray(q.illegal)&&(q.illegal=C(...q.illegal))}function Ut(q,me){if(q.match){if(q.begin||q.end)throw new Error("begin & end are not supported with match");q.begin=q.match,delete q.match}}function Ve(q,me){q.relevance===void 0&&(q.relevance=1)}const At=(q,me)=>{if(!q.beforeMatch)return;if(q.starts)throw new Error("beforeMatch cannot be used with starts");const Me=Object.assign({},q);Object.keys(q).forEach(nt=>{delete q[nt]}),q.keywords=Me.keywords,q.begin=N(Me.beforeMatch,T(Me.begin)),q.starts={relevance:0,contains:[Object.assign(Me,{endsParent:!0})]},q.relevance=0,delete Me.beforeMatch},an=["of","and","for","in","not","or","if","then","parent","list","value"],wt="keyword";function Zt(q,me,Me=wt){const nt=Object.create(null);return typeof q=="string"?Jt(Me,q.split(" ")):Array.isArray(q)?Jt(Me,q):Object.keys(q).forEach(function(ln){Object.assign(nt,Zt(q[ln],me,ln))}),nt;function Jt(ln,Pe){me&&(Pe=Pe.map(Re=>Re.toLowerCase())),Pe.forEach(function(Re){const qe=Re.split("|");nt[qe[0]]=[ln,Ln(qe[0],qe[1])]})}}function Ln(q,me){return me?Number(me):di(q)?0:1}function di(q){return an.includes(q.toLowerCase())}const pa={},cr=q=>{console.error(q)},Cn=(q,...me)=>{console.log(`WARN: ${q}`,...me)},re=(q,me)=>{pa[`${q}/${me}`]||(console.log(`Deprecated as of ${q}. ${me}`),pa[`${q}/${me}`]=!0)},Te=new Error;function Ke(q,me,{key:Me}){let nt=0;const Jt=q[Me],ln={},Pe={};for(let Re=1;Re<=me.length;Re++)Pe[Re+nt]=Jt[Re],ln[Re+nt]=!0,nt+=I(me[Re-1]);q[Me]=Pe,q[Me]._emit=ln,q[Me]._multi=!0}function $e(q){if(Array.isArray(q.begin)){if(q.skip||q.excludeBegin||q.returnBegin)throw cr("skip, excludeBegin, returnBegin not compatible with beginScope: {}"),Te;if(typeof q.beginScope!="object"||q.beginScope===null)throw cr("beginScope must be object"),Te;Ke(q,q.begin,{key:"beginScope"}),q.begin=K(q.begin,{joinWith:""})}}function Rt(q){if(Array.isArray(q.end)){if(q.skip||q.excludeEnd||q.returnEnd)throw cr("skip, excludeEnd, returnEnd not compatible with endScope: {}"),Te;if(typeof q.endScope!="object"||q.endScope===null)throw cr("endScope must be object"),Te;Ke(q,q.end,{key:"endScope"}),q.end=K(q.end,{joinWith:""})}}function Zn(q){q.scope&&typeof q.scope=="object"&&q.scope!==null&&(q.beginScope=q.scope,delete q.scope)}function aa(q){Zn(q),typeof q.beginScope=="string"&&(q.beginScope={_wrap:q.beginScope}),typeof q.endScope=="string"&&(q.endScope={_wrap:q.endScope}),$e(q),Rt(q)}function Vn(q){function me(Pe,Re){return new RegExp(E(Pe),"m"+(q.case_insensitive?"i":"")+(q.unicodeRegex?"u":"")+(Re?"g":""))}class Me{constructor(){this.matchIndexes={},this.regexes=[],this.matchAt=1,this.position=0}addRule(Re,qe){qe.position=this.position++,this.matchIndexes[this.matchAt]=qe,this.regexes.push([qe,Re]),this.matchAt+=I(Re)+1}compile(){this.regexes.length===0&&(this.exec=()=>null);const Re=this.regexes.map(qe=>qe[1]);this.matcherRe=me(K(Re,{joinWith:"|"}),!0),this.lastIndex=0}exec(Re){this.matcherRe.lastIndex=this.lastIndex;const qe=this.matcherRe.exec(Re);if(!qe)return null;const Qt=qe.findIndex((nl,js)=>js>0&&nl!==void 0),en=this.matchIndexes[Qt];return qe.splice(0,Qt),Object.assign(qe,en)}}class nt{constructor(){this.rules=[],this.multiRegexes=[],this.count=0,this.lastIndex=0,this.regexIndex=0}getMatcher(Re){if(this.multiRegexes[Re])return this.multiRegexes[Re];const qe=new Me;return this.rules.slice(Re).forEach(([Qt,en])=>qe.addRule(Qt,en)),qe.compile(),this.multiRegexes[Re]=qe,qe}resumingScanAtSamePosition(){return this.regexIndex!==0}considerAll(){this.regexIndex=0}addRule(Re,qe){this.rules.push([Re,qe]),qe.type==="begin"&&this.count++}exec(Re){const qe=this.getMatcher(this.regexIndex);qe.lastIndex=this.lastIndex;let Qt=qe.exec(Re);if(this.resumingScanAtSamePosition()&&!(Qt&&Qt.index===this.lastIndex)){const en=this.getMatcher(0);en.lastIndex=this.lastIndex+1,Qt=en.exec(Re)}return Qt&&(this.regexIndex+=Qt.position+1,this.regexIndex===this.count&&this.considerAll()),Qt}}function Jt(Pe){const Re=new nt;return Pe.contains.forEach(qe=>Re.addRule(qe.begin,{rule:qe,type:"begin"})),Pe.terminatorEnd&&Re.addRule(Pe.terminatorEnd,{type:"end"}),Pe.illegal&&Re.addRule(Pe.illegal,{type:"illegal"}),Re}function ln(Pe,Re){const qe=Pe;if(Pe.isCompiled)return qe;[zr,Ut,aa,At].forEach(en=>en(Pe,Re)),q.compilerExtensions.forEach(en=>en(Pe,Re)),Pe.__beforeBegin=null,[vt,ht,Ve].forEach(en=>en(Pe,Re)),Pe.isCompiled=!0;let Qt=null;return typeof Pe.keywords=="object"&&Pe.keywords.$pattern&&(Pe.keywords=Object.assign({},Pe.keywords),Qt=Pe.keywords.$pattern,delete Pe.keywords.$pattern),Qt=Qt||/\w+/,Pe.keywords&&(Pe.keywords=Zt(Pe.keywords,q.case_insensitive)),qe.keywordPatternRe=me(Qt,!0),Re&&(Pe.begin||(Pe.begin=/\B|\b/),qe.beginRe=me(qe.begin),!Pe.end&&!Pe.endsWithParent&&(Pe.end=/\B|\b/),Pe.end&&(qe.endRe=me(qe.end)),qe.terminatorEnd=E(qe.end)||"",Pe.endsWithParent&&Re.terminatorEnd&&(qe.terminatorEnd+=(Pe.end?"|":"")+Re.terminatorEnd)),Pe.illegal&&(qe.illegalRe=me(Pe.illegal)),Pe.contains||(Pe.contains=[]),Pe.contains=[].concat(...Pe.contains.map(function(en){return Jn(en==="self"?Pe:en)})),Pe.contains.forEach(function(en){ln(en,qe)}),Pe.starts&&ln(Pe.starts,Re),qe.matcher=Jt(qe),qe}if(q.compilerExtensions||(q.compilerExtensions=[]),q.contains&&q.contains.includes("self"))throw new Error("ERR: contains `self` is not supported at the top-level of a language.  See documentation.");return q.classNameAliases=a(q.classNameAliases||{}),ln(q)}function Sr(q){return q?q.endsWithParent||Sr(q.starts):!1}function Jn(q){return q.variants&&!q.cachedVariants&&(q.cachedVariants=q.variants.map(function(me){return a(q,{variants:null},me)})),q.cachedVariants?q.cachedVariants:Sr(q)?a(q,{starts:q.starts?a(q.starts):null}):Object.isFrozen(q)?a(q):q}var Tn="11.11.1";class dr extends Error{constructor(me,Me){super(me),this.name="HTMLInjectionError",this.html=Me}}const er=n,Gs=a,Vs=Symbol("nomatch"),Ks=7,fi=function(q){const me=Object.create(null),Me=Object.create(null),nt=[];let Jt=!0;const ln="Could not find the language '{}', did you forget to load/include a language module?",Pe={disableAutodetect:!0,name:"Plain text",contains:[]};let Re={ignoreUnescapedHTML:!1,throwUnescapedHTML:!1,noHighlightRe:/^(no-?highlight)$/i,languageDetectRe:/\blang(?:uage)?-([\w-]+)\b/i,classPrefix:"hljs-",cssSelector:"pre code",languages:null,__emitter:p};function qe(Ne){return Re.noHighlightRe.test(Ne)}function Qt(Ne){let je=Ne.className+" ";je+=Ne.parentNode?Ne.parentNode.className:"";const ut=Re.languageDetectRe.exec(je);if(ut){const Dt=tr(ut[1]);return Dt||(Cn(ln.replace("{}",ut[1])),Cn("Falling back to no-highlight mode for this block.",Ne)),Dt?ut[1]:"no-highlight"}return je.split(/\s+/).find(Dt=>qe(Dt)||tr(Dt))}function en(Ne,je,ut){let Dt="",un="";typeof je=="object"?(Dt=Ne,ut=je.ignoreIllegals,un=je.language):(re("10.7.0","highlight(lang, code, ...args) has been deprecated."),re("10.7.0",`Please use highlight(code, options) instead.
https://github.com/highlightjs/highlight.js/issues/2277`),un=Ne,Dt=je),ut===void 0&&(ut=!0);const Ar={code:Dt,language:un};Pa("before:highlight",Ar);const la=Ar.result?Ar.result:nl(Ar.language,Ar.code,ut);return la.code=Ar.code,Pa("after:highlight",la),la}function nl(Ne,je,ut,Dt){const un=Object.create(null);function Ar(Ie,He){return Ie.keywords[He]}function la(){if(!st.keywords){_n.addText(It);return}let Ie=0;st.keywordPatternRe.lastIndex=0;let He=st.keywordPatternRe.exec(It),lt="";for(;He;){lt+=It.substring(Ie,He.index);const Ct=xr.case_insensitive?He[0].toLowerCase():He[0],Sn=Ar(st,Ct);if(Sn){const[Fr,ol]=Sn;if(_n.addText(lt),lt="",un[Ct]=(un[Ct]||0)+1,un[Ct]<=Ks&&(zl+=ol),Fr.startsWith("_"))lt+=He[0];else{const sa=xr.classNameAliases[Fr]||Fr;Hr(He[0],sa)}}else lt+=He[0];Ie=st.keywordPatternRe.lastIndex,He=st.keywordPatternRe.exec(It)}lt+=It.substring(Ie),_n.addText(lt)}function Fn(){if(It==="")return;let Ie=null;if(typeof st.subLanguage=="string"){if(!me[st.subLanguage]){_n.addText(It);return}Ie=nl(st.subLanguage,It,!0,Qs[st.subLanguage]),Qs[st.subLanguage]=Ie._top}else Ie=Pl(It,st.subLanguage.length?st.subLanguage:null);st.relevance>0&&(zl+=Ie.relevance),_n.__addSublanguage(Ie._emitter,Ie.language)}function Kn(){st.subLanguage!=null?Fn():la(),It=""}function Hr(Ie,He){Ie!==""&&(_n.startScope(He),_n.addText(Ie),_n.endScope())}function ll(Ie,He){let lt=1;const Ct=He.length-1;for(;lt<=Ct;){if(!Ie._emit[lt]){lt++;continue}const Sn=xr.classNameAliases[Ie[lt]]||Ie[lt],Fr=He[lt];Sn?Hr(Fr,Sn):(It=Fr,la(),It=""),lt++}}function $s(Ie,He){return Ie.scope&&typeof Ie.scope=="string"&&_n.openNode(xr.classNameAliases[Ie.scope]||Ie.scope),Ie.beginScope&&(Ie.beginScope._wrap?(Hr(It,xr.classNameAliases[Ie.beginScope._wrap]||Ie.beginScope._wrap),It=""):Ie.beginScope._multi&&(ll(Ie.beginScope,He),It="")),st=Object.create(Ie,{parent:{value:st}}),st}function sl(Ie,He,lt){let Ct=F(Ie.endRe,lt);if(Ct){if(Ie["on:end"]){const Sn=new t(Ie);Ie["on:end"](He,Sn),Sn.isMatchIgnored&&(Ct=!1)}if(Ct){for(;Ie.endsParent&&Ie.parent;)Ie=Ie.parent;return Ie}}if(Ie.endsWithParent)return sl(Ie.parent,He,lt)}function hd(Ie){return st.matcher.regexIndex===0?(It+=Ie[0],1):(ul=!0,0)}function fr(Ie){const He=Ie[0],lt=Ie.rule,Ct=new t(lt),Sn=[lt.__beforeBegin,lt["on:begin"]];for(const Fr of Sn)if(Fr&&(Fr(Ie,Ct),Ct.isMatchIgnored))return hd(He);return lt.skip?It+=He:(lt.excludeBegin&&(It+=He),Kn(),!lt.returnBegin&&!lt.excludeBegin&&(It=He)),$s(lt,Ie),lt.returnBegin?0:He.length}function Ws(Ie){const He=Ie[0],lt=je.substring(Ie.index),Ct=sl(st,Ie,lt);if(!Ct)return Vs;const Sn=st;st.endScope&&st.endScope._wrap?(Kn(),Hr(He,st.endScope._wrap)):st.endScope&&st.endScope._multi?(Kn(),ll(st.endScope,Ie)):Sn.skip?It+=He:(Sn.returnEnd||Sn.excludeEnd||(It+=He),Kn(),Sn.excludeEnd&&(It=He));do st.scope&&_n.closeNode(),!st.skip&&!st.subLanguage&&(zl+=st.relevance),st=st.parent;while(st!==Ct.parent);return Ct.starts&&$s(Ct.starts,Ie),Sn.returnEnd?0:He.length}function zo(){const Ie=[];for(let He=st;He!==xr;He=He.parent)He.scope&&Ie.unshift(He.scope);Ie.forEach(He=>_n.openNode(He))}let gi={};function Ua(Ie,He){const lt=He&&He[0];if(It+=Ie,lt==null)return Kn(),0;if(gi.type==="begin"&&He.type==="end"&&gi.index===He.index&&lt===""){if(It+=je.slice(He.index,He.index+1),!Jt){const Ct=new Error(`0 width match regex (${Ne})`);throw Ct.languageName=Ne,Ct.badRule=gi.rule,Ct}return 1}if(gi=He,He.type==="begin")return fr(He);if(He.type==="illegal"&&!ut){const Ct=new Error('Illegal lexeme "'+lt+'" for mode "'+(st.scope||"<unnamed>")+'"');throw Ct.mode=st,Ct}else if(He.type==="end"){const Ct=Ws(He);if(Ct!==Vs)return Ct}if(He.type==="illegal"&&lt==="")return It+=`
`,1;if(bi>1e5&&bi>He.index*3)throw new Error("potential infinite loop, way more iterations than matches");return It+=lt,lt.length}const xr=tr(Ne);if(!xr)throw cr(ln.replace("{}",Ne)),new Error('Unknown language: "'+Ne+'"');const Ho=Vn(xr);let ga="",st=Dt||Ho;const Qs={},_n=new Re.__emitter(Re);zo();let It="",zl=0,za=0,bi=0,ul=!1;try{if(xr.__emitTokens)xr.__emitTokens(je,_n);else{for(st.matcher.considerAll();;){bi++,ul?ul=!1:st.matcher.considerAll(),st.matcher.lastIndex=za;const Ie=st.matcher.exec(je);if(!Ie)break;const He=je.substring(za,Ie.index),lt=Ua(He,Ie);za=Ie.index+lt}Ua(je.substring(za))}return _n.finalize(),ga=_n.toHTML(),{language:Ne,value:ga,relevance:zl,illegal:!1,_emitter:_n,_top:st}}catch(Ie){if(Ie.message&&Ie.message.includes("Illegal"))return{language:Ne,value:er(je),illegal:!0,relevance:0,_illegalBy:{message:Ie.message,index:za,context:je.slice(za-100,za+100),mode:Ie.mode,resultSoFar:ga},_emitter:_n};if(Jt)return{language:Ne,value:er(je),illegal:!1,relevance:0,errorRaised:Ie,_emitter:_n,_top:st};throw Ie}}function js(Ne){const je={value:er(Ne),illegal:!1,relevance:0,_top:Pe,_emitter:new Re.__emitter(Re)};return je._emitter.addText(Ne),je}function Pl(Ne,je){je=je||Re.languages||Object.keys(me);const ut=js(Ne),Dt=je.filter(tr).filter(Xs).map(Kn=>nl(Kn,Ne,!1));Dt.unshift(ut);const un=Dt.sort((Kn,Hr)=>{if(Kn.relevance!==Hr.relevance)return Hr.relevance-Kn.relevance;if(Kn.language&&Hr.language){if(tr(Kn.language).supersetOf===Hr.language)return 1;if(tr(Hr.language).supersetOf===Kn.language)return-1}return 0}),[Ar,la]=un,Fn=Ar;return Fn.secondBest=la,Fn}function rl(Ne,je,ut){const Dt=je&&Me[je]||ut;Ne.classList.add("hljs"),Ne.classList.add(`language-${Dt}`)}function al(Ne){let je=null;const ut=Qt(Ne);if(qe(ut))return;if(Pa("before:highlightElement",{el:Ne,language:ut}),Ne.dataset.highlighted){console.log("Element previously highlighted. To highlight again, first unset `dataset.highlighted`.",Ne);return}if(Ne.children.length>0&&(Re.ignoreUnescapedHTML||(console.warn("One of your code blocks includes unescaped HTML. This is a potentially serious security risk."),console.warn("https://github.com/highlightjs/highlight.js/wiki/security"),console.warn("The element with unescaped HTML:"),console.warn(Ne)),Re.throwUnescapedHTML))throw new dr("One of your code blocks includes unescaped HTML.",Ne.innerHTML);je=Ne;const Dt=je.textContent,un=ut?en(Dt,{language:ut,ignoreIllegals:!0}):Pl(Dt);Ne.innerHTML=un.value,Ne.dataset.highlighted="yes",rl(Ne,ut,un.language),Ne.result={language:un.language,re:un.relevance,relevance:un.relevance},un.secondBest&&(Ne.secondBest={language:un.secondBest.language,relevance:un.secondBest.relevance}),Pa("after:highlightElement",{el:Ne,result:un,text:Dt})}function mi(Ne){Re=Gs(Re,Ne)}const pi=()=>{sn(),re("10.6.0","initHighlighting() deprecated.  Use highlightAll() now.")};function il(){sn(),re("10.6.0","initHighlightingOnLoad() deprecated.  Use highlightAll() now.")}let La=!1;function sn(){function Ne(){sn()}if(document.readyState==="loading"){La||window.addEventListener("DOMContentLoaded",Ne,!1),La=!0;return}document.querySelectorAll(Re.cssSelector).forEach(al)}function Lo(Ne,je){let ut=null;try{ut=je(q)}catch(Dt){if(cr("Language definition for '{}' could not be registered.".replace("{}",Ne)),Jt)cr(Dt);else throw Dt;ut=Pe}ut.name||(ut.name=Ne),me[Ne]=ut,ut.rawDefinition=je.bind(null,q),ut.aliases&&Po(ut.aliases,{languageName:Ne})}function Bo(Ne){delete me[Ne];for(const je of Object.keys(Me))Me[je]===Ne&&delete Me[je]}function Ba(){return Object.keys(me)}function tr(Ne){return Ne=(Ne||"").toLowerCase(),me[Ne]||me[Me[Ne]]}function Po(Ne,{languageName:je}){typeof Ne=="string"&&(Ne=[Ne]),Ne.forEach(ut=>{Me[ut.toLowerCase()]=je})}function Xs(Ne){const je=tr(Ne);return je&&!je.disableAutodetect}function Uo(Ne){Ne["before:highlightBlock"]&&!Ne["before:highlightElement"]&&(Ne["before:highlightElement"]=je=>{Ne["before:highlightBlock"](Object.assign({block:je.el},je))}),Ne["after:highlightBlock"]&&!Ne["after:highlightElement"]&&(Ne["after:highlightElement"]=je=>{Ne["after:highlightBlock"](Object.assign({block:je.el},je))})}function fd(Ne){Uo(Ne),nt.push(Ne)}function Ul(Ne){const je=nt.indexOf(Ne);je!==-1&&nt.splice(je,1)}function Pa(Ne,je){const ut=Ne;nt.forEach(function(Dt){Dt[ut]&&Dt[ut](je)})}function ia(Ne){return re("10.7.0","highlightBlock will be removed entirely in v12.0"),re("10.7.0","Please use highlightElement now."),al(Ne)}Object.assign(q,{highlight:en,highlightAuto:Pl,highlightAll:sn,highlightElement:al,highlightBlock:ia,configure:mi,initHighlighting:pi,initHighlightingOnLoad:il,registerLanguage:Lo,unregisterLanguage:Bo,listLanguages:Ba,getLanguage:tr,registerAliases:Po,autoDetection:Xs,inherit:Gs,addPlugin:fd,removePlugin:Ul}),q.debugMode=function(){Jt=!1},q.safeMode=function(){Jt=!0},q.versionString=Tn,q.regex={concat:N,lookahead:T,either:C,optional:x,anyNumberOfTimes:v};for(const Ne in Pt)typeof Pt[Ne]=="object"&&e(Pt[Ne]);return Object.assign(q,Pt),q},hi=fi({});return hi.newInstance=()=>fi({}),Hh=hi,hi.HighlightJS=hi,hi.default=hi,Hh}var KO=VO();const jO=zc(KO),r3={},XO="hljs-";function $O(e){const t=jO.newInstance();return e&&s(e),{highlight:n,highlightAuto:a,listLanguages:l,register:s,registerAlias:o,registered:d};function n(f,h,p){const E=p||r3,T=typeof E.prefix=="string"?E.prefix:XO;if(!t.getLanguage(f))throw new Error("Unknown language: `"+f+"` is not registered");t.configure({__emitter:WO,classPrefix:T});const v=t.highlight(h,{ignoreIllegals:!0,language:f});if(v.errorRaised)throw new Error("Could not highlight with `Highlight.js`",{cause:v.errorRaised});const x=v._emitter.root,N=x.data;return N.language=v.language,N.relevance=v.relevance,x}function a(f,h){const E=(h||r3).subset||l();let T=-1,v=0,x;for(;++T<E.length;){const N=E[T];if(!t.getLanguage(N))continue;const D=n(N,f,h);D.data&&D.data.relevance!==void 0&&D.data.relevance>v&&(v=D.data.relevance,x=D)}return x||{type:"root",children:[],data:{language:void 0,relevance:v}}}function l(){return t.listLanguages()}function s(f,h){if(typeof f=="string")t.registerLanguage(f,h);else{let p;for(p in f)Object.hasOwn(f,p)&&t.registerLanguage(p,f[p])}}function o(f,h){if(typeof f=="string")t.registerAliases(typeof h=="string"?h:[...h],{languageName:f});else{let p;for(p in f)if(Object.hasOwn(f,p)){const E=f[p];t.registerAliases(typeof E=="string"?E:[...E],{languageName:p})}}}function d(f){return!!t.getLanguage(f)}}class WO{constructor(t){this.options=t,this.root={type:"root",children:[],data:{language:void 0,relevance:0}},this.stack=[this.root]}addText(t){if(t==="")return;const n=this.stack[this.stack.length-1],a=n.children[n.children.length-1];a&&a.type==="text"?a.value+=t:n.children.push({type:"text",value:t})}startScope(t){this.openNode(String(t))}endScope(){this.closeNode()}__addSublanguage(t,n){const a=this.stack[this.stack.length-1],l=t.root.children;n?a.children.push({type:"element",tagName:"span",properties:{className:[n]},children:l}):a.children.push(...l)}openNode(t){const n=this,a=t.split(".").map(function(o,d){return d?o+"_".repeat(d):n.options.classPrefix+o}),l=this.stack[this.stack.length-1],s={type:"element",tagName:"span",properties:{className:a},children:[]};l.children.push(s),this.stack.push(s)}closeNode(){this.stack.pop()}finalize(){}toHTML(){return""}}const QO={};function ZO(e){const t=e||QO,n=t.aliases,a=t.detect||!1,l=t.languages||GO,s=t.plainText,o=t.prefix,d=t.subset;let f="hljs";const h=$O(l);if(n&&h.registerAlias(n),o){const p=o.indexOf("-");f=p===-1?o:o.slice(0,p)}return function(p,E){So(p,"element",function(T,v,x){if(T.tagName!=="code"||!x||x.type!=="element"||x.tagName!=="pre")return;const N=JO(T);if(N===!1||!N&&!a||N&&s&&s.includes(N))return;Array.isArray(T.properties.className)||(T.properties.className=[]),T.properties.className.includes(f)||T.properties.className.unshift(f);const D=b5(T,{whitespace:"pre"});let C;try{C=N?h.highlight(N,D,{prefix:o}):h.highlightAuto(D,{prefix:o,subset:d})}catch(I){const F=I;if(N&&/Unknown language/.test(F.message)){E.message("Cannot highlight as `"+N+"`, it’s not registered",{ancestors:[x,T],cause:F,place:T.position,ruleId:"missing-language",source:"rehype-highlight"});return}throw F}!N&&C.data&&C.data.language&&T.properties.className.push("language-"+C.data.language),C.children.length>0&&(T.children=C.children)})}}function JO(e){const t=e.properties.className;let n=-1;if(!Array.isArray(t))return;let a;for(;++n<t.length;){const l=String(t[n]);if(l==="no-highlight"||l==="nohighlight")return!1;!a&&l.slice(0,5)==="lang-"&&(a=l.slice(5)),!a&&l.slice(0,9)==="language-"&&(a=l.slice(9))}return a}function eR(e,t){return U5(e,{})||{type:"root",children:[]}}function U5(e,t){const n=tR(e,t);return n&&t.afterTransform&&t.afterTransform(e,n),n}function tR(e,t){switch(e.nodeType){case 1:return iR(e,t);case 3:return rR(e);case 8:return aR(e);case 9:return a3(e,t);case 10:return nR();case 11:return a3(e,t);default:return}}function a3(e,t){return{type:"root",children:z5(e,t)}}function nR(){return{type:"doctype"}}function rR(e){return{type:"text",value:e.nodeValue||""}}function aR(e){return{type:"comment",value:e.nodeValue||""}}function iR(e,t){const n=e.namespaceURI,a=n===ka.svg?kE:xE,l=n===ka.html?e.tagName.toLowerCase():e.tagName,s=n===ka.html&&l==="template"?e.content:e,o=e.getAttributeNames(),d={};let f=-1;for(;++f<o.length;)d[o[f]]=e.getAttribute(o[f])||"";return a(l,d,z5(s,t))}function z5(e,t){const n=e.childNodes,a=[];let l=-1;for(;++l<n.length;){const s=U5(n[l],t);s!==void 0&&a.push(s)}return a}new DOMParser;function lR(e,t){const n=sR(e);return eR(n)}function sR(e){const t=document.createElement("template");return t.innerHTML=e,t.content}class Lr{constructor(t,n,a){this.lexer=void 0,this.start=void 0,this.end=void 0,this.lexer=t,this.start=n,this.end=a}static range(t,n){return n?!t||!t.loc||!n.loc||t.loc.lexer!==n.loc.lexer?null:new Lr(t.loc.lexer,t.loc.start,n.loc.end):t&&t.loc}}class Jr{constructor(t,n){this.text=void 0,this.loc=void 0,this.noexpand=void 0,this.treatAsRelax=void 0,this.text=t,this.loc=n}range(t,n){return new Jr(n,Lr.range(this,t))}}class ke{constructor(t,n){this.name=void 0,this.position=void 0,this.length=void 0,this.rawMessage=void 0;var a="KaTeX parse error: "+t,l,s,o=n&&n.loc;if(o&&o.start<=o.end){var d=o.lexer.input;l=o.start,s=o.end,l===d.length?a+=" at end of input: ":a+=" at position "+(l+1)+": ";var f=d.slice(l,s).replace(/[^]/g,"$&̲"),h;l>15?h="…"+d.slice(l-15,l):h=d.slice(0,l);var p;s+15<d.length?p=d.slice(s,s+15)+"…":p=d.slice(s),a+=h+f+p}var E=new Error(a);return E.name="ParseError",E.__proto__=ke.prototype,E.position=l,l!=null&&s!=null&&(E.length=s-l),E.rawMessage=t,E}}ke.prototype.__proto__=Error.prototype;var uR=function(t,n){return t.indexOf(n)!==-1},oR=function(t,n){return t===void 0?n:t},cR=/([A-Z])/g,dR=function(t){return t.replace(cR,"-$1").toLowerCase()},fR={"&":"&amp;",">":"&gt;","<":"&lt;",'"':"&quot;","'":"&#x27;"},hR=/[&><"']/g;function mR(e){return String(e).replace(hR,t=>fR[t])}var H5=function e(t){return t.type==="ordgroup"||t.type==="color"?t.body.length===1?e(t.body[0]):t:t.type==="font"?e(t.body):t},pR=function(t){var n=H5(t);return n.type==="mathord"||n.type==="textord"||n.type==="atom"},gR=function(t){if(!t)throw new Error("Expected non-null, but got "+String(t));return t},bR=function(t){var n=/^[\x00-\x20]*([^\\/#?]*?)(:|&#0*58|&#x0*3a|&colon)/i.exec(t);return n?n[2]!==":"||!/^[a-zA-Z][a-zA-Z0-9+\-.]*$/.test(n[1])?null:n[1].toLowerCase():"_relative"},We={contains:uR,deflt:oR,escape:mR,hyphenate:dR,getBaseElem:H5,isCharacterBox:pR,protocolFromUrl:bR},Tc={displayMode:{type:"boolean",description:"Render math in display mode, which puts the math in display style (so \\int and \\sum are large, for example), and centers the math on the page on its own line.",cli:"-d, --display-mode"},output:{type:{enum:["htmlAndMathml","html","mathml"]},description:"Determines the markup language of the output.",cli:"-F, --format <type>"},leqno:{type:"boolean",description:"Render display math in leqno style (left-justified tags)."},fleqn:{type:"boolean",description:"Render display math flush left."},throwOnError:{type:"boolean",default:!0,cli:"-t, --no-throw-on-error",cliDescription:"Render errors (in the color given by --error-color) instead of throwing a ParseError exception when encountering an error."},errorColor:{type:"string",default:"#cc0000",cli:"-c, --error-color <color>",cliDescription:"A color string given in the format 'rgb' or 'rrggbb' (no #). This option determines the color of errors rendered by the -t option.",cliProcessor:e=>"#"+e},macros:{type:"object",cli:"-m, --macro <def>",cliDescription:"Define custom macro of the form '\\foo:expansion' (use multiple -m arguments for multiple macros).",cliDefault:[],cliProcessor:(e,t)=>(t.push(e),t)},minRuleThickness:{type:"number",description:"Specifies a minimum thickness, in ems, for fraction lines, `\\sqrt` top lines, `{array}` vertical lines, `\\hline`, `\\hdashline`, `\\underline`, `\\overline`, and the borders of `\\fbox`, `\\boxed`, and `\\fcolorbox`.",processor:e=>Math.max(0,e),cli:"--min-rule-thickness <size>",cliProcessor:parseFloat},colorIsTextColor:{type:"boolean",description:"Makes \\color behave like LaTeX's 2-argument \\textcolor, instead of LaTeX's one-argument \\color mode change.",cli:"-b, --color-is-text-color"},strict:{type:[{enum:["warn","ignore","error"]},"boolean","function"],description:"Turn on strict / LaTeX faithfulness mode, which throws an error if the input uses features that are not supported by LaTeX.",cli:"-S, --strict",cliDefault:!1},trust:{type:["boolean","function"],description:"Trust the input, enabling all HTML features such as \\url.",cli:"-T, --trust"},maxSize:{type:"number",default:1/0,description:"If non-zero, all user-specified sizes, e.g. in \\rule{500em}{500em}, will be capped to maxSize ems. Otherwise, elements and spaces can be arbitrarily large",processor:e=>Math.max(0,e),cli:"-s, --max-size <n>",cliProcessor:parseInt},maxExpand:{type:"number",default:1e3,description:"Limit the number of macro expansions to the specified number, to prevent e.g. infinite macro loops. If set to Infinity, the macro expander will try to fully expand as in LaTeX.",processor:e=>Math.max(0,e),cli:"-e, --max-expand <n>",cliProcessor:e=>e==="Infinity"?1/0:parseInt(e)},globalGroup:{type:"boolean",cli:!1}};function ER(e){if(e.default)return e.default;var t=e.type,n=Array.isArray(t)?t[0]:t;if(typeof n!="string")return n.enum[0];switch(n){case"boolean":return!1;case"string":return"";case"number":return 0;case"object":return{}}}class Mm{constructor(t){this.displayMode=void 0,this.output=void 0,this.leqno=void 0,this.fleqn=void 0,this.throwOnError=void 0,this.errorColor=void 0,this.macros=void 0,this.minRuleThickness=void 0,this.colorIsTextColor=void 0,this.strict=void 0,this.trust=void 0,this.maxSize=void 0,this.maxExpand=void 0,this.globalGroup=void 0,t=t||{};for(var n in Tc)if(Tc.hasOwnProperty(n)){var a=Tc[n];this[n]=t[n]!==void 0?a.processor?a.processor(t[n]):t[n]:ER(a)}}reportNonstrict(t,n,a){var l=this.strict;if(typeof l=="function"&&(l=l(t,n,a)),!(!l||l==="ignore")){if(l===!0||l==="error")throw new ke("LaTeX-incompatible input and strict mode is set to 'error': "+(n+" ["+t+"]"),a);l==="warn"?typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(n+" ["+t+"]")):typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+l+"': "+n+" ["+t+"]"))}}useStrictBehavior(t,n,a){var l=this.strict;if(typeof l=="function")try{l=l(t,n,a)}catch{l="error"}return!l||l==="ignore"?!1:l===!0||l==="error"?!0:l==="warn"?(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(n+" ["+t+"]")),!1):(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+l+"': "+n+" ["+t+"]")),!1)}isTrusted(t){if(t.url&&!t.protocol){var n=We.protocolFromUrl(t.url);if(n==null)return!1;t.protocol=n}var a=typeof this.trust=="function"?this.trust(t):this.trust;return!!a}}class Fi{constructor(t,n,a){this.id=void 0,this.size=void 0,this.cramped=void 0,this.id=t,this.size=n,this.cramped=a}sup(){return xa[yR[this.id]]}sub(){return xa[vR[this.id]]}fracNum(){return xa[TR[this.id]]}fracDen(){return xa[_R[this.id]]}cramp(){return xa[SR[this.id]]}text(){return xa[AR[this.id]]}isTight(){return this.size>=2}}var Dm=0,Dc=1,ws=2,ri=3,bo=4,Zr=5,Ms=6,ur=7,xa=[new Fi(Dm,0,!1),new Fi(Dc,0,!0),new Fi(ws,1,!1),new Fi(ri,1,!0),new Fi(bo,2,!1),new Fi(Zr,2,!0),new Fi(Ms,3,!1),new Fi(ur,3,!0)],yR=[bo,Zr,bo,Zr,Ms,ur,Ms,ur],vR=[Zr,Zr,Zr,Zr,ur,ur,ur,ur],TR=[ws,ri,bo,Zr,Ms,ur,Ms,ur],_R=[ri,ri,Zr,Zr,ur,ur,ur,ur],SR=[Dc,Dc,ri,ri,Zr,Zr,ur,ur],AR=[Dm,Dc,ws,ri,ws,ri,ws,ri],Je={DISPLAY:xa[Dm],TEXT:xa[ws],SCRIPT:xa[bo],SCRIPTSCRIPT:xa[Ms]},P1=[{name:"latin",blocks:[[256,591],[768,879]]},{name:"cyrillic",blocks:[[1024,1279]]},{name:"armenian",blocks:[[1328,1423]]},{name:"brahmic",blocks:[[2304,4255]]},{name:"georgian",blocks:[[4256,4351]]},{name:"cjk",blocks:[[12288,12543],[19968,40879],[65280,65376]]},{name:"hangul",blocks:[[44032,55215]]}];function xR(e){for(var t=0;t<P1.length;t++)for(var n=P1[t],a=0;a<n.blocks.length;a++){var l=n.blocks[a];if(e>=l[0]&&e<=l[1])return n.name}return null}var _c=[];P1.forEach(e=>e.blocks.forEach(t=>_c.push(...t)));function F5(e){for(var t=0;t<_c.length;t+=2)if(e>=_c[t]&&e<=_c[t+1])return!0;return!1}var bs=80,kR=function(t,n){return"M95,"+(622+t+n)+`
c-2.7,0,-7.17,-2.7,-13.5,-8c-5.8,-5.3,-9.5,-10,-9.5,-14
c0,-2,0.3,-3.3,1,-4c1.3,-2.7,23.83,-20.7,67.5,-54
c44.2,-33.3,65.8,-50.3,66.5,-51c1.3,-1.3,3,-2,5,-2c4.7,0,8.7,3.3,12,10
s173,378,173,378c0.7,0,35.3,-71,104,-213c68.7,-142,137.5,-285,206.5,-429
c69,-144,104.5,-217.7,106.5,-221
l`+t/2.075+" -"+t+`
c5.3,-9.3,12,-14,20,-14
H400000v`+(40+t)+`H845.2724
s-225.272,467,-225.272,467s-235,486,-235,486c-2.7,4.7,-9,7,-19,7
c-6,0,-10,-1,-12,-3s-194,-422,-194,-422s-65,47,-65,47z
M`+(834+t)+" "+n+"h400000v"+(40+t)+"h-400000z"},NR=function(t,n){return"M263,"+(601+t+n)+`c0.7,0,18,39.7,52,119
c34,79.3,68.167,158.7,102.5,238c34.3,79.3,51.8,119.3,52.5,120
c340,-704.7,510.7,-1060.3,512,-1067
l`+t/2.084+" -"+t+`
c4.7,-7.3,11,-11,19,-11
H40000v`+(40+t)+`H1012.3
s-271.3,567,-271.3,567c-38.7,80.7,-84,175,-136,283c-52,108,-89.167,185.3,-111.5,232
c-22.3,46.7,-33.8,70.3,-34.5,71c-4.7,4.7,-12.3,7,-23,7s-12,-1,-12,-1
s-109,-253,-109,-253c-72.7,-168,-109.3,-252,-110,-252c-10.7,8,-22,16.7,-34,26
c-22,17.3,-33.3,26,-34,26s-26,-26,-26,-26s76,-59,76,-59s76,-60,76,-60z
M`+(1001+t)+" "+n+"h400000v"+(40+t)+"h-400000z"},wR=function(t,n){return"M983 "+(10+t+n)+`
l`+t/3.13+" -"+t+`
c4,-6.7,10,-10,18,-10 H400000v`+(40+t)+`
H1013.1s-83.4,268,-264.1,840c-180.7,572,-277,876.3,-289,913c-4.7,4.7,-12.7,7,-24,7
s-12,0,-12,0c-1.3,-3.3,-3.7,-11.7,-7,-25c-35.3,-125.3,-106.7,-373.3,-214,-744
c-10,12,-21,25,-33,39s-32,39,-32,39c-6,-5.3,-15,-14,-27,-26s25,-30,25,-30
c26.7,-32.7,52,-63,76,-91s52,-60,52,-60s208,722,208,722
c56,-175.3,126.3,-397.3,211,-666c84.7,-268.7,153.8,-488.2,207.5,-658.5
c53.7,-170.3,84.5,-266.8,92.5,-289.5z
M`+(1001+t)+" "+n+"h400000v"+(40+t)+"h-400000z"},CR=function(t,n){return"M424,"+(2398+t+n)+`
c-1.3,-0.7,-38.5,-172,-111.5,-514c-73,-342,-109.8,-513.3,-110.5,-514
c0,-2,-10.7,14.3,-32,49c-4.7,7.3,-9.8,15.7,-15.5,25c-5.7,9.3,-9.8,16,-12.5,20
s-5,7,-5,7c-4,-3.3,-8.3,-7.7,-13,-13s-13,-13,-13,-13s76,-122,76,-122s77,-121,77,-121
s209,968,209,968c0,-2,84.7,-361.7,254,-1079c169.3,-717.3,254.7,-1077.7,256,-1081
l`+t/4.223+" -"+t+`c4,-6.7,10,-10,18,-10 H400000
v`+(40+t)+`H1014.6
s-87.3,378.7,-272.6,1166c-185.3,787.3,-279.3,1182.3,-282,1185
c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2z M`+(1001+t)+" "+n+`
h400000v`+(40+t)+"h-400000z"},OR=function(t,n){return"M473,"+(2713+t+n)+`
c339.3,-1799.3,509.3,-2700,510,-2702 l`+t/5.298+" -"+t+`
c3.3,-7.3,9.3,-11,18,-11 H400000v`+(40+t)+`H1017.7
s-90.5,478,-276.2,1466c-185.7,988,-279.5,1483,-281.5,1485c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2c0,-1.3,-5.3,-32,-16,-92c-50.7,-293.3,-119.7,-693.3,-207,-1200
c0,-1.3,-5.3,8.7,-16,30c-10.7,21.3,-21.3,42.7,-32,64s-16,33,-16,33s-26,-26,-26,-26
s76,-153,76,-153s77,-151,77,-151c0.7,0.7,35.7,202,105,604c67.3,400.7,102,602.7,104,
606zM`+(1001+t)+" "+n+"h400000v"+(40+t)+"H1017.7z"},RR=function(t){var n=t/2;return"M400000 "+t+" H0 L"+n+" 0 l65 45 L145 "+(t-80)+" H400000z"},MR=function(t,n,a){var l=a-54-n-t;return"M702 "+(t+n)+"H400000"+(40+t)+`
H742v`+l+`l-4 4-4 4c-.667.7 -2 1.5-4 2.5s-4.167 1.833-6.5 2.5-5.5 1-9.5 1
h-12l-28-84c-16.667-52-96.667 -294.333-240-727l-212 -643 -85 170
c-4-3.333-8.333-7.667-13 -13l-13-13l77-155 77-156c66 199.333 139 419.667
219 661 l218 661zM702 `+n+"H400000v"+(40+t)+"H742z"},DR=function(t,n,a){n=1e3*n;var l="";switch(t){case"sqrtMain":l=kR(n,bs);break;case"sqrtSize1":l=NR(n,bs);break;case"sqrtSize2":l=wR(n,bs);break;case"sqrtSize3":l=CR(n,bs);break;case"sqrtSize4":l=OR(n,bs);break;case"sqrtTall":l=MR(n,bs,a)}return l},IR=function(t,n){switch(t){case"⎜":return"M291 0 H417 V"+n+" H291z M291 0 H417 V"+n+" H291z";case"∣":return"M145 0 H188 V"+n+" H145z M145 0 H188 V"+n+" H145z";case"∥":return"M145 0 H188 V"+n+" H145z M145 0 H188 V"+n+" H145z"+("M367 0 H410 V"+n+" H367z M367 0 H410 V"+n+" H367z");case"⎟":return"M457 0 H583 V"+n+" H457z M457 0 H583 V"+n+" H457z";case"⎢":return"M319 0 H403 V"+n+" H319z M319 0 H403 V"+n+" H319z";case"⎥":return"M263 0 H347 V"+n+" H263z M263 0 H347 V"+n+" H263z";case"⎪":return"M384 0 H504 V"+n+" H384z M384 0 H504 V"+n+" H384z";case"⏐":return"M312 0 H355 V"+n+" H312z M312 0 H355 V"+n+" H312z";case"‖":return"M257 0 H300 V"+n+" H257z M257 0 H300 V"+n+" H257z"+("M478 0 H521 V"+n+" H478z M478 0 H521 V"+n+" H478z");default:return""}},i3={doubleleftarrow:`M262 157
l10-10c34-36 62.7-77 86-123 3.3-8 5-13.3 5-16 0-5.3-6.7-8-20-8-7.3
 0-12.2.5-14.5 1.5-2.3 1-4.8 4.5-7.5 10.5-49.3 97.3-121.7 169.3-217 216-28
 14-57.3 25-88 33-6.7 2-11 3.8-13 5.5-2 1.7-3 4.2-3 7.5s1 5.8 3 7.5
c2 1.7 6.3 3.5 13 5.5 68 17.3 128.2 47.8 180.5 91.5 52.3 43.7 93.8 96.2 124.5
 157.5 9.3 8 15.3 12.3 18 13h6c12-.7 18-4 18-10 0-2-1.7-7-5-15-23.3-46-52-87
-86-123l-10-10h399738v-40H218c328 0 0 0 0 0l-10-8c-26.7-20-65.7-43-117-69 2.7
-2 6-3.7 10-5 36.7-16 72.3-37.3 107-64l10-8h399782v-40z
m8 0v40h399730v-40zm0 194v40h399730v-40z`,doublerightarrow:`M399738 392l
-10 10c-34 36-62.7 77-86 123-3.3 8-5 13.3-5 16 0 5.3 6.7 8 20 8 7.3 0 12.2-.5
 14.5-1.5 2.3-1 4.8-4.5 7.5-10.5 49.3-97.3 121.7-169.3 217-216 28-14 57.3-25 88
-33 6.7-2 11-3.8 13-5.5 2-1.7 3-4.2 3-7.5s-1-5.8-3-7.5c-2-1.7-6.3-3.5-13-5.5-68
-17.3-128.2-47.8-180.5-91.5-52.3-43.7-93.8-96.2-124.5-157.5-9.3-8-15.3-12.3-18
-13h-6c-12 .7-18 4-18 10 0 2 1.7 7 5 15 23.3 46 52 87 86 123l10 10H0v40h399782
c-328 0 0 0 0 0l10 8c26.7 20 65.7 43 117 69-2.7 2-6 3.7-10 5-36.7 16-72.3 37.3
-107 64l-10 8H0v40zM0 157v40h399730v-40zm0 194v40h399730v-40z`,leftarrow:`M400000 241H110l3-3c68.7-52.7 113.7-120
 135-202 4-14.7 6-23 6-25 0-7.3-7-11-21-11-8 0-13.2.8-15.5 2.5-2.3 1.7-4.2 5.8
-5.5 12.5-1.3 4.7-2.7 10.3-4 17-12 48.7-34.8 92-68.5 130S65.3 228.3 18 247
c-10 4-16 7.7-18 11 0 8.7 6 14.3 18 17 47.3 18.7 87.8 47 121.5 85S196 441.3 208
 490c.7 2 1.3 5 2 9s1.2 6.7 1.5 8c.3 1.3 1 3.3 2 6s2.2 4.5 3.5 5.5c1.3 1 3.3
 1.8 6 2.5s6 1 10 1c14 0 21-3.7 21-11 0-2-2-10.3-6-25-20-79.3-65-146.7-135-202
 l-3-3h399890zM100 241v40h399900v-40z`,leftbrace:`M6 548l-6-6v-35l6-11c56-104 135.3-181.3 238-232 57.3-28.7 117
-45 179-50h399577v120H403c-43.3 7-81 15-113 26-100.7 33-179.7 91-237 174-2.7
 5-6 9-10 13-.7 1-7.3 1-20 1H6z`,leftbraceunder:`M0 6l6-6h17c12.688 0 19.313.3 20 1 4 4 7.313 8.3 10 13
 35.313 51.3 80.813 93.8 136.5 127.5 55.688 33.7 117.188 55.8 184.5 66.5.688
 0 2 .3 4 1 18.688 2.7 76 4.3 172 5h399450v120H429l-6-1c-124.688-8-235-61.7
-331-161C60.687 138.7 32.312 99.3 7 54L0 41V6z`,leftgroup:`M400000 80
H435C64 80 168.3 229.4 21 260c-5.9 1.2-18 0-18 0-2 0-3-1-3-3v-38C76 61 257 0
 435 0h399565z`,leftgroupunder:`M400000 262
H435C64 262 168.3 112.6 21 82c-5.9-1.2-18 0-18 0-2 0-3 1-3 3v38c76 158 257 219
 435 219h399565z`,leftharpoon:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3
-3.3 10.2-9.5 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5
-18.3 3-21-1.3-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7
-196 228-6.7 4.7-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40z`,leftharpoonplus:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3-3.3 10.2-9.5
 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5-18.3 3-21-1.3
-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7-196 228-6.7 4.7
-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40zM0 435v40h400000v-40z
m0 0v40h400000v-40z`,leftharpoondown:`M7 241c-4 4-6.333 8.667-7 14 0 5.333.667 9 2 11s5.333
 5.333 12 10c90.667 54 156 130 196 228 3.333 10.667 6.333 16.333 9 17 2 .667 5
 1 9 1h5c10.667 0 16.667-2 18-6 2-2.667 1-9.667-3-21-32-87.333-82.667-157.667
-152-211l-3-3h399907v-40zM93 281 H400000 v-40L7 241z`,leftharpoondownplus:`M7 435c-4 4-6.3 8.7-7 14 0 5.3.7 9 2 11s5.3 5.3 12
 10c90.7 54 156 130 196 228 3.3 10.7 6.3 16.3 9 17 2 .7 5 1 9 1h5c10.7 0 16.7
-2 18-6 2-2.7 1-9.7-3-21-32-87.3-82.7-157.7-152-211l-3-3h399907v-40H7zm93 0
v40h399900v-40zM0 241v40h399900v-40zm0 0v40h399900v-40z`,lefthook:`M400000 281 H103s-33-11.2-61-33.5S0 197.3 0 164s14.2-61.2 42.5
-83.5C70.8 58.2 104 47 142 47 c16.7 0 25 6.7 25 20 0 12-8.7 18.7-26 20-40 3.3
-68.7 15.7-86 37-10 12-15 25.3-15 40 0 22.7 9.8 40.7 29.5 54 19.7 13.3 43.5 21
 71.5 23h399859zM103 281v-40h399897v40z`,leftlinesegment:`M40 281 V428 H0 V94 H40 V241 H400000 v40z
M40 281 V428 H0 V94 H40 V241 H400000 v40z`,leftmapsto:`M40 281 V448H0V74H40V241H400000v40z
M40 281 V448H0V74H40V241H400000v40z`,leftToFrom:`M0 147h400000v40H0zm0 214c68 40 115.7 95.7 143 167h22c15.3 0 23
-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69-70-101l-7-8h399905v-40H95l7-8
c28.7-32 52-65.7 70-101 10.7-23.3 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 265.3
 68 321 0 361zm0-174v-40h399900v40zm100 154v40h399900v-40z`,longequal:`M0 50 h400000 v40H0z m0 194h40000v40H0z
M0 50 h400000 v40H0z m0 194h40000v40H0z`,midbrace:`M200428 334
c-100.7-8.3-195.3-44-280-108-55.3-42-101.7-93-139-153l-9-14c-2.7 4-5.7 8.7-9 14
-53.3 86.7-123.7 153-211 199-66.7 36-137.3 56.3-212 62H0V214h199568c178.3-11.7
 311.7-78.3 403-201 6-8 9.7-12 11-12 .7-.7 6.7-1 18-1s17.3.3 18 1c1.3 0 5 4 11
 12 44.7 59.3 101.3 106.3 170 141s145.3 54.3 229 60h199572v120z`,midbraceunder:`M199572 214
c100.7 8.3 195.3 44 280 108 55.3 42 101.7 93 139 153l9 14c2.7-4 5.7-8.7 9-14
 53.3-86.7 123.7-153 211-199 66.7-36 137.3-56.3 212-62h199568v120H200432c-178.3
 11.7-311.7 78.3-403 201-6 8-9.7 12-11 12-.7.7-6.7 1-18 1s-17.3-.3-18-1c-1.3 0
-5-4-11-12-44.7-59.3-101.3-106.3-170-141s-145.3-54.3-229-60H0V214z`,oiintSize1:`M512.6 71.6c272.6 0 320.3 106.8 320.3 178.2 0 70.8-47.7 177.6
-320.3 177.6S193.1 320.6 193.1 249.8c0-71.4 46.9-178.2 319.5-178.2z
m368.1 178.2c0-86.4-60.9-215.4-368.1-215.4-306.4 0-367.3 129-367.3 215.4 0 85.8
60.9 214.8 367.3 214.8 307.2 0 368.1-129 368.1-214.8z`,oiintSize2:`M757.8 100.1c384.7 0 451.1 137.6 451.1 230 0 91.3-66.4 228.8
-451.1 228.8-386.3 0-452.7-137.5-452.7-228.8 0-92.4 66.4-230 452.7-230z
m502.4 230c0-111.2-82.4-277.2-502.4-277.2s-504 166-504 277.2
c0 110 84 276 504 276s502.4-166 502.4-276z`,oiiintSize1:`M681.4 71.6c408.9 0 480.5 106.8 480.5 178.2 0 70.8-71.6 177.6
-480.5 177.6S202.1 320.6 202.1 249.8c0-71.4 70.5-178.2 479.3-178.2z
m525.8 178.2c0-86.4-86.8-215.4-525.7-215.4-437.9 0-524.7 129-524.7 215.4 0
85.8 86.8 214.8 524.7 214.8 438.9 0 525.7-129 525.7-214.8z`,oiiintSize2:`M1021.2 53c603.6 0 707.8 165.8 707.8 277.2 0 110-104.2 275.8
-707.8 275.8-606 0-710.2-165.8-710.2-275.8C311 218.8 415.2 53 1021.2 53z
m770.4 277.1c0-131.2-126.4-327.6-770.5-327.6S248.4 198.9 248.4 330.1
c0 130 128.8 326.4 772.7 326.4s770.5-196.4 770.5-326.4z`,rightarrow:`M0 241v40h399891c-47.3 35.3-84 78-110 128
-16.7 32-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20
 11 8 0 13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7
 39-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85
-40.5-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
 151.7 139 205zm0 0v40h399900v-40z`,rightbrace:`M400000 542l
-6 6h-17c-12.7 0-19.3-.3-20-1-4-4-7.3-8.3-10-13-35.3-51.3-80.8-93.8-136.5-127.5
s-117.2-55.8-184.5-66.5c-.7 0-2-.3-4-1-18.7-2.7-76-4.3-172-5H0V214h399571l6 1
c124.7 8 235 61.7 331 161 31.3 33.3 59.7 72.7 85 118l7 13v35z`,rightbraceunder:`M399994 0l6 6v35l-6 11c-56 104-135.3 181.3-238 232-57.3
 28.7-117 45-179 50H-300V214h399897c43.3-7 81-15 113-26 100.7-33 179.7-91 237
-174 2.7-5 6-9 10-13 .7-1 7.3-1 20-1h17z`,rightgroup:`M0 80h399565c371 0 266.7 149.4 414 180 5.9 1.2 18 0 18 0 2 0
 3-1 3-3v-38c-76-158-257-219-435-219H0z`,rightgroupunder:`M0 262h399565c371 0 266.7-149.4 414-180 5.9-1.2 18 0 18
 0 2 0 3 1 3 3v38c-76 158-257 219-435 219H0z`,rightharpoon:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3
-3.7-15.3-11-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2
-10.7 0-16.7 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58
 69.2 92 94.5zm0 0v40h399900v-40z`,rightharpoonplus:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3-3.7-15.3-11
-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2-10.7 0-16.7
 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58 69.2 92 94.5z
m0 0v40h399900v-40z m100 194v40h399900v-40zm0 0v40h399900v-40z`,rightharpoondown:`M399747 511c0 7.3 6.7 11 20 11 8 0 13-.8 15-2.5s4.7-6.8
 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3 8.5-5.8 9.5
-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3-64.7 57-92 95
-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 241v40h399900v-40z`,rightharpoondownplus:`M399747 705c0 7.3 6.7 11 20 11 8 0 13-.8
 15-2.5s4.7-6.8 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3
 8.5-5.8 9.5-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3
-64.7 57-92 95-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 435v40h399900v-40z
m0-194v40h400000v-40zm0 0v40h400000v-40z`,righthook:`M399859 241c-764 0 0 0 0 0 40-3.3 68.7-15.7 86-37 10-12 15-25.3
 15-40 0-22.7-9.8-40.7-29.5-54-19.7-13.3-43.5-21-71.5-23-17.3-1.3-26-8-26-20 0
-13.3 8.7-20 26-20 38 0 71 11.2 99 33.5 0 0 7 5.6 21 16.7 14 11.2 21 33.5 21
 66.8s-14 61.2-42 83.5c-28 22.3-61 33.5-99 33.5L0 241z M0 281v-40h399859v40z`,rightlinesegment:`M399960 241 V94 h40 V428 h-40 V281 H0 v-40z
M399960 241 V94 h40 V428 h-40 V281 H0 v-40z`,rightToFrom:`M400000 167c-70.7-42-118-97.7-142-167h-23c-15.3 0-23 .3-23
 1 0 1.3 5.3 13.7 16 37 18 35.3 41.3 69 70 101l7 8H0v40h399905l-7 8c-28.7 32
-52 65.7-70 101-10.7 23.3-16 35.7-16 37 0 .7 7.7 1 23 1h23c24-69.3 71.3-125 142
-167z M100 147v40h399900v-40zM0 341v40h399900v-40z`,twoheadleftarrow:`M0 167c68 40
 115.7 95.7 143 167h22c15.3 0 23-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69
-70-101l-7-8h125l9 7c50.7 39.3 85 86 103 140h46c0-4.7-6.3-18.7-19-42-18-35.3
-40-67.3-66-96l-9-9h399716v-40H284l9-9c26-28.7 48-60.7 66-96 12.7-23.333 19
-37.333 19-42h-46c-18 54-52.3 100.7-103 140l-9 7H95l7-8c28.7-32 52-65.7 70-101
 10.7-23.333 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 71.3 68 127 0 167z`,twoheadrightarrow:`M400000 167
c-68-40-115.7-95.7-143-167h-22c-15.3 0-23 .3-23 1 0 1.3 5.3 13.7 16 37 18 35.3
 41.3 69 70 101l7 8h-125l-9-7c-50.7-39.3-85-86-103-140h-46c0 4.7 6.3 18.7 19 42
 18 35.3 40 67.3 66 96l9 9H0v40h399716l-9 9c-26 28.7-48 60.7-66 96-12.7 23.333
-19 37.333-19 42h46c18-54 52.3-100.7 103-140l9-7h125l-7 8c-28.7 32-52 65.7-70
 101-10.7 23.333-16 35.7-16 37 0 .7 7.7 1 23 1h22c27.3-71.3 75-127 143-167z`,tilde1:`M200 55.538c-77 0-168 73.953-177 73.953-3 0-7
-2.175-9-5.437L2 97c-1-2-2-4-2-6 0-4 2-7 5-9l20-12C116 12 171 0 207 0c86 0
 114 68 191 68 78 0 168-68 177-68 4 0 7 2 9 5l12 19c1 2.175 2 4.35 2 6.525 0
 4.35-2 7.613-5 9.788l-19 13.05c-92 63.077-116.937 75.308-183 76.128
-68.267.847-113-73.952-191-73.952z`,tilde2:`M344 55.266c-142 0-300.638 81.316-311.5 86.418
-8.01 3.762-22.5 10.91-23.5 5.562L1 120c-1-2-1-3-1-4 0-5 3-9 8-10l18.4-9C160.9
 31.9 283 0 358 0c148 0 188 122 331 122s314-97 326-97c4 0 8 2 10 7l7 21.114
c1 2.14 1 3.21 1 4.28 0 5.347-3 9.626-7 10.696l-22.3 12.622C852.6 158.372 751
 181.476 676 181.476c-149 0-189-126.21-332-126.21z`,tilde3:`M786 59C457 59 32 175.242 13 175.242c-6 0-10-3.457
-11-10.37L.15 138c-1-7 3-12 10-13l19.2-6.4C378.4 40.7 634.3 0 804.3 0c337 0
 411.8 157 746.8 157 328 0 754-112 773-112 5 0 10 3 11 9l1 14.075c1 8.066-.697
 16.595-6.697 17.492l-21.052 7.31c-367.9 98.146-609.15 122.696-778.15 122.696
 -338 0-409-156.573-744-156.573z`,tilde4:`M786 58C457 58 32 177.487 13 177.487c-6 0-10-3.345
-11-10.035L.15 143c-1-7 3-12 10-13l22-6.7C381.2 35 637.15 0 807.15 0c337 0 409
 177 744 177 328 0 754-127 773-127 5 0 10 3 11 9l1 14.794c1 7.805-3 13.38-9
 14.495l-20.7 5.574c-366.85 99.79-607.3 139.372-776.3 139.372-338 0-409
 -175.236-744-175.236z`,vec:`M377 20c0-5.333 1.833-10 5.5-14S391 0 397 0c4.667 0 8.667 1.667 12 5
3.333 2.667 6.667 9 10 19 6.667 24.667 20.333 43.667 41 57 7.333 4.667 11
10.667 11 18 0 6-1 10-3 12s-6.667 5-14 9c-28.667 14.667-53.667 35.667-75 63
-1.333 1.333-3.167 3.5-5.5 6.5s-4 4.833-5 5.5c-1 .667-2.5 1.333-4.5 2s-4.333 1
-7 1c-4.667 0-9.167-1.833-13.5-5.5S337 184 337 178c0-12.667 15.667-32.333 47-59
H213l-171-1c-8.667-6-13-12.333-13-19 0-4.667 4.333-11.333 13-20h359
c-16-25.333-24-45-24-59z`,widehat1:`M529 0h5l519 115c5 1 9 5 9 10 0 1-1 2-1 3l-4 22
c-1 5-5 9-11 9h-2L532 67 19 159h-2c-5 0-9-4-11-9l-5-22c-1-6 2-12 8-13z`,widehat2:`M1181 0h2l1171 176c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 220h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat3:`M1181 0h2l1171 236c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 280h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat4:`M1181 0h2l1171 296c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 340h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widecheck1:`M529,159h5l519,-115c5,-1,9,-5,9,-10c0,-1,-1,-2,-1,-3l-4,-22c-1,
-5,-5,-9,-11,-9h-2l-512,92l-513,-92h-2c-5,0,-9,4,-11,9l-5,22c-1,6,2,12,8,13z`,widecheck2:`M1181,220h2l1171,-176c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,153l-1167,-153h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck3:`M1181,280h2l1171,-236c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,213l-1167,-213h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck4:`M1181,340h2l1171,-296c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,273l-1167,-273h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,baraboveleftarrow:`M400000 620h-399890l3 -3c68.7 -52.7 113.7 -120 135 -202
c4 -14.7 6 -23 6 -25c0 -7.3 -7 -11 -21 -11c-8 0 -13.2 0.8 -15.5 2.5
c-2.3 1.7 -4.2 5.8 -5.5 12.5c-1.3 4.7 -2.7 10.3 -4 17c-12 48.7 -34.8 92 -68.5 130
s-74.2 66.3 -121.5 85c-10 4 -16 7.7 -18 11c0 8.7 6 14.3 18 17c47.3 18.7 87.8 47
121.5 85s56.5 81.3 68.5 130c0.7 2 1.3 5 2 9s1.2 6.7 1.5 8c0.3 1.3 1 3.3 2 6
s2.2 4.5 3.5 5.5c1.3 1 3.3 1.8 6 2.5s6 1 10 1c14 0 21 -3.7 21 -11
c0 -2 -2 -10.3 -6 -25c-20 -79.3 -65 -146.7 -135 -202l-3 -3h399890z
M100 620v40h399900v-40z M0 241v40h399900v-40zM0 241v40h399900v-40z`,rightarrowabovebar:`M0 241v40h399891c-47.3 35.3-84 78-110 128-16.7 32
-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20 11 8 0
13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7 39
-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85-40.5
-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
151.7 139 205zm96 379h399894v40H0zm0 0h399904v40H0z`,baraboveshortleftharpoon:`M507,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17
c2,0.7,5,1,9,1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21
c-32,-87.3,-82.7,-157.7,-152,-211c0,0,-3,-3,-3,-3l399351,0l0,-40
c-398570,0,-399437,0,-399437,0z M593 435 v40 H399500 v-40z
M0 281 v-40 H399908 v40z M0 281 v-40 H399908 v40z`,rightharpoonaboveshortbar:`M0,241 l0,40c399126,0,399993,0,399993,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M0 241 v40 H399908 v-40z M0 475 v-40 H399500 v40z M0 475 v-40 H399500 v40z`,shortbaraboveleftharpoon:`M7,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17c2,0.7,5,1,9,
1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21c-32,-87.3,-82.7,-157.7,
-152,-211c0,0,-3,-3,-3,-3l399907,0l0,-40c-399126,0,-399993,0,-399993,0z
M93 435 v40 H400000 v-40z M500 241 v40 H400000 v-40z M500 241 v40 H400000 v-40z`,shortrightharpoonabovebar:`M53,241l0,40c398570,0,399437,0,399437,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M500 241 v40 H399408 v-40z M500 435 v40 H400000 v-40z`},LR=function(t,n){switch(t){case"lbrack":return"M403 1759 V84 H666 V0 H319 V1759 v"+n+` v1759 h347 v-84
H403z M403 1759 V0 H319 V1759 v`+n+" v1759 h84z";case"rbrack":return"M347 1759 V0 H0 V84 H263 V1759 v"+n+` v1759 H0 v84 H347z
M347 1759 V0 H263 V1759 v`+n+" v1759 h84z";case"vert":return"M145 15 v585 v"+n+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-n+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+n+" v585 h43z";case"doublevert":return"M145 15 v585 v"+n+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-n+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+n+` v585 h43z
M367 15 v585 v`+n+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-n+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M410 15 H367 v585 v`+n+" v585 h43z";case"lfloor":return"M319 602 V0 H403 V602 v"+n+` v1715 h263 v84 H319z
MM319 602 V0 H403 V602 v`+n+" v1715 H319z";case"rfloor":return"M319 602 V0 H403 V602 v"+n+` v1799 H0 v-84 H319z
MM319 602 V0 H403 V602 v`+n+" v1715 H319z";case"lceil":return"M403 1759 V84 H666 V0 H319 V1759 v"+n+` v602 h84z
M403 1759 V0 H319 V1759 v`+n+" v602 h84z";case"rceil":return"M347 1759 V0 H0 V84 H263 V1759 v"+n+` v602 h84z
M347 1759 V0 h-84 V1759 v`+n+" v602 h84z";case"lparen":return`M863,9c0,-2,-2,-5,-6,-9c0,0,-17,0,-17,0c-12.7,0,-19.3,0.3,-20,1
c-5.3,5.3,-10.3,11,-15,17c-242.7,294.7,-395.3,682,-458,1162c-21.3,163.3,-33.3,349,
-36,557 l0,`+(n+84)+`c0.2,6,0,26,0,60c2,159.3,10,310.7,24,454c53.3,528,210,
949.7,470,1265c4.7,6,9.7,11.7,15,17c0.7,0.7,7,1,19,1c0,0,18,0,18,0c4,-4,6,-7,6,-9
c0,-2.7,-3.3,-8.7,-10,-18c-135.3,-192.7,-235.5,-414.3,-300.5,-665c-65,-250.7,-102.5,
-544.7,-112.5,-882c-2,-104,-3,-167,-3,-189
l0,-`+(n+92)+`c0,-162.7,5.7,-314,17,-454c20.7,-272,63.7,-513,129,-723c65.3,
-210,155.3,-396.3,270,-559c6.7,-9.3,10,-15.3,10,-18z`;case"rparen":return`M76,0c-16.7,0,-25,3,-25,9c0,2,2,6.3,6,13c21.3,28.7,42.3,60.3,
63,95c96.7,156.7,172.8,332.5,228.5,527.5c55.7,195,92.8,416.5,111.5,664.5
c11.3,139.3,17,290.7,17,454c0,28,1.7,43,3.3,45l0,`+(n+9)+`
c-3,4,-3.3,16.7,-3.3,38c0,162,-5.7,313.7,-17,455c-18.7,248,-55.8,469.3,-111.5,664
c-55.7,194.7,-131.8,370.3,-228.5,527c-20.7,34.7,-41.7,66.3,-63,95c-2,3.3,-4,7,-6,11
c0,7.3,5.7,11,17,11c0,0,11,0,11,0c9.3,0,14.3,-0.3,15,-1c5.3,-5.3,10.3,-11,15,-17
c242.7,-294.7,395.3,-681.7,458,-1161c21.3,-164.7,33.3,-350.7,36,-558
l0,-`+(n+144)+`c-2,-159.3,-10,-310.7,-24,-454c-53.3,-528,-210,-949.7,
-470,-1265c-4.7,-6,-9.7,-11.7,-15,-17c-0.7,-0.7,-6.7,-1,-18,-1z`;default:throw new Error("Unknown stretchy delimiter.")}};class wo{constructor(t){this.children=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.children=t,this.classes=[],this.height=0,this.depth=0,this.maxFontSize=0,this.style={}}hasClass(t){return We.contains(this.classes,t)}toNode(){for(var t=document.createDocumentFragment(),n=0;n<this.children.length;n++)t.appendChild(this.children[n].toNode());return t}toMarkup(){for(var t="",n=0;n<this.children.length;n++)t+=this.children[n].toMarkup();return t}toText(){var t=n=>n.toText();return this.children.map(t).join("")}}var Na={"AMS-Regular":{32:[0,0,0,0,.25],65:[0,.68889,0,0,.72222],66:[0,.68889,0,0,.66667],67:[0,.68889,0,0,.72222],68:[0,.68889,0,0,.72222],69:[0,.68889,0,0,.66667],70:[0,.68889,0,0,.61111],71:[0,.68889,0,0,.77778],72:[0,.68889,0,0,.77778],73:[0,.68889,0,0,.38889],74:[.16667,.68889,0,0,.5],75:[0,.68889,0,0,.77778],76:[0,.68889,0,0,.66667],77:[0,.68889,0,0,.94445],78:[0,.68889,0,0,.72222],79:[.16667,.68889,0,0,.77778],80:[0,.68889,0,0,.61111],81:[.16667,.68889,0,0,.77778],82:[0,.68889,0,0,.72222],83:[0,.68889,0,0,.55556],84:[0,.68889,0,0,.66667],85:[0,.68889,0,0,.72222],86:[0,.68889,0,0,.72222],87:[0,.68889,0,0,1],88:[0,.68889,0,0,.72222],89:[0,.68889,0,0,.72222],90:[0,.68889,0,0,.66667],107:[0,.68889,0,0,.55556],160:[0,0,0,0,.25],165:[0,.675,.025,0,.75],174:[.15559,.69224,0,0,.94666],240:[0,.68889,0,0,.55556],295:[0,.68889,0,0,.54028],710:[0,.825,0,0,2.33334],732:[0,.9,0,0,2.33334],770:[0,.825,0,0,2.33334],771:[0,.9,0,0,2.33334],989:[.08167,.58167,0,0,.77778],1008:[0,.43056,.04028,0,.66667],8245:[0,.54986,0,0,.275],8463:[0,.68889,0,0,.54028],8487:[0,.68889,0,0,.72222],8498:[0,.68889,0,0,.55556],8502:[0,.68889,0,0,.66667],8503:[0,.68889,0,0,.44445],8504:[0,.68889,0,0,.66667],8513:[0,.68889,0,0,.63889],8592:[-.03598,.46402,0,0,.5],8594:[-.03598,.46402,0,0,.5],8602:[-.13313,.36687,0,0,1],8603:[-.13313,.36687,0,0,1],8606:[.01354,.52239,0,0,1],8608:[.01354,.52239,0,0,1],8610:[.01354,.52239,0,0,1.11111],8611:[.01354,.52239,0,0,1.11111],8619:[0,.54986,0,0,1],8620:[0,.54986,0,0,1],8621:[-.13313,.37788,0,0,1.38889],8622:[-.13313,.36687,0,0,1],8624:[0,.69224,0,0,.5],8625:[0,.69224,0,0,.5],8630:[0,.43056,0,0,1],8631:[0,.43056,0,0,1],8634:[.08198,.58198,0,0,.77778],8635:[.08198,.58198,0,0,.77778],8638:[.19444,.69224,0,0,.41667],8639:[.19444,.69224,0,0,.41667],8642:[.19444,.69224,0,0,.41667],8643:[.19444,.69224,0,0,.41667],8644:[.1808,.675,0,0,1],8646:[.1808,.675,0,0,1],8647:[.1808,.675,0,0,1],8648:[.19444,.69224,0,0,.83334],8649:[.1808,.675,0,0,1],8650:[.19444,.69224,0,0,.83334],8651:[.01354,.52239,0,0,1],8652:[.01354,.52239,0,0,1],8653:[-.13313,.36687,0,0,1],8654:[-.13313,.36687,0,0,1],8655:[-.13313,.36687,0,0,1],8666:[.13667,.63667,0,0,1],8667:[.13667,.63667,0,0,1],8669:[-.13313,.37788,0,0,1],8672:[-.064,.437,0,0,1.334],8674:[-.064,.437,0,0,1.334],8705:[0,.825,0,0,.5],8708:[0,.68889,0,0,.55556],8709:[.08167,.58167,0,0,.77778],8717:[0,.43056,0,0,.42917],8722:[-.03598,.46402,0,0,.5],8724:[.08198,.69224,0,0,.77778],8726:[.08167,.58167,0,0,.77778],8733:[0,.69224,0,0,.77778],8736:[0,.69224,0,0,.72222],8737:[0,.69224,0,0,.72222],8738:[.03517,.52239,0,0,.72222],8739:[.08167,.58167,0,0,.22222],8740:[.25142,.74111,0,0,.27778],8741:[.08167,.58167,0,0,.38889],8742:[.25142,.74111,0,0,.5],8756:[0,.69224,0,0,.66667],8757:[0,.69224,0,0,.66667],8764:[-.13313,.36687,0,0,.77778],8765:[-.13313,.37788,0,0,.77778],8769:[-.13313,.36687,0,0,.77778],8770:[-.03625,.46375,0,0,.77778],8774:[.30274,.79383,0,0,.77778],8776:[-.01688,.48312,0,0,.77778],8778:[.08167,.58167,0,0,.77778],8782:[.06062,.54986,0,0,.77778],8783:[.06062,.54986,0,0,.77778],8785:[.08198,.58198,0,0,.77778],8786:[.08198,.58198,0,0,.77778],8787:[.08198,.58198,0,0,.77778],8790:[0,.69224,0,0,.77778],8791:[.22958,.72958,0,0,.77778],8796:[.08198,.91667,0,0,.77778],8806:[.25583,.75583,0,0,.77778],8807:[.25583,.75583,0,0,.77778],8808:[.25142,.75726,0,0,.77778],8809:[.25142,.75726,0,0,.77778],8812:[.25583,.75583,0,0,.5],8814:[.20576,.70576,0,0,.77778],8815:[.20576,.70576,0,0,.77778],8816:[.30274,.79383,0,0,.77778],8817:[.30274,.79383,0,0,.77778],8818:[.22958,.72958,0,0,.77778],8819:[.22958,.72958,0,0,.77778],8822:[.1808,.675,0,0,.77778],8823:[.1808,.675,0,0,.77778],8828:[.13667,.63667,0,0,.77778],8829:[.13667,.63667,0,0,.77778],8830:[.22958,.72958,0,0,.77778],8831:[.22958,.72958,0,0,.77778],8832:[.20576,.70576,0,0,.77778],8833:[.20576,.70576,0,0,.77778],8840:[.30274,.79383,0,0,.77778],8841:[.30274,.79383,0,0,.77778],8842:[.13597,.63597,0,0,.77778],8843:[.13597,.63597,0,0,.77778],8847:[.03517,.54986,0,0,.77778],8848:[.03517,.54986,0,0,.77778],8858:[.08198,.58198,0,0,.77778],8859:[.08198,.58198,0,0,.77778],8861:[.08198,.58198,0,0,.77778],8862:[0,.675,0,0,.77778],8863:[0,.675,0,0,.77778],8864:[0,.675,0,0,.77778],8865:[0,.675,0,0,.77778],8872:[0,.69224,0,0,.61111],8873:[0,.69224,0,0,.72222],8874:[0,.69224,0,0,.88889],8876:[0,.68889,0,0,.61111],8877:[0,.68889,0,0,.61111],8878:[0,.68889,0,0,.72222],8879:[0,.68889,0,0,.72222],8882:[.03517,.54986,0,0,.77778],8883:[.03517,.54986,0,0,.77778],8884:[.13667,.63667,0,0,.77778],8885:[.13667,.63667,0,0,.77778],8888:[0,.54986,0,0,1.11111],8890:[.19444,.43056,0,0,.55556],8891:[.19444,.69224,0,0,.61111],8892:[.19444,.69224,0,0,.61111],8901:[0,.54986,0,0,.27778],8903:[.08167,.58167,0,0,.77778],8905:[.08167,.58167,0,0,.77778],8906:[.08167,.58167,0,0,.77778],8907:[0,.69224,0,0,.77778],8908:[0,.69224,0,0,.77778],8909:[-.03598,.46402,0,0,.77778],8910:[0,.54986,0,0,.76042],8911:[0,.54986,0,0,.76042],8912:[.03517,.54986,0,0,.77778],8913:[.03517,.54986,0,0,.77778],8914:[0,.54986,0,0,.66667],8915:[0,.54986,0,0,.66667],8916:[0,.69224,0,0,.66667],8918:[.0391,.5391,0,0,.77778],8919:[.0391,.5391,0,0,.77778],8920:[.03517,.54986,0,0,1.33334],8921:[.03517,.54986,0,0,1.33334],8922:[.38569,.88569,0,0,.77778],8923:[.38569,.88569,0,0,.77778],8926:[.13667,.63667,0,0,.77778],8927:[.13667,.63667,0,0,.77778],8928:[.30274,.79383,0,0,.77778],8929:[.30274,.79383,0,0,.77778],8934:[.23222,.74111,0,0,.77778],8935:[.23222,.74111,0,0,.77778],8936:[.23222,.74111,0,0,.77778],8937:[.23222,.74111,0,0,.77778],8938:[.20576,.70576,0,0,.77778],8939:[.20576,.70576,0,0,.77778],8940:[.30274,.79383,0,0,.77778],8941:[.30274,.79383,0,0,.77778],8994:[.19444,.69224,0,0,.77778],8995:[.19444,.69224,0,0,.77778],9416:[.15559,.69224,0,0,.90222],9484:[0,.69224,0,0,.5],9488:[0,.69224,0,0,.5],9492:[0,.37788,0,0,.5],9496:[0,.37788,0,0,.5],9585:[.19444,.68889,0,0,.88889],9586:[.19444,.74111,0,0,.88889],9632:[0,.675,0,0,.77778],9633:[0,.675,0,0,.77778],9650:[0,.54986,0,0,.72222],9651:[0,.54986,0,0,.72222],9654:[.03517,.54986,0,0,.77778],9660:[0,.54986,0,0,.72222],9661:[0,.54986,0,0,.72222],9664:[.03517,.54986,0,0,.77778],9674:[.11111,.69224,0,0,.66667],9733:[.19444,.69224,0,0,.94445],10003:[0,.69224,0,0,.83334],10016:[0,.69224,0,0,.83334],10731:[.11111,.69224,0,0,.66667],10846:[.19444,.75583,0,0,.61111],10877:[.13667,.63667,0,0,.77778],10878:[.13667,.63667,0,0,.77778],10885:[.25583,.75583,0,0,.77778],10886:[.25583,.75583,0,0,.77778],10887:[.13597,.63597,0,0,.77778],10888:[.13597,.63597,0,0,.77778],10889:[.26167,.75726,0,0,.77778],10890:[.26167,.75726,0,0,.77778],10891:[.48256,.98256,0,0,.77778],10892:[.48256,.98256,0,0,.77778],10901:[.13667,.63667,0,0,.77778],10902:[.13667,.63667,0,0,.77778],10933:[.25142,.75726,0,0,.77778],10934:[.25142,.75726,0,0,.77778],10935:[.26167,.75726,0,0,.77778],10936:[.26167,.75726,0,0,.77778],10937:[.26167,.75726,0,0,.77778],10938:[.26167,.75726,0,0,.77778],10949:[.25583,.75583,0,0,.77778],10950:[.25583,.75583,0,0,.77778],10955:[.28481,.79383,0,0,.77778],10956:[.28481,.79383,0,0,.77778],57350:[.08167,.58167,0,0,.22222],57351:[.08167,.58167,0,0,.38889],57352:[.08167,.58167,0,0,.77778],57353:[0,.43056,.04028,0,.66667],57356:[.25142,.75726,0,0,.77778],57357:[.25142,.75726,0,0,.77778],57358:[.41951,.91951,0,0,.77778],57359:[.30274,.79383,0,0,.77778],57360:[.30274,.79383,0,0,.77778],57361:[.41951,.91951,0,0,.77778],57366:[.25142,.75726,0,0,.77778],57367:[.25142,.75726,0,0,.77778],57368:[.25142,.75726,0,0,.77778],57369:[.25142,.75726,0,0,.77778],57370:[.13597,.63597,0,0,.77778],57371:[.13597,.63597,0,0,.77778]},"Caligraphic-Regular":{32:[0,0,0,0,.25],65:[0,.68333,0,.19445,.79847],66:[0,.68333,.03041,.13889,.65681],67:[0,.68333,.05834,.13889,.52653],68:[0,.68333,.02778,.08334,.77139],69:[0,.68333,.08944,.11111,.52778],70:[0,.68333,.09931,.11111,.71875],71:[.09722,.68333,.0593,.11111,.59487],72:[0,.68333,.00965,.11111,.84452],73:[0,.68333,.07382,0,.54452],74:[.09722,.68333,.18472,.16667,.67778],75:[0,.68333,.01445,.05556,.76195],76:[0,.68333,0,.13889,.68972],77:[0,.68333,0,.13889,1.2009],78:[0,.68333,.14736,.08334,.82049],79:[0,.68333,.02778,.11111,.79611],80:[0,.68333,.08222,.08334,.69556],81:[.09722,.68333,0,.11111,.81667],82:[0,.68333,0,.08334,.8475],83:[0,.68333,.075,.13889,.60556],84:[0,.68333,.25417,0,.54464],85:[0,.68333,.09931,.08334,.62583],86:[0,.68333,.08222,0,.61278],87:[0,.68333,.08222,.08334,.98778],88:[0,.68333,.14643,.13889,.7133],89:[.09722,.68333,.08222,.08334,.66834],90:[0,.68333,.07944,.13889,.72473],160:[0,0,0,0,.25]},"Fraktur-Regular":{32:[0,0,0,0,.25],33:[0,.69141,0,0,.29574],34:[0,.69141,0,0,.21471],38:[0,.69141,0,0,.73786],39:[0,.69141,0,0,.21201],40:[.24982,.74947,0,0,.38865],41:[.24982,.74947,0,0,.38865],42:[0,.62119,0,0,.27764],43:[.08319,.58283,0,0,.75623],44:[0,.10803,0,0,.27764],45:[.08319,.58283,0,0,.75623],46:[0,.10803,0,0,.27764],47:[.24982,.74947,0,0,.50181],48:[0,.47534,0,0,.50181],49:[0,.47534,0,0,.50181],50:[0,.47534,0,0,.50181],51:[.18906,.47534,0,0,.50181],52:[.18906,.47534,0,0,.50181],53:[.18906,.47534,0,0,.50181],54:[0,.69141,0,0,.50181],55:[.18906,.47534,0,0,.50181],56:[0,.69141,0,0,.50181],57:[.18906,.47534,0,0,.50181],58:[0,.47534,0,0,.21606],59:[.12604,.47534,0,0,.21606],61:[-.13099,.36866,0,0,.75623],63:[0,.69141,0,0,.36245],65:[0,.69141,0,0,.7176],66:[0,.69141,0,0,.88397],67:[0,.69141,0,0,.61254],68:[0,.69141,0,0,.83158],69:[0,.69141,0,0,.66278],70:[.12604,.69141,0,0,.61119],71:[0,.69141,0,0,.78539],72:[.06302,.69141,0,0,.7203],73:[0,.69141,0,0,.55448],74:[.12604,.69141,0,0,.55231],75:[0,.69141,0,0,.66845],76:[0,.69141,0,0,.66602],77:[0,.69141,0,0,1.04953],78:[0,.69141,0,0,.83212],79:[0,.69141,0,0,.82699],80:[.18906,.69141,0,0,.82753],81:[.03781,.69141,0,0,.82699],82:[0,.69141,0,0,.82807],83:[0,.69141,0,0,.82861],84:[0,.69141,0,0,.66899],85:[0,.69141,0,0,.64576],86:[0,.69141,0,0,.83131],87:[0,.69141,0,0,1.04602],88:[0,.69141,0,0,.71922],89:[.18906,.69141,0,0,.83293],90:[.12604,.69141,0,0,.60201],91:[.24982,.74947,0,0,.27764],93:[.24982,.74947,0,0,.27764],94:[0,.69141,0,0,.49965],97:[0,.47534,0,0,.50046],98:[0,.69141,0,0,.51315],99:[0,.47534,0,0,.38946],100:[0,.62119,0,0,.49857],101:[0,.47534,0,0,.40053],102:[.18906,.69141,0,0,.32626],103:[.18906,.47534,0,0,.5037],104:[.18906,.69141,0,0,.52126],105:[0,.69141,0,0,.27899],106:[0,.69141,0,0,.28088],107:[0,.69141,0,0,.38946],108:[0,.69141,0,0,.27953],109:[0,.47534,0,0,.76676],110:[0,.47534,0,0,.52666],111:[0,.47534,0,0,.48885],112:[.18906,.52396,0,0,.50046],113:[.18906,.47534,0,0,.48912],114:[0,.47534,0,0,.38919],115:[0,.47534,0,0,.44266],116:[0,.62119,0,0,.33301],117:[0,.47534,0,0,.5172],118:[0,.52396,0,0,.5118],119:[0,.52396,0,0,.77351],120:[.18906,.47534,0,0,.38865],121:[.18906,.47534,0,0,.49884],122:[.18906,.47534,0,0,.39054],160:[0,0,0,0,.25],8216:[0,.69141,0,0,.21471],8217:[0,.69141,0,0,.21471],58112:[0,.62119,0,0,.49749],58113:[0,.62119,0,0,.4983],58114:[.18906,.69141,0,0,.33328],58115:[.18906,.69141,0,0,.32923],58116:[.18906,.47534,0,0,.50343],58117:[0,.69141,0,0,.33301],58118:[0,.62119,0,0,.33409],58119:[0,.47534,0,0,.50073]},"Main-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.35],34:[0,.69444,0,0,.60278],35:[.19444,.69444,0,0,.95833],36:[.05556,.75,0,0,.575],37:[.05556,.75,0,0,.95833],38:[0,.69444,0,0,.89444],39:[0,.69444,0,0,.31944],40:[.25,.75,0,0,.44722],41:[.25,.75,0,0,.44722],42:[0,.75,0,0,.575],43:[.13333,.63333,0,0,.89444],44:[.19444,.15556,0,0,.31944],45:[0,.44444,0,0,.38333],46:[0,.15556,0,0,.31944],47:[.25,.75,0,0,.575],48:[0,.64444,0,0,.575],49:[0,.64444,0,0,.575],50:[0,.64444,0,0,.575],51:[0,.64444,0,0,.575],52:[0,.64444,0,0,.575],53:[0,.64444,0,0,.575],54:[0,.64444,0,0,.575],55:[0,.64444,0,0,.575],56:[0,.64444,0,0,.575],57:[0,.64444,0,0,.575],58:[0,.44444,0,0,.31944],59:[.19444,.44444,0,0,.31944],60:[.08556,.58556,0,0,.89444],61:[-.10889,.39111,0,0,.89444],62:[.08556,.58556,0,0,.89444],63:[0,.69444,0,0,.54305],64:[0,.69444,0,0,.89444],65:[0,.68611,0,0,.86944],66:[0,.68611,0,0,.81805],67:[0,.68611,0,0,.83055],68:[0,.68611,0,0,.88194],69:[0,.68611,0,0,.75555],70:[0,.68611,0,0,.72361],71:[0,.68611,0,0,.90416],72:[0,.68611,0,0,.9],73:[0,.68611,0,0,.43611],74:[0,.68611,0,0,.59444],75:[0,.68611,0,0,.90138],76:[0,.68611,0,0,.69166],77:[0,.68611,0,0,1.09166],78:[0,.68611,0,0,.9],79:[0,.68611,0,0,.86388],80:[0,.68611,0,0,.78611],81:[.19444,.68611,0,0,.86388],82:[0,.68611,0,0,.8625],83:[0,.68611,0,0,.63889],84:[0,.68611,0,0,.8],85:[0,.68611,0,0,.88472],86:[0,.68611,.01597,0,.86944],87:[0,.68611,.01597,0,1.18888],88:[0,.68611,0,0,.86944],89:[0,.68611,.02875,0,.86944],90:[0,.68611,0,0,.70277],91:[.25,.75,0,0,.31944],92:[.25,.75,0,0,.575],93:[.25,.75,0,0,.31944],94:[0,.69444,0,0,.575],95:[.31,.13444,.03194,0,.575],97:[0,.44444,0,0,.55902],98:[0,.69444,0,0,.63889],99:[0,.44444,0,0,.51111],100:[0,.69444,0,0,.63889],101:[0,.44444,0,0,.52708],102:[0,.69444,.10903,0,.35139],103:[.19444,.44444,.01597,0,.575],104:[0,.69444,0,0,.63889],105:[0,.69444,0,0,.31944],106:[.19444,.69444,0,0,.35139],107:[0,.69444,0,0,.60694],108:[0,.69444,0,0,.31944],109:[0,.44444,0,0,.95833],110:[0,.44444,0,0,.63889],111:[0,.44444,0,0,.575],112:[.19444,.44444,0,0,.63889],113:[.19444,.44444,0,0,.60694],114:[0,.44444,0,0,.47361],115:[0,.44444,0,0,.45361],116:[0,.63492,0,0,.44722],117:[0,.44444,0,0,.63889],118:[0,.44444,.01597,0,.60694],119:[0,.44444,.01597,0,.83055],120:[0,.44444,0,0,.60694],121:[.19444,.44444,.01597,0,.60694],122:[0,.44444,0,0,.51111],123:[.25,.75,0,0,.575],124:[.25,.75,0,0,.31944],125:[.25,.75,0,0,.575],126:[.35,.34444,0,0,.575],160:[0,0,0,0,.25],163:[0,.69444,0,0,.86853],168:[0,.69444,0,0,.575],172:[0,.44444,0,0,.76666],176:[0,.69444,0,0,.86944],177:[.13333,.63333,0,0,.89444],184:[.17014,0,0,0,.51111],198:[0,.68611,0,0,1.04166],215:[.13333,.63333,0,0,.89444],216:[.04861,.73472,0,0,.89444],223:[0,.69444,0,0,.59722],230:[0,.44444,0,0,.83055],247:[.13333,.63333,0,0,.89444],248:[.09722,.54167,0,0,.575],305:[0,.44444,0,0,.31944],338:[0,.68611,0,0,1.16944],339:[0,.44444,0,0,.89444],567:[.19444,.44444,0,0,.35139],710:[0,.69444,0,0,.575],711:[0,.63194,0,0,.575],713:[0,.59611,0,0,.575],714:[0,.69444,0,0,.575],715:[0,.69444,0,0,.575],728:[0,.69444,0,0,.575],729:[0,.69444,0,0,.31944],730:[0,.69444,0,0,.86944],732:[0,.69444,0,0,.575],733:[0,.69444,0,0,.575],915:[0,.68611,0,0,.69166],916:[0,.68611,0,0,.95833],920:[0,.68611,0,0,.89444],923:[0,.68611,0,0,.80555],926:[0,.68611,0,0,.76666],928:[0,.68611,0,0,.9],931:[0,.68611,0,0,.83055],933:[0,.68611,0,0,.89444],934:[0,.68611,0,0,.83055],936:[0,.68611,0,0,.89444],937:[0,.68611,0,0,.83055],8211:[0,.44444,.03194,0,.575],8212:[0,.44444,.03194,0,1.14999],8216:[0,.69444,0,0,.31944],8217:[0,.69444,0,0,.31944],8220:[0,.69444,0,0,.60278],8221:[0,.69444,0,0,.60278],8224:[.19444,.69444,0,0,.51111],8225:[.19444,.69444,0,0,.51111],8242:[0,.55556,0,0,.34444],8407:[0,.72444,.15486,0,.575],8463:[0,.69444,0,0,.66759],8465:[0,.69444,0,0,.83055],8467:[0,.69444,0,0,.47361],8472:[.19444,.44444,0,0,.74027],8476:[0,.69444,0,0,.83055],8501:[0,.69444,0,0,.70277],8592:[-.10889,.39111,0,0,1.14999],8593:[.19444,.69444,0,0,.575],8594:[-.10889,.39111,0,0,1.14999],8595:[.19444,.69444,0,0,.575],8596:[-.10889,.39111,0,0,1.14999],8597:[.25,.75,0,0,.575],8598:[.19444,.69444,0,0,1.14999],8599:[.19444,.69444,0,0,1.14999],8600:[.19444,.69444,0,0,1.14999],8601:[.19444,.69444,0,0,1.14999],8636:[-.10889,.39111,0,0,1.14999],8637:[-.10889,.39111,0,0,1.14999],8640:[-.10889,.39111,0,0,1.14999],8641:[-.10889,.39111,0,0,1.14999],8656:[-.10889,.39111,0,0,1.14999],8657:[.19444,.69444,0,0,.70277],8658:[-.10889,.39111,0,0,1.14999],8659:[.19444,.69444,0,0,.70277],8660:[-.10889,.39111,0,0,1.14999],8661:[.25,.75,0,0,.70277],8704:[0,.69444,0,0,.63889],8706:[0,.69444,.06389,0,.62847],8707:[0,.69444,0,0,.63889],8709:[.05556,.75,0,0,.575],8711:[0,.68611,0,0,.95833],8712:[.08556,.58556,0,0,.76666],8715:[.08556,.58556,0,0,.76666],8722:[.13333,.63333,0,0,.89444],8723:[.13333,.63333,0,0,.89444],8725:[.25,.75,0,0,.575],8726:[.25,.75,0,0,.575],8727:[-.02778,.47222,0,0,.575],8728:[-.02639,.47361,0,0,.575],8729:[-.02639,.47361,0,0,.575],8730:[.18,.82,0,0,.95833],8733:[0,.44444,0,0,.89444],8734:[0,.44444,0,0,1.14999],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.31944],8741:[.25,.75,0,0,.575],8743:[0,.55556,0,0,.76666],8744:[0,.55556,0,0,.76666],8745:[0,.55556,0,0,.76666],8746:[0,.55556,0,0,.76666],8747:[.19444,.69444,.12778,0,.56875],8764:[-.10889,.39111,0,0,.89444],8768:[.19444,.69444,0,0,.31944],8771:[.00222,.50222,0,0,.89444],8773:[.027,.638,0,0,.894],8776:[.02444,.52444,0,0,.89444],8781:[.00222,.50222,0,0,.89444],8801:[.00222,.50222,0,0,.89444],8804:[.19667,.69667,0,0,.89444],8805:[.19667,.69667,0,0,.89444],8810:[.08556,.58556,0,0,1.14999],8811:[.08556,.58556,0,0,1.14999],8826:[.08556,.58556,0,0,.89444],8827:[.08556,.58556,0,0,.89444],8834:[.08556,.58556,0,0,.89444],8835:[.08556,.58556,0,0,.89444],8838:[.19667,.69667,0,0,.89444],8839:[.19667,.69667,0,0,.89444],8846:[0,.55556,0,0,.76666],8849:[.19667,.69667,0,0,.89444],8850:[.19667,.69667,0,0,.89444],8851:[0,.55556,0,0,.76666],8852:[0,.55556,0,0,.76666],8853:[.13333,.63333,0,0,.89444],8854:[.13333,.63333,0,0,.89444],8855:[.13333,.63333,0,0,.89444],8856:[.13333,.63333,0,0,.89444],8857:[.13333,.63333,0,0,.89444],8866:[0,.69444,0,0,.70277],8867:[0,.69444,0,0,.70277],8868:[0,.69444,0,0,.89444],8869:[0,.69444,0,0,.89444],8900:[-.02639,.47361,0,0,.575],8901:[-.02639,.47361,0,0,.31944],8902:[-.02778,.47222,0,0,.575],8968:[.25,.75,0,0,.51111],8969:[.25,.75,0,0,.51111],8970:[.25,.75,0,0,.51111],8971:[.25,.75,0,0,.51111],8994:[-.13889,.36111,0,0,1.14999],8995:[-.13889,.36111,0,0,1.14999],9651:[.19444,.69444,0,0,1.02222],9657:[-.02778,.47222,0,0,.575],9661:[.19444,.69444,0,0,1.02222],9667:[-.02778,.47222,0,0,.575],9711:[.19444,.69444,0,0,1.14999],9824:[.12963,.69444,0,0,.89444],9825:[.12963,.69444,0,0,.89444],9826:[.12963,.69444,0,0,.89444],9827:[.12963,.69444,0,0,.89444],9837:[0,.75,0,0,.44722],9838:[.19444,.69444,0,0,.44722],9839:[.19444,.69444,0,0,.44722],10216:[.25,.75,0,0,.44722],10217:[.25,.75,0,0,.44722],10815:[0,.68611,0,0,.9],10927:[.19667,.69667,0,0,.89444],10928:[.19667,.69667,0,0,.89444],57376:[.19444,.69444,0,0,0]},"Main-BoldItalic":{32:[0,0,0,0,.25],33:[0,.69444,.11417,0,.38611],34:[0,.69444,.07939,0,.62055],35:[.19444,.69444,.06833,0,.94444],37:[.05556,.75,.12861,0,.94444],38:[0,.69444,.08528,0,.88555],39:[0,.69444,.12945,0,.35555],40:[.25,.75,.15806,0,.47333],41:[.25,.75,.03306,0,.47333],42:[0,.75,.14333,0,.59111],43:[.10333,.60333,.03306,0,.88555],44:[.19444,.14722,0,0,.35555],45:[0,.44444,.02611,0,.41444],46:[0,.14722,0,0,.35555],47:[.25,.75,.15806,0,.59111],48:[0,.64444,.13167,0,.59111],49:[0,.64444,.13167,0,.59111],50:[0,.64444,.13167,0,.59111],51:[0,.64444,.13167,0,.59111],52:[.19444,.64444,.13167,0,.59111],53:[0,.64444,.13167,0,.59111],54:[0,.64444,.13167,0,.59111],55:[.19444,.64444,.13167,0,.59111],56:[0,.64444,.13167,0,.59111],57:[0,.64444,.13167,0,.59111],58:[0,.44444,.06695,0,.35555],59:[.19444,.44444,.06695,0,.35555],61:[-.10889,.39111,.06833,0,.88555],63:[0,.69444,.11472,0,.59111],64:[0,.69444,.09208,0,.88555],65:[0,.68611,0,0,.86555],66:[0,.68611,.0992,0,.81666],67:[0,.68611,.14208,0,.82666],68:[0,.68611,.09062,0,.87555],69:[0,.68611,.11431,0,.75666],70:[0,.68611,.12903,0,.72722],71:[0,.68611,.07347,0,.89527],72:[0,.68611,.17208,0,.8961],73:[0,.68611,.15681,0,.47166],74:[0,.68611,.145,0,.61055],75:[0,.68611,.14208,0,.89499],76:[0,.68611,0,0,.69777],77:[0,.68611,.17208,0,1.07277],78:[0,.68611,.17208,0,.8961],79:[0,.68611,.09062,0,.85499],80:[0,.68611,.0992,0,.78721],81:[.19444,.68611,.09062,0,.85499],82:[0,.68611,.02559,0,.85944],83:[0,.68611,.11264,0,.64999],84:[0,.68611,.12903,0,.7961],85:[0,.68611,.17208,0,.88083],86:[0,.68611,.18625,0,.86555],87:[0,.68611,.18625,0,1.15999],88:[0,.68611,.15681,0,.86555],89:[0,.68611,.19803,0,.86555],90:[0,.68611,.14208,0,.70888],91:[.25,.75,.1875,0,.35611],93:[.25,.75,.09972,0,.35611],94:[0,.69444,.06709,0,.59111],95:[.31,.13444,.09811,0,.59111],97:[0,.44444,.09426,0,.59111],98:[0,.69444,.07861,0,.53222],99:[0,.44444,.05222,0,.53222],100:[0,.69444,.10861,0,.59111],101:[0,.44444,.085,0,.53222],102:[.19444,.69444,.21778,0,.4],103:[.19444,.44444,.105,0,.53222],104:[0,.69444,.09426,0,.59111],105:[0,.69326,.11387,0,.35555],106:[.19444,.69326,.1672,0,.35555],107:[0,.69444,.11111,0,.53222],108:[0,.69444,.10861,0,.29666],109:[0,.44444,.09426,0,.94444],110:[0,.44444,.09426,0,.64999],111:[0,.44444,.07861,0,.59111],112:[.19444,.44444,.07861,0,.59111],113:[.19444,.44444,.105,0,.53222],114:[0,.44444,.11111,0,.50167],115:[0,.44444,.08167,0,.48694],116:[0,.63492,.09639,0,.385],117:[0,.44444,.09426,0,.62055],118:[0,.44444,.11111,0,.53222],119:[0,.44444,.11111,0,.76777],120:[0,.44444,.12583,0,.56055],121:[.19444,.44444,.105,0,.56166],122:[0,.44444,.13889,0,.49055],126:[.35,.34444,.11472,0,.59111],160:[0,0,0,0,.25],168:[0,.69444,.11473,0,.59111],176:[0,.69444,0,0,.94888],184:[.17014,0,0,0,.53222],198:[0,.68611,.11431,0,1.02277],216:[.04861,.73472,.09062,0,.88555],223:[.19444,.69444,.09736,0,.665],230:[0,.44444,.085,0,.82666],248:[.09722,.54167,.09458,0,.59111],305:[0,.44444,.09426,0,.35555],338:[0,.68611,.11431,0,1.14054],339:[0,.44444,.085,0,.82666],567:[.19444,.44444,.04611,0,.385],710:[0,.69444,.06709,0,.59111],711:[0,.63194,.08271,0,.59111],713:[0,.59444,.10444,0,.59111],714:[0,.69444,.08528,0,.59111],715:[0,.69444,0,0,.59111],728:[0,.69444,.10333,0,.59111],729:[0,.69444,.12945,0,.35555],730:[0,.69444,0,0,.94888],732:[0,.69444,.11472,0,.59111],733:[0,.69444,.11472,0,.59111],915:[0,.68611,.12903,0,.69777],916:[0,.68611,0,0,.94444],920:[0,.68611,.09062,0,.88555],923:[0,.68611,0,0,.80666],926:[0,.68611,.15092,0,.76777],928:[0,.68611,.17208,0,.8961],931:[0,.68611,.11431,0,.82666],933:[0,.68611,.10778,0,.88555],934:[0,.68611,.05632,0,.82666],936:[0,.68611,.10778,0,.88555],937:[0,.68611,.0992,0,.82666],8211:[0,.44444,.09811,0,.59111],8212:[0,.44444,.09811,0,1.18221],8216:[0,.69444,.12945,0,.35555],8217:[0,.69444,.12945,0,.35555],8220:[0,.69444,.16772,0,.62055],8221:[0,.69444,.07939,0,.62055]},"Main-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.12417,0,.30667],34:[0,.69444,.06961,0,.51444],35:[.19444,.69444,.06616,0,.81777],37:[.05556,.75,.13639,0,.81777],38:[0,.69444,.09694,0,.76666],39:[0,.69444,.12417,0,.30667],40:[.25,.75,.16194,0,.40889],41:[.25,.75,.03694,0,.40889],42:[0,.75,.14917,0,.51111],43:[.05667,.56167,.03694,0,.76666],44:[.19444,.10556,0,0,.30667],45:[0,.43056,.02826,0,.35778],46:[0,.10556,0,0,.30667],47:[.25,.75,.16194,0,.51111],48:[0,.64444,.13556,0,.51111],49:[0,.64444,.13556,0,.51111],50:[0,.64444,.13556,0,.51111],51:[0,.64444,.13556,0,.51111],52:[.19444,.64444,.13556,0,.51111],53:[0,.64444,.13556,0,.51111],54:[0,.64444,.13556,0,.51111],55:[.19444,.64444,.13556,0,.51111],56:[0,.64444,.13556,0,.51111],57:[0,.64444,.13556,0,.51111],58:[0,.43056,.0582,0,.30667],59:[.19444,.43056,.0582,0,.30667],61:[-.13313,.36687,.06616,0,.76666],63:[0,.69444,.1225,0,.51111],64:[0,.69444,.09597,0,.76666],65:[0,.68333,0,0,.74333],66:[0,.68333,.10257,0,.70389],67:[0,.68333,.14528,0,.71555],68:[0,.68333,.09403,0,.755],69:[0,.68333,.12028,0,.67833],70:[0,.68333,.13305,0,.65277],71:[0,.68333,.08722,0,.77361],72:[0,.68333,.16389,0,.74333],73:[0,.68333,.15806,0,.38555],74:[0,.68333,.14028,0,.525],75:[0,.68333,.14528,0,.76888],76:[0,.68333,0,0,.62722],77:[0,.68333,.16389,0,.89666],78:[0,.68333,.16389,0,.74333],79:[0,.68333,.09403,0,.76666],80:[0,.68333,.10257,0,.67833],81:[.19444,.68333,.09403,0,.76666],82:[0,.68333,.03868,0,.72944],83:[0,.68333,.11972,0,.56222],84:[0,.68333,.13305,0,.71555],85:[0,.68333,.16389,0,.74333],86:[0,.68333,.18361,0,.74333],87:[0,.68333,.18361,0,.99888],88:[0,.68333,.15806,0,.74333],89:[0,.68333,.19383,0,.74333],90:[0,.68333,.14528,0,.61333],91:[.25,.75,.1875,0,.30667],93:[.25,.75,.10528,0,.30667],94:[0,.69444,.06646,0,.51111],95:[.31,.12056,.09208,0,.51111],97:[0,.43056,.07671,0,.51111],98:[0,.69444,.06312,0,.46],99:[0,.43056,.05653,0,.46],100:[0,.69444,.10333,0,.51111],101:[0,.43056,.07514,0,.46],102:[.19444,.69444,.21194,0,.30667],103:[.19444,.43056,.08847,0,.46],104:[0,.69444,.07671,0,.51111],105:[0,.65536,.1019,0,.30667],106:[.19444,.65536,.14467,0,.30667],107:[0,.69444,.10764,0,.46],108:[0,.69444,.10333,0,.25555],109:[0,.43056,.07671,0,.81777],110:[0,.43056,.07671,0,.56222],111:[0,.43056,.06312,0,.51111],112:[.19444,.43056,.06312,0,.51111],113:[.19444,.43056,.08847,0,.46],114:[0,.43056,.10764,0,.42166],115:[0,.43056,.08208,0,.40889],116:[0,.61508,.09486,0,.33222],117:[0,.43056,.07671,0,.53666],118:[0,.43056,.10764,0,.46],119:[0,.43056,.10764,0,.66444],120:[0,.43056,.12042,0,.46389],121:[.19444,.43056,.08847,0,.48555],122:[0,.43056,.12292,0,.40889],126:[.35,.31786,.11585,0,.51111],160:[0,0,0,0,.25],168:[0,.66786,.10474,0,.51111],176:[0,.69444,0,0,.83129],184:[.17014,0,0,0,.46],198:[0,.68333,.12028,0,.88277],216:[.04861,.73194,.09403,0,.76666],223:[.19444,.69444,.10514,0,.53666],230:[0,.43056,.07514,0,.71555],248:[.09722,.52778,.09194,0,.51111],338:[0,.68333,.12028,0,.98499],339:[0,.43056,.07514,0,.71555],710:[0,.69444,.06646,0,.51111],711:[0,.62847,.08295,0,.51111],713:[0,.56167,.10333,0,.51111],714:[0,.69444,.09694,0,.51111],715:[0,.69444,0,0,.51111],728:[0,.69444,.10806,0,.51111],729:[0,.66786,.11752,0,.30667],730:[0,.69444,0,0,.83129],732:[0,.66786,.11585,0,.51111],733:[0,.69444,.1225,0,.51111],915:[0,.68333,.13305,0,.62722],916:[0,.68333,0,0,.81777],920:[0,.68333,.09403,0,.76666],923:[0,.68333,0,0,.69222],926:[0,.68333,.15294,0,.66444],928:[0,.68333,.16389,0,.74333],931:[0,.68333,.12028,0,.71555],933:[0,.68333,.11111,0,.76666],934:[0,.68333,.05986,0,.71555],936:[0,.68333,.11111,0,.76666],937:[0,.68333,.10257,0,.71555],8211:[0,.43056,.09208,0,.51111],8212:[0,.43056,.09208,0,1.02222],8216:[0,.69444,.12417,0,.30667],8217:[0,.69444,.12417,0,.30667],8220:[0,.69444,.1685,0,.51444],8221:[0,.69444,.06961,0,.51444],8463:[0,.68889,0,0,.54028]},"Main-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.27778],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.77778],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.19444,.10556,0,0,.27778],45:[0,.43056,0,0,.33333],46:[0,.10556,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.64444,0,0,.5],49:[0,.64444,0,0,.5],50:[0,.64444,0,0,.5],51:[0,.64444,0,0,.5],52:[0,.64444,0,0,.5],53:[0,.64444,0,0,.5],54:[0,.64444,0,0,.5],55:[0,.64444,0,0,.5],56:[0,.64444,0,0,.5],57:[0,.64444,0,0,.5],58:[0,.43056,0,0,.27778],59:[.19444,.43056,0,0,.27778],60:[.0391,.5391,0,0,.77778],61:[-.13313,.36687,0,0,.77778],62:[.0391,.5391,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.77778],65:[0,.68333,0,0,.75],66:[0,.68333,0,0,.70834],67:[0,.68333,0,0,.72222],68:[0,.68333,0,0,.76389],69:[0,.68333,0,0,.68056],70:[0,.68333,0,0,.65278],71:[0,.68333,0,0,.78472],72:[0,.68333,0,0,.75],73:[0,.68333,0,0,.36111],74:[0,.68333,0,0,.51389],75:[0,.68333,0,0,.77778],76:[0,.68333,0,0,.625],77:[0,.68333,0,0,.91667],78:[0,.68333,0,0,.75],79:[0,.68333,0,0,.77778],80:[0,.68333,0,0,.68056],81:[.19444,.68333,0,0,.77778],82:[0,.68333,0,0,.73611],83:[0,.68333,0,0,.55556],84:[0,.68333,0,0,.72222],85:[0,.68333,0,0,.75],86:[0,.68333,.01389,0,.75],87:[0,.68333,.01389,0,1.02778],88:[0,.68333,0,0,.75],89:[0,.68333,.025,0,.75],90:[0,.68333,0,0,.61111],91:[.25,.75,0,0,.27778],92:[.25,.75,0,0,.5],93:[.25,.75,0,0,.27778],94:[0,.69444,0,0,.5],95:[.31,.12056,.02778,0,.5],97:[0,.43056,0,0,.5],98:[0,.69444,0,0,.55556],99:[0,.43056,0,0,.44445],100:[0,.69444,0,0,.55556],101:[0,.43056,0,0,.44445],102:[0,.69444,.07778,0,.30556],103:[.19444,.43056,.01389,0,.5],104:[0,.69444,0,0,.55556],105:[0,.66786,0,0,.27778],106:[.19444,.66786,0,0,.30556],107:[0,.69444,0,0,.52778],108:[0,.69444,0,0,.27778],109:[0,.43056,0,0,.83334],110:[0,.43056,0,0,.55556],111:[0,.43056,0,0,.5],112:[.19444,.43056,0,0,.55556],113:[.19444,.43056,0,0,.52778],114:[0,.43056,0,0,.39167],115:[0,.43056,0,0,.39445],116:[0,.61508,0,0,.38889],117:[0,.43056,0,0,.55556],118:[0,.43056,.01389,0,.52778],119:[0,.43056,.01389,0,.72222],120:[0,.43056,0,0,.52778],121:[.19444,.43056,.01389,0,.52778],122:[0,.43056,0,0,.44445],123:[.25,.75,0,0,.5],124:[.25,.75,0,0,.27778],125:[.25,.75,0,0,.5],126:[.35,.31786,0,0,.5],160:[0,0,0,0,.25],163:[0,.69444,0,0,.76909],167:[.19444,.69444,0,0,.44445],168:[0,.66786,0,0,.5],172:[0,.43056,0,0,.66667],176:[0,.69444,0,0,.75],177:[.08333,.58333,0,0,.77778],182:[.19444,.69444,0,0,.61111],184:[.17014,0,0,0,.44445],198:[0,.68333,0,0,.90278],215:[.08333,.58333,0,0,.77778],216:[.04861,.73194,0,0,.77778],223:[0,.69444,0,0,.5],230:[0,.43056,0,0,.72222],247:[.08333,.58333,0,0,.77778],248:[.09722,.52778,0,0,.5],305:[0,.43056,0,0,.27778],338:[0,.68333,0,0,1.01389],339:[0,.43056,0,0,.77778],567:[.19444,.43056,0,0,.30556],710:[0,.69444,0,0,.5],711:[0,.62847,0,0,.5],713:[0,.56778,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.66786,0,0,.27778],730:[0,.69444,0,0,.75],732:[0,.66786,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.68333,0,0,.625],916:[0,.68333,0,0,.83334],920:[0,.68333,0,0,.77778],923:[0,.68333,0,0,.69445],926:[0,.68333,0,0,.66667],928:[0,.68333,0,0,.75],931:[0,.68333,0,0,.72222],933:[0,.68333,0,0,.77778],934:[0,.68333,0,0,.72222],936:[0,.68333,0,0,.77778],937:[0,.68333,0,0,.72222],8211:[0,.43056,.02778,0,.5],8212:[0,.43056,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5],8224:[.19444,.69444,0,0,.44445],8225:[.19444,.69444,0,0,.44445],8230:[0,.123,0,0,1.172],8242:[0,.55556,0,0,.275],8407:[0,.71444,.15382,0,.5],8463:[0,.68889,0,0,.54028],8465:[0,.69444,0,0,.72222],8467:[0,.69444,0,.11111,.41667],8472:[.19444,.43056,0,.11111,.63646],8476:[0,.69444,0,0,.72222],8501:[0,.69444,0,0,.61111],8592:[-.13313,.36687,0,0,1],8593:[.19444,.69444,0,0,.5],8594:[-.13313,.36687,0,0,1],8595:[.19444,.69444,0,0,.5],8596:[-.13313,.36687,0,0,1],8597:[.25,.75,0,0,.5],8598:[.19444,.69444,0,0,1],8599:[.19444,.69444,0,0,1],8600:[.19444,.69444,0,0,1],8601:[.19444,.69444,0,0,1],8614:[.011,.511,0,0,1],8617:[.011,.511,0,0,1.126],8618:[.011,.511,0,0,1.126],8636:[-.13313,.36687,0,0,1],8637:[-.13313,.36687,0,0,1],8640:[-.13313,.36687,0,0,1],8641:[-.13313,.36687,0,0,1],8652:[.011,.671,0,0,1],8656:[-.13313,.36687,0,0,1],8657:[.19444,.69444,0,0,.61111],8658:[-.13313,.36687,0,0,1],8659:[.19444,.69444,0,0,.61111],8660:[-.13313,.36687,0,0,1],8661:[.25,.75,0,0,.61111],8704:[0,.69444,0,0,.55556],8706:[0,.69444,.05556,.08334,.5309],8707:[0,.69444,0,0,.55556],8709:[.05556,.75,0,0,.5],8711:[0,.68333,0,0,.83334],8712:[.0391,.5391,0,0,.66667],8715:[.0391,.5391,0,0,.66667],8722:[.08333,.58333,0,0,.77778],8723:[.08333,.58333,0,0,.77778],8725:[.25,.75,0,0,.5],8726:[.25,.75,0,0,.5],8727:[-.03472,.46528,0,0,.5],8728:[-.05555,.44445,0,0,.5],8729:[-.05555,.44445,0,0,.5],8730:[.2,.8,0,0,.83334],8733:[0,.43056,0,0,.77778],8734:[0,.43056,0,0,1],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.27778],8741:[.25,.75,0,0,.5],8743:[0,.55556,0,0,.66667],8744:[0,.55556,0,0,.66667],8745:[0,.55556,0,0,.66667],8746:[0,.55556,0,0,.66667],8747:[.19444,.69444,.11111,0,.41667],8764:[-.13313,.36687,0,0,.77778],8768:[.19444,.69444,0,0,.27778],8771:[-.03625,.46375,0,0,.77778],8773:[-.022,.589,0,0,.778],8776:[-.01688,.48312,0,0,.77778],8781:[-.03625,.46375,0,0,.77778],8784:[-.133,.673,0,0,.778],8801:[-.03625,.46375,0,0,.77778],8804:[.13597,.63597,0,0,.77778],8805:[.13597,.63597,0,0,.77778],8810:[.0391,.5391,0,0,1],8811:[.0391,.5391,0,0,1],8826:[.0391,.5391,0,0,.77778],8827:[.0391,.5391,0,0,.77778],8834:[.0391,.5391,0,0,.77778],8835:[.0391,.5391,0,0,.77778],8838:[.13597,.63597,0,0,.77778],8839:[.13597,.63597,0,0,.77778],8846:[0,.55556,0,0,.66667],8849:[.13597,.63597,0,0,.77778],8850:[.13597,.63597,0,0,.77778],8851:[0,.55556,0,0,.66667],8852:[0,.55556,0,0,.66667],8853:[.08333,.58333,0,0,.77778],8854:[.08333,.58333,0,0,.77778],8855:[.08333,.58333,0,0,.77778],8856:[.08333,.58333,0,0,.77778],8857:[.08333,.58333,0,0,.77778],8866:[0,.69444,0,0,.61111],8867:[0,.69444,0,0,.61111],8868:[0,.69444,0,0,.77778],8869:[0,.69444,0,0,.77778],8872:[.249,.75,0,0,.867],8900:[-.05555,.44445,0,0,.5],8901:[-.05555,.44445,0,0,.27778],8902:[-.03472,.46528,0,0,.5],8904:[.005,.505,0,0,.9],8942:[.03,.903,0,0,.278],8943:[-.19,.313,0,0,1.172],8945:[-.1,.823,0,0,1.282],8968:[.25,.75,0,0,.44445],8969:[.25,.75,0,0,.44445],8970:[.25,.75,0,0,.44445],8971:[.25,.75,0,0,.44445],8994:[-.14236,.35764,0,0,1],8995:[-.14236,.35764,0,0,1],9136:[.244,.744,0,0,.412],9137:[.244,.745,0,0,.412],9651:[.19444,.69444,0,0,.88889],9657:[-.03472,.46528,0,0,.5],9661:[.19444,.69444,0,0,.88889],9667:[-.03472,.46528,0,0,.5],9711:[.19444,.69444,0,0,1],9824:[.12963,.69444,0,0,.77778],9825:[.12963,.69444,0,0,.77778],9826:[.12963,.69444,0,0,.77778],9827:[.12963,.69444,0,0,.77778],9837:[0,.75,0,0,.38889],9838:[.19444,.69444,0,0,.38889],9839:[.19444,.69444,0,0,.38889],10216:[.25,.75,0,0,.38889],10217:[.25,.75,0,0,.38889],10222:[.244,.744,0,0,.412],10223:[.244,.745,0,0,.412],10229:[.011,.511,0,0,1.609],10230:[.011,.511,0,0,1.638],10231:[.011,.511,0,0,1.859],10232:[.024,.525,0,0,1.609],10233:[.024,.525,0,0,1.638],10234:[.024,.525,0,0,1.858],10236:[.011,.511,0,0,1.638],10815:[0,.68333,0,0,.75],10927:[.13597,.63597,0,0,.77778],10928:[.13597,.63597,0,0,.77778],57376:[.19444,.69444,0,0,0]},"Math-BoldItalic":{32:[0,0,0,0,.25],48:[0,.44444,0,0,.575],49:[0,.44444,0,0,.575],50:[0,.44444,0,0,.575],51:[.19444,.44444,0,0,.575],52:[.19444,.44444,0,0,.575],53:[.19444,.44444,0,0,.575],54:[0,.64444,0,0,.575],55:[.19444,.44444,0,0,.575],56:[0,.64444,0,0,.575],57:[.19444,.44444,0,0,.575],65:[0,.68611,0,0,.86944],66:[0,.68611,.04835,0,.8664],67:[0,.68611,.06979,0,.81694],68:[0,.68611,.03194,0,.93812],69:[0,.68611,.05451,0,.81007],70:[0,.68611,.15972,0,.68889],71:[0,.68611,0,0,.88673],72:[0,.68611,.08229,0,.98229],73:[0,.68611,.07778,0,.51111],74:[0,.68611,.10069,0,.63125],75:[0,.68611,.06979,0,.97118],76:[0,.68611,0,0,.75555],77:[0,.68611,.11424,0,1.14201],78:[0,.68611,.11424,0,.95034],79:[0,.68611,.03194,0,.83666],80:[0,.68611,.15972,0,.72309],81:[.19444,.68611,0,0,.86861],82:[0,.68611,.00421,0,.87235],83:[0,.68611,.05382,0,.69271],84:[0,.68611,.15972,0,.63663],85:[0,.68611,.11424,0,.80027],86:[0,.68611,.25555,0,.67778],87:[0,.68611,.15972,0,1.09305],88:[0,.68611,.07778,0,.94722],89:[0,.68611,.25555,0,.67458],90:[0,.68611,.06979,0,.77257],97:[0,.44444,0,0,.63287],98:[0,.69444,0,0,.52083],99:[0,.44444,0,0,.51342],100:[0,.69444,0,0,.60972],101:[0,.44444,0,0,.55361],102:[.19444,.69444,.11042,0,.56806],103:[.19444,.44444,.03704,0,.5449],104:[0,.69444,0,0,.66759],105:[0,.69326,0,0,.4048],106:[.19444,.69326,.0622,0,.47083],107:[0,.69444,.01852,0,.6037],108:[0,.69444,.0088,0,.34815],109:[0,.44444,0,0,1.0324],110:[0,.44444,0,0,.71296],111:[0,.44444,0,0,.58472],112:[.19444,.44444,0,0,.60092],113:[.19444,.44444,.03704,0,.54213],114:[0,.44444,.03194,0,.5287],115:[0,.44444,0,0,.53125],116:[0,.63492,0,0,.41528],117:[0,.44444,0,0,.68102],118:[0,.44444,.03704,0,.56666],119:[0,.44444,.02778,0,.83148],120:[0,.44444,0,0,.65903],121:[.19444,.44444,.03704,0,.59028],122:[0,.44444,.04213,0,.55509],160:[0,0,0,0,.25],915:[0,.68611,.15972,0,.65694],916:[0,.68611,0,0,.95833],920:[0,.68611,.03194,0,.86722],923:[0,.68611,0,0,.80555],926:[0,.68611,.07458,0,.84125],928:[0,.68611,.08229,0,.98229],931:[0,.68611,.05451,0,.88507],933:[0,.68611,.15972,0,.67083],934:[0,.68611,0,0,.76666],936:[0,.68611,.11653,0,.71402],937:[0,.68611,.04835,0,.8789],945:[0,.44444,0,0,.76064],946:[.19444,.69444,.03403,0,.65972],947:[.19444,.44444,.06389,0,.59003],948:[0,.69444,.03819,0,.52222],949:[0,.44444,0,0,.52882],950:[.19444,.69444,.06215,0,.50833],951:[.19444,.44444,.03704,0,.6],952:[0,.69444,.03194,0,.5618],953:[0,.44444,0,0,.41204],954:[0,.44444,0,0,.66759],955:[0,.69444,0,0,.67083],956:[.19444,.44444,0,0,.70787],957:[0,.44444,.06898,0,.57685],958:[.19444,.69444,.03021,0,.50833],959:[0,.44444,0,0,.58472],960:[0,.44444,.03704,0,.68241],961:[.19444,.44444,0,0,.6118],962:[.09722,.44444,.07917,0,.42361],963:[0,.44444,.03704,0,.68588],964:[0,.44444,.13472,0,.52083],965:[0,.44444,.03704,0,.63055],966:[.19444,.44444,0,0,.74722],967:[.19444,.44444,0,0,.71805],968:[.19444,.69444,.03704,0,.75833],969:[0,.44444,.03704,0,.71782],977:[0,.69444,0,0,.69155],981:[.19444,.69444,0,0,.7125],982:[0,.44444,.03194,0,.975],1009:[.19444,.44444,0,0,.6118],1013:[0,.44444,0,0,.48333],57649:[0,.44444,0,0,.39352],57911:[.19444,.44444,0,0,.43889]},"Math-Italic":{32:[0,0,0,0,.25],48:[0,.43056,0,0,.5],49:[0,.43056,0,0,.5],50:[0,.43056,0,0,.5],51:[.19444,.43056,0,0,.5],52:[.19444,.43056,0,0,.5],53:[.19444,.43056,0,0,.5],54:[0,.64444,0,0,.5],55:[.19444,.43056,0,0,.5],56:[0,.64444,0,0,.5],57:[.19444,.43056,0,0,.5],65:[0,.68333,0,.13889,.75],66:[0,.68333,.05017,.08334,.75851],67:[0,.68333,.07153,.08334,.71472],68:[0,.68333,.02778,.05556,.82792],69:[0,.68333,.05764,.08334,.7382],70:[0,.68333,.13889,.08334,.64306],71:[0,.68333,0,.08334,.78625],72:[0,.68333,.08125,.05556,.83125],73:[0,.68333,.07847,.11111,.43958],74:[0,.68333,.09618,.16667,.55451],75:[0,.68333,.07153,.05556,.84931],76:[0,.68333,0,.02778,.68056],77:[0,.68333,.10903,.08334,.97014],78:[0,.68333,.10903,.08334,.80347],79:[0,.68333,.02778,.08334,.76278],80:[0,.68333,.13889,.08334,.64201],81:[.19444,.68333,0,.08334,.79056],82:[0,.68333,.00773,.08334,.75929],83:[0,.68333,.05764,.08334,.6132],84:[0,.68333,.13889,.08334,.58438],85:[0,.68333,.10903,.02778,.68278],86:[0,.68333,.22222,0,.58333],87:[0,.68333,.13889,0,.94445],88:[0,.68333,.07847,.08334,.82847],89:[0,.68333,.22222,0,.58056],90:[0,.68333,.07153,.08334,.68264],97:[0,.43056,0,0,.52859],98:[0,.69444,0,0,.42917],99:[0,.43056,0,.05556,.43276],100:[0,.69444,0,.16667,.52049],101:[0,.43056,0,.05556,.46563],102:[.19444,.69444,.10764,.16667,.48959],103:[.19444,.43056,.03588,.02778,.47697],104:[0,.69444,0,0,.57616],105:[0,.65952,0,0,.34451],106:[.19444,.65952,.05724,0,.41181],107:[0,.69444,.03148,0,.5206],108:[0,.69444,.01968,.08334,.29838],109:[0,.43056,0,0,.87801],110:[0,.43056,0,0,.60023],111:[0,.43056,0,.05556,.48472],112:[.19444,.43056,0,.08334,.50313],113:[.19444,.43056,.03588,.08334,.44641],114:[0,.43056,.02778,.05556,.45116],115:[0,.43056,0,.05556,.46875],116:[0,.61508,0,.08334,.36111],117:[0,.43056,0,.02778,.57246],118:[0,.43056,.03588,.02778,.48472],119:[0,.43056,.02691,.08334,.71592],120:[0,.43056,0,.02778,.57153],121:[.19444,.43056,.03588,.05556,.49028],122:[0,.43056,.04398,.05556,.46505],160:[0,0,0,0,.25],915:[0,.68333,.13889,.08334,.61528],916:[0,.68333,0,.16667,.83334],920:[0,.68333,.02778,.08334,.76278],923:[0,.68333,0,.16667,.69445],926:[0,.68333,.07569,.08334,.74236],928:[0,.68333,.08125,.05556,.83125],931:[0,.68333,.05764,.08334,.77986],933:[0,.68333,.13889,.05556,.58333],934:[0,.68333,0,.08334,.66667],936:[0,.68333,.11,.05556,.61222],937:[0,.68333,.05017,.08334,.7724],945:[0,.43056,.0037,.02778,.6397],946:[.19444,.69444,.05278,.08334,.56563],947:[.19444,.43056,.05556,0,.51773],948:[0,.69444,.03785,.05556,.44444],949:[0,.43056,0,.08334,.46632],950:[.19444,.69444,.07378,.08334,.4375],951:[.19444,.43056,.03588,.05556,.49653],952:[0,.69444,.02778,.08334,.46944],953:[0,.43056,0,.05556,.35394],954:[0,.43056,0,0,.57616],955:[0,.69444,0,0,.58334],956:[.19444,.43056,0,.02778,.60255],957:[0,.43056,.06366,.02778,.49398],958:[.19444,.69444,.04601,.11111,.4375],959:[0,.43056,0,.05556,.48472],960:[0,.43056,.03588,0,.57003],961:[.19444,.43056,0,.08334,.51702],962:[.09722,.43056,.07986,.08334,.36285],963:[0,.43056,.03588,0,.57141],964:[0,.43056,.1132,.02778,.43715],965:[0,.43056,.03588,.02778,.54028],966:[.19444,.43056,0,.08334,.65417],967:[.19444,.43056,0,.05556,.62569],968:[.19444,.69444,.03588,.11111,.65139],969:[0,.43056,.03588,0,.62245],977:[0,.69444,0,.08334,.59144],981:[.19444,.69444,0,.08334,.59583],982:[0,.43056,.02778,0,.82813],1009:[.19444,.43056,0,.08334,.51702],1013:[0,.43056,0,.05556,.4059],57649:[0,.43056,0,.02778,.32246],57911:[.19444,.43056,0,.08334,.38403]},"SansSerif-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.36667],34:[0,.69444,0,0,.55834],35:[.19444,.69444,0,0,.91667],36:[.05556,.75,0,0,.55],37:[.05556,.75,0,0,1.02912],38:[0,.69444,0,0,.83056],39:[0,.69444,0,0,.30556],40:[.25,.75,0,0,.42778],41:[.25,.75,0,0,.42778],42:[0,.75,0,0,.55],43:[.11667,.61667,0,0,.85556],44:[.10556,.13056,0,0,.30556],45:[0,.45833,0,0,.36667],46:[0,.13056,0,0,.30556],47:[.25,.75,0,0,.55],48:[0,.69444,0,0,.55],49:[0,.69444,0,0,.55],50:[0,.69444,0,0,.55],51:[0,.69444,0,0,.55],52:[0,.69444,0,0,.55],53:[0,.69444,0,0,.55],54:[0,.69444,0,0,.55],55:[0,.69444,0,0,.55],56:[0,.69444,0,0,.55],57:[0,.69444,0,0,.55],58:[0,.45833,0,0,.30556],59:[.10556,.45833,0,0,.30556],61:[-.09375,.40625,0,0,.85556],63:[0,.69444,0,0,.51945],64:[0,.69444,0,0,.73334],65:[0,.69444,0,0,.73334],66:[0,.69444,0,0,.73334],67:[0,.69444,0,0,.70278],68:[0,.69444,0,0,.79445],69:[0,.69444,0,0,.64167],70:[0,.69444,0,0,.61111],71:[0,.69444,0,0,.73334],72:[0,.69444,0,0,.79445],73:[0,.69444,0,0,.33056],74:[0,.69444,0,0,.51945],75:[0,.69444,0,0,.76389],76:[0,.69444,0,0,.58056],77:[0,.69444,0,0,.97778],78:[0,.69444,0,0,.79445],79:[0,.69444,0,0,.79445],80:[0,.69444,0,0,.70278],81:[.10556,.69444,0,0,.79445],82:[0,.69444,0,0,.70278],83:[0,.69444,0,0,.61111],84:[0,.69444,0,0,.73334],85:[0,.69444,0,0,.76389],86:[0,.69444,.01528,0,.73334],87:[0,.69444,.01528,0,1.03889],88:[0,.69444,0,0,.73334],89:[0,.69444,.0275,0,.73334],90:[0,.69444,0,0,.67223],91:[.25,.75,0,0,.34306],93:[.25,.75,0,0,.34306],94:[0,.69444,0,0,.55],95:[.35,.10833,.03056,0,.55],97:[0,.45833,0,0,.525],98:[0,.69444,0,0,.56111],99:[0,.45833,0,0,.48889],100:[0,.69444,0,0,.56111],101:[0,.45833,0,0,.51111],102:[0,.69444,.07639,0,.33611],103:[.19444,.45833,.01528,0,.55],104:[0,.69444,0,0,.56111],105:[0,.69444,0,0,.25556],106:[.19444,.69444,0,0,.28611],107:[0,.69444,0,0,.53056],108:[0,.69444,0,0,.25556],109:[0,.45833,0,0,.86667],110:[0,.45833,0,0,.56111],111:[0,.45833,0,0,.55],112:[.19444,.45833,0,0,.56111],113:[.19444,.45833,0,0,.56111],114:[0,.45833,.01528,0,.37222],115:[0,.45833,0,0,.42167],116:[0,.58929,0,0,.40417],117:[0,.45833,0,0,.56111],118:[0,.45833,.01528,0,.5],119:[0,.45833,.01528,0,.74445],120:[0,.45833,0,0,.5],121:[.19444,.45833,.01528,0,.5],122:[0,.45833,0,0,.47639],126:[.35,.34444,0,0,.55],160:[0,0,0,0,.25],168:[0,.69444,0,0,.55],176:[0,.69444,0,0,.73334],180:[0,.69444,0,0,.55],184:[.17014,0,0,0,.48889],305:[0,.45833,0,0,.25556],567:[.19444,.45833,0,0,.28611],710:[0,.69444,0,0,.55],711:[0,.63542,0,0,.55],713:[0,.63778,0,0,.55],728:[0,.69444,0,0,.55],729:[0,.69444,0,0,.30556],730:[0,.69444,0,0,.73334],732:[0,.69444,0,0,.55],733:[0,.69444,0,0,.55],915:[0,.69444,0,0,.58056],916:[0,.69444,0,0,.91667],920:[0,.69444,0,0,.85556],923:[0,.69444,0,0,.67223],926:[0,.69444,0,0,.73334],928:[0,.69444,0,0,.79445],931:[0,.69444,0,0,.79445],933:[0,.69444,0,0,.85556],934:[0,.69444,0,0,.79445],936:[0,.69444,0,0,.85556],937:[0,.69444,0,0,.79445],8211:[0,.45833,.03056,0,.55],8212:[0,.45833,.03056,0,1.10001],8216:[0,.69444,0,0,.30556],8217:[0,.69444,0,0,.30556],8220:[0,.69444,0,0,.55834],8221:[0,.69444,0,0,.55834]},"SansSerif-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.05733,0,.31945],34:[0,.69444,.00316,0,.5],35:[.19444,.69444,.05087,0,.83334],36:[.05556,.75,.11156,0,.5],37:[.05556,.75,.03126,0,.83334],38:[0,.69444,.03058,0,.75834],39:[0,.69444,.07816,0,.27778],40:[.25,.75,.13164,0,.38889],41:[.25,.75,.02536,0,.38889],42:[0,.75,.11775,0,.5],43:[.08333,.58333,.02536,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,.01946,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,.13164,0,.5],48:[0,.65556,.11156,0,.5],49:[0,.65556,.11156,0,.5],50:[0,.65556,.11156,0,.5],51:[0,.65556,.11156,0,.5],52:[0,.65556,.11156,0,.5],53:[0,.65556,.11156,0,.5],54:[0,.65556,.11156,0,.5],55:[0,.65556,.11156,0,.5],56:[0,.65556,.11156,0,.5],57:[0,.65556,.11156,0,.5],58:[0,.44444,.02502,0,.27778],59:[.125,.44444,.02502,0,.27778],61:[-.13,.37,.05087,0,.77778],63:[0,.69444,.11809,0,.47222],64:[0,.69444,.07555,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,.08293,0,.66667],67:[0,.69444,.11983,0,.63889],68:[0,.69444,.07555,0,.72223],69:[0,.69444,.11983,0,.59722],70:[0,.69444,.13372,0,.56945],71:[0,.69444,.11983,0,.66667],72:[0,.69444,.08094,0,.70834],73:[0,.69444,.13372,0,.27778],74:[0,.69444,.08094,0,.47222],75:[0,.69444,.11983,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,.08094,0,.875],78:[0,.69444,.08094,0,.70834],79:[0,.69444,.07555,0,.73611],80:[0,.69444,.08293,0,.63889],81:[.125,.69444,.07555,0,.73611],82:[0,.69444,.08293,0,.64584],83:[0,.69444,.09205,0,.55556],84:[0,.69444,.13372,0,.68056],85:[0,.69444,.08094,0,.6875],86:[0,.69444,.1615,0,.66667],87:[0,.69444,.1615,0,.94445],88:[0,.69444,.13372,0,.66667],89:[0,.69444,.17261,0,.66667],90:[0,.69444,.11983,0,.61111],91:[.25,.75,.15942,0,.28889],93:[.25,.75,.08719,0,.28889],94:[0,.69444,.0799,0,.5],95:[.35,.09444,.08616,0,.5],97:[0,.44444,.00981,0,.48056],98:[0,.69444,.03057,0,.51667],99:[0,.44444,.08336,0,.44445],100:[0,.69444,.09483,0,.51667],101:[0,.44444,.06778,0,.44445],102:[0,.69444,.21705,0,.30556],103:[.19444,.44444,.10836,0,.5],104:[0,.69444,.01778,0,.51667],105:[0,.67937,.09718,0,.23889],106:[.19444,.67937,.09162,0,.26667],107:[0,.69444,.08336,0,.48889],108:[0,.69444,.09483,0,.23889],109:[0,.44444,.01778,0,.79445],110:[0,.44444,.01778,0,.51667],111:[0,.44444,.06613,0,.5],112:[.19444,.44444,.0389,0,.51667],113:[.19444,.44444,.04169,0,.51667],114:[0,.44444,.10836,0,.34167],115:[0,.44444,.0778,0,.38333],116:[0,.57143,.07225,0,.36111],117:[0,.44444,.04169,0,.51667],118:[0,.44444,.10836,0,.46111],119:[0,.44444,.10836,0,.68334],120:[0,.44444,.09169,0,.46111],121:[.19444,.44444,.10836,0,.46111],122:[0,.44444,.08752,0,.43472],126:[.35,.32659,.08826,0,.5],160:[0,0,0,0,.25],168:[0,.67937,.06385,0,.5],176:[0,.69444,0,0,.73752],184:[.17014,0,0,0,.44445],305:[0,.44444,.04169,0,.23889],567:[.19444,.44444,.04169,0,.26667],710:[0,.69444,.0799,0,.5],711:[0,.63194,.08432,0,.5],713:[0,.60889,.08776,0,.5],714:[0,.69444,.09205,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,.09483,0,.5],729:[0,.67937,.07774,0,.27778],730:[0,.69444,0,0,.73752],732:[0,.67659,.08826,0,.5],733:[0,.69444,.09205,0,.5],915:[0,.69444,.13372,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,.07555,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,.12816,0,.66667],928:[0,.69444,.08094,0,.70834],931:[0,.69444,.11983,0,.72222],933:[0,.69444,.09031,0,.77778],934:[0,.69444,.04603,0,.72222],936:[0,.69444,.09031,0,.77778],937:[0,.69444,.08293,0,.72222],8211:[0,.44444,.08616,0,.5],8212:[0,.44444,.08616,0,1],8216:[0,.69444,.07816,0,.27778],8217:[0,.69444,.07816,0,.27778],8220:[0,.69444,.14205,0,.5],8221:[0,.69444,.00316,0,.5]},"SansSerif-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.31945],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.75834],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,0,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.65556,0,0,.5],49:[0,.65556,0,0,.5],50:[0,.65556,0,0,.5],51:[0,.65556,0,0,.5],52:[0,.65556,0,0,.5],53:[0,.65556,0,0,.5],54:[0,.65556,0,0,.5],55:[0,.65556,0,0,.5],56:[0,.65556,0,0,.5],57:[0,.65556,0,0,.5],58:[0,.44444,0,0,.27778],59:[.125,.44444,0,0,.27778],61:[-.13,.37,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,0,0,.66667],67:[0,.69444,0,0,.63889],68:[0,.69444,0,0,.72223],69:[0,.69444,0,0,.59722],70:[0,.69444,0,0,.56945],71:[0,.69444,0,0,.66667],72:[0,.69444,0,0,.70834],73:[0,.69444,0,0,.27778],74:[0,.69444,0,0,.47222],75:[0,.69444,0,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,0,0,.875],78:[0,.69444,0,0,.70834],79:[0,.69444,0,0,.73611],80:[0,.69444,0,0,.63889],81:[.125,.69444,0,0,.73611],82:[0,.69444,0,0,.64584],83:[0,.69444,0,0,.55556],84:[0,.69444,0,0,.68056],85:[0,.69444,0,0,.6875],86:[0,.69444,.01389,0,.66667],87:[0,.69444,.01389,0,.94445],88:[0,.69444,0,0,.66667],89:[0,.69444,.025,0,.66667],90:[0,.69444,0,0,.61111],91:[.25,.75,0,0,.28889],93:[.25,.75,0,0,.28889],94:[0,.69444,0,0,.5],95:[.35,.09444,.02778,0,.5],97:[0,.44444,0,0,.48056],98:[0,.69444,0,0,.51667],99:[0,.44444,0,0,.44445],100:[0,.69444,0,0,.51667],101:[0,.44444,0,0,.44445],102:[0,.69444,.06944,0,.30556],103:[.19444,.44444,.01389,0,.5],104:[0,.69444,0,0,.51667],105:[0,.67937,0,0,.23889],106:[.19444,.67937,0,0,.26667],107:[0,.69444,0,0,.48889],108:[0,.69444,0,0,.23889],109:[0,.44444,0,0,.79445],110:[0,.44444,0,0,.51667],111:[0,.44444,0,0,.5],112:[.19444,.44444,0,0,.51667],113:[.19444,.44444,0,0,.51667],114:[0,.44444,.01389,0,.34167],115:[0,.44444,0,0,.38333],116:[0,.57143,0,0,.36111],117:[0,.44444,0,0,.51667],118:[0,.44444,.01389,0,.46111],119:[0,.44444,.01389,0,.68334],120:[0,.44444,0,0,.46111],121:[.19444,.44444,.01389,0,.46111],122:[0,.44444,0,0,.43472],126:[.35,.32659,0,0,.5],160:[0,0,0,0,.25],168:[0,.67937,0,0,.5],176:[0,.69444,0,0,.66667],184:[.17014,0,0,0,.44445],305:[0,.44444,0,0,.23889],567:[.19444,.44444,0,0,.26667],710:[0,.69444,0,0,.5],711:[0,.63194,0,0,.5],713:[0,.60889,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.67937,0,0,.27778],730:[0,.69444,0,0,.66667],732:[0,.67659,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.69444,0,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,0,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,0,0,.66667],928:[0,.69444,0,0,.70834],931:[0,.69444,0,0,.72222],933:[0,.69444,0,0,.77778],934:[0,.69444,0,0,.72222],936:[0,.69444,0,0,.77778],937:[0,.69444,0,0,.72222],8211:[0,.44444,.02778,0,.5],8212:[0,.44444,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5]},"Script-Regular":{32:[0,0,0,0,.25],65:[0,.7,.22925,0,.80253],66:[0,.7,.04087,0,.90757],67:[0,.7,.1689,0,.66619],68:[0,.7,.09371,0,.77443],69:[0,.7,.18583,0,.56162],70:[0,.7,.13634,0,.89544],71:[0,.7,.17322,0,.60961],72:[0,.7,.29694,0,.96919],73:[0,.7,.19189,0,.80907],74:[.27778,.7,.19189,0,1.05159],75:[0,.7,.31259,0,.91364],76:[0,.7,.19189,0,.87373],77:[0,.7,.15981,0,1.08031],78:[0,.7,.3525,0,.9015],79:[0,.7,.08078,0,.73787],80:[0,.7,.08078,0,1.01262],81:[0,.7,.03305,0,.88282],82:[0,.7,.06259,0,.85],83:[0,.7,.19189,0,.86767],84:[0,.7,.29087,0,.74697],85:[0,.7,.25815,0,.79996],86:[0,.7,.27523,0,.62204],87:[0,.7,.27523,0,.80532],88:[0,.7,.26006,0,.94445],89:[0,.7,.2939,0,.70961],90:[0,.7,.24037,0,.8212],160:[0,0,0,0,.25]},"Size1-Regular":{32:[0,0,0,0,.25],40:[.35001,.85,0,0,.45834],41:[.35001,.85,0,0,.45834],47:[.35001,.85,0,0,.57778],91:[.35001,.85,0,0,.41667],92:[.35001,.85,0,0,.57778],93:[.35001,.85,0,0,.41667],123:[.35001,.85,0,0,.58334],125:[.35001,.85,0,0,.58334],160:[0,0,0,0,.25],710:[0,.72222,0,0,.55556],732:[0,.72222,0,0,.55556],770:[0,.72222,0,0,.55556],771:[0,.72222,0,0,.55556],8214:[-99e-5,.601,0,0,.77778],8593:[1e-5,.6,0,0,.66667],8595:[1e-5,.6,0,0,.66667],8657:[1e-5,.6,0,0,.77778],8659:[1e-5,.6,0,0,.77778],8719:[.25001,.75,0,0,.94445],8720:[.25001,.75,0,0,.94445],8721:[.25001,.75,0,0,1.05556],8730:[.35001,.85,0,0,1],8739:[-.00599,.606,0,0,.33333],8741:[-.00599,.606,0,0,.55556],8747:[.30612,.805,.19445,0,.47222],8748:[.306,.805,.19445,0,.47222],8749:[.306,.805,.19445,0,.47222],8750:[.30612,.805,.19445,0,.47222],8896:[.25001,.75,0,0,.83334],8897:[.25001,.75,0,0,.83334],8898:[.25001,.75,0,0,.83334],8899:[.25001,.75,0,0,.83334],8968:[.35001,.85,0,0,.47222],8969:[.35001,.85,0,0,.47222],8970:[.35001,.85,0,0,.47222],8971:[.35001,.85,0,0,.47222],9168:[-99e-5,.601,0,0,.66667],10216:[.35001,.85,0,0,.47222],10217:[.35001,.85,0,0,.47222],10752:[.25001,.75,0,0,1.11111],10753:[.25001,.75,0,0,1.11111],10754:[.25001,.75,0,0,1.11111],10756:[.25001,.75,0,0,.83334],10758:[.25001,.75,0,0,.83334]},"Size2-Regular":{32:[0,0,0,0,.25],40:[.65002,1.15,0,0,.59722],41:[.65002,1.15,0,0,.59722],47:[.65002,1.15,0,0,.81111],91:[.65002,1.15,0,0,.47222],92:[.65002,1.15,0,0,.81111],93:[.65002,1.15,0,0,.47222],123:[.65002,1.15,0,0,.66667],125:[.65002,1.15,0,0,.66667],160:[0,0,0,0,.25],710:[0,.75,0,0,1],732:[0,.75,0,0,1],770:[0,.75,0,0,1],771:[0,.75,0,0,1],8719:[.55001,1.05,0,0,1.27778],8720:[.55001,1.05,0,0,1.27778],8721:[.55001,1.05,0,0,1.44445],8730:[.65002,1.15,0,0,1],8747:[.86225,1.36,.44445,0,.55556],8748:[.862,1.36,.44445,0,.55556],8749:[.862,1.36,.44445,0,.55556],8750:[.86225,1.36,.44445,0,.55556],8896:[.55001,1.05,0,0,1.11111],8897:[.55001,1.05,0,0,1.11111],8898:[.55001,1.05,0,0,1.11111],8899:[.55001,1.05,0,0,1.11111],8968:[.65002,1.15,0,0,.52778],8969:[.65002,1.15,0,0,.52778],8970:[.65002,1.15,0,0,.52778],8971:[.65002,1.15,0,0,.52778],10216:[.65002,1.15,0,0,.61111],10217:[.65002,1.15,0,0,.61111],10752:[.55001,1.05,0,0,1.51112],10753:[.55001,1.05,0,0,1.51112],10754:[.55001,1.05,0,0,1.51112],10756:[.55001,1.05,0,0,1.11111],10758:[.55001,1.05,0,0,1.11111]},"Size3-Regular":{32:[0,0,0,0,.25],40:[.95003,1.45,0,0,.73611],41:[.95003,1.45,0,0,.73611],47:[.95003,1.45,0,0,1.04445],91:[.95003,1.45,0,0,.52778],92:[.95003,1.45,0,0,1.04445],93:[.95003,1.45,0,0,.52778],123:[.95003,1.45,0,0,.75],125:[.95003,1.45,0,0,.75],160:[0,0,0,0,.25],710:[0,.75,0,0,1.44445],732:[0,.75,0,0,1.44445],770:[0,.75,0,0,1.44445],771:[0,.75,0,0,1.44445],8730:[.95003,1.45,0,0,1],8968:[.95003,1.45,0,0,.58334],8969:[.95003,1.45,0,0,.58334],8970:[.95003,1.45,0,0,.58334],8971:[.95003,1.45,0,0,.58334],10216:[.95003,1.45,0,0,.75],10217:[.95003,1.45,0,0,.75]},"Size4-Regular":{32:[0,0,0,0,.25],40:[1.25003,1.75,0,0,.79167],41:[1.25003,1.75,0,0,.79167],47:[1.25003,1.75,0,0,1.27778],91:[1.25003,1.75,0,0,.58334],92:[1.25003,1.75,0,0,1.27778],93:[1.25003,1.75,0,0,.58334],123:[1.25003,1.75,0,0,.80556],125:[1.25003,1.75,0,0,.80556],160:[0,0,0,0,.25],710:[0,.825,0,0,1.8889],732:[0,.825,0,0,1.8889],770:[0,.825,0,0,1.8889],771:[0,.825,0,0,1.8889],8730:[1.25003,1.75,0,0,1],8968:[1.25003,1.75,0,0,.63889],8969:[1.25003,1.75,0,0,.63889],8970:[1.25003,1.75,0,0,.63889],8971:[1.25003,1.75,0,0,.63889],9115:[.64502,1.155,0,0,.875],9116:[1e-5,.6,0,0,.875],9117:[.64502,1.155,0,0,.875],9118:[.64502,1.155,0,0,.875],9119:[1e-5,.6,0,0,.875],9120:[.64502,1.155,0,0,.875],9121:[.64502,1.155,0,0,.66667],9122:[-99e-5,.601,0,0,.66667],9123:[.64502,1.155,0,0,.66667],9124:[.64502,1.155,0,0,.66667],9125:[-99e-5,.601,0,0,.66667],9126:[.64502,1.155,0,0,.66667],9127:[1e-5,.9,0,0,.88889],9128:[.65002,1.15,0,0,.88889],9129:[.90001,0,0,0,.88889],9130:[0,.3,0,0,.88889],9131:[1e-5,.9,0,0,.88889],9132:[.65002,1.15,0,0,.88889],9133:[.90001,0,0,0,.88889],9143:[.88502,.915,0,0,1.05556],10216:[1.25003,1.75,0,0,.80556],10217:[1.25003,1.75,0,0,.80556],57344:[-.00499,.605,0,0,1.05556],57345:[-.00499,.605,0,0,1.05556],57680:[0,.12,0,0,.45],57681:[0,.12,0,0,.45],57682:[0,.12,0,0,.45],57683:[0,.12,0,0,.45]},"Typewriter-Regular":{32:[0,0,0,0,.525],33:[0,.61111,0,0,.525],34:[0,.61111,0,0,.525],35:[0,.61111,0,0,.525],36:[.08333,.69444,0,0,.525],37:[.08333,.69444,0,0,.525],38:[0,.61111,0,0,.525],39:[0,.61111,0,0,.525],40:[.08333,.69444,0,0,.525],41:[.08333,.69444,0,0,.525],42:[0,.52083,0,0,.525],43:[-.08056,.53055,0,0,.525],44:[.13889,.125,0,0,.525],45:[-.08056,.53055,0,0,.525],46:[0,.125,0,0,.525],47:[.08333,.69444,0,0,.525],48:[0,.61111,0,0,.525],49:[0,.61111,0,0,.525],50:[0,.61111,0,0,.525],51:[0,.61111,0,0,.525],52:[0,.61111,0,0,.525],53:[0,.61111,0,0,.525],54:[0,.61111,0,0,.525],55:[0,.61111,0,0,.525],56:[0,.61111,0,0,.525],57:[0,.61111,0,0,.525],58:[0,.43056,0,0,.525],59:[.13889,.43056,0,0,.525],60:[-.05556,.55556,0,0,.525],61:[-.19549,.41562,0,0,.525],62:[-.05556,.55556,0,0,.525],63:[0,.61111,0,0,.525],64:[0,.61111,0,0,.525],65:[0,.61111,0,0,.525],66:[0,.61111,0,0,.525],67:[0,.61111,0,0,.525],68:[0,.61111,0,0,.525],69:[0,.61111,0,0,.525],70:[0,.61111,0,0,.525],71:[0,.61111,0,0,.525],72:[0,.61111,0,0,.525],73:[0,.61111,0,0,.525],74:[0,.61111,0,0,.525],75:[0,.61111,0,0,.525],76:[0,.61111,0,0,.525],77:[0,.61111,0,0,.525],78:[0,.61111,0,0,.525],79:[0,.61111,0,0,.525],80:[0,.61111,0,0,.525],81:[.13889,.61111,0,0,.525],82:[0,.61111,0,0,.525],83:[0,.61111,0,0,.525],84:[0,.61111,0,0,.525],85:[0,.61111,0,0,.525],86:[0,.61111,0,0,.525],87:[0,.61111,0,0,.525],88:[0,.61111,0,0,.525],89:[0,.61111,0,0,.525],90:[0,.61111,0,0,.525],91:[.08333,.69444,0,0,.525],92:[.08333,.69444,0,0,.525],93:[.08333,.69444,0,0,.525],94:[0,.61111,0,0,.525],95:[.09514,0,0,0,.525],96:[0,.61111,0,0,.525],97:[0,.43056,0,0,.525],98:[0,.61111,0,0,.525],99:[0,.43056,0,0,.525],100:[0,.61111,0,0,.525],101:[0,.43056,0,0,.525],102:[0,.61111,0,0,.525],103:[.22222,.43056,0,0,.525],104:[0,.61111,0,0,.525],105:[0,.61111,0,0,.525],106:[.22222,.61111,0,0,.525],107:[0,.61111,0,0,.525],108:[0,.61111,0,0,.525],109:[0,.43056,0,0,.525],110:[0,.43056,0,0,.525],111:[0,.43056,0,0,.525],112:[.22222,.43056,0,0,.525],113:[.22222,.43056,0,0,.525],114:[0,.43056,0,0,.525],115:[0,.43056,0,0,.525],116:[0,.55358,0,0,.525],117:[0,.43056,0,0,.525],118:[0,.43056,0,0,.525],119:[0,.43056,0,0,.525],120:[0,.43056,0,0,.525],121:[.22222,.43056,0,0,.525],122:[0,.43056,0,0,.525],123:[.08333,.69444,0,0,.525],124:[.08333,.69444,0,0,.525],125:[.08333,.69444,0,0,.525],126:[0,.61111,0,0,.525],127:[0,.61111,0,0,.525],160:[0,0,0,0,.525],176:[0,.61111,0,0,.525],184:[.19445,0,0,0,.525],305:[0,.43056,0,0,.525],567:[.22222,.43056,0,0,.525],711:[0,.56597,0,0,.525],713:[0,.56555,0,0,.525],714:[0,.61111,0,0,.525],715:[0,.61111,0,0,.525],728:[0,.61111,0,0,.525],730:[0,.61111,0,0,.525],770:[0,.61111,0,0,.525],771:[0,.61111,0,0,.525],776:[0,.61111,0,0,.525],915:[0,.61111,0,0,.525],916:[0,.61111,0,0,.525],920:[0,.61111,0,0,.525],923:[0,.61111,0,0,.525],926:[0,.61111,0,0,.525],928:[0,.61111,0,0,.525],931:[0,.61111,0,0,.525],933:[0,.61111,0,0,.525],934:[0,.61111,0,0,.525],936:[0,.61111,0,0,.525],937:[0,.61111,0,0,.525],8216:[0,.61111,0,0,.525],8217:[0,.61111,0,0,.525],8242:[0,.61111,0,0,.525],9251:[.11111,.21944,0,0,.525]}},nc={slant:[.25,.25,.25],space:[0,0,0],stretch:[0,0,0],shrink:[0,0,0],xHeight:[.431,.431,.431],quad:[1,1.171,1.472],extraSpace:[0,0,0],num1:[.677,.732,.925],num2:[.394,.384,.387],num3:[.444,.471,.504],denom1:[.686,.752,1.025],denom2:[.345,.344,.532],sup1:[.413,.503,.504],sup2:[.363,.431,.404],sup3:[.289,.286,.294],sub1:[.15,.143,.2],sub2:[.247,.286,.4],supDrop:[.386,.353,.494],subDrop:[.05,.071,.1],delim1:[2.39,1.7,1.98],delim2:[1.01,1.157,1.42],axisHeight:[.25,.25,.25],defaultRuleThickness:[.04,.049,.049],bigOpSpacing1:[.111,.111,.111],bigOpSpacing2:[.166,.166,.166],bigOpSpacing3:[.2,.2,.2],bigOpSpacing4:[.6,.611,.611],bigOpSpacing5:[.1,.143,.143],sqrtRuleThickness:[.04,.04,.04],ptPerEm:[10,10,10],doubleRuleSep:[.2,.2,.2],arrayRuleWidth:[.04,.04,.04],fboxsep:[.3,.3,.3],fboxrule:[.04,.04,.04]},l3={Å:"A",Ð:"D",Þ:"o",å:"a",ð:"d",þ:"o",А:"A",Б:"B",В:"B",Г:"F",Д:"A",Е:"E",Ж:"K",З:"3",И:"N",Й:"N",К:"K",Л:"N",М:"M",Н:"H",О:"O",П:"N",Р:"P",С:"C",Т:"T",У:"y",Ф:"O",Х:"X",Ц:"U",Ч:"h",Ш:"W",Щ:"W",Ъ:"B",Ы:"X",Ь:"B",Э:"3",Ю:"X",Я:"R",а:"a",б:"b",в:"a",г:"r",д:"y",е:"e",ж:"m",з:"e",и:"n",й:"n",к:"n",л:"n",м:"m",н:"n",о:"o",п:"n",р:"p",с:"c",т:"o",у:"y",ф:"b",х:"x",ц:"n",ч:"n",ш:"w",щ:"w",ъ:"a",ы:"m",ь:"a",э:"e",ю:"m",я:"r"};function BR(e,t){Na[e]=t}function Im(e,t,n){if(!Na[t])throw new Error("Font metrics not found for font: "+t+".");var a=e.charCodeAt(0),l=Na[t][a];if(!l&&e[0]in l3&&(a=l3[e[0]].charCodeAt(0),l=Na[t][a]),!l&&n==="text"&&F5(a)&&(l=Na[t][77]),l)return{depth:l[0],height:l[1],italic:l[2],skew:l[3],width:l[4]}}var Fh={};function PR(e){var t;if(e>=5?t=0:e>=3?t=1:t=2,!Fh[t]){var n=Fh[t]={cssEmPerMu:nc.quad[t]/18};for(var a in nc)nc.hasOwnProperty(a)&&(n[a]=nc[a][t])}return Fh[t]}var UR=[[1,1,1],[2,1,1],[3,1,1],[4,2,1],[5,2,1],[6,3,1],[7,4,2],[8,6,3],[9,7,6],[10,8,7],[11,10,9]],s3=[.5,.6,.7,.8,.9,1,1.2,1.44,1.728,2.074,2.488],u3=function(t,n){return n.size<2?t:UR[t-1][n.size-1]};class ti{constructor(t){this.style=void 0,this.color=void 0,this.size=void 0,this.textSize=void 0,this.phantom=void 0,this.font=void 0,this.fontFamily=void 0,this.fontWeight=void 0,this.fontShape=void 0,this.sizeMultiplier=void 0,this.maxSize=void 0,this.minRuleThickness=void 0,this._fontMetrics=void 0,this.style=t.style,this.color=t.color,this.size=t.size||ti.BASESIZE,this.textSize=t.textSize||this.size,this.phantom=!!t.phantom,this.font=t.font||"",this.fontFamily=t.fontFamily||"",this.fontWeight=t.fontWeight||"",this.fontShape=t.fontShape||"",this.sizeMultiplier=s3[this.size-1],this.maxSize=t.maxSize,this.minRuleThickness=t.minRuleThickness,this._fontMetrics=void 0}extend(t){var n={style:this.style,size:this.size,textSize:this.textSize,color:this.color,phantom:this.phantom,font:this.font,fontFamily:this.fontFamily,fontWeight:this.fontWeight,fontShape:this.fontShape,maxSize:this.maxSize,minRuleThickness:this.minRuleThickness};for(var a in t)t.hasOwnProperty(a)&&(n[a]=t[a]);return new ti(n)}havingStyle(t){return this.style===t?this:this.extend({style:t,size:u3(this.textSize,t)})}havingCrampedStyle(){return this.havingStyle(this.style.cramp())}havingSize(t){return this.size===t&&this.textSize===t?this:this.extend({style:this.style.text(),size:t,textSize:t,sizeMultiplier:s3[t-1]})}havingBaseStyle(t){t=t||this.style.text();var n=u3(ti.BASESIZE,t);return this.size===n&&this.textSize===ti.BASESIZE&&this.style===t?this:this.extend({style:t,size:n})}havingBaseSizing(){var t;switch(this.style.id){case 4:case 5:t=3;break;case 6:case 7:t=1;break;default:t=6}return this.extend({style:this.style.text(),size:t})}withColor(t){return this.extend({color:t})}withPhantom(){return this.extend({phantom:!0})}withFont(t){return this.extend({font:t})}withTextFontFamily(t){return this.extend({fontFamily:t,font:""})}withTextFontWeight(t){return this.extend({fontWeight:t,font:""})}withTextFontShape(t){return this.extend({fontShape:t,font:""})}sizingClasses(t){return t.size!==this.size?["sizing","reset-size"+t.size,"size"+this.size]:[]}baseSizingClasses(){return this.size!==ti.BASESIZE?["sizing","reset-size"+this.size,"size"+ti.BASESIZE]:[]}fontMetrics(){return this._fontMetrics||(this._fontMetrics=PR(this.size)),this._fontMetrics}getColor(){return this.phantom?"transparent":this.color}}ti.BASESIZE=6;var U1={pt:1,mm:7227/2540,cm:7227/254,in:72.27,bp:803/800,pc:12,dd:1238/1157,cc:14856/1157,nd:685/642,nc:1370/107,sp:1/65536,px:803/800},zR={ex:!0,em:!0,mu:!0},q5=function(t){return typeof t!="string"&&(t=t.unit),t in U1||t in zR||t==="ex"},fn=function(t,n){var a;if(t.unit in U1)a=U1[t.unit]/n.fontMetrics().ptPerEm/n.sizeMultiplier;else if(t.unit==="mu")a=n.fontMetrics().cssEmPerMu;else{var l;if(n.style.isTight()?l=n.havingStyle(n.style.text()):l=n,t.unit==="ex")a=l.fontMetrics().xHeight;else if(t.unit==="em")a=l.fontMetrics().quad;else throw new ke("Invalid unit: '"+t.unit+"'");l!==n&&(a*=l.sizeMultiplier/n.sizeMultiplier)}return Math.min(t.number*a,n.maxSize)},Oe=function(t){return+t.toFixed(4)+"em"},Qi=function(t){return t.filter(n=>n).join(" ")},Y5=function(t,n,a){if(this.classes=t||[],this.attributes={},this.height=0,this.depth=0,this.maxFontSize=0,this.style=a||{},n){n.style.isTight()&&this.classes.push("mtight");var l=n.getColor();l&&(this.style.color=l)}},G5=function(t){var n=document.createElement(t);n.className=Qi(this.classes);for(var a in this.style)this.style.hasOwnProperty(a)&&(n.style[a]=this.style[a]);for(var l in this.attributes)this.attributes.hasOwnProperty(l)&&n.setAttribute(l,this.attributes[l]);for(var s=0;s<this.children.length;s++)n.appendChild(this.children[s].toNode());return n},HR=/[\s"'>/=\x00-\x1f]/,V5=function(t){var n="<"+t;this.classes.length&&(n+=' class="'+We.escape(Qi(this.classes))+'"');var a="";for(var l in this.style)this.style.hasOwnProperty(l)&&(a+=We.hyphenate(l)+":"+this.style[l]+";");a&&(n+=' style="'+We.escape(a)+'"');for(var s in this.attributes)if(this.attributes.hasOwnProperty(s)){if(HR.test(s))throw new ke("Invalid attribute name '"+s+"'");n+=" "+s+'="'+We.escape(this.attributes[s])+'"'}n+=">";for(var o=0;o<this.children.length;o++)n+=this.children[o].toMarkup();return n+="</"+t+">",n};class Co{constructor(t,n,a,l){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.width=void 0,this.maxFontSize=void 0,this.style=void 0,Y5.call(this,t,a,l),this.children=n||[]}setAttribute(t,n){this.attributes[t]=n}hasClass(t){return We.contains(this.classes,t)}toNode(){return G5.call(this,"span")}toMarkup(){return V5.call(this,"span")}}class Lm{constructor(t,n,a,l){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,Y5.call(this,n,l),this.children=a||[],this.setAttribute("href",t)}setAttribute(t,n){this.attributes[t]=n}hasClass(t){return We.contains(this.classes,t)}toNode(){return G5.call(this,"a")}toMarkup(){return V5.call(this,"a")}}class FR{constructor(t,n,a){this.src=void 0,this.alt=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.alt=n,this.src=t,this.classes=["mord"],this.style=a}hasClass(t){return We.contains(this.classes,t)}toNode(){var t=document.createElement("img");t.src=this.src,t.alt=this.alt,t.className="mord";for(var n in this.style)this.style.hasOwnProperty(n)&&(t.style[n]=this.style[n]);return t}toMarkup(){var t='<img src="'+We.escape(this.src)+'"'+(' alt="'+We.escape(this.alt)+'"'),n="";for(var a in this.style)this.style.hasOwnProperty(a)&&(n+=We.hyphenate(a)+":"+this.style[a]+";");return n&&(t+=' style="'+We.escape(n)+'"'),t+="'/>",t}}var qR={î:"ı̂",ï:"ı̈",í:"ı́",ì:"ı̀"};class ea{constructor(t,n,a,l,s,o,d,f){this.text=void 0,this.height=void 0,this.depth=void 0,this.italic=void 0,this.skew=void 0,this.width=void 0,this.maxFontSize=void 0,this.classes=void 0,this.style=void 0,this.text=t,this.height=n||0,this.depth=a||0,this.italic=l||0,this.skew=s||0,this.width=o||0,this.classes=d||[],this.style=f||{},this.maxFontSize=0;var h=xR(this.text.charCodeAt(0));h&&this.classes.push(h+"_fallback"),/[îïíì]/.test(this.text)&&(this.text=qR[this.text])}hasClass(t){return We.contains(this.classes,t)}toNode(){var t=document.createTextNode(this.text),n=null;this.italic>0&&(n=document.createElement("span"),n.style.marginRight=Oe(this.italic)),this.classes.length>0&&(n=n||document.createElement("span"),n.className=Qi(this.classes));for(var a in this.style)this.style.hasOwnProperty(a)&&(n=n||document.createElement("span"),n.style[a]=this.style[a]);return n?(n.appendChild(t),n):t}toMarkup(){var t=!1,n="<span";this.classes.length&&(t=!0,n+=' class="',n+=We.escape(Qi(this.classes)),n+='"');var a="";this.italic>0&&(a+="margin-right:"+this.italic+"em;");for(var l in this.style)this.style.hasOwnProperty(l)&&(a+=We.hyphenate(l)+":"+this.style[l]+";");a&&(t=!0,n+=' style="'+We.escape(a)+'"');var s=We.escape(this.text);return t?(n+=">",n+=s,n+="</span>",n):s}}class ii{constructor(t,n){this.children=void 0,this.attributes=void 0,this.children=t||[],this.attributes=n||{}}toNode(){var t="http://www.w3.org/2000/svg",n=document.createElementNS(t,"svg");for(var a in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,a)&&n.setAttribute(a,this.attributes[a]);for(var l=0;l<this.children.length;l++)n.appendChild(this.children[l].toNode());return n}toMarkup(){var t='<svg xmlns="http://www.w3.org/2000/svg"';for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(t+=" "+n+'="'+We.escape(this.attributes[n])+'"');t+=">";for(var a=0;a<this.children.length;a++)t+=this.children[a].toMarkup();return t+="</svg>",t}}class Zi{constructor(t,n){this.pathName=void 0,this.alternate=void 0,this.pathName=t,this.alternate=n}toNode(){var t="http://www.w3.org/2000/svg",n=document.createElementNS(t,"path");return this.alternate?n.setAttribute("d",this.alternate):n.setAttribute("d",i3[this.pathName]),n}toMarkup(){return this.alternate?'<path d="'+We.escape(this.alternate)+'"/>':'<path d="'+We.escape(i3[this.pathName])+'"/>'}}class z1{constructor(t){this.attributes=void 0,this.attributes=t||{}}toNode(){var t="http://www.w3.org/2000/svg",n=document.createElementNS(t,"line");for(var a in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,a)&&n.setAttribute(a,this.attributes[a]);return n}toMarkup(){var t="<line";for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(t+=" "+n+'="'+We.escape(this.attributes[n])+'"');return t+="/>",t}}function o3(e){if(e instanceof ea)return e;throw new Error("Expected symbolNode but got "+String(e)+".")}function YR(e){if(e instanceof Co)return e;throw new Error("Expected span<HtmlDomNode> but got "+String(e)+".")}var GR={bin:1,close:1,inner:1,open:1,punct:1,rel:1},VR={"accent-token":1,mathord:1,"op-token":1,spacing:1,textord:1},$t={math:{},text:{}};function y(e,t,n,a,l,s){$t[e][l]={font:t,group:n,replace:a},s&&a&&($t[e][a]=$t[e][l])}var _="math",ve="text",k="main",B="ams",rn="accent-token",Ue="bin",or="close",Fs="inner",Ze="mathord",wn="op-token",Ur="open",Qc="punct",P="rel",ci="spacing",V="textord";y(_,k,P,"≡","\\equiv",!0);y(_,k,P,"≺","\\prec",!0);y(_,k,P,"≻","\\succ",!0);y(_,k,P,"∼","\\sim",!0);y(_,k,P,"⊥","\\perp");y(_,k,P,"⪯","\\preceq",!0);y(_,k,P,"⪰","\\succeq",!0);y(_,k,P,"≃","\\simeq",!0);y(_,k,P,"∣","\\mid",!0);y(_,k,P,"≪","\\ll",!0);y(_,k,P,"≫","\\gg",!0);y(_,k,P,"≍","\\asymp",!0);y(_,k,P,"∥","\\parallel");y(_,k,P,"⋈","\\bowtie",!0);y(_,k,P,"⌣","\\smile",!0);y(_,k,P,"⊑","\\sqsubseteq",!0);y(_,k,P,"⊒","\\sqsupseteq",!0);y(_,k,P,"≐","\\doteq",!0);y(_,k,P,"⌢","\\frown",!0);y(_,k,P,"∋","\\ni",!0);y(_,k,P,"∝","\\propto",!0);y(_,k,P,"⊢","\\vdash",!0);y(_,k,P,"⊣","\\dashv",!0);y(_,k,P,"∋","\\owns");y(_,k,Qc,".","\\ldotp");y(_,k,Qc,"⋅","\\cdotp");y(_,k,V,"#","\\#");y(ve,k,V,"#","\\#");y(_,k,V,"&","\\&");y(ve,k,V,"&","\\&");y(_,k,V,"ℵ","\\aleph",!0);y(_,k,V,"∀","\\forall",!0);y(_,k,V,"ℏ","\\hbar",!0);y(_,k,V,"∃","\\exists",!0);y(_,k,V,"∇","\\nabla",!0);y(_,k,V,"♭","\\flat",!0);y(_,k,V,"ℓ","\\ell",!0);y(_,k,V,"♮","\\natural",!0);y(_,k,V,"♣","\\clubsuit",!0);y(_,k,V,"℘","\\wp",!0);y(_,k,V,"♯","\\sharp",!0);y(_,k,V,"♢","\\diamondsuit",!0);y(_,k,V,"ℜ","\\Re",!0);y(_,k,V,"♡","\\heartsuit",!0);y(_,k,V,"ℑ","\\Im",!0);y(_,k,V,"♠","\\spadesuit",!0);y(_,k,V,"§","\\S",!0);y(ve,k,V,"§","\\S");y(_,k,V,"¶","\\P",!0);y(ve,k,V,"¶","\\P");y(_,k,V,"†","\\dag");y(ve,k,V,"†","\\dag");y(ve,k,V,"†","\\textdagger");y(_,k,V,"‡","\\ddag");y(ve,k,V,"‡","\\ddag");y(ve,k,V,"‡","\\textdaggerdbl");y(_,k,or,"⎱","\\rmoustache",!0);y(_,k,Ur,"⎰","\\lmoustache",!0);y(_,k,or,"⟯","\\rgroup",!0);y(_,k,Ur,"⟮","\\lgroup",!0);y(_,k,Ue,"∓","\\mp",!0);y(_,k,Ue,"⊖","\\ominus",!0);y(_,k,Ue,"⊎","\\uplus",!0);y(_,k,Ue,"⊓","\\sqcap",!0);y(_,k,Ue,"∗","\\ast");y(_,k,Ue,"⊔","\\sqcup",!0);y(_,k,Ue,"◯","\\bigcirc",!0);y(_,k,Ue,"∙","\\bullet",!0);y(_,k,Ue,"‡","\\ddagger");y(_,k,Ue,"≀","\\wr",!0);y(_,k,Ue,"⨿","\\amalg");y(_,k,Ue,"&","\\And");y(_,k,P,"⟵","\\longleftarrow",!0);y(_,k,P,"⇐","\\Leftarrow",!0);y(_,k,P,"⟸","\\Longleftarrow",!0);y(_,k,P,"⟶","\\longrightarrow",!0);y(_,k,P,"⇒","\\Rightarrow",!0);y(_,k,P,"⟹","\\Longrightarrow",!0);y(_,k,P,"↔","\\leftrightarrow",!0);y(_,k,P,"⟷","\\longleftrightarrow",!0);y(_,k,P,"⇔","\\Leftrightarrow",!0);y(_,k,P,"⟺","\\Longleftrightarrow",!0);y(_,k,P,"↦","\\mapsto",!0);y(_,k,P,"⟼","\\longmapsto",!0);y(_,k,P,"↗","\\nearrow",!0);y(_,k,P,"↩","\\hookleftarrow",!0);y(_,k,P,"↪","\\hookrightarrow",!0);y(_,k,P,"↘","\\searrow",!0);y(_,k,P,"↼","\\leftharpoonup",!0);y(_,k,P,"⇀","\\rightharpoonup",!0);y(_,k,P,"↙","\\swarrow",!0);y(_,k,P,"↽","\\leftharpoondown",!0);y(_,k,P,"⇁","\\rightharpoondown",!0);y(_,k,P,"↖","\\nwarrow",!0);y(_,k,P,"⇌","\\rightleftharpoons",!0);y(_,B,P,"≮","\\nless",!0);y(_,B,P,"","\\@nleqslant");y(_,B,P,"","\\@nleqq");y(_,B,P,"⪇","\\lneq",!0);y(_,B,P,"≨","\\lneqq",!0);y(_,B,P,"","\\@lvertneqq");y(_,B,P,"⋦","\\lnsim",!0);y(_,B,P,"⪉","\\lnapprox",!0);y(_,B,P,"⊀","\\nprec",!0);y(_,B,P,"⋠","\\npreceq",!0);y(_,B,P,"⋨","\\precnsim",!0);y(_,B,P,"⪹","\\precnapprox",!0);y(_,B,P,"≁","\\nsim",!0);y(_,B,P,"","\\@nshortmid");y(_,B,P,"∤","\\nmid",!0);y(_,B,P,"⊬","\\nvdash",!0);y(_,B,P,"⊭","\\nvDash",!0);y(_,B,P,"⋪","\\ntriangleleft");y(_,B,P,"⋬","\\ntrianglelefteq",!0);y(_,B,P,"⊊","\\subsetneq",!0);y(_,B,P,"","\\@varsubsetneq");y(_,B,P,"⫋","\\subsetneqq",!0);y(_,B,P,"","\\@varsubsetneqq");y(_,B,P,"≯","\\ngtr",!0);y(_,B,P,"","\\@ngeqslant");y(_,B,P,"","\\@ngeqq");y(_,B,P,"⪈","\\gneq",!0);y(_,B,P,"≩","\\gneqq",!0);y(_,B,P,"","\\@gvertneqq");y(_,B,P,"⋧","\\gnsim",!0);y(_,B,P,"⪊","\\gnapprox",!0);y(_,B,P,"⊁","\\nsucc",!0);y(_,B,P,"⋡","\\nsucceq",!0);y(_,B,P,"⋩","\\succnsim",!0);y(_,B,P,"⪺","\\succnapprox",!0);y(_,B,P,"≆","\\ncong",!0);y(_,B,P,"","\\@nshortparallel");y(_,B,P,"∦","\\nparallel",!0);y(_,B,P,"⊯","\\nVDash",!0);y(_,B,P,"⋫","\\ntriangleright");y(_,B,P,"⋭","\\ntrianglerighteq",!0);y(_,B,P,"","\\@nsupseteqq");y(_,B,P,"⊋","\\supsetneq",!0);y(_,B,P,"","\\@varsupsetneq");y(_,B,P,"⫌","\\supsetneqq",!0);y(_,B,P,"","\\@varsupsetneqq");y(_,B,P,"⊮","\\nVdash",!0);y(_,B,P,"⪵","\\precneqq",!0);y(_,B,P,"⪶","\\succneqq",!0);y(_,B,P,"","\\@nsubseteqq");y(_,B,Ue,"⊴","\\unlhd");y(_,B,Ue,"⊵","\\unrhd");y(_,B,P,"↚","\\nleftarrow",!0);y(_,B,P,"↛","\\nrightarrow",!0);y(_,B,P,"⇍","\\nLeftarrow",!0);y(_,B,P,"⇏","\\nRightarrow",!0);y(_,B,P,"↮","\\nleftrightarrow",!0);y(_,B,P,"⇎","\\nLeftrightarrow",!0);y(_,B,P,"△","\\vartriangle");y(_,B,V,"ℏ","\\hslash");y(_,B,V,"▽","\\triangledown");y(_,B,V,"◊","\\lozenge");y(_,B,V,"Ⓢ","\\circledS");y(_,B,V,"®","\\circledR");y(ve,B,V,"®","\\circledR");y(_,B,V,"∡","\\measuredangle",!0);y(_,B,V,"∄","\\nexists");y(_,B,V,"℧","\\mho");y(_,B,V,"Ⅎ","\\Finv",!0);y(_,B,V,"⅁","\\Game",!0);y(_,B,V,"‵","\\backprime");y(_,B,V,"▲","\\blacktriangle");y(_,B,V,"▼","\\blacktriangledown");y(_,B,V,"■","\\blacksquare");y(_,B,V,"⧫","\\blacklozenge");y(_,B,V,"★","\\bigstar");y(_,B,V,"∢","\\sphericalangle",!0);y(_,B,V,"∁","\\complement",!0);y(_,B,V,"ð","\\eth",!0);y(ve,k,V,"ð","ð");y(_,B,V,"╱","\\diagup");y(_,B,V,"╲","\\diagdown");y(_,B,V,"□","\\square");y(_,B,V,"□","\\Box");y(_,B,V,"◊","\\Diamond");y(_,B,V,"¥","\\yen",!0);y(ve,B,V,"¥","\\yen",!0);y(_,B,V,"✓","\\checkmark",!0);y(ve,B,V,"✓","\\checkmark");y(_,B,V,"ℶ","\\beth",!0);y(_,B,V,"ℸ","\\daleth",!0);y(_,B,V,"ℷ","\\gimel",!0);y(_,B,V,"ϝ","\\digamma",!0);y(_,B,V,"ϰ","\\varkappa");y(_,B,Ur,"┌","\\@ulcorner",!0);y(_,B,or,"┐","\\@urcorner",!0);y(_,B,Ur,"└","\\@llcorner",!0);y(_,B,or,"┘","\\@lrcorner",!0);y(_,B,P,"≦","\\leqq",!0);y(_,B,P,"⩽","\\leqslant",!0);y(_,B,P,"⪕","\\eqslantless",!0);y(_,B,P,"≲","\\lesssim",!0);y(_,B,P,"⪅","\\lessapprox",!0);y(_,B,P,"≊","\\approxeq",!0);y(_,B,Ue,"⋖","\\lessdot");y(_,B,P,"⋘","\\lll",!0);y(_,B,P,"≶","\\lessgtr",!0);y(_,B,P,"⋚","\\lesseqgtr",!0);y(_,B,P,"⪋","\\lesseqqgtr",!0);y(_,B,P,"≑","\\doteqdot");y(_,B,P,"≓","\\risingdotseq",!0);y(_,B,P,"≒","\\fallingdotseq",!0);y(_,B,P,"∽","\\backsim",!0);y(_,B,P,"⋍","\\backsimeq",!0);y(_,B,P,"⫅","\\subseteqq",!0);y(_,B,P,"⋐","\\Subset",!0);y(_,B,P,"⊏","\\sqsubset",!0);y(_,B,P,"≼","\\preccurlyeq",!0);y(_,B,P,"⋞","\\curlyeqprec",!0);y(_,B,P,"≾","\\precsim",!0);y(_,B,P,"⪷","\\precapprox",!0);y(_,B,P,"⊲","\\vartriangleleft");y(_,B,P,"⊴","\\trianglelefteq");y(_,B,P,"⊨","\\vDash",!0);y(_,B,P,"⊪","\\Vvdash",!0);y(_,B,P,"⌣","\\smallsmile");y(_,B,P,"⌢","\\smallfrown");y(_,B,P,"≏","\\bumpeq",!0);y(_,B,P,"≎","\\Bumpeq",!0);y(_,B,P,"≧","\\geqq",!0);y(_,B,P,"⩾","\\geqslant",!0);y(_,B,P,"⪖","\\eqslantgtr",!0);y(_,B,P,"≳","\\gtrsim",!0);y(_,B,P,"⪆","\\gtrapprox",!0);y(_,B,Ue,"⋗","\\gtrdot");y(_,B,P,"⋙","\\ggg",!0);y(_,B,P,"≷","\\gtrless",!0);y(_,B,P,"⋛","\\gtreqless",!0);y(_,B,P,"⪌","\\gtreqqless",!0);y(_,B,P,"≖","\\eqcirc",!0);y(_,B,P,"≗","\\circeq",!0);y(_,B,P,"≜","\\triangleq",!0);y(_,B,P,"∼","\\thicksim");y(_,B,P,"≈","\\thickapprox");y(_,B,P,"⫆","\\supseteqq",!0);y(_,B,P,"⋑","\\Supset",!0);y(_,B,P,"⊐","\\sqsupset",!0);y(_,B,P,"≽","\\succcurlyeq",!0);y(_,B,P,"⋟","\\curlyeqsucc",!0);y(_,B,P,"≿","\\succsim",!0);y(_,B,P,"⪸","\\succapprox",!0);y(_,B,P,"⊳","\\vartriangleright");y(_,B,P,"⊵","\\trianglerighteq");y(_,B,P,"⊩","\\Vdash",!0);y(_,B,P,"∣","\\shortmid");y(_,B,P,"∥","\\shortparallel");y(_,B,P,"≬","\\between",!0);y(_,B,P,"⋔","\\pitchfork",!0);y(_,B,P,"∝","\\varpropto");y(_,B,P,"◀","\\blacktriangleleft");y(_,B,P,"∴","\\therefore",!0);y(_,B,P,"∍","\\backepsilon");y(_,B,P,"▶","\\blacktriangleright");y(_,B,P,"∵","\\because",!0);y(_,B,P,"⋘","\\llless");y(_,B,P,"⋙","\\gggtr");y(_,B,Ue,"⊲","\\lhd");y(_,B,Ue,"⊳","\\rhd");y(_,B,P,"≂","\\eqsim",!0);y(_,k,P,"⋈","\\Join");y(_,B,P,"≑","\\Doteq",!0);y(_,B,Ue,"∔","\\dotplus",!0);y(_,B,Ue,"∖","\\smallsetminus");y(_,B,Ue,"⋒","\\Cap",!0);y(_,B,Ue,"⋓","\\Cup",!0);y(_,B,Ue,"⩞","\\doublebarwedge",!0);y(_,B,Ue,"⊟","\\boxminus",!0);y(_,B,Ue,"⊞","\\boxplus",!0);y(_,B,Ue,"⋇","\\divideontimes",!0);y(_,B,Ue,"⋉","\\ltimes",!0);y(_,B,Ue,"⋊","\\rtimes",!0);y(_,B,Ue,"⋋","\\leftthreetimes",!0);y(_,B,Ue,"⋌","\\rightthreetimes",!0);y(_,B,Ue,"⋏","\\curlywedge",!0);y(_,B,Ue,"⋎","\\curlyvee",!0);y(_,B,Ue,"⊝","\\circleddash",!0);y(_,B,Ue,"⊛","\\circledast",!0);y(_,B,Ue,"⋅","\\centerdot");y(_,B,Ue,"⊺","\\intercal",!0);y(_,B,Ue,"⋒","\\doublecap");y(_,B,Ue,"⋓","\\doublecup");y(_,B,Ue,"⊠","\\boxtimes",!0);y(_,B,P,"⇢","\\dashrightarrow",!0);y(_,B,P,"⇠","\\dashleftarrow",!0);y(_,B,P,"⇇","\\leftleftarrows",!0);y(_,B,P,"⇆","\\leftrightarrows",!0);y(_,B,P,"⇚","\\Lleftarrow",!0);y(_,B,P,"↞","\\twoheadleftarrow",!0);y(_,B,P,"↢","\\leftarrowtail",!0);y(_,B,P,"↫","\\looparrowleft",!0);y(_,B,P,"⇋","\\leftrightharpoons",!0);y(_,B,P,"↶","\\curvearrowleft",!0);y(_,B,P,"↺","\\circlearrowleft",!0);y(_,B,P,"↰","\\Lsh",!0);y(_,B,P,"⇈","\\upuparrows",!0);y(_,B,P,"↿","\\upharpoonleft",!0);y(_,B,P,"⇃","\\downharpoonleft",!0);y(_,k,P,"⊶","\\origof",!0);y(_,k,P,"⊷","\\imageof",!0);y(_,B,P,"⊸","\\multimap",!0);y(_,B,P,"↭","\\leftrightsquigarrow",!0);y(_,B,P,"⇉","\\rightrightarrows",!0);y(_,B,P,"⇄","\\rightleftarrows",!0);y(_,B,P,"↠","\\twoheadrightarrow",!0);y(_,B,P,"↣","\\rightarrowtail",!0);y(_,B,P,"↬","\\looparrowright",!0);y(_,B,P,"↷","\\curvearrowright",!0);y(_,B,P,"↻","\\circlearrowright",!0);y(_,B,P,"↱","\\Rsh",!0);y(_,B,P,"⇊","\\downdownarrows",!0);y(_,B,P,"↾","\\upharpoonright",!0);y(_,B,P,"⇂","\\downharpoonright",!0);y(_,B,P,"⇝","\\rightsquigarrow",!0);y(_,B,P,"⇝","\\leadsto");y(_,B,P,"⇛","\\Rrightarrow",!0);y(_,B,P,"↾","\\restriction");y(_,k,V,"‘","`");y(_,k,V,"$","\\$");y(ve,k,V,"$","\\$");y(ve,k,V,"$","\\textdollar");y(_,k,V,"%","\\%");y(ve,k,V,"%","\\%");y(_,k,V,"_","\\_");y(ve,k,V,"_","\\_");y(ve,k,V,"_","\\textunderscore");y(_,k,V,"∠","\\angle",!0);y(_,k,V,"∞","\\infty",!0);y(_,k,V,"′","\\prime");y(_,k,V,"△","\\triangle");y(_,k,V,"Γ","\\Gamma",!0);y(_,k,V,"Δ","\\Delta",!0);y(_,k,V,"Θ","\\Theta",!0);y(_,k,V,"Λ","\\Lambda",!0);y(_,k,V,"Ξ","\\Xi",!0);y(_,k,V,"Π","\\Pi",!0);y(_,k,V,"Σ","\\Sigma",!0);y(_,k,V,"Υ","\\Upsilon",!0);y(_,k,V,"Φ","\\Phi",!0);y(_,k,V,"Ψ","\\Psi",!0);y(_,k,V,"Ω","\\Omega",!0);y(_,k,V,"A","Α");y(_,k,V,"B","Β");y(_,k,V,"E","Ε");y(_,k,V,"Z","Ζ");y(_,k,V,"H","Η");y(_,k,V,"I","Ι");y(_,k,V,"K","Κ");y(_,k,V,"M","Μ");y(_,k,V,"N","Ν");y(_,k,V,"O","Ο");y(_,k,V,"P","Ρ");y(_,k,V,"T","Τ");y(_,k,V,"X","Χ");y(_,k,V,"¬","\\neg",!0);y(_,k,V,"¬","\\lnot");y(_,k,V,"⊤","\\top");y(_,k,V,"⊥","\\bot");y(_,k,V,"∅","\\emptyset");y(_,B,V,"∅","\\varnothing");y(_,k,Ze,"α","\\alpha",!0);y(_,k,Ze,"β","\\beta",!0);y(_,k,Ze,"γ","\\gamma",!0);y(_,k,Ze,"δ","\\delta",!0);y(_,k,Ze,"ϵ","\\epsilon",!0);y(_,k,Ze,"ζ","\\zeta",!0);y(_,k,Ze,"η","\\eta",!0);y(_,k,Ze,"θ","\\theta",!0);y(_,k,Ze,"ι","\\iota",!0);y(_,k,Ze,"κ","\\kappa",!0);y(_,k,Ze,"λ","\\lambda",!0);y(_,k,Ze,"μ","\\mu",!0);y(_,k,Ze,"ν","\\nu",!0);y(_,k,Ze,"ξ","\\xi",!0);y(_,k,Ze,"ο","\\omicron",!0);y(_,k,Ze,"π","\\pi",!0);y(_,k,Ze,"ρ","\\rho",!0);y(_,k,Ze,"σ","\\sigma",!0);y(_,k,Ze,"τ","\\tau",!0);y(_,k,Ze,"υ","\\upsilon",!0);y(_,k,Ze,"ϕ","\\phi",!0);y(_,k,Ze,"χ","\\chi",!0);y(_,k,Ze,"ψ","\\psi",!0);y(_,k,Ze,"ω","\\omega",!0);y(_,k,Ze,"ε","\\varepsilon",!0);y(_,k,Ze,"ϑ","\\vartheta",!0);y(_,k,Ze,"ϖ","\\varpi",!0);y(_,k,Ze,"ϱ","\\varrho",!0);y(_,k,Ze,"ς","\\varsigma",!0);y(_,k,Ze,"φ","\\varphi",!0);y(_,k,Ue,"∗","*",!0);y(_,k,Ue,"+","+");y(_,k,Ue,"−","-",!0);y(_,k,Ue,"⋅","\\cdot",!0);y(_,k,Ue,"∘","\\circ",!0);y(_,k,Ue,"÷","\\div",!0);y(_,k,Ue,"±","\\pm",!0);y(_,k,Ue,"×","\\times",!0);y(_,k,Ue,"∩","\\cap",!0);y(_,k,Ue,"∪","\\cup",!0);y(_,k,Ue,"∖","\\setminus",!0);y(_,k,Ue,"∧","\\land");y(_,k,Ue,"∨","\\lor");y(_,k,Ue,"∧","\\wedge",!0);y(_,k,Ue,"∨","\\vee",!0);y(_,k,V,"√","\\surd");y(_,k,Ur,"⟨","\\langle",!0);y(_,k,Ur,"∣","\\lvert");y(_,k,Ur,"∥","\\lVert");y(_,k,or,"?","?");y(_,k,or,"!","!");y(_,k,or,"⟩","\\rangle",!0);y(_,k,or,"∣","\\rvert");y(_,k,or,"∥","\\rVert");y(_,k,P,"=","=");y(_,k,P,":",":");y(_,k,P,"≈","\\approx",!0);y(_,k,P,"≅","\\cong",!0);y(_,k,P,"≥","\\ge");y(_,k,P,"≥","\\geq",!0);y(_,k,P,"←","\\gets");y(_,k,P,">","\\gt",!0);y(_,k,P,"∈","\\in",!0);y(_,k,P,"","\\@not");y(_,k,P,"⊂","\\subset",!0);y(_,k,P,"⊃","\\supset",!0);y(_,k,P,"⊆","\\subseteq",!0);y(_,k,P,"⊇","\\supseteq",!0);y(_,B,P,"⊈","\\nsubseteq",!0);y(_,B,P,"⊉","\\nsupseteq",!0);y(_,k,P,"⊨","\\models");y(_,k,P,"←","\\leftarrow",!0);y(_,k,P,"≤","\\le");y(_,k,P,"≤","\\leq",!0);y(_,k,P,"<","\\lt",!0);y(_,k,P,"→","\\rightarrow",!0);y(_,k,P,"→","\\to");y(_,B,P,"≱","\\ngeq",!0);y(_,B,P,"≰","\\nleq",!0);y(_,k,ci," ","\\ ");y(_,k,ci," ","\\space");y(_,k,ci," ","\\nobreakspace");y(ve,k,ci," ","\\ ");y(ve,k,ci," "," ");y(ve,k,ci," ","\\space");y(ve,k,ci," ","\\nobreakspace");y(_,k,ci,null,"\\nobreak");y(_,k,ci,null,"\\allowbreak");y(_,k,Qc,",",",");y(_,k,Qc,";",";");y(_,B,Ue,"⊼","\\barwedge",!0);y(_,B,Ue,"⊻","\\veebar",!0);y(_,k,Ue,"⊙","\\odot",!0);y(_,k,Ue,"⊕","\\oplus",!0);y(_,k,Ue,"⊗","\\otimes",!0);y(_,k,V,"∂","\\partial",!0);y(_,k,Ue,"⊘","\\oslash",!0);y(_,B,Ue,"⊚","\\circledcirc",!0);y(_,B,Ue,"⊡","\\boxdot",!0);y(_,k,Ue,"△","\\bigtriangleup");y(_,k,Ue,"▽","\\bigtriangledown");y(_,k,Ue,"†","\\dagger");y(_,k,Ue,"⋄","\\diamond");y(_,k,Ue,"⋆","\\star");y(_,k,Ue,"◃","\\triangleleft");y(_,k,Ue,"▹","\\triangleright");y(_,k,Ur,"{","\\{");y(ve,k,V,"{","\\{");y(ve,k,V,"{","\\textbraceleft");y(_,k,or,"}","\\}");y(ve,k,V,"}","\\}");y(ve,k,V,"}","\\textbraceright");y(_,k,Ur,"{","\\lbrace");y(_,k,or,"}","\\rbrace");y(_,k,Ur,"[","\\lbrack",!0);y(ve,k,V,"[","\\lbrack",!0);y(_,k,or,"]","\\rbrack",!0);y(ve,k,V,"]","\\rbrack",!0);y(_,k,Ur,"(","\\lparen",!0);y(_,k,or,")","\\rparen",!0);y(ve,k,V,"<","\\textless",!0);y(ve,k,V,">","\\textgreater",!0);y(_,k,Ur,"⌊","\\lfloor",!0);y(_,k,or,"⌋","\\rfloor",!0);y(_,k,Ur,"⌈","\\lceil",!0);y(_,k,or,"⌉","\\rceil",!0);y(_,k,V,"\\","\\backslash");y(_,k,V,"∣","|");y(_,k,V,"∣","\\vert");y(ve,k,V,"|","\\textbar",!0);y(_,k,V,"∥","\\|");y(_,k,V,"∥","\\Vert");y(ve,k,V,"∥","\\textbardbl");y(ve,k,V,"~","\\textasciitilde");y(ve,k,V,"\\","\\textbackslash");y(ve,k,V,"^","\\textasciicircum");y(_,k,P,"↑","\\uparrow",!0);y(_,k,P,"⇑","\\Uparrow",!0);y(_,k,P,"↓","\\downarrow",!0);y(_,k,P,"⇓","\\Downarrow",!0);y(_,k,P,"↕","\\updownarrow",!0);y(_,k,P,"⇕","\\Updownarrow",!0);y(_,k,wn,"∐","\\coprod");y(_,k,wn,"⋁","\\bigvee");y(_,k,wn,"⋀","\\bigwedge");y(_,k,wn,"⨄","\\biguplus");y(_,k,wn,"⋂","\\bigcap");y(_,k,wn,"⋃","\\bigcup");y(_,k,wn,"∫","\\int");y(_,k,wn,"∫","\\intop");y(_,k,wn,"∬","\\iint");y(_,k,wn,"∭","\\iiint");y(_,k,wn,"∏","\\prod");y(_,k,wn,"∑","\\sum");y(_,k,wn,"⨂","\\bigotimes");y(_,k,wn,"⨁","\\bigoplus");y(_,k,wn,"⨀","\\bigodot");y(_,k,wn,"∮","\\oint");y(_,k,wn,"∯","\\oiint");y(_,k,wn,"∰","\\oiiint");y(_,k,wn,"⨆","\\bigsqcup");y(_,k,wn,"∫","\\smallint");y(ve,k,Fs,"…","\\textellipsis");y(_,k,Fs,"…","\\mathellipsis");y(ve,k,Fs,"…","\\ldots",!0);y(_,k,Fs,"…","\\ldots",!0);y(_,k,Fs,"⋯","\\@cdots",!0);y(_,k,Fs,"⋱","\\ddots",!0);y(_,k,V,"⋮","\\varvdots");y(ve,k,V,"⋮","\\varvdots");y(_,k,rn,"ˊ","\\acute");y(_,k,rn,"ˋ","\\grave");y(_,k,rn,"¨","\\ddot");y(_,k,rn,"~","\\tilde");y(_,k,rn,"ˉ","\\bar");y(_,k,rn,"˘","\\breve");y(_,k,rn,"ˇ","\\check");y(_,k,rn,"^","\\hat");y(_,k,rn,"⃗","\\vec");y(_,k,rn,"˙","\\dot");y(_,k,rn,"˚","\\mathring");y(_,k,Ze,"","\\@imath");y(_,k,Ze,"","\\@jmath");y(_,k,V,"ı","ı");y(_,k,V,"ȷ","ȷ");y(ve,k,V,"ı","\\i",!0);y(ve,k,V,"ȷ","\\j",!0);y(ve,k,V,"ß","\\ss",!0);y(ve,k,V,"æ","\\ae",!0);y(ve,k,V,"œ","\\oe",!0);y(ve,k,V,"ø","\\o",!0);y(ve,k,V,"Æ","\\AE",!0);y(ve,k,V,"Œ","\\OE",!0);y(ve,k,V,"Ø","\\O",!0);y(ve,k,rn,"ˊ","\\'");y(ve,k,rn,"ˋ","\\`");y(ve,k,rn,"ˆ","\\^");y(ve,k,rn,"˜","\\~");y(ve,k,rn,"ˉ","\\=");y(ve,k,rn,"˘","\\u");y(ve,k,rn,"˙","\\.");y(ve,k,rn,"¸","\\c");y(ve,k,rn,"˚","\\r");y(ve,k,rn,"ˇ","\\v");y(ve,k,rn,"¨",'\\"');y(ve,k,rn,"˝","\\H");y(ve,k,rn,"◯","\\textcircled");var K5={"--":!0,"---":!0,"``":!0,"''":!0};y(ve,k,V,"–","--",!0);y(ve,k,V,"–","\\textendash");y(ve,k,V,"—","---",!0);y(ve,k,V,"—","\\textemdash");y(ve,k,V,"‘","`",!0);y(ve,k,V,"‘","\\textquoteleft");y(ve,k,V,"’","'",!0);y(ve,k,V,"’","\\textquoteright");y(ve,k,V,"“","``",!0);y(ve,k,V,"“","\\textquotedblleft");y(ve,k,V,"”","''",!0);y(ve,k,V,"”","\\textquotedblright");y(_,k,V,"°","\\degree",!0);y(ve,k,V,"°","\\degree");y(ve,k,V,"°","\\textdegree",!0);y(_,k,V,"£","\\pounds");y(_,k,V,"£","\\mathsterling",!0);y(ve,k,V,"£","\\pounds");y(ve,k,V,"£","\\textsterling",!0);y(_,B,V,"✠","\\maltese");y(ve,B,V,"✠","\\maltese");var c3='0123456789/@."';for(var qh=0;qh<c3.length;qh++){var d3=c3.charAt(qh);y(_,k,V,d3,d3)}var f3='0123456789!@*()-=+";:?/.,';for(var Yh=0;Yh<f3.length;Yh++){var h3=f3.charAt(Yh);y(ve,k,V,h3,h3)}var Ic="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";for(var Gh=0;Gh<Ic.length;Gh++){var rc=Ic.charAt(Gh);y(_,k,Ze,rc,rc),y(ve,k,V,rc,rc)}y(_,B,V,"C","ℂ");y(ve,B,V,"C","ℂ");y(_,B,V,"H","ℍ");y(ve,B,V,"H","ℍ");y(_,B,V,"N","ℕ");y(ve,B,V,"N","ℕ");y(_,B,V,"P","ℙ");y(ve,B,V,"P","ℙ");y(_,B,V,"Q","ℚ");y(ve,B,V,"Q","ℚ");y(_,B,V,"R","ℝ");y(ve,B,V,"R","ℝ");y(_,B,V,"Z","ℤ");y(ve,B,V,"Z","ℤ");y(_,k,Ze,"h","ℎ");y(ve,k,Ze,"h","ℎ");var at="";for(var rr=0;rr<Ic.length;rr++){var pn=Ic.charAt(rr);at=String.fromCharCode(55349,56320+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),at=String.fromCharCode(55349,56372+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),at=String.fromCharCode(55349,56424+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),at=String.fromCharCode(55349,56580+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),at=String.fromCharCode(55349,56684+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),at=String.fromCharCode(55349,56736+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),at=String.fromCharCode(55349,56788+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),at=String.fromCharCode(55349,56840+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),at=String.fromCharCode(55349,56944+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),rr<26&&(at=String.fromCharCode(55349,56632+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at),at=String.fromCharCode(55349,56476+rr),y(_,k,Ze,pn,at),y(ve,k,V,pn,at))}at="𝕜";y(_,k,Ze,"k",at);y(ve,k,V,"k",at);for(var Nl=0;Nl<10;Nl++){var qi=Nl.toString();at=String.fromCharCode(55349,57294+Nl),y(_,k,Ze,qi,at),y(ve,k,V,qi,at),at=String.fromCharCode(55349,57314+Nl),y(_,k,Ze,qi,at),y(ve,k,V,qi,at),at=String.fromCharCode(55349,57324+Nl),y(_,k,Ze,qi,at),y(ve,k,V,qi,at),at=String.fromCharCode(55349,57334+Nl),y(_,k,Ze,qi,at),y(ve,k,V,qi,at)}var H1="ÐÞþ";for(var Vh=0;Vh<H1.length;Vh++){var ac=H1.charAt(Vh);y(_,k,Ze,ac,ac),y(ve,k,V,ac,ac)}var ic=[["mathbf","textbf","Main-Bold"],["mathbf","textbf","Main-Bold"],["mathnormal","textit","Math-Italic"],["mathnormal","textit","Math-Italic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["mathscr","textscr","Script-Regular"],["","",""],["","",""],["","",""],["mathfrak","textfrak","Fraktur-Regular"],["mathfrak","textfrak","Fraktur-Regular"],["mathbb","textbb","AMS-Regular"],["mathbb","textbb","AMS-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathitsf","textitsf","SansSerif-Italic"],["mathitsf","textitsf","SansSerif-Italic"],["","",""],["","",""],["mathtt","texttt","Typewriter-Regular"],["mathtt","texttt","Typewriter-Regular"]],m3=[["mathbf","textbf","Main-Bold"],["","",""],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathtt","texttt","Typewriter-Regular"]],KR=function(t,n){var a=t.charCodeAt(0),l=t.charCodeAt(1),s=(a-55296)*1024+(l-56320)+65536,o=n==="math"?0:1;if(119808<=s&&s<120484){var d=Math.floor((s-119808)/26);return[ic[d][2],ic[d][o]]}else if(120782<=s&&s<=120831){var f=Math.floor((s-120782)/10);return[m3[f][2],m3[f][o]]}else{if(s===120485||s===120486)return[ic[0][2],ic[0][o]];if(120486<s&&s<120782)return["",""];throw new ke("Unsupported character: "+t)}},Zc=function(t,n,a){return $t[a][t]&&$t[a][t].replace&&(t=$t[a][t].replace),{value:t,metrics:Im(t,n,a)}},da=function(t,n,a,l,s){var o=Zc(t,n,a),d=o.metrics;t=o.value;var f;if(d){var h=d.italic;(a==="text"||l&&l.font==="mathit")&&(h=0),f=new ea(t,d.height,d.depth,h,d.skew,d.width,s)}else typeof console<"u"&&console.warn("No character metrics "+("for '"+t+"' in style '"+n+"' and mode '"+a+"'")),f=new ea(t,0,0,0,0,0,s);if(l){f.maxFontSize=l.sizeMultiplier,l.style.isTight()&&f.classes.push("mtight");var p=l.getColor();p&&(f.style.color=p)}return f},jR=function(t,n,a,l){return l===void 0&&(l=[]),a.font==="boldsymbol"&&Zc(t,"Main-Bold",n).metrics?da(t,"Main-Bold",n,a,l.concat(["mathbf"])):t==="\\"||$t[n][t].font==="main"?da(t,"Main-Regular",n,a,l):da(t,"AMS-Regular",n,a,l.concat(["amsrm"]))},XR=function(t,n,a,l,s){return s!=="textord"&&Zc(t,"Math-BoldItalic",n).metrics?{fontName:"Math-BoldItalic",fontClass:"boldsymbol"}:{fontName:"Main-Bold",fontClass:"mathbf"}},$R=function(t,n,a){var l=t.mode,s=t.text,o=["mord"],d=l==="math"||l==="text"&&n.font,f=d?n.font:n.fontFamily,h="",p="";if(s.charCodeAt(0)===55349&&([h,p]=KR(s,l)),h.length>0)return da(s,h,l,n,o.concat(p));if(f){var E,T;if(f==="boldsymbol"){var v=XR(s,l,n,o,a);E=v.fontName,T=[v.fontClass]}else d?(E=$5[f].fontName,T=[f]):(E=lc(f,n.fontWeight,n.fontShape),T=[f,n.fontWeight,n.fontShape]);if(Zc(s,E,l).metrics)return da(s,E,l,n,o.concat(T));if(K5.hasOwnProperty(s)&&E.slice(0,10)==="Typewriter"){for(var x=[],N=0;N<s.length;N++)x.push(da(s[N],E,l,n,o.concat(T)));return X5(x)}}if(a==="mathord")return da(s,"Math-Italic",l,n,o.concat(["mathnormal"]));if(a==="textord"){var D=$t[l][s]&&$t[l][s].font;if(D==="ams"){var C=lc("amsrm",n.fontWeight,n.fontShape);return da(s,C,l,n,o.concat("amsrm",n.fontWeight,n.fontShape))}else if(D==="main"||!D){var I=lc("textrm",n.fontWeight,n.fontShape);return da(s,I,l,n,o.concat(n.fontWeight,n.fontShape))}else{var F=lc(D,n.fontWeight,n.fontShape);return da(s,F,l,n,o.concat(F,n.fontWeight,n.fontShape))}}else throw new Error("unexpected type: "+a+" in makeOrd")},WR=(e,t)=>{if(Qi(e.classes)!==Qi(t.classes)||e.skew!==t.skew||e.maxFontSize!==t.maxFontSize)return!1;if(e.classes.length===1){var n=e.classes[0];if(n==="mbin"||n==="mord")return!1}for(var a in e.style)if(e.style.hasOwnProperty(a)&&e.style[a]!==t.style[a])return!1;for(var l in t.style)if(t.style.hasOwnProperty(l)&&e.style[l]!==t.style[l])return!1;return!0},QR=e=>{for(var t=0;t<e.length-1;t++){var n=e[t],a=e[t+1];n instanceof ea&&a instanceof ea&&WR(n,a)&&(n.text+=a.text,n.height=Math.max(n.height,a.height),n.depth=Math.max(n.depth,a.depth),n.italic=a.italic,e.splice(t+1,1),t--)}return e},Bm=function(t){for(var n=0,a=0,l=0,s=0;s<t.children.length;s++){var o=t.children[s];o.height>n&&(n=o.height),o.depth>a&&(a=o.depth),o.maxFontSize>l&&(l=o.maxFontSize)}t.height=n,t.depth=a,t.maxFontSize=l},yr=function(t,n,a,l){var s=new Co(t,n,a,l);return Bm(s),s},j5=(e,t,n,a)=>new Co(e,t,n,a),ZR=function(t,n,a){var l=yr([t],[],n);return l.height=Math.max(a||n.fontMetrics().defaultRuleThickness,n.minRuleThickness),l.style.borderBottomWidth=Oe(l.height),l.maxFontSize=1,l},JR=function(t,n,a,l){var s=new Lm(t,n,a,l);return Bm(s),s},X5=function(t){var n=new wo(t);return Bm(n),n},eM=function(t,n){return t instanceof wo?yr([],[t],n):t},tM=function(t){if(t.positionType==="individualShift"){for(var n=t.children,a=[n[0]],l=-n[0].shift-n[0].elem.depth,s=l,o=1;o<n.length;o++){var d=-n[o].shift-s-n[o].elem.depth,f=d-(n[o-1].elem.height+n[o-1].elem.depth);s=s+d,a.push({type:"kern",size:f}),a.push(n[o])}return{children:a,depth:l}}var h;if(t.positionType==="top"){for(var p=t.positionData,E=0;E<t.children.length;E++){var T=t.children[E];p-=T.type==="kern"?T.size:T.elem.height+T.elem.depth}h=p}else if(t.positionType==="bottom")h=-t.positionData;else{var v=t.children[0];if(v.type!=="elem")throw new Error('First child must have type "elem".');if(t.positionType==="shift")h=-v.elem.depth-t.positionData;else if(t.positionType==="firstBaseline")h=-v.elem.depth;else throw new Error("Invalid positionType "+t.positionType+".")}return{children:t.children,depth:h}},nM=function(t,n){for(var{children:a,depth:l}=tM(t),s=0,o=0;o<a.length;o++){var d=a[o];if(d.type==="elem"){var f=d.elem;s=Math.max(s,f.maxFontSize,f.height)}}s+=2;var h=yr(["pstrut"],[]);h.style.height=Oe(s);for(var p=[],E=l,T=l,v=l,x=0;x<a.length;x++){var N=a[x];if(N.type==="kern")v+=N.size;else{var D=N.elem,C=N.wrapperClasses||[],I=N.wrapperStyle||{},F=yr(C,[h,D],void 0,I);F.style.top=Oe(-s-v-D.depth),N.marginLeft&&(F.style.marginLeft=N.marginLeft),N.marginRight&&(F.style.marginRight=N.marginRight),p.push(F),v+=D.height+D.depth}E=Math.min(E,v),T=Math.max(T,v)}var J=yr(["vlist"],p);J.style.height=Oe(T);var K;if(E<0){var U=yr([],[]),le=yr(["vlist"],[U]);le.style.height=Oe(-E);var ae=yr(["vlist-s"],[new ea("​")]);K=[yr(["vlist-r"],[J,ae]),yr(["vlist-r"],[le])]}else K=[yr(["vlist-r"],[J])];var se=yr(["vlist-t"],K);return K.length===2&&se.classes.push("vlist-t2"),se.height=T,se.depth=-E,se},rM=(e,t)=>{var n=yr(["mspace"],[],t),a=fn(e,t);return n.style.marginRight=Oe(a),n},lc=function(t,n,a){var l="";switch(t){case"amsrm":l="AMS";break;case"textrm":l="Main";break;case"textsf":l="SansSerif";break;case"texttt":l="Typewriter";break;default:l=t}var s;return n==="textbf"&&a==="textit"?s="BoldItalic":n==="textbf"?s="Bold":n==="textit"?s="Italic":s="Regular",l+"-"+s},$5={mathbf:{variant:"bold",fontName:"Main-Bold"},mathrm:{variant:"normal",fontName:"Main-Regular"},textit:{variant:"italic",fontName:"Main-Italic"},mathit:{variant:"italic",fontName:"Main-Italic"},mathnormal:{variant:"italic",fontName:"Math-Italic"},mathsfit:{variant:"sans-serif-italic",fontName:"SansSerif-Italic"},mathbb:{variant:"double-struck",fontName:"AMS-Regular"},mathcal:{variant:"script",fontName:"Caligraphic-Regular"},mathfrak:{variant:"fraktur",fontName:"Fraktur-Regular"},mathscr:{variant:"script",fontName:"Script-Regular"},mathsf:{variant:"sans-serif",fontName:"SansSerif-Regular"},mathtt:{variant:"monospace",fontName:"Typewriter-Regular"}},W5={vec:["vec",.471,.714],oiintSize1:["oiintSize1",.957,.499],oiintSize2:["oiintSize2",1.472,.659],oiiintSize1:["oiiintSize1",1.304,.499],oiiintSize2:["oiiintSize2",1.98,.659]},aM=function(t,n){var[a,l,s]=W5[t],o=new Zi(a),d=new ii([o],{width:Oe(l),height:Oe(s),style:"width:"+Oe(l),viewBox:"0 0 "+1e3*l+" "+1e3*s,preserveAspectRatio:"xMinYMin"}),f=j5(["overlay"],[d],n);return f.height=s,f.style.height=Oe(s),f.style.width=Oe(l),f},Z={fontMap:$5,makeSymbol:da,mathsym:jR,makeSpan:yr,makeSvgSpan:j5,makeLineSpan:ZR,makeAnchor:JR,makeFragment:X5,wrapFragment:eM,makeVList:nM,makeOrd:$R,makeGlue:rM,staticSvg:aM,svgData:W5,tryCombineChars:QR},dn={number:3,unit:"mu"},wl={number:4,unit:"mu"},Ja={number:5,unit:"mu"},iM={mord:{mop:dn,mbin:wl,mrel:Ja,minner:dn},mop:{mord:dn,mop:dn,mrel:Ja,minner:dn},mbin:{mord:wl,mop:wl,mopen:wl,minner:wl},mrel:{mord:Ja,mop:Ja,mopen:Ja,minner:Ja},mopen:{},mclose:{mop:dn,mbin:wl,mrel:Ja,minner:dn},mpunct:{mord:dn,mop:dn,mrel:Ja,mopen:dn,mclose:dn,mpunct:dn,minner:dn},minner:{mord:dn,mop:dn,mbin:wl,mrel:Ja,mopen:dn,mpunct:dn,minner:dn}},lM={mord:{mop:dn},mop:{mord:dn,mop:dn},mbin:{},mrel:{},mopen:{},mclose:{mop:dn},mpunct:{},minner:{mop:dn}},Q5={},Lc={},Bc={};function Be(e){for(var{type:t,names:n,props:a,handler:l,htmlBuilder:s,mathmlBuilder:o}=e,d={type:t,numArgs:a.numArgs,argTypes:a.argTypes,allowedInArgument:!!a.allowedInArgument,allowedInText:!!a.allowedInText,allowedInMath:a.allowedInMath===void 0?!0:a.allowedInMath,numOptionalArgs:a.numOptionalArgs||0,infix:!!a.infix,primitive:!!a.primitive,handler:l},f=0;f<n.length;++f)Q5[n[f]]=d;t&&(s&&(Lc[t]=s),o&&(Bc[t]=o))}function Bl(e){var{type:t,htmlBuilder:n,mathmlBuilder:a}=e;Be({type:t,names:[],props:{numArgs:0},handler(){throw new Error("Should never be called.")},htmlBuilder:n,mathmlBuilder:a})}var Pc=function(t){return t.type==="ordgroup"&&t.body.length===1?t.body[0]:t},vn=function(t){return t.type==="ordgroup"?t.body:[t]},li=Z.makeSpan,sM=["leftmost","mbin","mopen","mrel","mop","mpunct"],uM=["rightmost","mrel","mclose","mpunct"],oM={display:Je.DISPLAY,text:Je.TEXT,script:Je.SCRIPT,scriptscript:Je.SCRIPTSCRIPT},cM={mord:"mord",mop:"mop",mbin:"mbin",mrel:"mrel",mopen:"mopen",mclose:"mclose",mpunct:"mpunct",minner:"minner"},Dn=function(t,n,a,l){l===void 0&&(l=[null,null]);for(var s=[],o=0;o<t.length;o++){var d=Nt(t[o],n);if(d instanceof wo){var f=d.children;s.push(...f)}else s.push(d)}if(Z.tryCombineChars(s),!a)return s;var h=n;if(t.length===1){var p=t[0];p.type==="sizing"?h=n.havingSize(p.size):p.type==="styling"&&(h=n.havingStyle(oM[p.style]))}var E=li([l[0]||"leftmost"],[],n),T=li([l[1]||"rightmost"],[],n),v=a==="root";return p3(s,(x,N)=>{var D=N.classes[0],C=x.classes[0];D==="mbin"&&We.contains(uM,C)?N.classes[0]="mord":C==="mbin"&&We.contains(sM,D)&&(x.classes[0]="mord")},{node:E},T,v),p3(s,(x,N)=>{var D=F1(N),C=F1(x),I=D&&C?x.hasClass("mtight")?lM[D][C]:iM[D][C]:null;if(I)return Z.makeGlue(I,h)},{node:E},T,v),s},p3=function e(t,n,a,l,s){l&&t.push(l);for(var o=0;o<t.length;o++){var d=t[o],f=Z5(d);if(f){e(f.children,n,a,null,s);continue}var h=!d.hasClass("mspace");if(h){var p=n(d,a.node);p&&(a.insertAfter?a.insertAfter(p):(t.unshift(p),o++))}h?a.node=d:s&&d.hasClass("newline")&&(a.node=li(["leftmost"])),a.insertAfter=(E=>T=>{t.splice(E+1,0,T),o++})(o)}l&&t.pop()},Z5=function(t){return t instanceof wo||t instanceof Lm||t instanceof Co&&t.hasClass("enclosing")?t:null},dM=function e(t,n){var a=Z5(t);if(a){var l=a.children;if(l.length){if(n==="right")return e(l[l.length-1],"right");if(n==="left")return e(l[0],"left")}}return t},F1=function(t,n){return t?(n&&(t=dM(t,n)),cM[t.classes[0]]||null):null},Eo=function(t,n){var a=["nulldelimiter"].concat(t.baseSizingClasses());return li(n.concat(a))},Nt=function(t,n,a){if(!t)return li();if(Lc[t.type]){var l=Lc[t.type](t,n);if(a&&n.size!==a.size){l=li(n.sizingClasses(a),[l],n);var s=n.sizeMultiplier/a.sizeMultiplier;l.height*=s,l.depth*=s}return l}else throw new ke("Got group of unknown type: '"+t.type+"'")};function sc(e,t){var n=li(["base"],e,t),a=li(["strut"]);return a.style.height=Oe(n.height+n.depth),n.depth&&(a.style.verticalAlign=Oe(-n.depth)),n.children.unshift(a),n}function q1(e,t){var n=null;e.length===1&&e[0].type==="tag"&&(n=e[0].tag,e=e[0].body);var a=Dn(e,t,"root"),l;a.length===2&&a[1].hasClass("tag")&&(l=a.pop());for(var s=[],o=[],d=0;d<a.length;d++)if(o.push(a[d]),a[d].hasClass("mbin")||a[d].hasClass("mrel")||a[d].hasClass("allowbreak")){for(var f=!1;d<a.length-1&&a[d+1].hasClass("mspace")&&!a[d+1].hasClass("newline");)d++,o.push(a[d]),a[d].hasClass("nobreak")&&(f=!0);f||(s.push(sc(o,t)),o=[])}else a[d].hasClass("newline")&&(o.pop(),o.length>0&&(s.push(sc(o,t)),o=[]),s.push(a[d]));o.length>0&&s.push(sc(o,t));var h;n?(h=sc(Dn(n,t,!0)),h.classes=["tag"],s.push(h)):l&&s.push(l);var p=li(["katex-html"],s);if(p.setAttribute("aria-hidden","true"),h){var E=h.children[0];E.style.height=Oe(p.height+p.depth),p.depth&&(E.style.verticalAlign=Oe(-p.depth))}return p}function J5(e){return new wo(e)}class Br{constructor(t,n,a){this.type=void 0,this.attributes=void 0,this.children=void 0,this.classes=void 0,this.type=t,this.attributes={},this.children=n||[],this.classes=a||[]}setAttribute(t,n){this.attributes[t]=n}getAttribute(t){return this.attributes[t]}toNode(){var t=document.createElementNS("http://www.w3.org/1998/Math/MathML",this.type);for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&t.setAttribute(n,this.attributes[n]);this.classes.length>0&&(t.className=Qi(this.classes));for(var a=0;a<this.children.length;a++)if(this.children[a]instanceof wa&&this.children[a+1]instanceof wa){for(var l=this.children[a].toText()+this.children[++a].toText();this.children[a+1]instanceof wa;)l+=this.children[++a].toText();t.appendChild(new wa(l).toNode())}else t.appendChild(this.children[a].toNode());return t}toMarkup(){var t="<"+this.type;for(var n in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,n)&&(t+=" "+n+'="',t+=We.escape(this.attributes[n]),t+='"');this.classes.length>0&&(t+=' class ="'+We.escape(Qi(this.classes))+'"'),t+=">";for(var a=0;a<this.children.length;a++)t+=this.children[a].toMarkup();return t+="</"+this.type+">",t}toText(){return this.children.map(t=>t.toText()).join("")}}class wa{constructor(t){this.text=void 0,this.text=t}toNode(){return document.createTextNode(this.text)}toMarkup(){return We.escape(this.toText())}toText(){return this.text}}class fM{constructor(t){this.width=void 0,this.character=void 0,this.width=t,t>=.05555&&t<=.05556?this.character=" ":t>=.1666&&t<=.1667?this.character=" ":t>=.2222&&t<=.2223?this.character=" ":t>=.2777&&t<=.2778?this.character="  ":t>=-.05556&&t<=-.05555?this.character=" ⁣":t>=-.1667&&t<=-.1666?this.character=" ⁣":t>=-.2223&&t<=-.2222?this.character=" ⁣":t>=-.2778&&t<=-.2777?this.character=" ⁣":this.character=null}toNode(){if(this.character)return document.createTextNode(this.character);var t=document.createElementNS("http://www.w3.org/1998/Math/MathML","mspace");return t.setAttribute("width",Oe(this.width)),t}toMarkup(){return this.character?"<mtext>"+this.character+"</mtext>":'<mspace width="'+Oe(this.width)+'"/>'}toText(){return this.character?this.character:" "}}var xe={MathNode:Br,TextNode:wa,SpaceNode:fM,newDocumentFragment:J5},ta=function(t,n,a){return $t[n][t]&&$t[n][t].replace&&t.charCodeAt(0)!==55349&&!(K5.hasOwnProperty(t)&&a&&(a.fontFamily&&a.fontFamily.slice(4,6)==="tt"||a.font&&a.font.slice(4,6)==="tt"))&&(t=$t[n][t].replace),new xe.TextNode(t)},Pm=function(t){return t.length===1?t[0]:new xe.MathNode("mrow",t)},Um=function(t,n){if(n.fontFamily==="texttt")return"monospace";if(n.fontFamily==="textsf")return n.fontShape==="textit"&&n.fontWeight==="textbf"?"sans-serif-bold-italic":n.fontShape==="textit"?"sans-serif-italic":n.fontWeight==="textbf"?"bold-sans-serif":"sans-serif";if(n.fontShape==="textit"&&n.fontWeight==="textbf")return"bold-italic";if(n.fontShape==="textit")return"italic";if(n.fontWeight==="textbf")return"bold";var a=n.font;if(!a||a==="mathnormal")return null;var l=t.mode;if(a==="mathit")return"italic";if(a==="boldsymbol")return t.type==="textord"?"bold":"bold-italic";if(a==="mathbf")return"bold";if(a==="mathbb")return"double-struck";if(a==="mathsfit")return"sans-serif-italic";if(a==="mathfrak")return"fraktur";if(a==="mathscr"||a==="mathcal")return"script";if(a==="mathsf")return"sans-serif";if(a==="mathtt")return"monospace";var s=t.text;if(We.contains(["\\imath","\\jmath"],s))return null;$t[l][s]&&$t[l][s].replace&&(s=$t[l][s].replace);var o=Z.fontMap[a].fontName;return Im(s,o,l)?Z.fontMap[a].variant:null};function Kh(e){if(!e)return!1;if(e.type==="mi"&&e.children.length===1){var t=e.children[0];return t instanceof wa&&t.text==="."}else if(e.type==="mo"&&e.children.length===1&&e.getAttribute("separator")==="true"&&e.getAttribute("lspace")==="0em"&&e.getAttribute("rspace")==="0em"){var n=e.children[0];return n instanceof wa&&n.text===","}else return!1}var Tr=function(t,n,a){if(t.length===1){var l=Vt(t[0],n);return a&&l instanceof Br&&l.type==="mo"&&(l.setAttribute("lspace","0em"),l.setAttribute("rspace","0em")),[l]}for(var s=[],o,d=0;d<t.length;d++){var f=Vt(t[d],n);if(f instanceof Br&&o instanceof Br){if(f.type==="mtext"&&o.type==="mtext"&&f.getAttribute("mathvariant")===o.getAttribute("mathvariant")){o.children.push(...f.children);continue}else if(f.type==="mn"&&o.type==="mn"){o.children.push(...f.children);continue}else if(Kh(f)&&o.type==="mn"){o.children.push(...f.children);continue}else if(f.type==="mn"&&Kh(o))f.children=[...o.children,...f.children],s.pop();else if((f.type==="msup"||f.type==="msub")&&f.children.length>=1&&(o.type==="mn"||Kh(o))){var h=f.children[0];h instanceof Br&&h.type==="mn"&&(h.children=[...o.children,...h.children],s.pop())}else if(o.type==="mi"&&o.children.length===1){var p=o.children[0];if(p instanceof wa&&p.text==="̸"&&(f.type==="mo"||f.type==="mi"||f.type==="mn")){var E=f.children[0];E instanceof wa&&E.text.length>0&&(E.text=E.text.slice(0,1)+"̸"+E.text.slice(1),s.pop())}}}s.push(f),o=f}return s},Ji=function(t,n,a){return Pm(Tr(t,n,a))},Vt=function(t,n){if(!t)return new xe.MathNode("mrow");if(Bc[t.type]){var a=Bc[t.type](t,n);return a}else throw new ke("Got group of unknown type: '"+t.type+"'")};function g3(e,t,n,a,l){var s=Tr(e,n),o;s.length===1&&s[0]instanceof Br&&We.contains(["mrow","mtable"],s[0].type)?o=s[0]:o=new xe.MathNode("mrow",s);var d=new xe.MathNode("annotation",[new xe.TextNode(t)]);d.setAttribute("encoding","application/x-tex");var f=new xe.MathNode("semantics",[o,d]),h=new xe.MathNode("math",[f]);h.setAttribute("xmlns","http://www.w3.org/1998/Math/MathML"),a&&h.setAttribute("display","block");var p=l?"katex":"katex-mathml";return Z.makeSpan([p],[h])}var e7=function(t){return new ti({style:t.displayMode?Je.DISPLAY:Je.TEXT,maxSize:t.maxSize,minRuleThickness:t.minRuleThickness})},t7=function(t,n){if(n.displayMode){var a=["katex-display"];n.leqno&&a.push("leqno"),n.fleqn&&a.push("fleqn"),t=Z.makeSpan(a,[t])}return t},hM=function(t,n,a){var l=e7(a),s;if(a.output==="mathml")return g3(t,n,l,a.displayMode,!0);if(a.output==="html"){var o=q1(t,l);s=Z.makeSpan(["katex"],[o])}else{var d=g3(t,n,l,a.displayMode,!1),f=q1(t,l);s=Z.makeSpan(["katex"],[d,f])}return t7(s,a)},mM=function(t,n,a){var l=e7(a),s=q1(t,l),o=Z.makeSpan(["katex"],[s]);return t7(o,a)},pM={widehat:"^",widecheck:"ˇ",widetilde:"~",utilde:"~",overleftarrow:"←",underleftarrow:"←",xleftarrow:"←",overrightarrow:"→",underrightarrow:"→",xrightarrow:"→",underbrace:"⏟",overbrace:"⏞",overgroup:"⏠",undergroup:"⏡",overleftrightarrow:"↔",underleftrightarrow:"↔",xleftrightarrow:"↔",Overrightarrow:"⇒",xRightarrow:"⇒",overleftharpoon:"↼",xleftharpoonup:"↼",overrightharpoon:"⇀",xrightharpoonup:"⇀",xLeftarrow:"⇐",xLeftrightarrow:"⇔",xhookleftarrow:"↩",xhookrightarrow:"↪",xmapsto:"↦",xrightharpoondown:"⇁",xleftharpoondown:"↽",xrightleftharpoons:"⇌",xleftrightharpoons:"⇋",xtwoheadleftarrow:"↞",xtwoheadrightarrow:"↠",xlongequal:"=",xtofrom:"⇄",xrightleftarrows:"⇄",xrightequilibrium:"⇌",xleftequilibrium:"⇋","\\cdrightarrow":"→","\\cdleftarrow":"←","\\cdlongequal":"="},gM=function(t){var n=new xe.MathNode("mo",[new xe.TextNode(pM[t.replace(/^\\/,"")])]);return n.setAttribute("stretchy","true"),n},bM={overrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],overleftarrow:[["leftarrow"],.888,522,"xMinYMin"],underrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],underleftarrow:[["leftarrow"],.888,522,"xMinYMin"],xrightarrow:[["rightarrow"],1.469,522,"xMaxYMin"],"\\cdrightarrow":[["rightarrow"],3,522,"xMaxYMin"],xleftarrow:[["leftarrow"],1.469,522,"xMinYMin"],"\\cdleftarrow":[["leftarrow"],3,522,"xMinYMin"],Overrightarrow:[["doublerightarrow"],.888,560,"xMaxYMin"],xRightarrow:[["doublerightarrow"],1.526,560,"xMaxYMin"],xLeftarrow:[["doubleleftarrow"],1.526,560,"xMinYMin"],overleftharpoon:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoonup:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoondown:[["leftharpoondown"],.888,522,"xMinYMin"],overrightharpoon:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoonup:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoondown:[["rightharpoondown"],.888,522,"xMaxYMin"],xlongequal:[["longequal"],.888,334,"xMinYMin"],"\\cdlongequal":[["longequal"],3,334,"xMinYMin"],xtwoheadleftarrow:[["twoheadleftarrow"],.888,334,"xMinYMin"],xtwoheadrightarrow:[["twoheadrightarrow"],.888,334,"xMaxYMin"],overleftrightarrow:[["leftarrow","rightarrow"],.888,522],overbrace:[["leftbrace","midbrace","rightbrace"],1.6,548],underbrace:[["leftbraceunder","midbraceunder","rightbraceunder"],1.6,548],underleftrightarrow:[["leftarrow","rightarrow"],.888,522],xleftrightarrow:[["leftarrow","rightarrow"],1.75,522],xLeftrightarrow:[["doubleleftarrow","doublerightarrow"],1.75,560],xrightleftharpoons:[["leftharpoondownplus","rightharpoonplus"],1.75,716],xleftrightharpoons:[["leftharpoonplus","rightharpoondownplus"],1.75,716],xhookleftarrow:[["leftarrow","righthook"],1.08,522],xhookrightarrow:[["lefthook","rightarrow"],1.08,522],overlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],underlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],overgroup:[["leftgroup","rightgroup"],.888,342],undergroup:[["leftgroupunder","rightgroupunder"],.888,342],xmapsto:[["leftmapsto","rightarrow"],1.5,522],xtofrom:[["leftToFrom","rightToFrom"],1.75,528],xrightleftarrows:[["baraboveleftarrow","rightarrowabovebar"],1.75,901],xrightequilibrium:[["baraboveshortleftharpoon","rightharpoonaboveshortbar"],1.75,716],xleftequilibrium:[["shortbaraboveleftharpoon","shortrightharpoonabovebar"],1.75,716]},EM=function(t){return t.type==="ordgroup"?t.body.length:1},yM=function(t,n){function a(){var d=4e5,f=t.label.slice(1);if(We.contains(["widehat","widecheck","widetilde","utilde"],f)){var h=t,p=EM(h.base),E,T,v;if(p>5)f==="widehat"||f==="widecheck"?(E=420,d=2364,v=.42,T=f+"4"):(E=312,d=2340,v=.34,T="tilde4");else{var x=[1,1,2,2,3,3][p];f==="widehat"||f==="widecheck"?(d=[0,1062,2364,2364,2364][x],E=[0,239,300,360,420][x],v=[0,.24,.3,.3,.36,.42][x],T=f+x):(d=[0,600,1033,2339,2340][x],E=[0,260,286,306,312][x],v=[0,.26,.286,.3,.306,.34][x],T="tilde"+x)}var N=new Zi(T),D=new ii([N],{width:"100%",height:Oe(v),viewBox:"0 0 "+d+" "+E,preserveAspectRatio:"none"});return{span:Z.makeSvgSpan([],[D],n),minWidth:0,height:v}}else{var C=[],I=bM[f],[F,J,K]=I,U=K/1e3,le=F.length,ae,se;if(le===1){var G=I[3];ae=["hide-tail"],se=[G]}else if(le===2)ae=["halfarrow-left","halfarrow-right"],se=["xMinYMin","xMaxYMin"];else if(le===3)ae=["brace-left","brace-center","brace-right"],se=["xMinYMin","xMidYMin","xMaxYMin"];else throw new Error(`Correct katexImagesData or update code here to support
                    `+le+" children.");for(var ge=0;ge<le;ge++){var ce=new Zi(F[ge]),Se=new ii([ce],{width:"400em",height:Oe(U),viewBox:"0 0 "+d+" "+K,preserveAspectRatio:se[ge]+" slice"}),fe=Z.makeSvgSpan([ae[ge]],[Se],n);if(le===1)return{span:fe,minWidth:J,height:U};fe.style.height=Oe(U),C.push(fe)}return{span:Z.makeSpan(["stretchy"],C,n),minWidth:J,height:U}}}var{span:l,minWidth:s,height:o}=a();return l.height=o,l.style.height=Oe(o),s>0&&(l.style.minWidth=Oe(s)),l},vM=function(t,n,a,l,s){var o,d=t.height+t.depth+a+l;if(/fbox|color|angl/.test(n)){if(o=Z.makeSpan(["stretchy",n],[],s),n==="fbox"){var f=s.color&&s.getColor();f&&(o.style.borderColor=f)}}else{var h=[];/^[bx]cancel$/.test(n)&&h.push(new z1({x1:"0",y1:"0",x2:"100%",y2:"100%","stroke-width":"0.046em"})),/^x?cancel$/.test(n)&&h.push(new z1({x1:"0",y1:"100%",x2:"100%",y2:"0","stroke-width":"0.046em"}));var p=new ii(h,{width:"100%",height:Oe(d)});o=Z.makeSvgSpan([],[p],s)}return o.height=d,o.style.height=Oe(d),o},si={encloseSpan:vM,mathMLnode:gM,svgSpan:yM};function ft(e,t){if(!e||e.type!==t)throw new Error("Expected node of type "+t+", but got "+(e?"node of type "+e.type:String(e)));return e}function zm(e){var t=Jc(e);if(!t)throw new Error("Expected node of symbol group type, but got "+(e?"node of type "+e.type:String(e)));return t}function Jc(e){return e&&(e.type==="atom"||VR.hasOwnProperty(e.type))?e:null}var Hm=(e,t)=>{var n,a,l;e&&e.type==="supsub"?(a=ft(e.base,"accent"),n=a.base,e.base=n,l=YR(Nt(e,t)),e.base=a):(a=ft(e,"accent"),n=a.base);var s=Nt(n,t.havingCrampedStyle()),o=a.isShifty&&We.isCharacterBox(n),d=0;if(o){var f=We.getBaseElem(n),h=Nt(f,t.havingCrampedStyle());d=o3(h).skew}var p=a.label==="\\c",E=p?s.height+s.depth:Math.min(s.height,t.fontMetrics().xHeight),T;if(a.isStretchy)T=si.svgSpan(a,t),T=Z.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:s},{type:"elem",elem:T,wrapperClasses:["svg-align"],wrapperStyle:d>0?{width:"calc(100% - "+Oe(2*d)+")",marginLeft:Oe(2*d)}:void 0}]},t);else{var v,x;a.label==="\\vec"?(v=Z.staticSvg("vec",t),x=Z.svgData.vec[1]):(v=Z.makeOrd({mode:a.mode,text:a.label},t,"textord"),v=o3(v),v.italic=0,x=v.width,p&&(E+=v.depth)),T=Z.makeSpan(["accent-body"],[v]);var N=a.label==="\\textcircled";N&&(T.classes.push("accent-full"),E=s.height);var D=d;N||(D-=x/2),T.style.left=Oe(D),a.label==="\\textcircled"&&(T.style.top=".2em"),T=Z.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:s},{type:"kern",size:-E},{type:"elem",elem:T}]},t)}var C=Z.makeSpan(["mord","accent"],[T],t);return l?(l.children[0]=C,l.height=Math.max(C.height,l.height),l.classes[0]="mord",l):C},n7=(e,t)=>{var n=e.isStretchy?si.mathMLnode(e.label):new xe.MathNode("mo",[ta(e.label,e.mode)]),a=new xe.MathNode("mover",[Vt(e.base,t),n]);return a.setAttribute("accent","true"),a},TM=new RegExp(["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring"].map(e=>"\\"+e).join("|"));Be({type:"accent",names:["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring","\\widecheck","\\widehat","\\widetilde","\\overrightarrow","\\overleftarrow","\\Overrightarrow","\\overleftrightarrow","\\overgroup","\\overlinesegment","\\overleftharpoon","\\overrightharpoon"],props:{numArgs:1},handler:(e,t)=>{var n=Pc(t[0]),a=!TM.test(e.funcName),l=!a||e.funcName==="\\widehat"||e.funcName==="\\widetilde"||e.funcName==="\\widecheck";return{type:"accent",mode:e.parser.mode,label:e.funcName,isStretchy:a,isShifty:l,base:n}},htmlBuilder:Hm,mathmlBuilder:n7});Be({type:"accent",names:["\\'","\\`","\\^","\\~","\\=","\\u","\\.",'\\"',"\\c","\\r","\\H","\\v","\\textcircled"],props:{numArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["primitive"]},handler:(e,t)=>{var n=t[0],a=e.parser.mode;return a==="math"&&(e.parser.settings.reportNonstrict("mathVsTextAccents","LaTeX's accent "+e.funcName+" works only in text mode"),a="text"),{type:"accent",mode:a,label:e.funcName,isStretchy:!1,isShifty:!0,base:n}},htmlBuilder:Hm,mathmlBuilder:n7});Be({type:"accentUnder",names:["\\underleftarrow","\\underrightarrow","\\underleftrightarrow","\\undergroup","\\underlinesegment","\\utilde"],props:{numArgs:1},handler:(e,t)=>{var{parser:n,funcName:a}=e,l=t[0];return{type:"accentUnder",mode:n.mode,label:a,base:l}},htmlBuilder:(e,t)=>{var n=Nt(e.base,t),a=si.svgSpan(e,t),l=e.label==="\\utilde"?.12:0,s=Z.makeVList({positionType:"top",positionData:n.height,children:[{type:"elem",elem:a,wrapperClasses:["svg-align"]},{type:"kern",size:l},{type:"elem",elem:n}]},t);return Z.makeSpan(["mord","accentunder"],[s],t)},mathmlBuilder:(e,t)=>{var n=si.mathMLnode(e.label),a=new xe.MathNode("munder",[Vt(e.base,t),n]);return a.setAttribute("accentunder","true"),a}});var uc=e=>{var t=new xe.MathNode("mpadded",e?[e]:[]);return t.setAttribute("width","+0.6em"),t.setAttribute("lspace","0.3em"),t};Be({type:"xArrow",names:["\\xleftarrow","\\xrightarrow","\\xLeftarrow","\\xRightarrow","\\xleftrightarrow","\\xLeftrightarrow","\\xhookleftarrow","\\xhookrightarrow","\\xmapsto","\\xrightharpoondown","\\xrightharpoonup","\\xleftharpoondown","\\xleftharpoonup","\\xrightleftharpoons","\\xleftrightharpoons","\\xlongequal","\\xtwoheadrightarrow","\\xtwoheadleftarrow","\\xtofrom","\\xrightleftarrows","\\xrightequilibrium","\\xleftequilibrium","\\\\cdrightarrow","\\\\cdleftarrow","\\\\cdlongequal"],props:{numArgs:1,numOptionalArgs:1},handler(e,t,n){var{parser:a,funcName:l}=e;return{type:"xArrow",mode:a.mode,label:l,body:t[0],below:n[0]}},htmlBuilder(e,t){var n=t.style,a=t.havingStyle(n.sup()),l=Z.wrapFragment(Nt(e.body,a,t),t),s=e.label.slice(0,2)==="\\x"?"x":"cd";l.classes.push(s+"-arrow-pad");var o;e.below&&(a=t.havingStyle(n.sub()),o=Z.wrapFragment(Nt(e.below,a,t),t),o.classes.push(s+"-arrow-pad"));var d=si.svgSpan(e,t),f=-t.fontMetrics().axisHeight+.5*d.height,h=-t.fontMetrics().axisHeight-.5*d.height-.111;(l.depth>.25||e.label==="\\xleftequilibrium")&&(h-=l.depth);var p;if(o){var E=-t.fontMetrics().axisHeight+o.height+.5*d.height+.111;p=Z.makeVList({positionType:"individualShift",children:[{type:"elem",elem:l,shift:h},{type:"elem",elem:d,shift:f},{type:"elem",elem:o,shift:E}]},t)}else p=Z.makeVList({positionType:"individualShift",children:[{type:"elem",elem:l,shift:h},{type:"elem",elem:d,shift:f}]},t);return p.children[0].children[0].children[1].classes.push("svg-align"),Z.makeSpan(["mrel","x-arrow"],[p],t)},mathmlBuilder(e,t){var n=si.mathMLnode(e.label);n.setAttribute("minsize",e.label.charAt(0)==="x"?"1.75em":"3.0em");var a;if(e.body){var l=uc(Vt(e.body,t));if(e.below){var s=uc(Vt(e.below,t));a=new xe.MathNode("munderover",[n,s,l])}else a=new xe.MathNode("mover",[n,l])}else if(e.below){var o=uc(Vt(e.below,t));a=new xe.MathNode("munder",[n,o])}else a=uc(),a=new xe.MathNode("mover",[n,a]);return a}});var _M=Z.makeSpan;function r7(e,t){var n=Dn(e.body,t,!0);return _M([e.mclass],n,t)}function a7(e,t){var n,a=Tr(e.body,t);return e.mclass==="minner"?n=new xe.MathNode("mpadded",a):e.mclass==="mord"?e.isCharacterBox?(n=a[0],n.type="mi"):n=new xe.MathNode("mi",a):(e.isCharacterBox?(n=a[0],n.type="mo"):n=new xe.MathNode("mo",a),e.mclass==="mbin"?(n.attributes.lspace="0.22em",n.attributes.rspace="0.22em"):e.mclass==="mpunct"?(n.attributes.lspace="0em",n.attributes.rspace="0.17em"):e.mclass==="mopen"||e.mclass==="mclose"?(n.attributes.lspace="0em",n.attributes.rspace="0em"):e.mclass==="minner"&&(n.attributes.lspace="0.0556em",n.attributes.width="+0.1111em")),n}Be({type:"mclass",names:["\\mathord","\\mathbin","\\mathrel","\\mathopen","\\mathclose","\\mathpunct","\\mathinner"],props:{numArgs:1,primitive:!0},handler(e,t){var{parser:n,funcName:a}=e,l=t[0];return{type:"mclass",mode:n.mode,mclass:"m"+a.slice(5),body:vn(l),isCharacterBox:We.isCharacterBox(l)}},htmlBuilder:r7,mathmlBuilder:a7});var ed=e=>{var t=e.type==="ordgroup"&&e.body.length?e.body[0]:e;return t.type==="atom"&&(t.family==="bin"||t.family==="rel")?"m"+t.family:"mord"};Be({type:"mclass",names:["\\@binrel"],props:{numArgs:2},handler(e,t){var{parser:n}=e;return{type:"mclass",mode:n.mode,mclass:ed(t[0]),body:vn(t[1]),isCharacterBox:We.isCharacterBox(t[1])}}});Be({type:"mclass",names:["\\stackrel","\\overset","\\underset"],props:{numArgs:2},handler(e,t){var{parser:n,funcName:a}=e,l=t[1],s=t[0],o;a!=="\\stackrel"?o=ed(l):o="mrel";var d={type:"op",mode:l.mode,limits:!0,alwaysHandleSupSub:!0,parentIsSupSub:!1,symbol:!1,suppressBaseShift:a!=="\\stackrel",body:vn(l)},f={type:"supsub",mode:s.mode,base:d,sup:a==="\\underset"?null:s,sub:a==="\\underset"?s:null};return{type:"mclass",mode:n.mode,mclass:o,body:[f],isCharacterBox:We.isCharacterBox(f)}},htmlBuilder:r7,mathmlBuilder:a7});Be({type:"pmb",names:["\\pmb"],props:{numArgs:1,allowedInText:!0},handler(e,t){var{parser:n}=e;return{type:"pmb",mode:n.mode,mclass:ed(t[0]),body:vn(t[0])}},htmlBuilder(e,t){var n=Dn(e.body,t,!0),a=Z.makeSpan([e.mclass],n,t);return a.style.textShadow="0.02em 0.01em 0.04px",a},mathmlBuilder(e,t){var n=Tr(e.body,t),a=new xe.MathNode("mstyle",n);return a.setAttribute("style","text-shadow: 0.02em 0.01em 0.04px"),a}});var SM={">":"\\\\cdrightarrow","<":"\\\\cdleftarrow","=":"\\\\cdlongequal",A:"\\uparrow",V:"\\downarrow","|":"\\Vert",".":"no arrow"},b3=()=>({type:"styling",body:[],mode:"math",style:"display"}),E3=e=>e.type==="textord"&&e.text==="@",AM=(e,t)=>(e.type==="mathord"||e.type==="atom")&&e.text===t;function xM(e,t,n){var a=SM[e];switch(a){case"\\\\cdrightarrow":case"\\\\cdleftarrow":return n.callFunction(a,[t[0]],[t[1]]);case"\\uparrow":case"\\downarrow":{var l=n.callFunction("\\\\cdleft",[t[0]],[]),s={type:"atom",text:a,mode:"math",family:"rel"},o=n.callFunction("\\Big",[s],[]),d=n.callFunction("\\\\cdright",[t[1]],[]),f={type:"ordgroup",mode:"math",body:[l,o,d]};return n.callFunction("\\\\cdparent",[f],[])}case"\\\\cdlongequal":return n.callFunction("\\\\cdlongequal",[],[]);case"\\Vert":{var h={type:"textord",text:"\\Vert",mode:"math"};return n.callFunction("\\Big",[h],[])}default:return{type:"textord",text:" ",mode:"math"}}}function kM(e){var t=[];for(e.gullet.beginGroup(),e.gullet.macros.set("\\cr","\\\\\\relax"),e.gullet.beginGroup();;){t.push(e.parseExpression(!1,"\\\\")),e.gullet.endGroup(),e.gullet.beginGroup();var n=e.fetch().text;if(n==="&"||n==="\\\\")e.consume();else if(n==="\\end"){t[t.length-1].length===0&&t.pop();break}else throw new ke("Expected \\\\ or \\cr or \\end",e.nextToken)}for(var a=[],l=[a],s=0;s<t.length;s++){for(var o=t[s],d=b3(),f=0;f<o.length;f++)if(!E3(o[f]))d.body.push(o[f]);else{a.push(d),f+=1;var h=zm(o[f]).text,p=new Array(2);if(p[0]={type:"ordgroup",mode:"math",body:[]},p[1]={type:"ordgroup",mode:"math",body:[]},!("=|.".indexOf(h)>-1))if("<>AV".indexOf(h)>-1)for(var E=0;E<2;E++){for(var T=!0,v=f+1;v<o.length;v++){if(AM(o[v],h)){T=!1,f=v;break}if(E3(o[v]))throw new ke("Missing a "+h+" character to complete a CD arrow.",o[v]);p[E].body.push(o[v])}if(T)throw new ke("Missing a "+h+" character to complete a CD arrow.",o[f])}else throw new ke('Expected one of "<>AV=|." after @',o[f]);var x=xM(h,p,e),N={type:"styling",body:[x],mode:"math",style:"display"};a.push(N),d=b3()}s%2===0?a.push(d):a.shift(),a=[],l.push(a)}e.gullet.endGroup(),e.gullet.endGroup();var D=new Array(l[0].length).fill({type:"align",align:"c",pregap:.25,postgap:.25});return{type:"array",mode:"math",body:l,arraystretch:1,addJot:!0,rowGaps:[null],cols:D,colSeparationType:"CD",hLinesBeforeRow:new Array(l.length+1).fill([])}}Be({type:"cdlabel",names:["\\\\cdleft","\\\\cdright"],props:{numArgs:1},handler(e,t){var{parser:n,funcName:a}=e;return{type:"cdlabel",mode:n.mode,side:a.slice(4),label:t[0]}},htmlBuilder(e,t){var n=t.havingStyle(t.style.sup()),a=Z.wrapFragment(Nt(e.label,n,t),t);return a.classes.push("cd-label-"+e.side),a.style.bottom=Oe(.8-a.depth),a.height=0,a.depth=0,a},mathmlBuilder(e,t){var n=new xe.MathNode("mrow",[Vt(e.label,t)]);return n=new xe.MathNode("mpadded",[n]),n.setAttribute("width","0"),e.side==="left"&&n.setAttribute("lspace","-1width"),n.setAttribute("voffset","0.7em"),n=new xe.MathNode("mstyle",[n]),n.setAttribute("displaystyle","false"),n.setAttribute("scriptlevel","1"),n}});Be({type:"cdlabelparent",names:["\\\\cdparent"],props:{numArgs:1},handler(e,t){var{parser:n}=e;return{type:"cdlabelparent",mode:n.mode,fragment:t[0]}},htmlBuilder(e,t){var n=Z.wrapFragment(Nt(e.fragment,t),t);return n.classes.push("cd-vert-arrow"),n},mathmlBuilder(e,t){return new xe.MathNode("mrow",[Vt(e.fragment,t)])}});Be({type:"textord",names:["\\@char"],props:{numArgs:1,allowedInText:!0},handler(e,t){for(var{parser:n}=e,a=ft(t[0],"ordgroup"),l=a.body,s="",o=0;o<l.length;o++){var d=ft(l[o],"textord");s+=d.text}var f=parseInt(s),h;if(isNaN(f))throw new ke("\\@char has non-numeric argument "+s);if(f<0||f>=1114111)throw new ke("\\@char with invalid code point "+s);return f<=65535?h=String.fromCharCode(f):(f-=65536,h=String.fromCharCode((f>>10)+55296,(f&1023)+56320)),{type:"textord",mode:n.mode,text:h}}});var i7=(e,t)=>{var n=Dn(e.body,t.withColor(e.color),!1);return Z.makeFragment(n)},l7=(e,t)=>{var n=Tr(e.body,t.withColor(e.color)),a=new xe.MathNode("mstyle",n);return a.setAttribute("mathcolor",e.color),a};Be({type:"color",names:["\\textcolor"],props:{numArgs:2,allowedInText:!0,argTypes:["color","original"]},handler(e,t){var{parser:n}=e,a=ft(t[0],"color-token").color,l=t[1];return{type:"color",mode:n.mode,color:a,body:vn(l)}},htmlBuilder:i7,mathmlBuilder:l7});Be({type:"color",names:["\\color"],props:{numArgs:1,allowedInText:!0,argTypes:["color"]},handler(e,t){var{parser:n,breakOnTokenText:a}=e,l=ft(t[0],"color-token").color;n.gullet.macros.set("\\current@color",l);var s=n.parseExpression(!0,a);return{type:"color",mode:n.mode,color:l,body:s}},htmlBuilder:i7,mathmlBuilder:l7});Be({type:"cr",names:["\\\\"],props:{numArgs:0,numOptionalArgs:0,allowedInText:!0},handler(e,t,n){var{parser:a}=e,l=a.gullet.future().text==="["?a.parseSizeGroup(!0):null,s=!a.settings.displayMode||!a.settings.useStrictBehavior("newLineInDisplayMode","In LaTeX, \\\\ or \\newline does nothing in display mode");return{type:"cr",mode:a.mode,newLine:s,size:l&&ft(l,"size").value}},htmlBuilder(e,t){var n=Z.makeSpan(["mspace"],[],t);return e.newLine&&(n.classes.push("newline"),e.size&&(n.style.marginTop=Oe(fn(e.size,t)))),n},mathmlBuilder(e,t){var n=new xe.MathNode("mspace");return e.newLine&&(n.setAttribute("linebreak","newline"),e.size&&n.setAttribute("height",Oe(fn(e.size,t)))),n}});var Y1={"\\global":"\\global","\\long":"\\\\globallong","\\\\globallong":"\\\\globallong","\\def":"\\gdef","\\gdef":"\\gdef","\\edef":"\\xdef","\\xdef":"\\xdef","\\let":"\\\\globallet","\\futurelet":"\\\\globalfuture"},s7=e=>{var t=e.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(t))throw new ke("Expected a control sequence",e);return t},NM=e=>{var t=e.gullet.popToken();return t.text==="="&&(t=e.gullet.popToken(),t.text===" "&&(t=e.gullet.popToken())),t},u7=(e,t,n,a)=>{var l=e.gullet.macros.get(n.text);l==null&&(n.noexpand=!0,l={tokens:[n],numArgs:0,unexpandable:!e.gullet.isExpandable(n.text)}),e.gullet.macros.set(t,l,a)};Be({type:"internal",names:["\\global","\\long","\\\\globallong"],props:{numArgs:0,allowedInText:!0},handler(e){var{parser:t,funcName:n}=e;t.consumeSpaces();var a=t.fetch();if(Y1[a.text])return(n==="\\global"||n==="\\\\globallong")&&(a.text=Y1[a.text]),ft(t.parseFunction(),"internal");throw new ke("Invalid token after macro prefix",a)}});Be({type:"internal",names:["\\def","\\gdef","\\edef","\\xdef"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:n}=e,a=t.gullet.popToken(),l=a.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(l))throw new ke("Expected a control sequence",a);for(var s=0,o,d=[[]];t.gullet.future().text!=="{";)if(a=t.gullet.popToken(),a.text==="#"){if(t.gullet.future().text==="{"){o=t.gullet.future(),d[s].push("{");break}if(a=t.gullet.popToken(),!/^[1-9]$/.test(a.text))throw new ke('Invalid argument number "'+a.text+'"');if(parseInt(a.text)!==s+1)throw new ke('Argument number "'+a.text+'" out of order');s++,d.push([])}else{if(a.text==="EOF")throw new ke("Expected a macro definition");d[s].push(a.text)}var{tokens:f}=t.gullet.consumeArg();return o&&f.unshift(o),(n==="\\edef"||n==="\\xdef")&&(f=t.gullet.expandTokens(f),f.reverse()),t.gullet.macros.set(l,{tokens:f,numArgs:s,delimiters:d},n===Y1[n]),{type:"internal",mode:t.mode}}});Be({type:"internal",names:["\\let","\\\\globallet"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:n}=e,a=s7(t.gullet.popToken());t.gullet.consumeSpaces();var l=NM(t);return u7(t,a,l,n==="\\\\globallet"),{type:"internal",mode:t.mode}}});Be({type:"internal",names:["\\futurelet","\\\\globalfuture"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e){var{parser:t,funcName:n}=e,a=s7(t.gullet.popToken()),l=t.gullet.popToken(),s=t.gullet.popToken();return u7(t,a,s,n==="\\\\globalfuture"),t.gullet.pushToken(s),t.gullet.pushToken(l),{type:"internal",mode:t.mode}}});var Ju=function(t,n,a){var l=$t.math[t]&&$t.math[t].replace,s=Im(l||t,n,a);if(!s)throw new Error("Unsupported symbol "+t+" and font size "+n+".");return s},Fm=function(t,n,a,l){var s=a.havingBaseStyle(n),o=Z.makeSpan(l.concat(s.sizingClasses(a)),[t],a),d=s.sizeMultiplier/a.sizeMultiplier;return o.height*=d,o.depth*=d,o.maxFontSize=s.sizeMultiplier,o},o7=function(t,n,a){var l=n.havingBaseStyle(a),s=(1-n.sizeMultiplier/l.sizeMultiplier)*n.fontMetrics().axisHeight;t.classes.push("delimcenter"),t.style.top=Oe(s),t.height-=s,t.depth+=s},wM=function(t,n,a,l,s,o){var d=Z.makeSymbol(t,"Main-Regular",s,l),f=Fm(d,n,l,o);return a&&o7(f,l,n),f},CM=function(t,n,a,l){return Z.makeSymbol(t,"Size"+n+"-Regular",a,l)},c7=function(t,n,a,l,s,o){var d=CM(t,n,s,l),f=Fm(Z.makeSpan(["delimsizing","size"+n],[d],l),Je.TEXT,l,o);return a&&o7(f,l,Je.TEXT),f},jh=function(t,n,a){var l;n==="Size1-Regular"?l="delim-size1":l="delim-size4";var s=Z.makeSpan(["delimsizinginner",l],[Z.makeSpan([],[Z.makeSymbol(t,n,a)])]);return{type:"elem",elem:s}},Xh=function(t,n,a){var l=Na["Size4-Regular"][t.charCodeAt(0)]?Na["Size4-Regular"][t.charCodeAt(0)][4]:Na["Size1-Regular"][t.charCodeAt(0)][4],s=new Zi("inner",IR(t,Math.round(1e3*n))),o=new ii([s],{width:Oe(l),height:Oe(n),style:"width:"+Oe(l),viewBox:"0 0 "+1e3*l+" "+Math.round(1e3*n),preserveAspectRatio:"xMinYMin"}),d=Z.makeSvgSpan([],[o],a);return d.height=n,d.style.height=Oe(n),d.style.width=Oe(l),{type:"elem",elem:d}},G1=.008,oc={type:"kern",size:-1*G1},OM=["|","\\lvert","\\rvert","\\vert"],RM=["\\|","\\lVert","\\rVert","\\Vert"],d7=function(t,n,a,l,s,o){var d,f,h,p,E="",T=0;d=h=p=t,f=null;var v="Size1-Regular";t==="\\uparrow"?h=p="⏐":t==="\\Uparrow"?h=p="‖":t==="\\downarrow"?d=h="⏐":t==="\\Downarrow"?d=h="‖":t==="\\updownarrow"?(d="\\uparrow",h="⏐",p="\\downarrow"):t==="\\Updownarrow"?(d="\\Uparrow",h="‖",p="\\Downarrow"):We.contains(OM,t)?(h="∣",E="vert",T=333):We.contains(RM,t)?(h="∥",E="doublevert",T=556):t==="["||t==="\\lbrack"?(d="⎡",h="⎢",p="⎣",v="Size4-Regular",E="lbrack",T=667):t==="]"||t==="\\rbrack"?(d="⎤",h="⎥",p="⎦",v="Size4-Regular",E="rbrack",T=667):t==="\\lfloor"||t==="⌊"?(h=d="⎢",p="⎣",v="Size4-Regular",E="lfloor",T=667):t==="\\lceil"||t==="⌈"?(d="⎡",h=p="⎢",v="Size4-Regular",E="lceil",T=667):t==="\\rfloor"||t==="⌋"?(h=d="⎥",p="⎦",v="Size4-Regular",E="rfloor",T=667):t==="\\rceil"||t==="⌉"?(d="⎤",h=p="⎥",v="Size4-Regular",E="rceil",T=667):t==="("||t==="\\lparen"?(d="⎛",h="⎜",p="⎝",v="Size4-Regular",E="lparen",T=875):t===")"||t==="\\rparen"?(d="⎞",h="⎟",p="⎠",v="Size4-Regular",E="rparen",T=875):t==="\\{"||t==="\\lbrace"?(d="⎧",f="⎨",p="⎩",h="⎪",v="Size4-Regular"):t==="\\}"||t==="\\rbrace"?(d="⎫",f="⎬",p="⎭",h="⎪",v="Size4-Regular"):t==="\\lgroup"||t==="⟮"?(d="⎧",p="⎩",h="⎪",v="Size4-Regular"):t==="\\rgroup"||t==="⟯"?(d="⎫",p="⎭",h="⎪",v="Size4-Regular"):t==="\\lmoustache"||t==="⎰"?(d="⎧",p="⎭",h="⎪",v="Size4-Regular"):(t==="\\rmoustache"||t==="⎱")&&(d="⎫",p="⎩",h="⎪",v="Size4-Regular");var x=Ju(d,v,s),N=x.height+x.depth,D=Ju(h,v,s),C=D.height+D.depth,I=Ju(p,v,s),F=I.height+I.depth,J=0,K=1;if(f!==null){var U=Ju(f,v,s);J=U.height+U.depth,K=2}var le=N+F+J,ae=Math.max(0,Math.ceil((n-le)/(K*C))),se=le+ae*K*C,G=l.fontMetrics().axisHeight;a&&(G*=l.sizeMultiplier);var ge=se/2-G,ce=[];if(E.length>0){var Se=se-N-F,fe=Math.round(se*1e3),ye=LR(E,Math.round(Se*1e3)),X=new Zi(E,ye),oe=(T/1e3).toFixed(3)+"em",be=(fe/1e3).toFixed(3)+"em",ze=new ii([X],{width:oe,height:be,viewBox:"0 0 "+T+" "+fe}),A=Z.makeSvgSpan([],[ze],l);A.height=fe/1e3,A.style.width=oe,A.style.height=be,ce.push({type:"elem",elem:A})}else{if(ce.push(jh(p,v,s)),ce.push(oc),f===null){var te=se-N-F+2*G1;ce.push(Xh(h,te,l))}else{var ue=(se-N-F-J)/2+2*G1;ce.push(Xh(h,ue,l)),ce.push(oc),ce.push(jh(f,v,s)),ce.push(oc),ce.push(Xh(h,ue,l))}ce.push(oc),ce.push(jh(d,v,s))}var R=l.havingBaseStyle(Je.TEXT),De=Z.makeVList({positionType:"bottom",positionData:ge,children:ce},R);return Fm(Z.makeSpan(["delimsizing","mult"],[De],R),Je.TEXT,l,o)},$h=80,Wh=.08,Qh=function(t,n,a,l,s){var o=DR(t,l,a),d=new Zi(t,o),f=new ii([d],{width:"400em",height:Oe(n),viewBox:"0 0 400000 "+a,preserveAspectRatio:"xMinYMin slice"});return Z.makeSvgSpan(["hide-tail"],[f],s)},MM=function(t,n){var a=n.havingBaseSizing(),l=p7("\\surd",t*a.sizeMultiplier,m7,a),s=a.sizeMultiplier,o=Math.max(0,n.minRuleThickness-n.fontMetrics().sqrtRuleThickness),d,f=0,h=0,p=0,E;return l.type==="small"?(p=1e3+1e3*o+$h,t<1?s=1:t<1.4&&(s=.7),f=(1+o+Wh)/s,h=(1+o)/s,d=Qh("sqrtMain",f,p,o,n),d.style.minWidth="0.853em",E=.833/s):l.type==="large"?(p=(1e3+$h)*uo[l.size],h=(uo[l.size]+o)/s,f=(uo[l.size]+o+Wh)/s,d=Qh("sqrtSize"+l.size,f,p,o,n),d.style.minWidth="1.02em",E=1/s):(f=t+o+Wh,h=t+o,p=Math.floor(1e3*t+o)+$h,d=Qh("sqrtTall",f,p,o,n),d.style.minWidth="0.742em",E=1.056),d.height=h,d.style.height=Oe(f),{span:d,advanceWidth:E,ruleWidth:(n.fontMetrics().sqrtRuleThickness+o)*s}},f7=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","\\surd"],DM=["\\uparrow","\\downarrow","\\updownarrow","\\Uparrow","\\Downarrow","\\Updownarrow","|","\\|","\\vert","\\Vert","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱"],h7=["<",">","\\langle","\\rangle","/","\\backslash","\\lt","\\gt"],uo=[0,1.2,1.8,2.4,3],IM=function(t,n,a,l,s){if(t==="<"||t==="\\lt"||t==="⟨"?t="\\langle":(t===">"||t==="\\gt"||t==="⟩")&&(t="\\rangle"),We.contains(f7,t)||We.contains(h7,t))return c7(t,n,!1,a,l,s);if(We.contains(DM,t))return d7(t,uo[n],!1,a,l,s);throw new ke("Illegal delimiter: '"+t+"'")},LM=[{type:"small",style:Je.SCRIPTSCRIPT},{type:"small",style:Je.SCRIPT},{type:"small",style:Je.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4}],BM=[{type:"small",style:Je.SCRIPTSCRIPT},{type:"small",style:Je.SCRIPT},{type:"small",style:Je.TEXT},{type:"stack"}],m7=[{type:"small",style:Je.SCRIPTSCRIPT},{type:"small",style:Je.SCRIPT},{type:"small",style:Je.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4},{type:"stack"}],PM=function(t){if(t.type==="small")return"Main-Regular";if(t.type==="large")return"Size"+t.size+"-Regular";if(t.type==="stack")return"Size4-Regular";throw new Error("Add support for delim type '"+t.type+"' here.")},p7=function(t,n,a,l){for(var s=Math.min(2,3-l.style.size),o=s;o<a.length&&a[o].type!=="stack";o++){var d=Ju(t,PM(a[o]),"math"),f=d.height+d.depth;if(a[o].type==="small"){var h=l.havingBaseStyle(a[o].style);f*=h.sizeMultiplier}if(f>n)return a[o]}return a[a.length-1]},g7=function(t,n,a,l,s,o){t==="<"||t==="\\lt"||t==="⟨"?t="\\langle":(t===">"||t==="\\gt"||t==="⟩")&&(t="\\rangle");var d;We.contains(h7,t)?d=LM:We.contains(f7,t)?d=m7:d=BM;var f=p7(t,n,d,l);return f.type==="small"?wM(t,f.style,a,l,s,o):f.type==="large"?c7(t,f.size,a,l,s,o):d7(t,n,a,l,s,o)},UM=function(t,n,a,l,s,o){var d=l.fontMetrics().axisHeight*l.sizeMultiplier,f=901,h=5/l.fontMetrics().ptPerEm,p=Math.max(n-d,a+d),E=Math.max(p/500*f,2*p-h);return g7(t,E,!0,l,s,o)},ai={sqrtImage:MM,sizedDelim:IM,sizeToMaxHeight:uo,customSizedDelim:g7,leftRightDelim:UM},y3={"\\bigl":{mclass:"mopen",size:1},"\\Bigl":{mclass:"mopen",size:2},"\\biggl":{mclass:"mopen",size:3},"\\Biggl":{mclass:"mopen",size:4},"\\bigr":{mclass:"mclose",size:1},"\\Bigr":{mclass:"mclose",size:2},"\\biggr":{mclass:"mclose",size:3},"\\Biggr":{mclass:"mclose",size:4},"\\bigm":{mclass:"mrel",size:1},"\\Bigm":{mclass:"mrel",size:2},"\\biggm":{mclass:"mrel",size:3},"\\Biggm":{mclass:"mrel",size:4},"\\big":{mclass:"mord",size:1},"\\Big":{mclass:"mord",size:2},"\\bigg":{mclass:"mord",size:3},"\\Bigg":{mclass:"mord",size:4}},zM=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","<",">","\\langle","⟨","\\rangle","⟩","\\lt","\\gt","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱","/","\\backslash","|","\\vert","\\|","\\Vert","\\uparrow","\\Uparrow","\\downarrow","\\Downarrow","\\updownarrow","\\Updownarrow","."];function td(e,t){var n=Jc(e);if(n&&We.contains(zM,n.text))return n;throw n?new ke("Invalid delimiter '"+n.text+"' after '"+t.funcName+"'",e):new ke("Invalid delimiter type '"+e.type+"'",e)}Be({type:"delimsizing",names:["\\bigl","\\Bigl","\\biggl","\\Biggl","\\bigr","\\Bigr","\\biggr","\\Biggr","\\bigm","\\Bigm","\\biggm","\\Biggm","\\big","\\Big","\\bigg","\\Bigg"],props:{numArgs:1,argTypes:["primitive"]},handler:(e,t)=>{var n=td(t[0],e);return{type:"delimsizing",mode:e.parser.mode,size:y3[e.funcName].size,mclass:y3[e.funcName].mclass,delim:n.text}},htmlBuilder:(e,t)=>e.delim==="."?Z.makeSpan([e.mclass]):ai.sizedDelim(e.delim,e.size,t,e.mode,[e.mclass]),mathmlBuilder:e=>{var t=[];e.delim!=="."&&t.push(ta(e.delim,e.mode));var n=new xe.MathNode("mo",t);e.mclass==="mopen"||e.mclass==="mclose"?n.setAttribute("fence","true"):n.setAttribute("fence","false"),n.setAttribute("stretchy","true");var a=Oe(ai.sizeToMaxHeight[e.size]);return n.setAttribute("minsize",a),n.setAttribute("maxsize",a),n}});function v3(e){if(!e.body)throw new Error("Bug: The leftright ParseNode wasn't fully parsed.")}Be({type:"leftright-right",names:["\\right"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var n=e.parser.gullet.macros.get("\\current@color");if(n&&typeof n!="string")throw new ke("\\current@color set to non-string in \\right");return{type:"leftright-right",mode:e.parser.mode,delim:td(t[0],e).text,color:n}}});Be({type:"leftright",names:["\\left"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var n=td(t[0],e),a=e.parser;++a.leftrightDepth;var l=a.parseExpression(!1);--a.leftrightDepth,a.expect("\\right",!1);var s=ft(a.parseFunction(),"leftright-right");return{type:"leftright",mode:a.mode,body:l,left:n.text,right:s.delim,rightColor:s.color}},htmlBuilder:(e,t)=>{v3(e);for(var n=Dn(e.body,t,!0,["mopen","mclose"]),a=0,l=0,s=!1,o=0;o<n.length;o++)n[o].isMiddle?s=!0:(a=Math.max(n[o].height,a),l=Math.max(n[o].depth,l));a*=t.sizeMultiplier,l*=t.sizeMultiplier;var d;if(e.left==="."?d=Eo(t,["mopen"]):d=ai.leftRightDelim(e.left,a,l,t,e.mode,["mopen"]),n.unshift(d),s)for(var f=1;f<n.length;f++){var h=n[f],p=h.isMiddle;p&&(n[f]=ai.leftRightDelim(p.delim,a,l,p.options,e.mode,[]))}var E;if(e.right===".")E=Eo(t,["mclose"]);else{var T=e.rightColor?t.withColor(e.rightColor):t;E=ai.leftRightDelim(e.right,a,l,T,e.mode,["mclose"])}return n.push(E),Z.makeSpan(["minner"],n,t)},mathmlBuilder:(e,t)=>{v3(e);var n=Tr(e.body,t);if(e.left!=="."){var a=new xe.MathNode("mo",[ta(e.left,e.mode)]);a.setAttribute("fence","true"),n.unshift(a)}if(e.right!=="."){var l=new xe.MathNode("mo",[ta(e.right,e.mode)]);l.setAttribute("fence","true"),e.rightColor&&l.setAttribute("mathcolor",e.rightColor),n.push(l)}return Pm(n)}});Be({type:"middle",names:["\\middle"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var n=td(t[0],e);if(!e.parser.leftrightDepth)throw new ke("\\middle without preceding \\left",n);return{type:"middle",mode:e.parser.mode,delim:n.text}},htmlBuilder:(e,t)=>{var n;if(e.delim===".")n=Eo(t,[]);else{n=ai.sizedDelim(e.delim,1,t,e.mode,[]);var a={delim:e.delim,options:t};n.isMiddle=a}return n},mathmlBuilder:(e,t)=>{var n=e.delim==="\\vert"||e.delim==="|"?ta("|","text"):ta(e.delim,e.mode),a=new xe.MathNode("mo",[n]);return a.setAttribute("fence","true"),a.setAttribute("lspace","0.05em"),a.setAttribute("rspace","0.05em"),a}});var qm=(e,t)=>{var n=Z.wrapFragment(Nt(e.body,t),t),a=e.label.slice(1),l=t.sizeMultiplier,s,o=0,d=We.isCharacterBox(e.body);if(a==="sout")s=Z.makeSpan(["stretchy","sout"]),s.height=t.fontMetrics().defaultRuleThickness/l,o=-.5*t.fontMetrics().xHeight;else if(a==="phase"){var f=fn({number:.6,unit:"pt"},t),h=fn({number:.35,unit:"ex"},t),p=t.havingBaseSizing();l=l/p.sizeMultiplier;var E=n.height+n.depth+f+h;n.style.paddingLeft=Oe(E/2+f);var T=Math.floor(1e3*E*l),v=RR(T),x=new ii([new Zi("phase",v)],{width:"400em",height:Oe(T/1e3),viewBox:"0 0 400000 "+T,preserveAspectRatio:"xMinYMin slice"});s=Z.makeSvgSpan(["hide-tail"],[x],t),s.style.height=Oe(E),o=n.depth+f+h}else{/cancel/.test(a)?d||n.classes.push("cancel-pad"):a==="angl"?n.classes.push("anglpad"):n.classes.push("boxpad");var N=0,D=0,C=0;/box/.test(a)?(C=Math.max(t.fontMetrics().fboxrule,t.minRuleThickness),N=t.fontMetrics().fboxsep+(a==="colorbox"?0:C),D=N):a==="angl"?(C=Math.max(t.fontMetrics().defaultRuleThickness,t.minRuleThickness),N=4*C,D=Math.max(0,.25-n.depth)):(N=d?.2:0,D=N),s=si.encloseSpan(n,a,N,D,t),/fbox|boxed|fcolorbox/.test(a)?(s.style.borderStyle="solid",s.style.borderWidth=Oe(C)):a==="angl"&&C!==.049&&(s.style.borderTopWidth=Oe(C),s.style.borderRightWidth=Oe(C)),o=n.depth+D,e.backgroundColor&&(s.style.backgroundColor=e.backgroundColor,e.borderColor&&(s.style.borderColor=e.borderColor))}var I;if(e.backgroundColor)I=Z.makeVList({positionType:"individualShift",children:[{type:"elem",elem:s,shift:o},{type:"elem",elem:n,shift:0}]},t);else{var F=/cancel|phase/.test(a)?["svg-align"]:[];I=Z.makeVList({positionType:"individualShift",children:[{type:"elem",elem:n,shift:0},{type:"elem",elem:s,shift:o,wrapperClasses:F}]},t)}return/cancel/.test(a)&&(I.height=n.height,I.depth=n.depth),/cancel/.test(a)&&!d?Z.makeSpan(["mord","cancel-lap"],[I],t):Z.makeSpan(["mord"],[I],t)},Ym=(e,t)=>{var n=0,a=new xe.MathNode(e.label.indexOf("colorbox")>-1?"mpadded":"menclose",[Vt(e.body,t)]);switch(e.label){case"\\cancel":a.setAttribute("notation","updiagonalstrike");break;case"\\bcancel":a.setAttribute("notation","downdiagonalstrike");break;case"\\phase":a.setAttribute("notation","phasorangle");break;case"\\sout":a.setAttribute("notation","horizontalstrike");break;case"\\fbox":a.setAttribute("notation","box");break;case"\\angl":a.setAttribute("notation","actuarial");break;case"\\fcolorbox":case"\\colorbox":if(n=t.fontMetrics().fboxsep*t.fontMetrics().ptPerEm,a.setAttribute("width","+"+2*n+"pt"),a.setAttribute("height","+"+2*n+"pt"),a.setAttribute("lspace",n+"pt"),a.setAttribute("voffset",n+"pt"),e.label==="\\fcolorbox"){var l=Math.max(t.fontMetrics().fboxrule,t.minRuleThickness);a.setAttribute("style","border: "+l+"em solid "+String(e.borderColor))}break;case"\\xcancel":a.setAttribute("notation","updiagonalstrike downdiagonalstrike");break}return e.backgroundColor&&a.setAttribute("mathbackground",e.backgroundColor),a};Be({type:"enclose",names:["\\colorbox"],props:{numArgs:2,allowedInText:!0,argTypes:["color","text"]},handler(e,t,n){var{parser:a,funcName:l}=e,s=ft(t[0],"color-token").color,o=t[1];return{type:"enclose",mode:a.mode,label:l,backgroundColor:s,body:o}},htmlBuilder:qm,mathmlBuilder:Ym});Be({type:"enclose",names:["\\fcolorbox"],props:{numArgs:3,allowedInText:!0,argTypes:["color","color","text"]},handler(e,t,n){var{parser:a,funcName:l}=e,s=ft(t[0],"color-token").color,o=ft(t[1],"color-token").color,d=t[2];return{type:"enclose",mode:a.mode,label:l,backgroundColor:o,borderColor:s,body:d}},htmlBuilder:qm,mathmlBuilder:Ym});Be({type:"enclose",names:["\\fbox"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!0},handler(e,t){var{parser:n}=e;return{type:"enclose",mode:n.mode,label:"\\fbox",body:t[0]}}});Be({type:"enclose",names:["\\cancel","\\bcancel","\\xcancel","\\sout","\\phase"],props:{numArgs:1},handler(e,t){var{parser:n,funcName:a}=e,l=t[0];return{type:"enclose",mode:n.mode,label:a,body:l}},htmlBuilder:qm,mathmlBuilder:Ym});Be({type:"enclose",names:["\\angl"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!1},handler(e,t){var{parser:n}=e;return{type:"enclose",mode:n.mode,label:"\\angl",body:t[0]}}});var b7={};function Ma(e){for(var{type:t,names:n,props:a,handler:l,htmlBuilder:s,mathmlBuilder:o}=e,d={type:t,numArgs:a.numArgs||0,allowedInText:!1,numOptionalArgs:0,handler:l},f=0;f<n.length;++f)b7[n[f]]=d;s&&(Lc[t]=s),o&&(Bc[t]=o)}var E7={};function O(e,t){E7[e]=t}function T3(e){var t=[];e.consumeSpaces();var n=e.fetch().text;for(n==="\\relax"&&(e.consume(),e.consumeSpaces(),n=e.fetch().text);n==="\\hline"||n==="\\hdashline";)e.consume(),t.push(n==="\\hdashline"),e.consumeSpaces(),n=e.fetch().text;return t}var nd=e=>{var t=e.parser.settings;if(!t.displayMode)throw new ke("{"+e.envName+"} can be used only in display mode.")};function Gm(e){if(e.indexOf("ed")===-1)return e.indexOf("*")===-1}function tl(e,t,n){var{hskipBeforeAndAfter:a,addJot:l,cols:s,arraystretch:o,colSeparationType:d,autoTag:f,singleRow:h,emptySingleRow:p,maxNumCols:E,leqno:T}=t;if(e.gullet.beginGroup(),h||e.gullet.macros.set("\\cr","\\\\\\relax"),!o){var v=e.gullet.expandMacroAsText("\\arraystretch");if(v==null)o=1;else if(o=parseFloat(v),!o||o<0)throw new ke("Invalid \\arraystretch: "+v)}e.gullet.beginGroup();var x=[],N=[x],D=[],C=[],I=f!=null?[]:void 0;function F(){f&&e.gullet.macros.set("\\@eqnsw","1",!0)}function J(){I&&(e.gullet.macros.get("\\df@tag")?(I.push(e.subparse([new Jr("\\df@tag")])),e.gullet.macros.set("\\df@tag",void 0,!0)):I.push(!!f&&e.gullet.macros.get("\\@eqnsw")==="1"))}for(F(),C.push(T3(e));;){var K=e.parseExpression(!1,h?"\\end":"\\\\");e.gullet.endGroup(),e.gullet.beginGroup(),K={type:"ordgroup",mode:e.mode,body:K},n&&(K={type:"styling",mode:e.mode,style:n,body:[K]}),x.push(K);var U=e.fetch().text;if(U==="&"){if(E&&x.length===E){if(h||d)throw new ke("Too many tab characters: &",e.nextToken);e.settings.reportNonstrict("textEnv","Too few columns specified in the {array} column argument.")}e.consume()}else if(U==="\\end"){J(),x.length===1&&K.type==="styling"&&K.body[0].body.length===0&&(N.length>1||!p)&&N.pop(),C.length<N.length+1&&C.push([]);break}else if(U==="\\\\"){e.consume();var le=void 0;e.gullet.future().text!==" "&&(le=e.parseSizeGroup(!0)),D.push(le?le.value:null),J(),C.push(T3(e)),x=[],N.push(x),F()}else throw new ke("Expected & or \\\\ or \\cr or \\end",e.nextToken)}return e.gullet.endGroup(),e.gullet.endGroup(),{type:"array",mode:e.mode,addJot:l,arraystretch:o,body:N,cols:s,rowGaps:D,hskipBeforeAndAfter:a,hLinesBeforeRow:C,colSeparationType:d,tags:I,leqno:T}}function Vm(e){return e.slice(0,1)==="d"?"display":"text"}var Da=function(t,n){var a,l,s=t.body.length,o=t.hLinesBeforeRow,d=0,f=new Array(s),h=[],p=Math.max(n.fontMetrics().arrayRuleWidth,n.minRuleThickness),E=1/n.fontMetrics().ptPerEm,T=5*E;if(t.colSeparationType&&t.colSeparationType==="small"){var v=n.havingStyle(Je.SCRIPT).sizeMultiplier;T=.2778*(v/n.sizeMultiplier)}var x=t.colSeparationType==="CD"?fn({number:3,unit:"ex"},n):12*E,N=3*E,D=t.arraystretch*x,C=.7*D,I=.3*D,F=0;function J(an){for(var wt=0;wt<an.length;++wt)wt>0&&(F+=.25),h.push({pos:F,isDashed:an[wt]})}for(J(o[0]),a=0;a<t.body.length;++a){var K=t.body[a],U=C,le=I;d<K.length&&(d=K.length);var ae=new Array(K.length);for(l=0;l<K.length;++l){var se=Nt(K[l],n);le<se.depth&&(le=se.depth),U<se.height&&(U=se.height),ae[l]=se}var G=t.rowGaps[a],ge=0;G&&(ge=fn(G,n),ge>0&&(ge+=I,le<ge&&(le=ge),ge=0)),t.addJot&&(le+=N),ae.height=U,ae.depth=le,F+=U,ae.pos=F,F+=le+ge,f[a]=ae,J(o[a+1])}var ce=F/2+n.fontMetrics().axisHeight,Se=t.cols||[],fe=[],ye,X,oe=[];if(t.tags&&t.tags.some(an=>an))for(a=0;a<s;++a){var be=f[a],ze=be.pos-ce,A=t.tags[a],te=void 0;A===!0?te=Z.makeSpan(["eqn-num"],[],n):A===!1?te=Z.makeSpan([],[],n):te=Z.makeSpan([],Dn(A,n,!0),n),te.depth=be.depth,te.height=be.height,oe.push({type:"elem",elem:te,shift:ze})}for(l=0,X=0;l<d||X<Se.length;++l,++X){for(var ue=Se[X]||{},R=!0;ue.type==="separator";){if(R||(ye=Z.makeSpan(["arraycolsep"],[]),ye.style.width=Oe(n.fontMetrics().doubleRuleSep),fe.push(ye)),ue.separator==="|"||ue.separator===":"){var De=ue.separator==="|"?"solid":"dashed",Ge=Z.makeSpan(["vertical-separator"],[],n);Ge.style.height=Oe(F),Ge.style.borderRightWidth=Oe(p),Ge.style.borderRightStyle=De,Ge.style.margin="0 "+Oe(-p/2);var Le=F-ce;Le&&(Ge.style.verticalAlign=Oe(-Le)),fe.push(Ge)}else throw new ke("Invalid separator type: "+ue.separator);X++,ue=Se[X]||{},R=!1}if(!(l>=d)){var kt=void 0;(l>0||t.hskipBeforeAndAfter)&&(kt=We.deflt(ue.pregap,T),kt!==0&&(ye=Z.makeSpan(["arraycolsep"],[]),ye.style.width=Oe(kt),fe.push(ye)));var it=[];for(a=0;a<s;++a){var Wt=f[a],Pt=Wt[l];if(Pt){var In=Wt.pos-ce;Pt.depth=Wt.depth,Pt.height=Wt.height,it.push({type:"elem",elem:Pt,shift:In})}}it=Z.makeVList({positionType:"individualShift",children:it},n),it=Z.makeSpan(["col-align-"+(ue.align||"c")],[it]),fe.push(it),(l<d-1||t.hskipBeforeAndAfter)&&(kt=We.deflt(ue.postgap,T),kt!==0&&(ye=Z.makeSpan(["arraycolsep"],[]),ye.style.width=Oe(kt),fe.push(ye)))}}if(f=Z.makeSpan(["mtable"],fe),h.length>0){for(var zr=Z.makeLineSpan("hline",n,p),vt=Z.makeLineSpan("hdashline",n,p),ht=[{type:"elem",elem:f,shift:0}];h.length>0;){var Ut=h.pop(),Ve=Ut.pos-ce;Ut.isDashed?ht.push({type:"elem",elem:vt,shift:Ve}):ht.push({type:"elem",elem:zr,shift:Ve})}f=Z.makeVList({positionType:"individualShift",children:ht},n)}if(oe.length===0)return Z.makeSpan(["mord"],[f],n);var At=Z.makeVList({positionType:"individualShift",children:oe},n);return At=Z.makeSpan(["tag"],[At],n),Z.makeFragment([f,At])},HM={c:"center ",l:"left ",r:"right "},Ia=function(t,n){for(var a=[],l=new xe.MathNode("mtd",[],["mtr-glue"]),s=new xe.MathNode("mtd",[],["mml-eqn-num"]),o=0;o<t.body.length;o++){for(var d=t.body[o],f=[],h=0;h<d.length;h++)f.push(new xe.MathNode("mtd",[Vt(d[h],n)]));t.tags&&t.tags[o]&&(f.unshift(l),f.push(l),t.leqno?f.unshift(s):f.push(s)),a.push(new xe.MathNode("mtr",f))}var p=new xe.MathNode("mtable",a),E=t.arraystretch===.5?.1:.16+t.arraystretch-1+(t.addJot?.09:0);p.setAttribute("rowspacing",Oe(E));var T="",v="";if(t.cols&&t.cols.length>0){var x=t.cols,N="",D=!1,C=0,I=x.length;x[0].type==="separator"&&(T+="top ",C=1),x[x.length-1].type==="separator"&&(T+="bottom ",I-=1);for(var F=C;F<I;F++)x[F].type==="align"?(v+=HM[x[F].align],D&&(N+="none "),D=!0):x[F].type==="separator"&&D&&(N+=x[F].separator==="|"?"solid ":"dashed ",D=!1);p.setAttribute("columnalign",v.trim()),/[sd]/.test(N)&&p.setAttribute("columnlines",N.trim())}if(t.colSeparationType==="align"){for(var J=t.cols||[],K="",U=1;U<J.length;U++)K+=U%2?"0em ":"1em ";p.setAttribute("columnspacing",K.trim())}else t.colSeparationType==="alignat"||t.colSeparationType==="gather"?p.setAttribute("columnspacing","0em"):t.colSeparationType==="small"?p.setAttribute("columnspacing","0.2778em"):t.colSeparationType==="CD"?p.setAttribute("columnspacing","0.5em"):p.setAttribute("columnspacing","1em");var le="",ae=t.hLinesBeforeRow;T+=ae[0].length>0?"left ":"",T+=ae[ae.length-1].length>0?"right ":"";for(var se=1;se<ae.length-1;se++)le+=ae[se].length===0?"none ":ae[se][0]?"dashed ":"solid ";return/[sd]/.test(le)&&p.setAttribute("rowlines",le.trim()),T!==""&&(p=new xe.MathNode("menclose",[p]),p.setAttribute("notation",T.trim())),t.arraystretch&&t.arraystretch<1&&(p=new xe.MathNode("mstyle",[p]),p.setAttribute("scriptlevel","1")),p},y7=function(t,n){t.envName.indexOf("ed")===-1&&nd(t);var a=[],l=t.envName.indexOf("at")>-1?"alignat":"align",s=t.envName==="split",o=tl(t.parser,{cols:a,addJot:!0,autoTag:s?void 0:Gm(t.envName),emptySingleRow:!0,colSeparationType:l,maxNumCols:s?2:void 0,leqno:t.parser.settings.leqno},"display"),d,f=0,h={type:"ordgroup",mode:t.mode,body:[]};if(n[0]&&n[0].type==="ordgroup"){for(var p="",E=0;E<n[0].body.length;E++){var T=ft(n[0].body[E],"textord");p+=T.text}d=Number(p),f=d*2}var v=!f;o.body.forEach(function(C){for(var I=1;I<C.length;I+=2){var F=ft(C[I],"styling"),J=ft(F.body[0],"ordgroup");J.body.unshift(h)}if(v)f<C.length&&(f=C.length);else{var K=C.length/2;if(d<K)throw new ke("Too many math in a row: "+("expected "+d+", but got "+K),C[0])}});for(var x=0;x<f;++x){var N="r",D=0;x%2===1?N="l":x>0&&v&&(D=1),a[x]={type:"align",align:N,pregap:D,postgap:0}}return o.colSeparationType=v?"align":"alignat",o};Ma({type:"array",names:["array","darray"],props:{numArgs:1},handler(e,t){var n=Jc(t[0]),a=n?[t[0]]:ft(t[0],"ordgroup").body,l=a.map(function(o){var d=zm(o),f=d.text;if("lcr".indexOf(f)!==-1)return{type:"align",align:f};if(f==="|")return{type:"separator",separator:"|"};if(f===":")return{type:"separator",separator:":"};throw new ke("Unknown column alignment: "+f,o)}),s={cols:l,hskipBeforeAndAfter:!0,maxNumCols:l.length};return tl(e.parser,s,Vm(e.envName))},htmlBuilder:Da,mathmlBuilder:Ia});Ma({type:"array",names:["matrix","pmatrix","bmatrix","Bmatrix","vmatrix","Vmatrix","matrix*","pmatrix*","bmatrix*","Bmatrix*","vmatrix*","Vmatrix*"],props:{numArgs:0},handler(e){var t={matrix:null,pmatrix:["(",")"],bmatrix:["[","]"],Bmatrix:["\\{","\\}"],vmatrix:["|","|"],Vmatrix:["\\Vert","\\Vert"]}[e.envName.replace("*","")],n="c",a={hskipBeforeAndAfter:!1,cols:[{type:"align",align:n}]};if(e.envName.charAt(e.envName.length-1)==="*"){var l=e.parser;if(l.consumeSpaces(),l.fetch().text==="["){if(l.consume(),l.consumeSpaces(),n=l.fetch().text,"lcr".indexOf(n)===-1)throw new ke("Expected l or c or r",l.nextToken);l.consume(),l.consumeSpaces(),l.expect("]"),l.consume(),a.cols=[{type:"align",align:n}]}}var s=tl(e.parser,a,Vm(e.envName)),o=Math.max(0,...s.body.map(d=>d.length));return s.cols=new Array(o).fill({type:"align",align:n}),t?{type:"leftright",mode:e.mode,body:[s],left:t[0],right:t[1],rightColor:void 0}:s},htmlBuilder:Da,mathmlBuilder:Ia});Ma({type:"array",names:["smallmatrix"],props:{numArgs:0},handler(e){var t={arraystretch:.5},n=tl(e.parser,t,"script");return n.colSeparationType="small",n},htmlBuilder:Da,mathmlBuilder:Ia});Ma({type:"array",names:["subarray"],props:{numArgs:1},handler(e,t){var n=Jc(t[0]),a=n?[t[0]]:ft(t[0],"ordgroup").body,l=a.map(function(o){var d=zm(o),f=d.text;if("lc".indexOf(f)!==-1)return{type:"align",align:f};throw new ke("Unknown column alignment: "+f,o)});if(l.length>1)throw new ke("{subarray} can contain only one column");var s={cols:l,hskipBeforeAndAfter:!1,arraystretch:.5};if(s=tl(e.parser,s,"script"),s.body.length>0&&s.body[0].length>1)throw new ke("{subarray} can contain only one column");return s},htmlBuilder:Da,mathmlBuilder:Ia});Ma({type:"array",names:["cases","dcases","rcases","drcases"],props:{numArgs:0},handler(e){var t={arraystretch:1.2,cols:[{type:"align",align:"l",pregap:0,postgap:1},{type:"align",align:"l",pregap:0,postgap:0}]},n=tl(e.parser,t,Vm(e.envName));return{type:"leftright",mode:e.mode,body:[n],left:e.envName.indexOf("r")>-1?".":"\\{",right:e.envName.indexOf("r")>-1?"\\}":".",rightColor:void 0}},htmlBuilder:Da,mathmlBuilder:Ia});Ma({type:"array",names:["align","align*","aligned","split"],props:{numArgs:0},handler:y7,htmlBuilder:Da,mathmlBuilder:Ia});Ma({type:"array",names:["gathered","gather","gather*"],props:{numArgs:0},handler(e){We.contains(["gather","gather*"],e.envName)&&nd(e);var t={cols:[{type:"align",align:"c"}],addJot:!0,colSeparationType:"gather",autoTag:Gm(e.envName),emptySingleRow:!0,leqno:e.parser.settings.leqno};return tl(e.parser,t,"display")},htmlBuilder:Da,mathmlBuilder:Ia});Ma({type:"array",names:["alignat","alignat*","alignedat"],props:{numArgs:1},handler:y7,htmlBuilder:Da,mathmlBuilder:Ia});Ma({type:"array",names:["equation","equation*"],props:{numArgs:0},handler(e){nd(e);var t={autoTag:Gm(e.envName),emptySingleRow:!0,singleRow:!0,maxNumCols:1,leqno:e.parser.settings.leqno};return tl(e.parser,t,"display")},htmlBuilder:Da,mathmlBuilder:Ia});Ma({type:"array",names:["CD"],props:{numArgs:0},handler(e){return nd(e),kM(e.parser)},htmlBuilder:Da,mathmlBuilder:Ia});O("\\nonumber","\\gdef\\@eqnsw{0}");O("\\notag","\\nonumber");Be({type:"text",names:["\\hline","\\hdashline"],props:{numArgs:0,allowedInText:!0,allowedInMath:!0},handler(e,t){throw new ke(e.funcName+" valid only within array environment")}});var _3=b7;Be({type:"environment",names:["\\begin","\\end"],props:{numArgs:1,argTypes:["text"]},handler(e,t){var{parser:n,funcName:a}=e,l=t[0];if(l.type!=="ordgroup")throw new ke("Invalid environment name",l);for(var s="",o=0;o<l.body.length;++o)s+=ft(l.body[o],"textord").text;if(a==="\\begin"){if(!_3.hasOwnProperty(s))throw new ke("No such environment: "+s,l);var d=_3[s],{args:f,optArgs:h}=n.parseArguments("\\begin{"+s+"}",d),p={mode:n.mode,envName:s,parser:n},E=d.handler(p,f,h);n.expect("\\end",!1);var T=n.nextToken,v=ft(n.parseFunction(),"environment");if(v.name!==s)throw new ke("Mismatch: \\begin{"+s+"} matched by \\end{"+v.name+"}",T);return E}return{type:"environment",mode:n.mode,name:s,nameGroup:l}}});var v7=(e,t)=>{var n=e.font,a=t.withFont(n);return Nt(e.body,a)},T7=(e,t)=>{var n=e.font,a=t.withFont(n);return Vt(e.body,a)},S3={"\\Bbb":"\\mathbb","\\bold":"\\mathbf","\\frak":"\\mathfrak","\\bm":"\\boldsymbol"};Be({type:"font",names:["\\mathrm","\\mathit","\\mathbf","\\mathnormal","\\mathsfit","\\mathbb","\\mathcal","\\mathfrak","\\mathscr","\\mathsf","\\mathtt","\\Bbb","\\bold","\\frak"],props:{numArgs:1,allowedInArgument:!0},handler:(e,t)=>{var{parser:n,funcName:a}=e,l=Pc(t[0]),s=a;return s in S3&&(s=S3[s]),{type:"font",mode:n.mode,font:s.slice(1),body:l}},htmlBuilder:v7,mathmlBuilder:T7});Be({type:"mclass",names:["\\boldsymbol","\\bm"],props:{numArgs:1},handler:(e,t)=>{var{parser:n}=e,a=t[0],l=We.isCharacterBox(a);return{type:"mclass",mode:n.mode,mclass:ed(a),body:[{type:"font",mode:n.mode,font:"boldsymbol",body:a}],isCharacterBox:l}}});Be({type:"font",names:["\\rm","\\sf","\\tt","\\bf","\\it","\\cal"],props:{numArgs:0,allowedInText:!0},handler:(e,t)=>{var{parser:n,funcName:a,breakOnTokenText:l}=e,{mode:s}=n,o=n.parseExpression(!0,l),d="math"+a.slice(1);return{type:"font",mode:s,font:d,body:{type:"ordgroup",mode:n.mode,body:o}}},htmlBuilder:v7,mathmlBuilder:T7});var _7=(e,t)=>{var n=t;return e==="display"?n=n.id>=Je.SCRIPT.id?n.text():Je.DISPLAY:e==="text"&&n.size===Je.DISPLAY.size?n=Je.TEXT:e==="script"?n=Je.SCRIPT:e==="scriptscript"&&(n=Je.SCRIPTSCRIPT),n},Km=(e,t)=>{var n=_7(e.size,t.style),a=n.fracNum(),l=n.fracDen(),s;s=t.havingStyle(a);var o=Nt(e.numer,s,t);if(e.continued){var d=8.5/t.fontMetrics().ptPerEm,f=3.5/t.fontMetrics().ptPerEm;o.height=o.height<d?d:o.height,o.depth=o.depth<f?f:o.depth}s=t.havingStyle(l);var h=Nt(e.denom,s,t),p,E,T;e.hasBarLine?(e.barSize?(E=fn(e.barSize,t),p=Z.makeLineSpan("frac-line",t,E)):p=Z.makeLineSpan("frac-line",t),E=p.height,T=p.height):(p=null,E=0,T=t.fontMetrics().defaultRuleThickness);var v,x,N;n.size===Je.DISPLAY.size||e.size==="display"?(v=t.fontMetrics().num1,E>0?x=3*T:x=7*T,N=t.fontMetrics().denom1):(E>0?(v=t.fontMetrics().num2,x=T):(v=t.fontMetrics().num3,x=3*T),N=t.fontMetrics().denom2);var D;if(p){var I=t.fontMetrics().axisHeight;v-o.depth-(I+.5*E)<x&&(v+=x-(v-o.depth-(I+.5*E))),I-.5*E-(h.height-N)<x&&(N+=x-(I-.5*E-(h.height-N)));var F=-(I-.5*E);D=Z.makeVList({positionType:"individualShift",children:[{type:"elem",elem:h,shift:N},{type:"elem",elem:p,shift:F},{type:"elem",elem:o,shift:-v}]},t)}else{var C=v-o.depth-(h.height-N);C<x&&(v+=.5*(x-C),N+=.5*(x-C)),D=Z.makeVList({positionType:"individualShift",children:[{type:"elem",elem:h,shift:N},{type:"elem",elem:o,shift:-v}]},t)}s=t.havingStyle(n),D.height*=s.sizeMultiplier/t.sizeMultiplier,D.depth*=s.sizeMultiplier/t.sizeMultiplier;var J;n.size===Je.DISPLAY.size?J=t.fontMetrics().delim1:n.size===Je.SCRIPTSCRIPT.size?J=t.havingStyle(Je.SCRIPT).fontMetrics().delim2:J=t.fontMetrics().delim2;var K,U;return e.leftDelim==null?K=Eo(t,["mopen"]):K=ai.customSizedDelim(e.leftDelim,J,!0,t.havingStyle(n),e.mode,["mopen"]),e.continued?U=Z.makeSpan([]):e.rightDelim==null?U=Eo(t,["mclose"]):U=ai.customSizedDelim(e.rightDelim,J,!0,t.havingStyle(n),e.mode,["mclose"]),Z.makeSpan(["mord"].concat(s.sizingClasses(t)),[K,Z.makeSpan(["mfrac"],[D]),U],t)},jm=(e,t)=>{var n=new xe.MathNode("mfrac",[Vt(e.numer,t),Vt(e.denom,t)]);if(!e.hasBarLine)n.setAttribute("linethickness","0px");else if(e.barSize){var a=fn(e.barSize,t);n.setAttribute("linethickness",Oe(a))}var l=_7(e.size,t.style);if(l.size!==t.style.size){n=new xe.MathNode("mstyle",[n]);var s=l.size===Je.DISPLAY.size?"true":"false";n.setAttribute("displaystyle",s),n.setAttribute("scriptlevel","0")}if(e.leftDelim!=null||e.rightDelim!=null){var o=[];if(e.leftDelim!=null){var d=new xe.MathNode("mo",[new xe.TextNode(e.leftDelim.replace("\\",""))]);d.setAttribute("fence","true"),o.push(d)}if(o.push(n),e.rightDelim!=null){var f=new xe.MathNode("mo",[new xe.TextNode(e.rightDelim.replace("\\",""))]);f.setAttribute("fence","true"),o.push(f)}return Pm(o)}return n};Be({type:"genfrac",names:["\\dfrac","\\frac","\\tfrac","\\dbinom","\\binom","\\tbinom","\\\\atopfrac","\\\\bracefrac","\\\\brackfrac"],props:{numArgs:2,allowedInArgument:!0},handler:(e,t)=>{var{parser:n,funcName:a}=e,l=t[0],s=t[1],o,d=null,f=null,h="auto";switch(a){case"\\dfrac":case"\\frac":case"\\tfrac":o=!0;break;case"\\\\atopfrac":o=!1;break;case"\\dbinom":case"\\binom":case"\\tbinom":o=!1,d="(",f=")";break;case"\\\\bracefrac":o=!1,d="\\{",f="\\}";break;case"\\\\brackfrac":o=!1,d="[",f="]";break;default:throw new Error("Unrecognized genfrac command")}switch(a){case"\\dfrac":case"\\dbinom":h="display";break;case"\\tfrac":case"\\tbinom":h="text";break}return{type:"genfrac",mode:n.mode,continued:!1,numer:l,denom:s,hasBarLine:o,leftDelim:d,rightDelim:f,size:h,barSize:null}},htmlBuilder:Km,mathmlBuilder:jm});Be({type:"genfrac",names:["\\cfrac"],props:{numArgs:2},handler:(e,t)=>{var{parser:n,funcName:a}=e,l=t[0],s=t[1];return{type:"genfrac",mode:n.mode,continued:!0,numer:l,denom:s,hasBarLine:!0,leftDelim:null,rightDelim:null,size:"display",barSize:null}}});Be({type:"infix",names:["\\over","\\choose","\\atop","\\brace","\\brack"],props:{numArgs:0,infix:!0},handler(e){var{parser:t,funcName:n,token:a}=e,l;switch(n){case"\\over":l="\\frac";break;case"\\choose":l="\\binom";break;case"\\atop":l="\\\\atopfrac";break;case"\\brace":l="\\\\bracefrac";break;case"\\brack":l="\\\\brackfrac";break;default:throw new Error("Unrecognized infix genfrac command")}return{type:"infix",mode:t.mode,replaceWith:l,token:a}}});var A3=["display","text","script","scriptscript"],x3=function(t){var n=null;return t.length>0&&(n=t,n=n==="."?null:n),n};Be({type:"genfrac",names:["\\genfrac"],props:{numArgs:6,allowedInArgument:!0,argTypes:["math","math","size","text","math","math"]},handler(e,t){var{parser:n}=e,a=t[4],l=t[5],s=Pc(t[0]),o=s.type==="atom"&&s.family==="open"?x3(s.text):null,d=Pc(t[1]),f=d.type==="atom"&&d.family==="close"?x3(d.text):null,h=ft(t[2],"size"),p,E=null;h.isBlank?p=!0:(E=h.value,p=E.number>0);var T="auto",v=t[3];if(v.type==="ordgroup"){if(v.body.length>0){var x=ft(v.body[0],"textord");T=A3[Number(x.text)]}}else v=ft(v,"textord"),T=A3[Number(v.text)];return{type:"genfrac",mode:n.mode,numer:a,denom:l,continued:!1,hasBarLine:p,barSize:E,leftDelim:o,rightDelim:f,size:T}},htmlBuilder:Km,mathmlBuilder:jm});Be({type:"infix",names:["\\above"],props:{numArgs:1,argTypes:["size"],infix:!0},handler(e,t){var{parser:n,funcName:a,token:l}=e;return{type:"infix",mode:n.mode,replaceWith:"\\\\abovefrac",size:ft(t[0],"size").value,token:l}}});Be({type:"genfrac",names:["\\\\abovefrac"],props:{numArgs:3,argTypes:["math","size","math"]},handler:(e,t)=>{var{parser:n,funcName:a}=e,l=t[0],s=gR(ft(t[1],"infix").size),o=t[2],d=s.number>0;return{type:"genfrac",mode:n.mode,numer:l,denom:o,continued:!1,hasBarLine:d,barSize:s,leftDelim:null,rightDelim:null,size:"auto"}},htmlBuilder:Km,mathmlBuilder:jm});var S7=(e,t)=>{var n=t.style,a,l;e.type==="supsub"?(a=e.sup?Nt(e.sup,t.havingStyle(n.sup()),t):Nt(e.sub,t.havingStyle(n.sub()),t),l=ft(e.base,"horizBrace")):l=ft(e,"horizBrace");var s=Nt(l.base,t.havingBaseStyle(Je.DISPLAY)),o=si.svgSpan(l,t),d;if(l.isOver?(d=Z.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:s},{type:"kern",size:.1},{type:"elem",elem:o}]},t),d.children[0].children[0].children[1].classes.push("svg-align")):(d=Z.makeVList({positionType:"bottom",positionData:s.depth+.1+o.height,children:[{type:"elem",elem:o},{type:"kern",size:.1},{type:"elem",elem:s}]},t),d.children[0].children[0].children[0].classes.push("svg-align")),a){var f=Z.makeSpan(["mord",l.isOver?"mover":"munder"],[d],t);l.isOver?d=Z.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:f},{type:"kern",size:.2},{type:"elem",elem:a}]},t):d=Z.makeVList({positionType:"bottom",positionData:f.depth+.2+a.height+a.depth,children:[{type:"elem",elem:a},{type:"kern",size:.2},{type:"elem",elem:f}]},t)}return Z.makeSpan(["mord",l.isOver?"mover":"munder"],[d],t)},FM=(e,t)=>{var n=si.mathMLnode(e.label);return new xe.MathNode(e.isOver?"mover":"munder",[Vt(e.base,t),n])};Be({type:"horizBrace",names:["\\overbrace","\\underbrace"],props:{numArgs:1},handler(e,t){var{parser:n,funcName:a}=e;return{type:"horizBrace",mode:n.mode,label:a,isOver:/^\\over/.test(a),base:t[0]}},htmlBuilder:S7,mathmlBuilder:FM});Be({type:"href",names:["\\href"],props:{numArgs:2,argTypes:["url","original"],allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,a=t[1],l=ft(t[0],"url").url;return n.settings.isTrusted({command:"\\href",url:l})?{type:"href",mode:n.mode,href:l,body:vn(a)}:n.formatUnsupportedCmd("\\href")},htmlBuilder:(e,t)=>{var n=Dn(e.body,t,!1);return Z.makeAnchor(e.href,[],n,t)},mathmlBuilder:(e,t)=>{var n=Ji(e.body,t);return n instanceof Br||(n=new Br("mrow",[n])),n.setAttribute("href",e.href),n}});Be({type:"href",names:["\\url"],props:{numArgs:1,argTypes:["url"],allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,a=ft(t[0],"url").url;if(!n.settings.isTrusted({command:"\\url",url:a}))return n.formatUnsupportedCmd("\\url");for(var l=[],s=0;s<a.length;s++){var o=a[s];o==="~"&&(o="\\textasciitilde"),l.push({type:"textord",mode:"text",text:o})}var d={type:"text",mode:n.mode,font:"\\texttt",body:l};return{type:"href",mode:n.mode,href:a,body:vn(d)}}});Be({type:"hbox",names:["\\hbox"],props:{numArgs:1,argTypes:["text"],allowedInText:!0,primitive:!0},handler(e,t){var{parser:n}=e;return{type:"hbox",mode:n.mode,body:vn(t[0])}},htmlBuilder(e,t){var n=Dn(e.body,t,!1);return Z.makeFragment(n)},mathmlBuilder(e,t){return new xe.MathNode("mrow",Tr(e.body,t))}});Be({type:"html",names:["\\htmlClass","\\htmlId","\\htmlStyle","\\htmlData"],props:{numArgs:2,argTypes:["raw","original"],allowedInText:!0},handler:(e,t)=>{var{parser:n,funcName:a,token:l}=e,s=ft(t[0],"raw").string,o=t[1];n.settings.strict&&n.settings.reportNonstrict("htmlExtension","HTML extension is disabled on strict mode");var d,f={};switch(a){case"\\htmlClass":f.class=s,d={command:"\\htmlClass",class:s};break;case"\\htmlId":f.id=s,d={command:"\\htmlId",id:s};break;case"\\htmlStyle":f.style=s,d={command:"\\htmlStyle",style:s};break;case"\\htmlData":{for(var h=s.split(","),p=0;p<h.length;p++){var E=h[p].split("=");if(E.length!==2)throw new ke("Error parsing key-value for \\htmlData");f["data-"+E[0].trim()]=E[1].trim()}d={command:"\\htmlData",attributes:f};break}default:throw new Error("Unrecognized html command")}return n.settings.isTrusted(d)?{type:"html",mode:n.mode,attributes:f,body:vn(o)}:n.formatUnsupportedCmd(a)},htmlBuilder:(e,t)=>{var n=Dn(e.body,t,!1),a=["enclosing"];e.attributes.class&&a.push(...e.attributes.class.trim().split(/\s+/));var l=Z.makeSpan(a,n,t);for(var s in e.attributes)s!=="class"&&e.attributes.hasOwnProperty(s)&&l.setAttribute(s,e.attributes[s]);return l},mathmlBuilder:(e,t)=>Ji(e.body,t)});Be({type:"htmlmathml",names:["\\html@mathml"],props:{numArgs:2,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e;return{type:"htmlmathml",mode:n.mode,html:vn(t[0]),mathml:vn(t[1])}},htmlBuilder:(e,t)=>{var n=Dn(e.html,t,!1);return Z.makeFragment(n)},mathmlBuilder:(e,t)=>Ji(e.mathml,t)});var Zh=function(t){if(/^[-+]? *(\d+(\.\d*)?|\.\d+)$/.test(t))return{number:+t,unit:"bp"};var n=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(t);if(!n)throw new ke("Invalid size: '"+t+"' in \\includegraphics");var a={number:+(n[1]+n[2]),unit:n[3]};if(!q5(a))throw new ke("Invalid unit: '"+a.unit+"' in \\includegraphics.");return a};Be({type:"includegraphics",names:["\\includegraphics"],props:{numArgs:1,numOptionalArgs:1,argTypes:["raw","url"],allowedInText:!1},handler:(e,t,n)=>{var{parser:a}=e,l={number:0,unit:"em"},s={number:.9,unit:"em"},o={number:0,unit:"em"},d="";if(n[0])for(var f=ft(n[0],"raw").string,h=f.split(","),p=0;p<h.length;p++){var E=h[p].split("=");if(E.length===2){var T=E[1].trim();switch(E[0].trim()){case"alt":d=T;break;case"width":l=Zh(T);break;case"height":s=Zh(T);break;case"totalheight":o=Zh(T);break;default:throw new ke("Invalid key: '"+E[0]+"' in \\includegraphics.")}}}var v=ft(t[0],"url").url;return d===""&&(d=v,d=d.replace(/^.*[\\/]/,""),d=d.substring(0,d.lastIndexOf("."))),a.settings.isTrusted({command:"\\includegraphics",url:v})?{type:"includegraphics",mode:a.mode,alt:d,width:l,height:s,totalheight:o,src:v}:a.formatUnsupportedCmd("\\includegraphics")},htmlBuilder:(e,t)=>{var n=fn(e.height,t),a=0;e.totalheight.number>0&&(a=fn(e.totalheight,t)-n);var l=0;e.width.number>0&&(l=fn(e.width,t));var s={height:Oe(n+a)};l>0&&(s.width=Oe(l)),a>0&&(s.verticalAlign=Oe(-a));var o=new FR(e.src,e.alt,s);return o.height=n,o.depth=a,o},mathmlBuilder:(e,t)=>{var n=new xe.MathNode("mglyph",[]);n.setAttribute("alt",e.alt);var a=fn(e.height,t),l=0;if(e.totalheight.number>0&&(l=fn(e.totalheight,t)-a,n.setAttribute("valign",Oe(-l))),n.setAttribute("height",Oe(a+l)),e.width.number>0){var s=fn(e.width,t);n.setAttribute("width",Oe(s))}return n.setAttribute("src",e.src),n}});Be({type:"kern",names:["\\kern","\\mkern","\\hskip","\\mskip"],props:{numArgs:1,argTypes:["size"],primitive:!0,allowedInText:!0},handler(e,t){var{parser:n,funcName:a}=e,l=ft(t[0],"size");if(n.settings.strict){var s=a[1]==="m",o=l.value.unit==="mu";s?(o||n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+a+" supports only mu units, "+("not "+l.value.unit+" units")),n.mode!=="math"&&n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+a+" works only in math mode")):o&&n.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+a+" doesn't support mu units")}return{type:"kern",mode:n.mode,dimension:l.value}},htmlBuilder(e,t){return Z.makeGlue(e.dimension,t)},mathmlBuilder(e,t){var n=fn(e.dimension,t);return new xe.SpaceNode(n)}});Be({type:"lap",names:["\\mathllap","\\mathrlap","\\mathclap"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n,funcName:a}=e,l=t[0];return{type:"lap",mode:n.mode,alignment:a.slice(5),body:l}},htmlBuilder:(e,t)=>{var n;e.alignment==="clap"?(n=Z.makeSpan([],[Nt(e.body,t)]),n=Z.makeSpan(["inner"],[n],t)):n=Z.makeSpan(["inner"],[Nt(e.body,t)]);var a=Z.makeSpan(["fix"],[]),l=Z.makeSpan([e.alignment],[n,a],t),s=Z.makeSpan(["strut"]);return s.style.height=Oe(l.height+l.depth),l.depth&&(s.style.verticalAlign=Oe(-l.depth)),l.children.unshift(s),l=Z.makeSpan(["thinbox"],[l],t),Z.makeSpan(["mord","vbox"],[l],t)},mathmlBuilder:(e,t)=>{var n=new xe.MathNode("mpadded",[Vt(e.body,t)]);if(e.alignment!=="rlap"){var a=e.alignment==="llap"?"-1":"-0.5";n.setAttribute("lspace",a+"width")}return n.setAttribute("width","0px"),n}});Be({type:"styling",names:["\\(","$"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(e,t){var{funcName:n,parser:a}=e,l=a.mode;a.switchMode("math");var s=n==="\\("?"\\)":"$",o=a.parseExpression(!1,s);return a.expect(s),a.switchMode(l),{type:"styling",mode:a.mode,style:"text",body:o}}});Be({type:"text",names:["\\)","\\]"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(e,t){throw new ke("Mismatched "+e.funcName)}});var k3=(e,t)=>{switch(t.style.size){case Je.DISPLAY.size:return e.display;case Je.TEXT.size:return e.text;case Je.SCRIPT.size:return e.script;case Je.SCRIPTSCRIPT.size:return e.scriptscript;default:return e.text}};Be({type:"mathchoice",names:["\\mathchoice"],props:{numArgs:4,primitive:!0},handler:(e,t)=>{var{parser:n}=e;return{type:"mathchoice",mode:n.mode,display:vn(t[0]),text:vn(t[1]),script:vn(t[2]),scriptscript:vn(t[3])}},htmlBuilder:(e,t)=>{var n=k3(e,t),a=Dn(n,t,!1);return Z.makeFragment(a)},mathmlBuilder:(e,t)=>{var n=k3(e,t);return Ji(n,t)}});var A7=(e,t,n,a,l,s,o)=>{e=Z.makeSpan([],[e]);var d=n&&We.isCharacterBox(n),f,h;if(t){var p=Nt(t,a.havingStyle(l.sup()),a);h={elem:p,kern:Math.max(a.fontMetrics().bigOpSpacing1,a.fontMetrics().bigOpSpacing3-p.depth)}}if(n){var E=Nt(n,a.havingStyle(l.sub()),a);f={elem:E,kern:Math.max(a.fontMetrics().bigOpSpacing2,a.fontMetrics().bigOpSpacing4-E.height)}}var T;if(h&&f){var v=a.fontMetrics().bigOpSpacing5+f.elem.height+f.elem.depth+f.kern+e.depth+o;T=Z.makeVList({positionType:"bottom",positionData:v,children:[{type:"kern",size:a.fontMetrics().bigOpSpacing5},{type:"elem",elem:f.elem,marginLeft:Oe(-s)},{type:"kern",size:f.kern},{type:"elem",elem:e},{type:"kern",size:h.kern},{type:"elem",elem:h.elem,marginLeft:Oe(s)},{type:"kern",size:a.fontMetrics().bigOpSpacing5}]},a)}else if(f){var x=e.height-o;T=Z.makeVList({positionType:"top",positionData:x,children:[{type:"kern",size:a.fontMetrics().bigOpSpacing5},{type:"elem",elem:f.elem,marginLeft:Oe(-s)},{type:"kern",size:f.kern},{type:"elem",elem:e}]},a)}else if(h){var N=e.depth+o;T=Z.makeVList({positionType:"bottom",positionData:N,children:[{type:"elem",elem:e},{type:"kern",size:h.kern},{type:"elem",elem:h.elem,marginLeft:Oe(s)},{type:"kern",size:a.fontMetrics().bigOpSpacing5}]},a)}else return e;var D=[T];if(f&&s!==0&&!d){var C=Z.makeSpan(["mspace"],[],a);C.style.marginRight=Oe(s),D.unshift(C)}return Z.makeSpan(["mop","op-limits"],D,a)},x7=["\\smallint"],qs=(e,t)=>{var n,a,l=!1,s;e.type==="supsub"?(n=e.sup,a=e.sub,s=ft(e.base,"op"),l=!0):s=ft(e,"op");var o=t.style,d=!1;o.size===Je.DISPLAY.size&&s.symbol&&!We.contains(x7,s.name)&&(d=!0);var f;if(s.symbol){var h=d?"Size2-Regular":"Size1-Regular",p="";if((s.name==="\\oiint"||s.name==="\\oiiint")&&(p=s.name.slice(1),s.name=p==="oiint"?"\\iint":"\\iiint"),f=Z.makeSymbol(s.name,h,"math",t,["mop","op-symbol",d?"large-op":"small-op"]),p.length>0){var E=f.italic,T=Z.staticSvg(p+"Size"+(d?"2":"1"),t);f=Z.makeVList({positionType:"individualShift",children:[{type:"elem",elem:f,shift:0},{type:"elem",elem:T,shift:d?.08:0}]},t),s.name="\\"+p,f.classes.unshift("mop"),f.italic=E}}else if(s.body){var v=Dn(s.body,t,!0);v.length===1&&v[0]instanceof ea?(f=v[0],f.classes[0]="mop"):f=Z.makeSpan(["mop"],v,t)}else{for(var x=[],N=1;N<s.name.length;N++)x.push(Z.mathsym(s.name[N],s.mode,t));f=Z.makeSpan(["mop"],x,t)}var D=0,C=0;return(f instanceof ea||s.name==="\\oiint"||s.name==="\\oiiint")&&!s.suppressBaseShift&&(D=(f.height-f.depth)/2-t.fontMetrics().axisHeight,C=f.italic),l?A7(f,n,a,t,o,C,D):(D&&(f.style.position="relative",f.style.top=Oe(D)),f)},Oo=(e,t)=>{var n;if(e.symbol)n=new Br("mo",[ta(e.name,e.mode)]),We.contains(x7,e.name)&&n.setAttribute("largeop","false");else if(e.body)n=new Br("mo",Tr(e.body,t));else{n=new Br("mi",[new wa(e.name.slice(1))]);var a=new Br("mo",[ta("⁡","text")]);e.parentIsSupSub?n=new Br("mrow",[n,a]):n=J5([n,a])}return n},qM={"∏":"\\prod","∐":"\\coprod","∑":"\\sum","⋀":"\\bigwedge","⋁":"\\bigvee","⋂":"\\bigcap","⋃":"\\bigcup","⨀":"\\bigodot","⨁":"\\bigoplus","⨂":"\\bigotimes","⨄":"\\biguplus","⨆":"\\bigsqcup"};Be({type:"op",names:["\\coprod","\\bigvee","\\bigwedge","\\biguplus","\\bigcap","\\bigcup","\\intop","\\prod","\\sum","\\bigotimes","\\bigoplus","\\bigodot","\\bigsqcup","\\smallint","∏","∐","∑","⋀","⋁","⋂","⋃","⨀","⨁","⨂","⨄","⨆"],props:{numArgs:0},handler:(e,t)=>{var{parser:n,funcName:a}=e,l=a;return l.length===1&&(l=qM[l]),{type:"op",mode:n.mode,limits:!0,parentIsSupSub:!1,symbol:!0,name:l}},htmlBuilder:qs,mathmlBuilder:Oo});Be({type:"op",names:["\\mathop"],props:{numArgs:1,primitive:!0},handler:(e,t)=>{var{parser:n}=e,a=t[0];return{type:"op",mode:n.mode,limits:!1,parentIsSupSub:!1,symbol:!1,body:vn(a)}},htmlBuilder:qs,mathmlBuilder:Oo});var YM={"∫":"\\int","∬":"\\iint","∭":"\\iiint","∮":"\\oint","∯":"\\oiint","∰":"\\oiiint"};Be({type:"op",names:["\\arcsin","\\arccos","\\arctan","\\arctg","\\arcctg","\\arg","\\ch","\\cos","\\cosec","\\cosh","\\cot","\\cotg","\\coth","\\csc","\\ctg","\\cth","\\deg","\\dim","\\exp","\\hom","\\ker","\\lg","\\ln","\\log","\\sec","\\sin","\\sinh","\\sh","\\tan","\\tanh","\\tg","\\th"],props:{numArgs:0},handler(e){var{parser:t,funcName:n}=e;return{type:"op",mode:t.mode,limits:!1,parentIsSupSub:!1,symbol:!1,name:n}},htmlBuilder:qs,mathmlBuilder:Oo});Be({type:"op",names:["\\det","\\gcd","\\inf","\\lim","\\max","\\min","\\Pr","\\sup"],props:{numArgs:0},handler(e){var{parser:t,funcName:n}=e;return{type:"op",mode:t.mode,limits:!0,parentIsSupSub:!1,symbol:!1,name:n}},htmlBuilder:qs,mathmlBuilder:Oo});Be({type:"op",names:["\\int","\\iint","\\iiint","\\oint","\\oiint","\\oiiint","∫","∬","∭","∮","∯","∰"],props:{numArgs:0},handler(e){var{parser:t,funcName:n}=e,a=n;return a.length===1&&(a=YM[a]),{type:"op",mode:t.mode,limits:!1,parentIsSupSub:!1,symbol:!0,name:a}},htmlBuilder:qs,mathmlBuilder:Oo});var k7=(e,t)=>{var n,a,l=!1,s;e.type==="supsub"?(n=e.sup,a=e.sub,s=ft(e.base,"operatorname"),l=!0):s=ft(e,"operatorname");var o;if(s.body.length>0){for(var d=s.body.map(E=>{var T=E.text;return typeof T=="string"?{type:"textord",mode:E.mode,text:T}:E}),f=Dn(d,t.withFont("mathrm"),!0),h=0;h<f.length;h++){var p=f[h];p instanceof ea&&(p.text=p.text.replace(/\u2212/,"-").replace(/\u2217/,"*"))}o=Z.makeSpan(["mop"],f,t)}else o=Z.makeSpan(["mop"],[],t);return l?A7(o,n,a,t,t.style,0,0):o},GM=(e,t)=>{for(var n=Tr(e.body,t.withFont("mathrm")),a=!0,l=0;l<n.length;l++){var s=n[l];if(!(s instanceof xe.SpaceNode))if(s instanceof xe.MathNode)switch(s.type){case"mi":case"mn":case"ms":case"mspace":case"mtext":break;case"mo":{var o=s.children[0];s.children.length===1&&o instanceof xe.TextNode?o.text=o.text.replace(/\u2212/,"-").replace(/\u2217/,"*"):a=!1;break}default:a=!1}else a=!1}if(a){var d=n.map(p=>p.toText()).join("");n=[new xe.TextNode(d)]}var f=new xe.MathNode("mi",n);f.setAttribute("mathvariant","normal");var h=new xe.MathNode("mo",[ta("⁡","text")]);return e.parentIsSupSub?new xe.MathNode("mrow",[f,h]):xe.newDocumentFragment([f,h])};Be({type:"operatorname",names:["\\operatorname@","\\operatornamewithlimits"],props:{numArgs:1},handler:(e,t)=>{var{parser:n,funcName:a}=e,l=t[0];return{type:"operatorname",mode:n.mode,body:vn(l),alwaysHandleSupSub:a==="\\operatornamewithlimits",limits:!1,parentIsSupSub:!1}},htmlBuilder:k7,mathmlBuilder:GM});O("\\operatorname","\\@ifstar\\operatornamewithlimits\\operatorname@");Bl({type:"ordgroup",htmlBuilder(e,t){return e.semisimple?Z.makeFragment(Dn(e.body,t,!1)):Z.makeSpan(["mord"],Dn(e.body,t,!0),t)},mathmlBuilder(e,t){return Ji(e.body,t,!0)}});Be({type:"overline",names:["\\overline"],props:{numArgs:1},handler(e,t){var{parser:n}=e,a=t[0];return{type:"overline",mode:n.mode,body:a}},htmlBuilder(e,t){var n=Nt(e.body,t.havingCrampedStyle()),a=Z.makeLineSpan("overline-line",t),l=t.fontMetrics().defaultRuleThickness,s=Z.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n},{type:"kern",size:3*l},{type:"elem",elem:a},{type:"kern",size:l}]},t);return Z.makeSpan(["mord","overline"],[s],t)},mathmlBuilder(e,t){var n=new xe.MathNode("mo",[new xe.TextNode("‾")]);n.setAttribute("stretchy","true");var a=new xe.MathNode("mover",[Vt(e.body,t),n]);return a.setAttribute("accent","true"),a}});Be({type:"phantom",names:["\\phantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,a=t[0];return{type:"phantom",mode:n.mode,body:vn(a)}},htmlBuilder:(e,t)=>{var n=Dn(e.body,t.withPhantom(),!1);return Z.makeFragment(n)},mathmlBuilder:(e,t)=>{var n=Tr(e.body,t);return new xe.MathNode("mphantom",n)}});Be({type:"hphantom",names:["\\hphantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,a=t[0];return{type:"hphantom",mode:n.mode,body:a}},htmlBuilder:(e,t)=>{var n=Z.makeSpan([],[Nt(e.body,t.withPhantom())]);if(n.height=0,n.depth=0,n.children)for(var a=0;a<n.children.length;a++)n.children[a].height=0,n.children[a].depth=0;return n=Z.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n}]},t),Z.makeSpan(["mord"],[n],t)},mathmlBuilder:(e,t)=>{var n=Tr(vn(e.body),t),a=new xe.MathNode("mphantom",n),l=new xe.MathNode("mpadded",[a]);return l.setAttribute("height","0px"),l.setAttribute("depth","0px"),l}});Be({type:"vphantom",names:["\\vphantom"],props:{numArgs:1,allowedInText:!0},handler:(e,t)=>{var{parser:n}=e,a=t[0];return{type:"vphantom",mode:n.mode,body:a}},htmlBuilder:(e,t)=>{var n=Z.makeSpan(["inner"],[Nt(e.body,t.withPhantom())]),a=Z.makeSpan(["fix"],[]);return Z.makeSpan(["mord","rlap"],[n,a],t)},mathmlBuilder:(e,t)=>{var n=Tr(vn(e.body),t),a=new xe.MathNode("mphantom",n),l=new xe.MathNode("mpadded",[a]);return l.setAttribute("width","0px"),l}});Be({type:"raisebox",names:["\\raisebox"],props:{numArgs:2,argTypes:["size","hbox"],allowedInText:!0},handler(e,t){var{parser:n}=e,a=ft(t[0],"size").value,l=t[1];return{type:"raisebox",mode:n.mode,dy:a,body:l}},htmlBuilder(e,t){var n=Nt(e.body,t),a=fn(e.dy,t);return Z.makeVList({positionType:"shift",positionData:-a,children:[{type:"elem",elem:n}]},t)},mathmlBuilder(e,t){var n=new xe.MathNode("mpadded",[Vt(e.body,t)]),a=e.dy.number+e.dy.unit;return n.setAttribute("voffset",a),n}});Be({type:"internal",names:["\\relax"],props:{numArgs:0,allowedInText:!0,allowedInArgument:!0},handler(e){var{parser:t}=e;return{type:"internal",mode:t.mode}}});Be({type:"rule",names:["\\rule"],props:{numArgs:2,numOptionalArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["size","size","size"]},handler(e,t,n){var{parser:a}=e,l=n[0],s=ft(t[0],"size"),o=ft(t[1],"size");return{type:"rule",mode:a.mode,shift:l&&ft(l,"size").value,width:s.value,height:o.value}},htmlBuilder(e,t){var n=Z.makeSpan(["mord","rule"],[],t),a=fn(e.width,t),l=fn(e.height,t),s=e.shift?fn(e.shift,t):0;return n.style.borderRightWidth=Oe(a),n.style.borderTopWidth=Oe(l),n.style.bottom=Oe(s),n.width=a,n.height=l+s,n.depth=-s,n.maxFontSize=l*1.125*t.sizeMultiplier,n},mathmlBuilder(e,t){var n=fn(e.width,t),a=fn(e.height,t),l=e.shift?fn(e.shift,t):0,s=t.color&&t.getColor()||"black",o=new xe.MathNode("mspace");o.setAttribute("mathbackground",s),o.setAttribute("width",Oe(n)),o.setAttribute("height",Oe(a));var d=new xe.MathNode("mpadded",[o]);return l>=0?d.setAttribute("height",Oe(l)):(d.setAttribute("height",Oe(l)),d.setAttribute("depth",Oe(-l))),d.setAttribute("voffset",Oe(l)),d}});function N7(e,t,n){for(var a=Dn(e,t,!1),l=t.sizeMultiplier/n.sizeMultiplier,s=0;s<a.length;s++){var o=a[s].classes.indexOf("sizing");o<0?Array.prototype.push.apply(a[s].classes,t.sizingClasses(n)):a[s].classes[o+1]==="reset-size"+t.size&&(a[s].classes[o+1]="reset-size"+n.size),a[s].height*=l,a[s].depth*=l}return Z.makeFragment(a)}var N3=["\\tiny","\\sixptsize","\\scriptsize","\\footnotesize","\\small","\\normalsize","\\large","\\Large","\\LARGE","\\huge","\\Huge"],VM=(e,t)=>{var n=t.havingSize(e.size);return N7(e.body,n,t)};Be({type:"sizing",names:N3,props:{numArgs:0,allowedInText:!0},handler:(e,t)=>{var{breakOnTokenText:n,funcName:a,parser:l}=e,s=l.parseExpression(!1,n);return{type:"sizing",mode:l.mode,size:N3.indexOf(a)+1,body:s}},htmlBuilder:VM,mathmlBuilder:(e,t)=>{var n=t.havingSize(e.size),a=Tr(e.body,n),l=new xe.MathNode("mstyle",a);return l.setAttribute("mathsize",Oe(n.sizeMultiplier)),l}});Be({type:"smash",names:["\\smash"],props:{numArgs:1,numOptionalArgs:1,allowedInText:!0},handler:(e,t,n)=>{var{parser:a}=e,l=!1,s=!1,o=n[0]&&ft(n[0],"ordgroup");if(o)for(var d="",f=0;f<o.body.length;++f){var h=o.body[f];if(d=h.text,d==="t")l=!0;else if(d==="b")s=!0;else{l=!1,s=!1;break}}else l=!0,s=!0;var p=t[0];return{type:"smash",mode:a.mode,body:p,smashHeight:l,smashDepth:s}},htmlBuilder:(e,t)=>{var n=Z.makeSpan([],[Nt(e.body,t)]);if(!e.smashHeight&&!e.smashDepth)return n;if(e.smashHeight&&(n.height=0,n.children))for(var a=0;a<n.children.length;a++)n.children[a].height=0;if(e.smashDepth&&(n.depth=0,n.children))for(var l=0;l<n.children.length;l++)n.children[l].depth=0;var s=Z.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n}]},t);return Z.makeSpan(["mord"],[s],t)},mathmlBuilder:(e,t)=>{var n=new xe.MathNode("mpadded",[Vt(e.body,t)]);return e.smashHeight&&n.setAttribute("height","0px"),e.smashDepth&&n.setAttribute("depth","0px"),n}});Be({type:"sqrt",names:["\\sqrt"],props:{numArgs:1,numOptionalArgs:1},handler(e,t,n){var{parser:a}=e,l=n[0],s=t[0];return{type:"sqrt",mode:a.mode,body:s,index:l}},htmlBuilder(e,t){var n=Nt(e.body,t.havingCrampedStyle());n.height===0&&(n.height=t.fontMetrics().xHeight),n=Z.wrapFragment(n,t);var a=t.fontMetrics(),l=a.defaultRuleThickness,s=l;t.style.id<Je.TEXT.id&&(s=t.fontMetrics().xHeight);var o=l+s/4,d=n.height+n.depth+o+l,{span:f,ruleWidth:h,advanceWidth:p}=ai.sqrtImage(d,t),E=f.height-h;E>n.height+n.depth+o&&(o=(o+E-n.height-n.depth)/2);var T=f.height-n.height-o-h;n.style.paddingLeft=Oe(p);var v=Z.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:n,wrapperClasses:["svg-align"]},{type:"kern",size:-(n.height+T)},{type:"elem",elem:f},{type:"kern",size:h}]},t);if(e.index){var x=t.havingStyle(Je.SCRIPTSCRIPT),N=Nt(e.index,x,t),D=.6*(v.height-v.depth),C=Z.makeVList({positionType:"shift",positionData:-D,children:[{type:"elem",elem:N}]},t),I=Z.makeSpan(["root"],[C]);return Z.makeSpan(["mord","sqrt"],[I,v],t)}else return Z.makeSpan(["mord","sqrt"],[v],t)},mathmlBuilder(e,t){var{body:n,index:a}=e;return a?new xe.MathNode("mroot",[Vt(n,t),Vt(a,t)]):new xe.MathNode("msqrt",[Vt(n,t)])}});var w3={display:Je.DISPLAY,text:Je.TEXT,script:Je.SCRIPT,scriptscript:Je.SCRIPTSCRIPT};Be({type:"styling",names:["\\displaystyle","\\textstyle","\\scriptstyle","\\scriptscriptstyle"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(e,t){var{breakOnTokenText:n,funcName:a,parser:l}=e,s=l.parseExpression(!0,n),o=a.slice(1,a.length-5);return{type:"styling",mode:l.mode,style:o,body:s}},htmlBuilder(e,t){var n=w3[e.style],a=t.havingStyle(n).withFont("");return N7(e.body,a,t)},mathmlBuilder(e,t){var n=w3[e.style],a=t.havingStyle(n),l=Tr(e.body,a),s=new xe.MathNode("mstyle",l),o={display:["0","true"],text:["0","false"],script:["1","false"],scriptscript:["2","false"]},d=o[e.style];return s.setAttribute("scriptlevel",d[0]),s.setAttribute("displaystyle",d[1]),s}});var KM=function(t,n){var a=t.base;if(a)if(a.type==="op"){var l=a.limits&&(n.style.size===Je.DISPLAY.size||a.alwaysHandleSupSub);return l?qs:null}else if(a.type==="operatorname"){var s=a.alwaysHandleSupSub&&(n.style.size===Je.DISPLAY.size||a.limits);return s?k7:null}else{if(a.type==="accent")return We.isCharacterBox(a.base)?Hm:null;if(a.type==="horizBrace"){var o=!t.sub;return o===a.isOver?S7:null}else return null}else return null};Bl({type:"supsub",htmlBuilder(e,t){var n=KM(e,t);if(n)return n(e,t);var{base:a,sup:l,sub:s}=e,o=Nt(a,t),d,f,h=t.fontMetrics(),p=0,E=0,T=a&&We.isCharacterBox(a);if(l){var v=t.havingStyle(t.style.sup());d=Nt(l,v,t),T||(p=o.height-v.fontMetrics().supDrop*v.sizeMultiplier/t.sizeMultiplier)}if(s){var x=t.havingStyle(t.style.sub());f=Nt(s,x,t),T||(E=o.depth+x.fontMetrics().subDrop*x.sizeMultiplier/t.sizeMultiplier)}var N;t.style===Je.DISPLAY?N=h.sup1:t.style.cramped?N=h.sup3:N=h.sup2;var D=t.sizeMultiplier,C=Oe(.5/h.ptPerEm/D),I=null;if(f){var F=e.base&&e.base.type==="op"&&e.base.name&&(e.base.name==="\\oiint"||e.base.name==="\\oiiint");(o instanceof ea||F)&&(I=Oe(-o.italic))}var J;if(d&&f){p=Math.max(p,N,d.depth+.25*h.xHeight),E=Math.max(E,h.sub2);var K=h.defaultRuleThickness,U=4*K;if(p-d.depth-(f.height-E)<U){E=U-(p-d.depth)+f.height;var le=.8*h.xHeight-(p-d.depth);le>0&&(p+=le,E-=le)}var ae=[{type:"elem",elem:f,shift:E,marginRight:C,marginLeft:I},{type:"elem",elem:d,shift:-p,marginRight:C}];J=Z.makeVList({positionType:"individualShift",children:ae},t)}else if(f){E=Math.max(E,h.sub1,f.height-.8*h.xHeight);var se=[{type:"elem",elem:f,marginLeft:I,marginRight:C}];J=Z.makeVList({positionType:"shift",positionData:E,children:se},t)}else if(d)p=Math.max(p,N,d.depth+.25*h.xHeight),J=Z.makeVList({positionType:"shift",positionData:-p,children:[{type:"elem",elem:d,marginRight:C}]},t);else throw new Error("supsub must have either sup or sub.");var G=F1(o,"right")||"mord";return Z.makeSpan([G],[o,Z.makeSpan(["msupsub"],[J])],t)},mathmlBuilder(e,t){var n=!1,a,l;e.base&&e.base.type==="horizBrace"&&(l=!!e.sup,l===e.base.isOver&&(n=!0,a=e.base.isOver)),e.base&&(e.base.type==="op"||e.base.type==="operatorname")&&(e.base.parentIsSupSub=!0);var s=[Vt(e.base,t)];e.sub&&s.push(Vt(e.sub,t)),e.sup&&s.push(Vt(e.sup,t));var o;if(n)o=a?"mover":"munder";else if(e.sub)if(e.sup){var h=e.base;h&&h.type==="op"&&h.limits&&t.style===Je.DISPLAY||h&&h.type==="operatorname"&&h.alwaysHandleSupSub&&(t.style===Je.DISPLAY||h.limits)?o="munderover":o="msubsup"}else{var f=e.base;f&&f.type==="op"&&f.limits&&(t.style===Je.DISPLAY||f.alwaysHandleSupSub)||f&&f.type==="operatorname"&&f.alwaysHandleSupSub&&(f.limits||t.style===Je.DISPLAY)?o="munder":o="msub"}else{var d=e.base;d&&d.type==="op"&&d.limits&&(t.style===Je.DISPLAY||d.alwaysHandleSupSub)||d&&d.type==="operatorname"&&d.alwaysHandleSupSub&&(d.limits||t.style===Je.DISPLAY)?o="mover":o="msup"}return new xe.MathNode(o,s)}});Bl({type:"atom",htmlBuilder(e,t){return Z.mathsym(e.text,e.mode,t,["m"+e.family])},mathmlBuilder(e,t){var n=new xe.MathNode("mo",[ta(e.text,e.mode)]);if(e.family==="bin"){var a=Um(e,t);a==="bold-italic"&&n.setAttribute("mathvariant",a)}else e.family==="punct"?n.setAttribute("separator","true"):(e.family==="open"||e.family==="close")&&n.setAttribute("stretchy","false");return n}});var w7={mi:"italic",mn:"normal",mtext:"normal"};Bl({type:"mathord",htmlBuilder(e,t){return Z.makeOrd(e,t,"mathord")},mathmlBuilder(e,t){var n=new xe.MathNode("mi",[ta(e.text,e.mode,t)]),a=Um(e,t)||"italic";return a!==w7[n.type]&&n.setAttribute("mathvariant",a),n}});Bl({type:"textord",htmlBuilder(e,t){return Z.makeOrd(e,t,"textord")},mathmlBuilder(e,t){var n=ta(e.text,e.mode,t),a=Um(e,t)||"normal",l;return e.mode==="text"?l=new xe.MathNode("mtext",[n]):/[0-9]/.test(e.text)?l=new xe.MathNode("mn",[n]):e.text==="\\prime"?l=new xe.MathNode("mo",[n]):l=new xe.MathNode("mi",[n]),a!==w7[l.type]&&l.setAttribute("mathvariant",a),l}});var Jh={"\\nobreak":"nobreak","\\allowbreak":"allowbreak"},e1={" ":{},"\\ ":{},"~":{className:"nobreak"},"\\space":{},"\\nobreakspace":{className:"nobreak"}};Bl({type:"spacing",htmlBuilder(e,t){if(e1.hasOwnProperty(e.text)){var n=e1[e.text].className||"";if(e.mode==="text"){var a=Z.makeOrd(e,t,"textord");return a.classes.push(n),a}else return Z.makeSpan(["mspace",n],[Z.mathsym(e.text,e.mode,t)],t)}else{if(Jh.hasOwnProperty(e.text))return Z.makeSpan(["mspace",Jh[e.text]],[],t);throw new ke('Unknown type of space "'+e.text+'"')}},mathmlBuilder(e,t){var n;if(e1.hasOwnProperty(e.text))n=new xe.MathNode("mtext",[new xe.TextNode(" ")]);else{if(Jh.hasOwnProperty(e.text))return new xe.MathNode("mspace");throw new ke('Unknown type of space "'+e.text+'"')}return n}});var C3=()=>{var e=new xe.MathNode("mtd",[]);return e.setAttribute("width","50%"),e};Bl({type:"tag",mathmlBuilder(e,t){var n=new xe.MathNode("mtable",[new xe.MathNode("mtr",[C3(),new xe.MathNode("mtd",[Ji(e.body,t)]),C3(),new xe.MathNode("mtd",[Ji(e.tag,t)])])]);return n.setAttribute("width","100%"),n}});var O3={"\\text":void 0,"\\textrm":"textrm","\\textsf":"textsf","\\texttt":"texttt","\\textnormal":"textrm"},R3={"\\textbf":"textbf","\\textmd":"textmd"},jM={"\\textit":"textit","\\textup":"textup"},M3=(e,t)=>{var n=e.font;if(n){if(O3[n])return t.withTextFontFamily(O3[n]);if(R3[n])return t.withTextFontWeight(R3[n]);if(n==="\\emph")return t.fontShape==="textit"?t.withTextFontShape("textup"):t.withTextFontShape("textit")}else return t;return t.withTextFontShape(jM[n])};Be({type:"text",names:["\\text","\\textrm","\\textsf","\\texttt","\\textnormal","\\textbf","\\textmd","\\textit","\\textup","\\emph"],props:{numArgs:1,argTypes:["text"],allowedInArgument:!0,allowedInText:!0},handler(e,t){var{parser:n,funcName:a}=e,l=t[0];return{type:"text",mode:n.mode,body:vn(l),font:a}},htmlBuilder(e,t){var n=M3(e,t),a=Dn(e.body,n,!0);return Z.makeSpan(["mord","text"],a,n)},mathmlBuilder(e,t){var n=M3(e,t);return Ji(e.body,n)}});Be({type:"underline",names:["\\underline"],props:{numArgs:1,allowedInText:!0},handler(e,t){var{parser:n}=e;return{type:"underline",mode:n.mode,body:t[0]}},htmlBuilder(e,t){var n=Nt(e.body,t),a=Z.makeLineSpan("underline-line",t),l=t.fontMetrics().defaultRuleThickness,s=Z.makeVList({positionType:"top",positionData:n.height,children:[{type:"kern",size:l},{type:"elem",elem:a},{type:"kern",size:3*l},{type:"elem",elem:n}]},t);return Z.makeSpan(["mord","underline"],[s],t)},mathmlBuilder(e,t){var n=new xe.MathNode("mo",[new xe.TextNode("‾")]);n.setAttribute("stretchy","true");var a=new xe.MathNode("munder",[Vt(e.body,t),n]);return a.setAttribute("accentunder","true"),a}});Be({type:"vcenter",names:["\\vcenter"],props:{numArgs:1,argTypes:["original"],allowedInText:!1},handler(e,t){var{parser:n}=e;return{type:"vcenter",mode:n.mode,body:t[0]}},htmlBuilder(e,t){var n=Nt(e.body,t),a=t.fontMetrics().axisHeight,l=.5*(n.height-a-(n.depth+a));return Z.makeVList({positionType:"shift",positionData:l,children:[{type:"elem",elem:n}]},t)},mathmlBuilder(e,t){return new xe.MathNode("mpadded",[Vt(e.body,t)],["vcenter"])}});Be({type:"verb",names:["\\verb"],props:{numArgs:0,allowedInText:!0},handler(e,t,n){throw new ke("\\verb ended by end of line instead of matching delimiter")},htmlBuilder(e,t){for(var n=D3(e),a=[],l=t.havingStyle(t.style.text()),s=0;s<n.length;s++){var o=n[s];o==="~"&&(o="\\textasciitilde"),a.push(Z.makeSymbol(o,"Typewriter-Regular",e.mode,l,["mord","texttt"]))}return Z.makeSpan(["mord","text"].concat(l.sizingClasses(t)),Z.tryCombineChars(a),l)},mathmlBuilder(e,t){var n=new xe.TextNode(D3(e)),a=new xe.MathNode("mtext",[n]);return a.setAttribute("mathvariant","monospace"),a}});var D3=e=>e.body.replace(/ /g,e.star?"␣":" "),$i=Q5,C7=`[ \r
	]`,XM="\\\\[a-zA-Z@]+",$M="\\\\[^\uD800-\uDFFF]",WM="("+XM+")"+C7+"*",QM=`\\\\(
|[ \r	]+
?)[ \r	]*`,V1="[̀-ͯ]",ZM=new RegExp(V1+"+$"),JM="("+C7+"+)|"+(QM+"|")+"([!-\\[\\]-‧‪-퟿豈-]"+(V1+"*")+"|[\uD800-\uDBFF][\uDC00-\uDFFF]"+(V1+"*")+"|\\\\verb\\*([^]).*?\\4|\\\\verb([^*a-zA-Z]).*?\\5"+("|"+WM)+("|"+$M+")");class I3{constructor(t,n){this.input=void 0,this.settings=void 0,this.tokenRegex=void 0,this.catcodes=void 0,this.input=t,this.settings=n,this.tokenRegex=new RegExp(JM,"g"),this.catcodes={"%":14,"~":13}}setCatcode(t,n){this.catcodes[t]=n}lex(){var t=this.input,n=this.tokenRegex.lastIndex;if(n===t.length)return new Jr("EOF",new Lr(this,n,n));var a=this.tokenRegex.exec(t);if(a===null||a.index!==n)throw new ke("Unexpected character: '"+t[n]+"'",new Jr(t[n],new Lr(this,n,n+1)));var l=a[6]||a[3]||(a[2]?"\\ ":" ");if(this.catcodes[l]===14){var s=t.indexOf(`
`,this.tokenRegex.lastIndex);return s===-1?(this.tokenRegex.lastIndex=t.length,this.settings.reportNonstrict("commentAtEnd","% comment has no terminating newline; LaTeX would fail because of commenting the end of math mode (e.g. $)")):this.tokenRegex.lastIndex=s+1,this.lex()}return new Jr(l,new Lr(this,n,this.tokenRegex.lastIndex))}}class eD{constructor(t,n){t===void 0&&(t={}),n===void 0&&(n={}),this.current=void 0,this.builtins=void 0,this.undefStack=void 0,this.current=n,this.builtins=t,this.undefStack=[]}beginGroup(){this.undefStack.push({})}endGroup(){if(this.undefStack.length===0)throw new ke("Unbalanced namespace destruction: attempt to pop global namespace; please report this as a bug");var t=this.undefStack.pop();for(var n in t)t.hasOwnProperty(n)&&(t[n]==null?delete this.current[n]:this.current[n]=t[n])}endGroups(){for(;this.undefStack.length>0;)this.endGroup()}has(t){return this.current.hasOwnProperty(t)||this.builtins.hasOwnProperty(t)}get(t){return this.current.hasOwnProperty(t)?this.current[t]:this.builtins[t]}set(t,n,a){if(a===void 0&&(a=!1),a){for(var l=0;l<this.undefStack.length;l++)delete this.undefStack[l][t];this.undefStack.length>0&&(this.undefStack[this.undefStack.length-1][t]=n)}else{var s=this.undefStack[this.undefStack.length-1];s&&!s.hasOwnProperty(t)&&(s[t]=this.current[t])}n==null?delete this.current[t]:this.current[t]=n}}var tD=E7;O("\\noexpand",function(e){var t=e.popToken();return e.isExpandable(t.text)&&(t.noexpand=!0,t.treatAsRelax=!0),{tokens:[t],numArgs:0}});O("\\expandafter",function(e){var t=e.popToken();return e.expandOnce(!0),{tokens:[t],numArgs:0}});O("\\@firstoftwo",function(e){var t=e.consumeArgs(2);return{tokens:t[0],numArgs:0}});O("\\@secondoftwo",function(e){var t=e.consumeArgs(2);return{tokens:t[1],numArgs:0}});O("\\@ifnextchar",function(e){var t=e.consumeArgs(3);e.consumeSpaces();var n=e.future();return t[0].length===1&&t[0][0].text===n.text?{tokens:t[1],numArgs:0}:{tokens:t[2],numArgs:0}});O("\\@ifstar","\\@ifnextchar *{\\@firstoftwo{#1}}");O("\\TextOrMath",function(e){var t=e.consumeArgs(2);return e.mode==="text"?{tokens:t[0],numArgs:0}:{tokens:t[1],numArgs:0}});var L3={0:0,1:1,2:2,3:3,4:4,5:5,6:6,7:7,8:8,9:9,a:10,A:10,b:11,B:11,c:12,C:12,d:13,D:13,e:14,E:14,f:15,F:15};O("\\char",function(e){var t=e.popToken(),n,a="";if(t.text==="'")n=8,t=e.popToken();else if(t.text==='"')n=16,t=e.popToken();else if(t.text==="`")if(t=e.popToken(),t.text[0]==="\\")a=t.text.charCodeAt(1);else{if(t.text==="EOF")throw new ke("\\char` missing argument");a=t.text.charCodeAt(0)}else n=10;if(n){if(a=L3[t.text],a==null||a>=n)throw new ke("Invalid base-"+n+" digit "+t.text);for(var l;(l=L3[e.future().text])!=null&&l<n;)a*=n,a+=l,e.popToken()}return"\\@char{"+a+"}"});var Xm=(e,t,n,a)=>{var l=e.consumeArg().tokens;if(l.length!==1)throw new ke("\\newcommand's first argument must be a macro name");var s=l[0].text,o=e.isDefined(s);if(o&&!t)throw new ke("\\newcommand{"+s+"} attempting to redefine "+(s+"; use \\renewcommand"));if(!o&&!n)throw new ke("\\renewcommand{"+s+"} when command "+s+" does not yet exist; use \\newcommand");var d=0;if(l=e.consumeArg().tokens,l.length===1&&l[0].text==="["){for(var f="",h=e.expandNextToken();h.text!=="]"&&h.text!=="EOF";)f+=h.text,h=e.expandNextToken();if(!f.match(/^\s*[0-9]+\s*$/))throw new ke("Invalid number of arguments: "+f);d=parseInt(f),l=e.consumeArg().tokens}return o&&a||e.macros.set(s,{tokens:l,numArgs:d}),""};O("\\newcommand",e=>Xm(e,!1,!0,!1));O("\\renewcommand",e=>Xm(e,!0,!1,!1));O("\\providecommand",e=>Xm(e,!0,!0,!0));O("\\message",e=>{var t=e.consumeArgs(1)[0];return console.log(t.reverse().map(n=>n.text).join("")),""});O("\\errmessage",e=>{var t=e.consumeArgs(1)[0];return console.error(t.reverse().map(n=>n.text).join("")),""});O("\\show",e=>{var t=e.popToken(),n=t.text;return console.log(t,e.macros.get(n),$i[n],$t.math[n],$t.text[n]),""});O("\\bgroup","{");O("\\egroup","}");O("~","\\nobreakspace");O("\\lq","`");O("\\rq","'");O("\\aa","\\r a");O("\\AA","\\r A");O("\\textcopyright","\\html@mathml{\\textcircled{c}}{\\char`©}");O("\\copyright","\\TextOrMath{\\textcopyright}{\\text{\\textcopyright}}");O("\\textregistered","\\html@mathml{\\textcircled{\\scriptsize R}}{\\char`®}");O("ℬ","\\mathscr{B}");O("ℰ","\\mathscr{E}");O("ℱ","\\mathscr{F}");O("ℋ","\\mathscr{H}");O("ℐ","\\mathscr{I}");O("ℒ","\\mathscr{L}");O("ℳ","\\mathscr{M}");O("ℛ","\\mathscr{R}");O("ℭ","\\mathfrak{C}");O("ℌ","\\mathfrak{H}");O("ℨ","\\mathfrak{Z}");O("\\Bbbk","\\Bbb{k}");O("·","\\cdotp");O("\\llap","\\mathllap{\\textrm{#1}}");O("\\rlap","\\mathrlap{\\textrm{#1}}");O("\\clap","\\mathclap{\\textrm{#1}}");O("\\mathstrut","\\vphantom{(}");O("\\underbar","\\underline{\\text{#1}}");O("\\not",'\\html@mathml{\\mathrel{\\mathrlap\\@not}}{\\char"338}');O("\\neq","\\html@mathml{\\mathrel{\\not=}}{\\mathrel{\\char`≠}}");O("\\ne","\\neq");O("≠","\\neq");O("\\notin","\\html@mathml{\\mathrel{{\\in}\\mathllap{/\\mskip1mu}}}{\\mathrel{\\char`∉}}");O("∉","\\notin");O("≘","\\html@mathml{\\mathrel{=\\kern{-1em}\\raisebox{0.4em}{$\\scriptsize\\frown$}}}{\\mathrel{\\char`≘}}");O("≙","\\html@mathml{\\stackrel{\\tiny\\wedge}{=}}{\\mathrel{\\char`≘}}");O("≚","\\html@mathml{\\stackrel{\\tiny\\vee}{=}}{\\mathrel{\\char`≚}}");O("≛","\\html@mathml{\\stackrel{\\scriptsize\\star}{=}}{\\mathrel{\\char`≛}}");O("≝","\\html@mathml{\\stackrel{\\tiny\\mathrm{def}}{=}}{\\mathrel{\\char`≝}}");O("≞","\\html@mathml{\\stackrel{\\tiny\\mathrm{m}}{=}}{\\mathrel{\\char`≞}}");O("≟","\\html@mathml{\\stackrel{\\tiny?}{=}}{\\mathrel{\\char`≟}}");O("⟂","\\perp");O("‼","\\mathclose{!\\mkern-0.8mu!}");O("∌","\\notni");O("⌜","\\ulcorner");O("⌝","\\urcorner");O("⌞","\\llcorner");O("⌟","\\lrcorner");O("©","\\copyright");O("®","\\textregistered");O("️","\\textregistered");O("\\ulcorner",'\\html@mathml{\\@ulcorner}{\\mathop{\\char"231c}}');O("\\urcorner",'\\html@mathml{\\@urcorner}{\\mathop{\\char"231d}}');O("\\llcorner",'\\html@mathml{\\@llcorner}{\\mathop{\\char"231e}}');O("\\lrcorner",'\\html@mathml{\\@lrcorner}{\\mathop{\\char"231f}}');O("\\vdots","{\\varvdots\\rule{0pt}{15pt}}");O("⋮","\\vdots");O("\\varGamma","\\mathit{\\Gamma}");O("\\varDelta","\\mathit{\\Delta}");O("\\varTheta","\\mathit{\\Theta}");O("\\varLambda","\\mathit{\\Lambda}");O("\\varXi","\\mathit{\\Xi}");O("\\varPi","\\mathit{\\Pi}");O("\\varSigma","\\mathit{\\Sigma}");O("\\varUpsilon","\\mathit{\\Upsilon}");O("\\varPhi","\\mathit{\\Phi}");O("\\varPsi","\\mathit{\\Psi}");O("\\varOmega","\\mathit{\\Omega}");O("\\substack","\\begin{subarray}{c}#1\\end{subarray}");O("\\colon","\\nobreak\\mskip2mu\\mathpunct{}\\mathchoice{\\mkern-3mu}{\\mkern-3mu}{}{}{:}\\mskip6mu\\relax");O("\\boxed","\\fbox{$\\displaystyle{#1}$}");O("\\iff","\\DOTSB\\;\\Longleftrightarrow\\;");O("\\implies","\\DOTSB\\;\\Longrightarrow\\;");O("\\impliedby","\\DOTSB\\;\\Longleftarrow\\;");O("\\dddot","{\\overset{\\raisebox{-0.1ex}{\\normalsize ...}}{#1}}");O("\\ddddot","{\\overset{\\raisebox{-0.1ex}{\\normalsize ....}}{#1}}");var B3={",":"\\dotsc","\\not":"\\dotsb","+":"\\dotsb","=":"\\dotsb","<":"\\dotsb",">":"\\dotsb","-":"\\dotsb","*":"\\dotsb",":":"\\dotsb","\\DOTSB":"\\dotsb","\\coprod":"\\dotsb","\\bigvee":"\\dotsb","\\bigwedge":"\\dotsb","\\biguplus":"\\dotsb","\\bigcap":"\\dotsb","\\bigcup":"\\dotsb","\\prod":"\\dotsb","\\sum":"\\dotsb","\\bigotimes":"\\dotsb","\\bigoplus":"\\dotsb","\\bigodot":"\\dotsb","\\bigsqcup":"\\dotsb","\\And":"\\dotsb","\\longrightarrow":"\\dotsb","\\Longrightarrow":"\\dotsb","\\longleftarrow":"\\dotsb","\\Longleftarrow":"\\dotsb","\\longleftrightarrow":"\\dotsb","\\Longleftrightarrow":"\\dotsb","\\mapsto":"\\dotsb","\\longmapsto":"\\dotsb","\\hookrightarrow":"\\dotsb","\\doteq":"\\dotsb","\\mathbin":"\\dotsb","\\mathrel":"\\dotsb","\\relbar":"\\dotsb","\\Relbar":"\\dotsb","\\xrightarrow":"\\dotsb","\\xleftarrow":"\\dotsb","\\DOTSI":"\\dotsi","\\int":"\\dotsi","\\oint":"\\dotsi","\\iint":"\\dotsi","\\iiint":"\\dotsi","\\iiiint":"\\dotsi","\\idotsint":"\\dotsi","\\DOTSX":"\\dotsx"};O("\\dots",function(e){var t="\\dotso",n=e.expandAfterFuture().text;return n in B3?t=B3[n]:(n.slice(0,4)==="\\not"||n in $t.math&&We.contains(["bin","rel"],$t.math[n].group))&&(t="\\dotsb"),t});var $m={")":!0,"]":!0,"\\rbrack":!0,"\\}":!0,"\\rbrace":!0,"\\rangle":!0,"\\rceil":!0,"\\rfloor":!0,"\\rgroup":!0,"\\rmoustache":!0,"\\right":!0,"\\bigr":!0,"\\biggr":!0,"\\Bigr":!0,"\\Biggr":!0,$:!0,";":!0,".":!0,",":!0};O("\\dotso",function(e){var t=e.future().text;return t in $m?"\\ldots\\,":"\\ldots"});O("\\dotsc",function(e){var t=e.future().text;return t in $m&&t!==","?"\\ldots\\,":"\\ldots"});O("\\cdots",function(e){var t=e.future().text;return t in $m?"\\@cdots\\,":"\\@cdots"});O("\\dotsb","\\cdots");O("\\dotsm","\\cdots");O("\\dotsi","\\!\\cdots");O("\\dotsx","\\ldots\\,");O("\\DOTSI","\\relax");O("\\DOTSB","\\relax");O("\\DOTSX","\\relax");O("\\tmspace","\\TextOrMath{\\kern#1#3}{\\mskip#1#2}\\relax");O("\\,","\\tmspace+{3mu}{.1667em}");O("\\thinspace","\\,");O("\\>","\\mskip{4mu}");O("\\:","\\tmspace+{4mu}{.2222em}");O("\\medspace","\\:");O("\\;","\\tmspace+{5mu}{.2777em}");O("\\thickspace","\\;");O("\\!","\\tmspace-{3mu}{.1667em}");O("\\negthinspace","\\!");O("\\negmedspace","\\tmspace-{4mu}{.2222em}");O("\\negthickspace","\\tmspace-{5mu}{.277em}");O("\\enspace","\\kern.5em ");O("\\enskip","\\hskip.5em\\relax");O("\\quad","\\hskip1em\\relax");O("\\qquad","\\hskip2em\\relax");O("\\tag","\\@ifstar\\tag@literal\\tag@paren");O("\\tag@paren","\\tag@literal{({#1})}");O("\\tag@literal",e=>{if(e.macros.get("\\df@tag"))throw new ke("Multiple \\tag");return"\\gdef\\df@tag{\\text{#1}}"});O("\\bmod","\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}\\mathbin{\\rm mod}\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}");O("\\pod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern8mu}{\\mkern8mu}{\\mkern8mu}(#1)");O("\\pmod","\\pod{{\\rm mod}\\mkern6mu#1}");O("\\mod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern12mu}{\\mkern12mu}{\\mkern12mu}{\\rm mod}\\,\\,#1");O("\\newline","\\\\\\relax");O("\\TeX","\\textrm{\\html@mathml{T\\kern-.1667em\\raisebox{-.5ex}{E}\\kern-.125emX}{TeX}}");var O7=Oe(Na["Main-Regular"][84][1]-.7*Na["Main-Regular"][65][1]);O("\\LaTeX","\\textrm{\\html@mathml{"+("L\\kern-.36em\\raisebox{"+O7+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{LaTeX}}");O("\\KaTeX","\\textrm{\\html@mathml{"+("K\\kern-.17em\\raisebox{"+O7+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{KaTeX}}");O("\\hspace","\\@ifstar\\@hspacer\\@hspace");O("\\@hspace","\\hskip #1\\relax");O("\\@hspacer","\\rule{0pt}{0pt}\\hskip #1\\relax");O("\\ordinarycolon",":");O("\\vcentcolon","\\mathrel{\\mathop\\ordinarycolon}");O("\\dblcolon",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-.9mu}\\vcentcolon}}{\\mathop{\\char"2237}}');O("\\coloneqq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2254}}');O("\\Coloneqq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2237\\char"3d}}');O("\\coloneq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"3a\\char"2212}}');O("\\Coloneq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"2237\\char"2212}}');O("\\eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2255}}');O("\\Eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"3d\\char"2237}}');O("\\eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2239}}');O("\\Eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"2212\\char"2237}}');O("\\colonapprox",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"3a\\char"2248}}');O("\\Colonapprox",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"2237\\char"2248}}');O("\\colonsim",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"3a\\char"223c}}');O("\\Colonsim",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"2237\\char"223c}}');O("∷","\\dblcolon");O("∹","\\eqcolon");O("≔","\\coloneqq");O("≕","\\eqqcolon");O("⩴","\\Coloneqq");O("\\ratio","\\vcentcolon");O("\\coloncolon","\\dblcolon");O("\\colonequals","\\coloneqq");O("\\coloncolonequals","\\Coloneqq");O("\\equalscolon","\\eqqcolon");O("\\equalscoloncolon","\\Eqqcolon");O("\\colonminus","\\coloneq");O("\\coloncolonminus","\\Coloneq");O("\\minuscolon","\\eqcolon");O("\\minuscoloncolon","\\Eqcolon");O("\\coloncolonapprox","\\Colonapprox");O("\\coloncolonsim","\\Colonsim");O("\\simcolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\vcentcolon}");O("\\simcoloncolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\dblcolon}");O("\\approxcolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\vcentcolon}");O("\\approxcoloncolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\dblcolon}");O("\\notni","\\html@mathml{\\not\\ni}{\\mathrel{\\char`∌}}");O("\\limsup","\\DOTSB\\operatorname*{lim\\,sup}");O("\\liminf","\\DOTSB\\operatorname*{lim\\,inf}");O("\\injlim","\\DOTSB\\operatorname*{inj\\,lim}");O("\\projlim","\\DOTSB\\operatorname*{proj\\,lim}");O("\\varlimsup","\\DOTSB\\operatorname*{\\overline{lim}}");O("\\varliminf","\\DOTSB\\operatorname*{\\underline{lim}}");O("\\varinjlim","\\DOTSB\\operatorname*{\\underrightarrow{lim}}");O("\\varprojlim","\\DOTSB\\operatorname*{\\underleftarrow{lim}}");O("\\gvertneqq","\\html@mathml{\\@gvertneqq}{≩}");O("\\lvertneqq","\\html@mathml{\\@lvertneqq}{≨}");O("\\ngeqq","\\html@mathml{\\@ngeqq}{≱}");O("\\ngeqslant","\\html@mathml{\\@ngeqslant}{≱}");O("\\nleqq","\\html@mathml{\\@nleqq}{≰}");O("\\nleqslant","\\html@mathml{\\@nleqslant}{≰}");O("\\nshortmid","\\html@mathml{\\@nshortmid}{∤}");O("\\nshortparallel","\\html@mathml{\\@nshortparallel}{∦}");O("\\nsubseteqq","\\html@mathml{\\@nsubseteqq}{⊈}");O("\\nsupseteqq","\\html@mathml{\\@nsupseteqq}{⊉}");O("\\varsubsetneq","\\html@mathml{\\@varsubsetneq}{⊊}");O("\\varsubsetneqq","\\html@mathml{\\@varsubsetneqq}{⫋}");O("\\varsupsetneq","\\html@mathml{\\@varsupsetneq}{⊋}");O("\\varsupsetneqq","\\html@mathml{\\@varsupsetneqq}{⫌}");O("\\imath","\\html@mathml{\\@imath}{ı}");O("\\jmath","\\html@mathml{\\@jmath}{ȷ}");O("\\llbracket","\\html@mathml{\\mathopen{[\\mkern-3.2mu[}}{\\mathopen{\\char`⟦}}");O("\\rrbracket","\\html@mathml{\\mathclose{]\\mkern-3.2mu]}}{\\mathclose{\\char`⟧}}");O("⟦","\\llbracket");O("⟧","\\rrbracket");O("\\lBrace","\\html@mathml{\\mathopen{\\{\\mkern-3.2mu[}}{\\mathopen{\\char`⦃}}");O("\\rBrace","\\html@mathml{\\mathclose{]\\mkern-3.2mu\\}}}{\\mathclose{\\char`⦄}}");O("⦃","\\lBrace");O("⦄","\\rBrace");O("\\minuso","\\mathbin{\\html@mathml{{\\mathrlap{\\mathchoice{\\kern{0.145em}}{\\kern{0.145em}}{\\kern{0.1015em}}{\\kern{0.0725em}}\\circ}{-}}}{\\char`⦵}}");O("⦵","\\minuso");O("\\darr","\\downarrow");O("\\dArr","\\Downarrow");O("\\Darr","\\Downarrow");O("\\lang","\\langle");O("\\rang","\\rangle");O("\\uarr","\\uparrow");O("\\uArr","\\Uparrow");O("\\Uarr","\\Uparrow");O("\\N","\\mathbb{N}");O("\\R","\\mathbb{R}");O("\\Z","\\mathbb{Z}");O("\\alef","\\aleph");O("\\alefsym","\\aleph");O("\\Alpha","\\mathrm{A}");O("\\Beta","\\mathrm{B}");O("\\bull","\\bullet");O("\\Chi","\\mathrm{X}");O("\\clubs","\\clubsuit");O("\\cnums","\\mathbb{C}");O("\\Complex","\\mathbb{C}");O("\\Dagger","\\ddagger");O("\\diamonds","\\diamondsuit");O("\\empty","\\emptyset");O("\\Epsilon","\\mathrm{E}");O("\\Eta","\\mathrm{H}");O("\\exist","\\exists");O("\\harr","\\leftrightarrow");O("\\hArr","\\Leftrightarrow");O("\\Harr","\\Leftrightarrow");O("\\hearts","\\heartsuit");O("\\image","\\Im");O("\\infin","\\infty");O("\\Iota","\\mathrm{I}");O("\\isin","\\in");O("\\Kappa","\\mathrm{K}");O("\\larr","\\leftarrow");O("\\lArr","\\Leftarrow");O("\\Larr","\\Leftarrow");O("\\lrarr","\\leftrightarrow");O("\\lrArr","\\Leftrightarrow");O("\\Lrarr","\\Leftrightarrow");O("\\Mu","\\mathrm{M}");O("\\natnums","\\mathbb{N}");O("\\Nu","\\mathrm{N}");O("\\Omicron","\\mathrm{O}");O("\\plusmn","\\pm");O("\\rarr","\\rightarrow");O("\\rArr","\\Rightarrow");O("\\Rarr","\\Rightarrow");O("\\real","\\Re");O("\\reals","\\mathbb{R}");O("\\Reals","\\mathbb{R}");O("\\Rho","\\mathrm{P}");O("\\sdot","\\cdot");O("\\sect","\\S");O("\\spades","\\spadesuit");O("\\sub","\\subset");O("\\sube","\\subseteq");O("\\supe","\\supseteq");O("\\Tau","\\mathrm{T}");O("\\thetasym","\\vartheta");O("\\weierp","\\wp");O("\\Zeta","\\mathrm{Z}");O("\\argmin","\\DOTSB\\operatorname*{arg\\,min}");O("\\argmax","\\DOTSB\\operatorname*{arg\\,max}");O("\\plim","\\DOTSB\\mathop{\\operatorname{plim}}\\limits");O("\\bra","\\mathinner{\\langle{#1}|}");O("\\ket","\\mathinner{|{#1}\\rangle}");O("\\braket","\\mathinner{\\langle{#1}\\rangle}");O("\\Bra","\\left\\langle#1\\right|");O("\\Ket","\\left|#1\\right\\rangle");var R7=e=>t=>{var n=t.consumeArg().tokens,a=t.consumeArg().tokens,l=t.consumeArg().tokens,s=t.consumeArg().tokens,o=t.macros.get("|"),d=t.macros.get("\\|");t.macros.beginGroup();var f=E=>T=>{e&&(T.macros.set("|",o),l.length&&T.macros.set("\\|",d));var v=E;if(!E&&l.length){var x=T.future();x.text==="|"&&(T.popToken(),v=!0)}return{tokens:v?l:a,numArgs:0}};t.macros.set("|",f(!1)),l.length&&t.macros.set("\\|",f(!0));var h=t.consumeArg().tokens,p=t.expandTokens([...s,...h,...n]);return t.macros.endGroup(),{tokens:p.reverse(),numArgs:0}};O("\\bra@ket",R7(!1));O("\\bra@set",R7(!0));O("\\Braket","\\bra@ket{\\left\\langle}{\\,\\middle\\vert\\,}{\\,\\middle\\vert\\,}{\\right\\rangle}");O("\\Set","\\bra@set{\\left\\{\\:}{\\;\\middle\\vert\\;}{\\;\\middle\\Vert\\;}{\\:\\right\\}}");O("\\set","\\bra@set{\\{\\,}{\\mid}{}{\\,\\}}");O("\\angln","{\\angl n}");O("\\blue","\\textcolor{##6495ed}{#1}");O("\\orange","\\textcolor{##ffa500}{#1}");O("\\pink","\\textcolor{##ff00af}{#1}");O("\\red","\\textcolor{##df0030}{#1}");O("\\green","\\textcolor{##28ae7b}{#1}");O("\\gray","\\textcolor{gray}{#1}");O("\\purple","\\textcolor{##9d38bd}{#1}");O("\\blueA","\\textcolor{##ccfaff}{#1}");O("\\blueB","\\textcolor{##80f6ff}{#1}");O("\\blueC","\\textcolor{##63d9ea}{#1}");O("\\blueD","\\textcolor{##11accd}{#1}");O("\\blueE","\\textcolor{##0c7f99}{#1}");O("\\tealA","\\textcolor{##94fff5}{#1}");O("\\tealB","\\textcolor{##26edd5}{#1}");O("\\tealC","\\textcolor{##01d1c1}{#1}");O("\\tealD","\\textcolor{##01a995}{#1}");O("\\tealE","\\textcolor{##208170}{#1}");O("\\greenA","\\textcolor{##b6ffb0}{#1}");O("\\greenB","\\textcolor{##8af281}{#1}");O("\\greenC","\\textcolor{##74cf70}{#1}");O("\\greenD","\\textcolor{##1fab54}{#1}");O("\\greenE","\\textcolor{##0d923f}{#1}");O("\\goldA","\\textcolor{##ffd0a9}{#1}");O("\\goldB","\\textcolor{##ffbb71}{#1}");O("\\goldC","\\textcolor{##ff9c39}{#1}");O("\\goldD","\\textcolor{##e07d10}{#1}");O("\\goldE","\\textcolor{##a75a05}{#1}");O("\\redA","\\textcolor{##fca9a9}{#1}");O("\\redB","\\textcolor{##ff8482}{#1}");O("\\redC","\\textcolor{##f9685d}{#1}");O("\\redD","\\textcolor{##e84d39}{#1}");O("\\redE","\\textcolor{##bc2612}{#1}");O("\\maroonA","\\textcolor{##ffbde0}{#1}");O("\\maroonB","\\textcolor{##ff92c6}{#1}");O("\\maroonC","\\textcolor{##ed5fa6}{#1}");O("\\maroonD","\\textcolor{##ca337c}{#1}");O("\\maroonE","\\textcolor{##9e034e}{#1}");O("\\purpleA","\\textcolor{##ddd7ff}{#1}");O("\\purpleB","\\textcolor{##c6b9fc}{#1}");O("\\purpleC","\\textcolor{##aa87ff}{#1}");O("\\purpleD","\\textcolor{##7854ab}{#1}");O("\\purpleE","\\textcolor{##543b78}{#1}");O("\\mintA","\\textcolor{##f5f9e8}{#1}");O("\\mintB","\\textcolor{##edf2df}{#1}");O("\\mintC","\\textcolor{##e0e5cc}{#1}");O("\\grayA","\\textcolor{##f6f7f7}{#1}");O("\\grayB","\\textcolor{##f0f1f2}{#1}");O("\\grayC","\\textcolor{##e3e5e6}{#1}");O("\\grayD","\\textcolor{##d6d8da}{#1}");O("\\grayE","\\textcolor{##babec2}{#1}");O("\\grayF","\\textcolor{##888d93}{#1}");O("\\grayG","\\textcolor{##626569}{#1}");O("\\grayH","\\textcolor{##3b3e40}{#1}");O("\\grayI","\\textcolor{##21242c}{#1}");O("\\kaBlue","\\textcolor{##314453}{#1}");O("\\kaGreen","\\textcolor{##71B307}{#1}");var M7={"^":!0,_:!0,"\\limits":!0,"\\nolimits":!0};class nD{constructor(t,n,a){this.settings=void 0,this.expansionCount=void 0,this.lexer=void 0,this.macros=void 0,this.stack=void 0,this.mode=void 0,this.settings=n,this.expansionCount=0,this.feed(t),this.macros=new eD(tD,n.macros),this.mode=a,this.stack=[]}feed(t){this.lexer=new I3(t,this.settings)}switchMode(t){this.mode=t}beginGroup(){this.macros.beginGroup()}endGroup(){this.macros.endGroup()}endGroups(){this.macros.endGroups()}future(){return this.stack.length===0&&this.pushToken(this.lexer.lex()),this.stack[this.stack.length-1]}popToken(){return this.future(),this.stack.pop()}pushToken(t){this.stack.push(t)}pushTokens(t){this.stack.push(...t)}scanArgument(t){var n,a,l;if(t){if(this.consumeSpaces(),this.future().text!=="[")return null;n=this.popToken(),{tokens:l,end:a}=this.consumeArg(["]"])}else({tokens:l,start:n,end:a}=this.consumeArg());return this.pushToken(new Jr("EOF",a.loc)),this.pushTokens(l),n.range(a,"")}consumeSpaces(){for(;;){var t=this.future();if(t.text===" ")this.stack.pop();else break}}consumeArg(t){var n=[],a=t&&t.length>0;a||this.consumeSpaces();var l=this.future(),s,o=0,d=0;do{if(s=this.popToken(),n.push(s),s.text==="{")++o;else if(s.text==="}"){if(--o,o===-1)throw new ke("Extra }",s)}else if(s.text==="EOF")throw new ke("Unexpected end of input in a macro argument, expected '"+(t&&a?t[d]:"}")+"'",s);if(t&&a)if((o===0||o===1&&t[d]==="{")&&s.text===t[d]){if(++d,d===t.length){n.splice(-d,d);break}}else d=0}while(o!==0||a);return l.text==="{"&&n[n.length-1].text==="}"&&(n.pop(),n.shift()),n.reverse(),{tokens:n,start:l,end:s}}consumeArgs(t,n){if(n){if(n.length!==t+1)throw new ke("The length of delimiters doesn't match the number of args!");for(var a=n[0],l=0;l<a.length;l++){var s=this.popToken();if(a[l]!==s.text)throw new ke("Use of the macro doesn't match its definition",s)}}for(var o=[],d=0;d<t;d++)o.push(this.consumeArg(n&&n[d+1]).tokens);return o}countExpansion(t){if(this.expansionCount+=t,this.expansionCount>this.settings.maxExpand)throw new ke("Too many expansions: infinite loop or need to increase maxExpand setting")}expandOnce(t){var n=this.popToken(),a=n.text,l=n.noexpand?null:this._getExpansion(a);if(l==null||t&&l.unexpandable){if(t&&l==null&&a[0]==="\\"&&!this.isDefined(a))throw new ke("Undefined control sequence: "+a);return this.pushToken(n),!1}this.countExpansion(1);var s=l.tokens,o=this.consumeArgs(l.numArgs,l.delimiters);if(l.numArgs){s=s.slice();for(var d=s.length-1;d>=0;--d){var f=s[d];if(f.text==="#"){if(d===0)throw new ke("Incomplete placeholder at end of macro body",f);if(f=s[--d],f.text==="#")s.splice(d+1,1);else if(/^[1-9]$/.test(f.text))s.splice(d,2,...o[+f.text-1]);else throw new ke("Not a valid argument number",f)}}}return this.pushTokens(s),s.length}expandAfterFuture(){return this.expandOnce(),this.future()}expandNextToken(){for(;;)if(this.expandOnce()===!1){var t=this.stack.pop();return t.treatAsRelax&&(t.text="\\relax"),t}throw new Error}expandMacro(t){return this.macros.has(t)?this.expandTokens([new Jr(t)]):void 0}expandTokens(t){var n=[],a=this.stack.length;for(this.pushTokens(t);this.stack.length>a;)if(this.expandOnce(!0)===!1){var l=this.stack.pop();l.treatAsRelax&&(l.noexpand=!1,l.treatAsRelax=!1),n.push(l)}return this.countExpansion(n.length),n}expandMacroAsText(t){var n=this.expandMacro(t);return n&&n.map(a=>a.text).join("")}_getExpansion(t){var n=this.macros.get(t);if(n==null)return n;if(t.length===1){var a=this.lexer.catcodes[t];if(a!=null&&a!==13)return}var l=typeof n=="function"?n(this):n;if(typeof l=="string"){var s=0;if(l.indexOf("#")!==-1)for(var o=l.replace(/##/g,"");o.indexOf("#"+(s+1))!==-1;)++s;for(var d=new I3(l,this.settings),f=[],h=d.lex();h.text!=="EOF";)f.push(h),h=d.lex();f.reverse();var p={tokens:f,numArgs:s};return p}return l}isDefined(t){return this.macros.has(t)||$i.hasOwnProperty(t)||$t.math.hasOwnProperty(t)||$t.text.hasOwnProperty(t)||M7.hasOwnProperty(t)}isExpandable(t){var n=this.macros.get(t);return n!=null?typeof n=="string"||typeof n=="function"||!n.unexpandable:$i.hasOwnProperty(t)&&!$i[t].primitive}}var P3=/^[₊₋₌₍₎₀₁₂₃₄₅₆₇₈₉ₐₑₕᵢⱼₖₗₘₙₒₚᵣₛₜᵤᵥₓᵦᵧᵨᵩᵪ]/,cc=Object.freeze({"₊":"+","₋":"-","₌":"=","₍":"(","₎":")","₀":"0","₁":"1","₂":"2","₃":"3","₄":"4","₅":"5","₆":"6","₇":"7","₈":"8","₉":"9","ₐ":"a","ₑ":"e","ₕ":"h","ᵢ":"i","ⱼ":"j","ₖ":"k","ₗ":"l","ₘ":"m","ₙ":"n","ₒ":"o","ₚ":"p","ᵣ":"r","ₛ":"s","ₜ":"t","ᵤ":"u","ᵥ":"v","ₓ":"x","ᵦ":"β","ᵧ":"γ","ᵨ":"ρ","ᵩ":"ϕ","ᵪ":"χ","⁺":"+","⁻":"-","⁼":"=","⁽":"(","⁾":")","⁰":"0","¹":"1","²":"2","³":"3","⁴":"4","⁵":"5","⁶":"6","⁷":"7","⁸":"8","⁹":"9","ᴬ":"A","ᴮ":"B","ᴰ":"D","ᴱ":"E","ᴳ":"G","ᴴ":"H","ᴵ":"I","ᴶ":"J","ᴷ":"K","ᴸ":"L","ᴹ":"M","ᴺ":"N","ᴼ":"O","ᴾ":"P","ᴿ":"R","ᵀ":"T","ᵁ":"U","ⱽ":"V","ᵂ":"W","ᵃ":"a","ᵇ":"b","ᶜ":"c","ᵈ":"d","ᵉ":"e","ᶠ":"f","ᵍ":"g",ʰ:"h","ⁱ":"i",ʲ:"j","ᵏ":"k",ˡ:"l","ᵐ":"m",ⁿ:"n","ᵒ":"o","ᵖ":"p",ʳ:"r",ˢ:"s","ᵗ":"t","ᵘ":"u","ᵛ":"v",ʷ:"w",ˣ:"x",ʸ:"y","ᶻ":"z","ᵝ":"β","ᵞ":"γ","ᵟ":"δ","ᵠ":"ϕ","ᵡ":"χ","ᶿ":"θ"}),t1={"́":{text:"\\'",math:"\\acute"},"̀":{text:"\\`",math:"\\grave"},"̈":{text:'\\"',math:"\\ddot"},"̃":{text:"\\~",math:"\\tilde"},"̄":{text:"\\=",math:"\\bar"},"̆":{text:"\\u",math:"\\breve"},"̌":{text:"\\v",math:"\\check"},"̂":{text:"\\^",math:"\\hat"},"̇":{text:"\\.",math:"\\dot"},"̊":{text:"\\r",math:"\\mathring"},"̋":{text:"\\H"},"̧":{text:"\\c"}},U3={á:"á",à:"à",ä:"ä",ǟ:"ǟ",ã:"ã",ā:"ā",ă:"ă",ắ:"ắ",ằ:"ằ",ẵ:"ẵ",ǎ:"ǎ",â:"â",ấ:"ấ",ầ:"ầ",ẫ:"ẫ",ȧ:"ȧ",ǡ:"ǡ",å:"å",ǻ:"ǻ",ḃ:"ḃ",ć:"ć",ḉ:"ḉ",č:"č",ĉ:"ĉ",ċ:"ċ",ç:"ç",ď:"ď",ḋ:"ḋ",ḑ:"ḑ",é:"é",è:"è",ë:"ë",ẽ:"ẽ",ē:"ē",ḗ:"ḗ",ḕ:"ḕ",ĕ:"ĕ",ḝ:"ḝ",ě:"ě",ê:"ê",ế:"ế",ề:"ề",ễ:"ễ",ė:"ė",ȩ:"ȩ",ḟ:"ḟ",ǵ:"ǵ",ḡ:"ḡ",ğ:"ğ",ǧ:"ǧ",ĝ:"ĝ",ġ:"ġ",ģ:"ģ",ḧ:"ḧ",ȟ:"ȟ",ĥ:"ĥ",ḣ:"ḣ",ḩ:"ḩ",í:"í",ì:"ì",ï:"ï",ḯ:"ḯ",ĩ:"ĩ",ī:"ī",ĭ:"ĭ",ǐ:"ǐ",î:"î",ǰ:"ǰ",ĵ:"ĵ",ḱ:"ḱ",ǩ:"ǩ",ķ:"ķ",ĺ:"ĺ",ľ:"ľ",ļ:"ļ",ḿ:"ḿ",ṁ:"ṁ",ń:"ń",ǹ:"ǹ",ñ:"ñ",ň:"ň",ṅ:"ṅ",ņ:"ņ",ó:"ó",ò:"ò",ö:"ö",ȫ:"ȫ",õ:"õ",ṍ:"ṍ",ṏ:"ṏ",ȭ:"ȭ",ō:"ō",ṓ:"ṓ",ṑ:"ṑ",ŏ:"ŏ",ǒ:"ǒ",ô:"ô",ố:"ố",ồ:"ồ",ỗ:"ỗ",ȯ:"ȯ",ȱ:"ȱ",ő:"ő",ṕ:"ṕ",ṗ:"ṗ",ŕ:"ŕ",ř:"ř",ṙ:"ṙ",ŗ:"ŗ",ś:"ś",ṥ:"ṥ",š:"š",ṧ:"ṧ",ŝ:"ŝ",ṡ:"ṡ",ş:"ş",ẗ:"ẗ",ť:"ť",ṫ:"ṫ",ţ:"ţ",ú:"ú",ù:"ù",ü:"ü",ǘ:"ǘ",ǜ:"ǜ",ǖ:"ǖ",ǚ:"ǚ",ũ:"ũ",ṹ:"ṹ",ū:"ū",ṻ:"ṻ",ŭ:"ŭ",ǔ:"ǔ",û:"û",ů:"ů",ű:"ű",ṽ:"ṽ",ẃ:"ẃ",ẁ:"ẁ",ẅ:"ẅ",ŵ:"ŵ",ẇ:"ẇ",ẘ:"ẘ",ẍ:"ẍ",ẋ:"ẋ",ý:"ý",ỳ:"ỳ",ÿ:"ÿ",ỹ:"ỹ",ȳ:"ȳ",ŷ:"ŷ",ẏ:"ẏ",ẙ:"ẙ",ź:"ź",ž:"ž",ẑ:"ẑ",ż:"ż",Á:"Á",À:"À",Ä:"Ä",Ǟ:"Ǟ",Ã:"Ã",Ā:"Ā",Ă:"Ă",Ắ:"Ắ",Ằ:"Ằ",Ẵ:"Ẵ",Ǎ:"Ǎ",Â:"Â",Ấ:"Ấ",Ầ:"Ầ",Ẫ:"Ẫ",Ȧ:"Ȧ",Ǡ:"Ǡ",Å:"Å",Ǻ:"Ǻ",Ḃ:"Ḃ",Ć:"Ć",Ḉ:"Ḉ",Č:"Č",Ĉ:"Ĉ",Ċ:"Ċ",Ç:"Ç",Ď:"Ď",Ḋ:"Ḋ",Ḑ:"Ḑ",É:"É",È:"È",Ë:"Ë",Ẽ:"Ẽ",Ē:"Ē",Ḗ:"Ḗ",Ḕ:"Ḕ",Ĕ:"Ĕ",Ḝ:"Ḝ",Ě:"Ě",Ê:"Ê",Ế:"Ế",Ề:"Ề",Ễ:"Ễ",Ė:"Ė",Ȩ:"Ȩ",Ḟ:"Ḟ",Ǵ:"Ǵ",Ḡ:"Ḡ",Ğ:"Ğ",Ǧ:"Ǧ",Ĝ:"Ĝ",Ġ:"Ġ",Ģ:"Ģ",Ḧ:"Ḧ",Ȟ:"Ȟ",Ĥ:"Ĥ",Ḣ:"Ḣ",Ḩ:"Ḩ",Í:"Í",Ì:"Ì",Ï:"Ï",Ḯ:"Ḯ",Ĩ:"Ĩ",Ī:"Ī",Ĭ:"Ĭ",Ǐ:"Ǐ",Î:"Î",İ:"İ",Ĵ:"Ĵ",Ḱ:"Ḱ",Ǩ:"Ǩ",Ķ:"Ķ",Ĺ:"Ĺ",Ľ:"Ľ",Ļ:"Ļ",Ḿ:"Ḿ",Ṁ:"Ṁ",Ń:"Ń",Ǹ:"Ǹ",Ñ:"Ñ",Ň:"Ň",Ṅ:"Ṅ",Ņ:"Ņ",Ó:"Ó",Ò:"Ò",Ö:"Ö",Ȫ:"Ȫ",Õ:"Õ",Ṍ:"Ṍ",Ṏ:"Ṏ",Ȭ:"Ȭ",Ō:"Ō",Ṓ:"Ṓ",Ṑ:"Ṑ",Ŏ:"Ŏ",Ǒ:"Ǒ",Ô:"Ô",Ố:"Ố",Ồ:"Ồ",Ỗ:"Ỗ",Ȯ:"Ȯ",Ȱ:"Ȱ",Ő:"Ő",Ṕ:"Ṕ",Ṗ:"Ṗ",Ŕ:"Ŕ",Ř:"Ř",Ṙ:"Ṙ",Ŗ:"Ŗ",Ś:"Ś",Ṥ:"Ṥ",Š:"Š",Ṧ:"Ṧ",Ŝ:"Ŝ",Ṡ:"Ṡ",Ş:"Ş",Ť:"Ť",Ṫ:"Ṫ",Ţ:"Ţ",Ú:"Ú",Ù:"Ù",Ü:"Ü",Ǘ:"Ǘ",Ǜ:"Ǜ",Ǖ:"Ǖ",Ǚ:"Ǚ",Ũ:"Ũ",Ṹ:"Ṹ",Ū:"Ū",Ṻ:"Ṻ",Ŭ:"Ŭ",Ǔ:"Ǔ",Û:"Û",Ů:"Ů",Ű:"Ű",Ṽ:"Ṽ",Ẃ:"Ẃ",Ẁ:"Ẁ",Ẅ:"Ẅ",Ŵ:"Ŵ",Ẇ:"Ẇ",Ẍ:"Ẍ",Ẋ:"Ẋ",Ý:"Ý",Ỳ:"Ỳ",Ÿ:"Ÿ",Ỹ:"Ỹ",Ȳ:"Ȳ",Ŷ:"Ŷ",Ẏ:"Ẏ",Ź:"Ź",Ž:"Ž",Ẑ:"Ẑ",Ż:"Ż",ά:"ά",ὰ:"ὰ",ᾱ:"ᾱ",ᾰ:"ᾰ",έ:"έ",ὲ:"ὲ",ή:"ή",ὴ:"ὴ",ί:"ί",ὶ:"ὶ",ϊ:"ϊ",ΐ:"ΐ",ῒ:"ῒ",ῑ:"ῑ",ῐ:"ῐ",ό:"ό",ὸ:"ὸ",ύ:"ύ",ὺ:"ὺ",ϋ:"ϋ",ΰ:"ΰ",ῢ:"ῢ",ῡ:"ῡ",ῠ:"ῠ",ώ:"ώ",ὼ:"ὼ",Ύ:"Ύ",Ὺ:"Ὺ",Ϋ:"Ϋ",Ῡ:"Ῡ",Ῠ:"Ῠ",Ώ:"Ώ",Ὼ:"Ὼ"};class rd{constructor(t,n){this.mode=void 0,this.gullet=void 0,this.settings=void 0,this.leftrightDepth=void 0,this.nextToken=void 0,this.mode="math",this.gullet=new nD(t,n,this.mode),this.settings=n,this.leftrightDepth=0}expect(t,n){if(n===void 0&&(n=!0),this.fetch().text!==t)throw new ke("Expected '"+t+"', got '"+this.fetch().text+"'",this.fetch());n&&this.consume()}consume(){this.nextToken=null}fetch(){return this.nextToken==null&&(this.nextToken=this.gullet.expandNextToken()),this.nextToken}switchMode(t){this.mode=t,this.gullet.switchMode(t)}parse(){this.settings.globalGroup||this.gullet.beginGroup(),this.settings.colorIsTextColor&&this.gullet.macros.set("\\color","\\textcolor");try{var t=this.parseExpression(!1);return this.expect("EOF"),this.settings.globalGroup||this.gullet.endGroup(),t}finally{this.gullet.endGroups()}}subparse(t){var n=this.nextToken;this.consume(),this.gullet.pushToken(new Jr("}")),this.gullet.pushTokens(t);var a=this.parseExpression(!1);return this.expect("}"),this.nextToken=n,a}parseExpression(t,n){for(var a=[];;){this.mode==="math"&&this.consumeSpaces();var l=this.fetch();if(rd.endOfExpression.indexOf(l.text)!==-1||n&&l.text===n||t&&$i[l.text]&&$i[l.text].infix)break;var s=this.parseAtom(n);if(s){if(s.type==="internal")continue}else break;a.push(s)}return this.mode==="text"&&this.formLigatures(a),this.handleInfixNodes(a)}handleInfixNodes(t){for(var n=-1,a,l=0;l<t.length;l++)if(t[l].type==="infix"){if(n!==-1)throw new ke("only one infix operator per group",t[l].token);n=l,a=t[l].replaceWith}if(n!==-1&&a){var s,o,d=t.slice(0,n),f=t.slice(n+1);d.length===1&&d[0].type==="ordgroup"?s=d[0]:s={type:"ordgroup",mode:this.mode,body:d},f.length===1&&f[0].type==="ordgroup"?o=f[0]:o={type:"ordgroup",mode:this.mode,body:f};var h;return a==="\\\\abovefrac"?h=this.callFunction(a,[s,t[n],o],[]):h=this.callFunction(a,[s,o],[]),[h]}else return t}handleSupSubscript(t){var n=this.fetch(),a=n.text;this.consume(),this.consumeSpaces();var l;do{var s;l=this.parseGroup(t)}while(((s=l)==null?void 0:s.type)==="internal");if(!l)throw new ke("Expected group after '"+a+"'",n);return l}formatUnsupportedCmd(t){for(var n=[],a=0;a<t.length;a++)n.push({type:"textord",mode:"text",text:t[a]});var l={type:"text",mode:this.mode,body:n},s={type:"color",mode:this.mode,color:this.settings.errorColor,body:[l]};return s}parseAtom(t){var n=this.parseGroup("atom",t);if((n==null?void 0:n.type)==="internal"||this.mode==="text")return n;for(var a,l;;){this.consumeSpaces();var s=this.fetch();if(s.text==="\\limits"||s.text==="\\nolimits"){if(n&&n.type==="op"){var o=s.text==="\\limits";n.limits=o,n.alwaysHandleSupSub=!0}else if(n&&n.type==="operatorname")n.alwaysHandleSupSub&&(n.limits=s.text==="\\limits");else throw new ke("Limit controls must follow a math operator",s);this.consume()}else if(s.text==="^"){if(a)throw new ke("Double superscript",s);a=this.handleSupSubscript("superscript")}else if(s.text==="_"){if(l)throw new ke("Double subscript",s);l=this.handleSupSubscript("subscript")}else if(s.text==="'"){if(a)throw new ke("Double superscript",s);var d={type:"textord",mode:this.mode,text:"\\prime"},f=[d];for(this.consume();this.fetch().text==="'";)f.push(d),this.consume();this.fetch().text==="^"&&f.push(this.handleSupSubscript("superscript")),a={type:"ordgroup",mode:this.mode,body:f}}else if(cc[s.text]){var h=P3.test(s.text),p=[];for(p.push(new Jr(cc[s.text])),this.consume();;){var E=this.fetch().text;if(!cc[E]||P3.test(E)!==h)break;p.unshift(new Jr(cc[E])),this.consume()}var T=this.subparse(p);h?l={type:"ordgroup",mode:"math",body:T}:a={type:"ordgroup",mode:"math",body:T}}else break}return a||l?{type:"supsub",mode:this.mode,base:n,sup:a,sub:l}:n}parseFunction(t,n){var a=this.fetch(),l=a.text,s=$i[l];if(!s)return null;if(this.consume(),n&&n!=="atom"&&!s.allowedInArgument)throw new ke("Got function '"+l+"' with no arguments"+(n?" as "+n:""),a);if(this.mode==="text"&&!s.allowedInText)throw new ke("Can't use function '"+l+"' in text mode",a);if(this.mode==="math"&&s.allowedInMath===!1)throw new ke("Can't use function '"+l+"' in math mode",a);var{args:o,optArgs:d}=this.parseArguments(l,s);return this.callFunction(l,o,d,a,t)}callFunction(t,n,a,l,s){var o={funcName:t,parser:this,token:l,breakOnTokenText:s},d=$i[t];if(d&&d.handler)return d.handler(o,n,a);throw new ke("No function handler for "+t)}parseArguments(t,n){var a=n.numArgs+n.numOptionalArgs;if(a===0)return{args:[],optArgs:[]};for(var l=[],s=[],o=0;o<a;o++){var d=n.argTypes&&n.argTypes[o],f=o<n.numOptionalArgs;(n.primitive&&d==null||n.type==="sqrt"&&o===1&&s[0]==null)&&(d="primitive");var h=this.parseGroupOfType("argument to '"+t+"'",d,f);if(f)s.push(h);else if(h!=null)l.push(h);else throw new ke("Null argument, please report this as a bug")}return{args:l,optArgs:s}}parseGroupOfType(t,n,a){switch(n){case"color":return this.parseColorGroup(a);case"size":return this.parseSizeGroup(a);case"url":return this.parseUrlGroup(a);case"math":case"text":return this.parseArgumentGroup(a,n);case"hbox":{var l=this.parseArgumentGroup(a,"text");return l!=null?{type:"styling",mode:l.mode,body:[l],style:"text"}:null}case"raw":{var s=this.parseStringGroup("raw",a);return s!=null?{type:"raw",mode:"text",string:s.text}:null}case"primitive":{if(a)throw new ke("A primitive argument cannot be optional");var o=this.parseGroup(t);if(o==null)throw new ke("Expected group as "+t,this.fetch());return o}case"original":case null:case void 0:return this.parseArgumentGroup(a);default:throw new ke("Unknown group type as "+t,this.fetch())}}consumeSpaces(){for(;this.fetch().text===" ";)this.consume()}parseStringGroup(t,n){var a=this.gullet.scanArgument(n);if(a==null)return null;for(var l="",s;(s=this.fetch()).text!=="EOF";)l+=s.text,this.consume();return this.consume(),a.text=l,a}parseRegexGroup(t,n){for(var a=this.fetch(),l=a,s="",o;(o=this.fetch()).text!=="EOF"&&t.test(s+o.text);)l=o,s+=l.text,this.consume();if(s==="")throw new ke("Invalid "+n+": '"+a.text+"'",a);return a.range(l,s)}parseColorGroup(t){var n=this.parseStringGroup("color",t);if(n==null)return null;var a=/^(#[a-f0-9]{3}|#?[a-f0-9]{6}|[a-z]+)$/i.exec(n.text);if(!a)throw new ke("Invalid color: '"+n.text+"'",n);var l=a[0];return/^[0-9a-f]{6}$/i.test(l)&&(l="#"+l),{type:"color-token",mode:this.mode,color:l}}parseSizeGroup(t){var n,a=!1;if(this.gullet.consumeSpaces(),!t&&this.gullet.future().text!=="{"?n=this.parseRegexGroup(/^[-+]? *(?:$|\d+|\d+\.\d*|\.\d*) *[a-z]{0,2} *$/,"size"):n=this.parseStringGroup("size",t),!n)return null;!t&&n.text.length===0&&(n.text="0pt",a=!0);var l=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(n.text);if(!l)throw new ke("Invalid size: '"+n.text+"'",n);var s={number:+(l[1]+l[2]),unit:l[3]};if(!q5(s))throw new ke("Invalid unit: '"+s.unit+"'",n);return{type:"size",mode:this.mode,value:s,isBlank:a}}parseUrlGroup(t){this.gullet.lexer.setCatcode("%",13),this.gullet.lexer.setCatcode("~",12);var n=this.parseStringGroup("url",t);if(this.gullet.lexer.setCatcode("%",14),this.gullet.lexer.setCatcode("~",13),n==null)return null;var a=n.text.replace(/\\([#$%&~_^{}])/g,"$1");return{type:"url",mode:this.mode,url:a}}parseArgumentGroup(t,n){var a=this.gullet.scanArgument(t);if(a==null)return null;var l=this.mode;n&&this.switchMode(n),this.gullet.beginGroup();var s=this.parseExpression(!1,"EOF");this.expect("EOF"),this.gullet.endGroup();var o={type:"ordgroup",mode:this.mode,loc:a.loc,body:s};return n&&this.switchMode(l),o}parseGroup(t,n){var a=this.fetch(),l=a.text,s;if(l==="{"||l==="\\begingroup"){this.consume();var o=l==="{"?"}":"\\endgroup";this.gullet.beginGroup();var d=this.parseExpression(!1,o),f=this.fetch();this.expect(o),this.gullet.endGroup(),s={type:"ordgroup",mode:this.mode,loc:Lr.range(a,f),body:d,semisimple:l==="\\begingroup"||void 0}}else if(s=this.parseFunction(n,t)||this.parseSymbol(),s==null&&l[0]==="\\"&&!M7.hasOwnProperty(l)){if(this.settings.throwOnError)throw new ke("Undefined control sequence: "+l,a);s=this.formatUnsupportedCmd(l),this.consume()}return s}formLigatures(t){for(var n=t.length-1,a=0;a<n;++a){var l=t[a],s=l.text;s==="-"&&t[a+1].text==="-"&&(a+1<n&&t[a+2].text==="-"?(t.splice(a,3,{type:"textord",mode:"text",loc:Lr.range(l,t[a+2]),text:"---"}),n-=2):(t.splice(a,2,{type:"textord",mode:"text",loc:Lr.range(l,t[a+1]),text:"--"}),n-=1)),(s==="'"||s==="`")&&t[a+1].text===s&&(t.splice(a,2,{type:"textord",mode:"text",loc:Lr.range(l,t[a+1]),text:s+s}),n-=1)}}parseSymbol(){var t=this.fetch(),n=t.text;if(/^\\verb[^a-zA-Z]/.test(n)){this.consume();var a=n.slice(5),l=a.charAt(0)==="*";if(l&&(a=a.slice(1)),a.length<2||a.charAt(0)!==a.slice(-1))throw new ke(`\\verb assertion failed --
                    please report what input caused this bug`);return a=a.slice(1,-1),{type:"verb",mode:"text",body:a,star:l}}U3.hasOwnProperty(n[0])&&!$t[this.mode][n[0]]&&(this.settings.strict&&this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Accented Unicode text character "'+n[0]+'" used in math mode',t),n=U3[n[0]]+n.slice(1));var s=ZM.exec(n);s&&(n=n.substring(0,s.index),n==="i"?n="ı":n==="j"&&(n="ȷ"));var o;if($t[this.mode][n]){this.settings.strict&&this.mode==="math"&&H1.indexOf(n)>=0&&this.settings.reportNonstrict("unicodeTextInMathMode",'Latin-1/Unicode text character "'+n[0]+'" used in math mode',t);var d=$t[this.mode][n].group,f=Lr.range(t),h;if(GR.hasOwnProperty(d)){var p=d;h={type:"atom",mode:this.mode,family:p,loc:f,text:n}}else h={type:d,mode:this.mode,loc:f,text:n};o=h}else if(n.charCodeAt(0)>=128)this.settings.strict&&(F5(n.charCodeAt(0))?this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Unicode text character "'+n[0]+'" used in math mode',t):this.settings.reportNonstrict("unknownSymbol",'Unrecognized Unicode character "'+n[0]+'"'+(" ("+n.charCodeAt(0)+")"),t)),o={type:"textord",mode:"text",loc:Lr.range(t),text:n};else return null;if(this.consume(),s)for(var E=0;E<s[0].length;E++){var T=s[0][E];if(!t1[T])throw new ke("Unknown accent ' "+T+"'",t);var v=t1[T][this.mode]||t1[T].text;if(!v)throw new ke("Accent "+T+" unsupported in "+this.mode+" mode",t);o={type:"accent",mode:this.mode,loc:Lr.range(t),label:v,isStretchy:!1,isShifty:!0,base:o}}return o}}rd.endOfExpression=["}","\\endgroup","\\end","\\right","&"];var Wm=function(t,n){if(!(typeof t=="string"||t instanceof String))throw new TypeError("KaTeX can only parse string typed expression");var a=new rd(t,n);delete a.gullet.macros.current["\\df@tag"];var l=a.parse();if(delete a.gullet.macros.current["\\current@color"],delete a.gullet.macros.current["\\color"],a.gullet.macros.get("\\df@tag")){if(!n.displayMode)throw new ke("\\tag works only in display equations");l=[{type:"tag",mode:"text",body:l,tag:a.subparse([new Jr("\\df@tag")])}]}return l},D7=function(t,n,a){n.textContent="";var l=Qm(t,a).toNode();n.appendChild(l)};typeof document<"u"&&document.compatMode!=="CSS1Compat"&&(typeof console<"u"&&console.warn("Warning: KaTeX doesn't work in quirks mode. Make sure your website has a suitable doctype."),D7=function(){throw new ke("KaTeX doesn't work in quirks mode.")});var rD=function(t,n){var a=Qm(t,n).toMarkup();return a},aD=function(t,n){var a=new Mm(n);return Wm(t,a)},I7=function(t,n,a){if(a.throwOnError||!(t instanceof ke))throw t;var l=Z.makeSpan(["katex-error"],[new ea(n)]);return l.setAttribute("title",t.toString()),l.setAttribute("style","color:"+a.errorColor),l},Qm=function(t,n){var a=new Mm(n);try{var l=Wm(t,a);return hM(l,t,a)}catch(s){return I7(s,t,a)}},iD=function(t,n){var a=new Mm(n);try{var l=Wm(t,a);return mM(l,t,a)}catch(s){return I7(s,t,a)}},lD="0.16.22",sD={Span:Co,Anchor:Lm,SymbolNode:ea,SvgNode:ii,PathNode:Zi,LineNode:z1},z3={version:lD,render:D7,renderToString:rD,ParseError:ke,SETTINGS_SCHEMA:Tc,__parse:aD,__renderToDomTree:Qm,__renderToHTMLTree:iD,__setFontMetrics:BR,__defineSymbol:y,__defineFunction:Be,__defineMacro:O,__domTree:sD};const uD={},oD=[];function cD(e){const t=e||uD;return function(n,a){Em(n,"element",function(l,s){const o=Array.isArray(l.properties.className)?l.properties.className:oD,d=o.includes("language-math"),f=o.includes("math-display"),h=o.includes("math-inline");let p=f;if(!d&&!f&&!h)return;let E=s[s.length-1],T=l;if(l.tagName==="code"&&d&&E&&E.type==="element"&&E.tagName==="pre"&&(T=E,E=s[s.length-2],p=!0),!E)return;const v=b5(T,{whitespace:"pre"});let x;try{x=z3.renderToString(v,{...t,displayMode:p,throwOnError:!0})}catch(D){const C=D,I=C.name.toLowerCase();a.message("Could not render math with KaTeX",{ancestors:[...s,l],cause:C,place:l.position,ruleId:I,source:"rehype-katex"});try{x=z3.renderToString(v,{...t,displayMode:p,strict:"ignore",throwOnError:!1})}catch{x=[{type:"element",tagName:"span",properties:{className:["katex-error"],style:"color:"+(t.errorColor||"#cc0000"),title:String(D)},children:[{type:"text",value:v}]}]}}typeof x=="string"&&(x=lR(x).children);const N=E.children.indexOf(T);return E.children.splice(N,1,...x),Q6})}}function dD(){return{enter:{mathFlow:e,mathFlowFenceMeta:t,mathText:s},exit:{mathFlow:l,mathFlowFence:a,mathFlowFenceMeta:n,mathFlowValue:d,mathText:o,mathTextData:d}};function e(f){const h={type:"element",tagName:"code",properties:{className:["language-math","math-display"]},children:[]};this.enter({type:"math",meta:null,value:"",data:{hName:"pre",hChildren:[h]}},f)}function t(){this.buffer()}function n(){const f=this.resume(),h=this.stack[this.stack.length-1];h.type,h.meta=f}function a(){this.data.mathFlowInside||(this.buffer(),this.data.mathFlowInside=!0)}function l(f){const h=this.resume().replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),p=this.stack[this.stack.length-1];p.type,this.exit(f),p.value=h;const E=p.data.hChildren[0];E.type,E.tagName,E.children.push({type:"text",value:h}),this.data.mathFlowInside=void 0}function s(f){this.enter({type:"inlineMath",value:"",data:{hName:"code",hProperties:{className:["language-math","math-inline"]},hChildren:[]}},f),this.buffer()}function o(f){const h=this.resume(),p=this.stack[this.stack.length-1];p.type,this.exit(f),p.value=h,p.data.hChildren.push({type:"text",value:h})}function d(f){this.config.enter.data.call(this,f),this.config.exit.data.call(this,f)}}function fD(e){let t=(e||{}).singleDollarTextMath;return t==null&&(t=!0),a.peek=l,{unsafe:[{character:"\r",inConstruct:"mathFlowMeta"},{character:`
`,inConstruct:"mathFlowMeta"},{character:"$",after:t?void 0:"\\$",inConstruct:"phrasing"},{character:"$",inConstruct:"mathFlowMeta"},{atBreak:!0,character:"$",after:"\\$"}],handlers:{math:n,inlineMath:a}};function n(s,o,d,f){const h=s.value||"",p=d.createTracker(f),E="$".repeat(Math.max(aE(h,"$")+1,2)),T=d.enter("mathFlow");let v=p.move(E);if(s.meta){const x=d.enter("mathFlowMeta");v+=p.move(d.safe(s.meta,{after:`
`,before:v,encode:["$"],...p.current()})),x()}return v+=p.move(`
`),h&&(v+=p.move(h+`
`)),v+=p.move(E),T(),v}function a(s,o,d){let f=s.value||"",h=1;for(t||h++;new RegExp("(^|[^$])"+"\\$".repeat(h)+"([^$]|$)").test(f);)h++;const p="$".repeat(h);/[^ \r\n]/.test(f)&&(/^[ \r\n]/.test(f)&&/[ \r\n]$/.test(f)||/^\$|\$$/.test(f))&&(f=" "+f+" ");let E=-1;for(;++E<d.unsafe.length;){const T=d.unsafe[E];if(!T.atBreak)continue;const v=d.compilePattern(T);let x;for(;x=v.exec(f);){let N=x.index;f.codePointAt(N)===10&&f.codePointAt(N-1)===13&&N--,f=f.slice(0,N)+" "+f.slice(x.index+1)}}return p+f+p}function l(){return"$"}}const hD={tokenize:mD,concrete:!0,name:"mathFlow"},H3={tokenize:pD,partial:!0};function mD(e,t,n){const a=this,l=a.events[a.events.length-1],s=l&&l[1].type==="linePrefix"?l[2].sliceSerialize(l[1],!0).length:0;let o=0;return d;function d(I){return e.enter("mathFlow"),e.enter("mathFlowFence"),e.enter("mathFlowFenceSequence"),f(I)}function f(I){return I===36?(e.consume(I),o++,f):o<2?n(I):(e.exit("mathFlowFenceSequence"),yt(e,h,"whitespace")(I))}function h(I){return I===null||Ye(I)?E(I):(e.enter("mathFlowFenceMeta"),e.enter("chunkString",{contentType:"string"}),p(I))}function p(I){return I===null||Ye(I)?(e.exit("chunkString"),e.exit("mathFlowFenceMeta"),E(I)):I===36?n(I):(e.consume(I),p)}function E(I){return e.exit("mathFlowFence"),a.interrupt?t(I):e.attempt(H3,T,D)(I)}function T(I){return e.attempt({tokenize:C,partial:!0},D,v)(I)}function v(I){return(s?yt(e,x,"linePrefix",s+1):x)(I)}function x(I){return I===null?D(I):Ye(I)?e.attempt(H3,T,D)(I):(e.enter("mathFlowValue"),N(I))}function N(I){return I===null||Ye(I)?(e.exit("mathFlowValue"),x(I)):(e.consume(I),N)}function D(I){return e.exit("mathFlow"),t(I)}function C(I,F,J){let K=0;return yt(I,U,"linePrefix",a.parser.constructs.disable.null.includes("codeIndented")?void 0:4);function U(se){return I.enter("mathFlowFence"),I.enter("mathFlowFenceSequence"),le(se)}function le(se){return se===36?(K++,I.consume(se),le):K<o?J(se):(I.exit("mathFlowFenceSequence"),yt(I,ae,"whitespace")(se))}function ae(se){return se===null||Ye(se)?(I.exit("mathFlowFence"),F(se)):J(se)}}}function pD(e,t,n){const a=this;return l;function l(o){return o===null?t(o):(e.enter("lineEnding"),e.consume(o),e.exit("lineEnding"),s)}function s(o){return a.parser.lazy[a.now().line]?n(o):t(o)}}function gD(e){let n=(e||{}).singleDollarTextMath;return n==null&&(n=!0),{tokenize:a,resolve:bD,previous:ED,name:"mathText"};function a(l,s,o){let d=0,f,h;return p;function p(N){return l.enter("mathText"),l.enter("mathTextSequence"),E(N)}function E(N){return N===36?(l.consume(N),d++,E):d<2&&!n?o(N):(l.exit("mathTextSequence"),T(N))}function T(N){return N===null?o(N):N===36?(h=l.enter("mathTextSequence"),f=0,x(N)):N===32?(l.enter("space"),l.consume(N),l.exit("space"),T):Ye(N)?(l.enter("lineEnding"),l.consume(N),l.exit("lineEnding"),T):(l.enter("mathTextData"),v(N))}function v(N){return N===null||N===32||N===36||Ye(N)?(l.exit("mathTextData"),T(N)):(l.consume(N),v)}function x(N){return N===36?(l.consume(N),f++,x):f===d?(l.exit("mathTextSequence"),l.exit("mathText"),s(N)):(h.type="mathTextData",v(N))}}}function bD(e){let t=e.length-4,n=3,a,l;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(a=n;++a<t;)if(e[a][1].type==="mathTextData"){e[t][1].type="mathTextPadding",e[n][1].type="mathTextPadding",n+=2,t-=2;break}}for(a=n-1,t++;++a<=t;)l===void 0?a!==t&&e[a][1].type!=="lineEnding"&&(l=a):(a===t||e[a][1].type==="lineEnding")&&(e[l][1].type="mathTextData",a!==l+2&&(e[l][1].end=e[a-1][1].end,e.splice(l+2,a-l-2),t-=a-l-2,a=l+2),l=void 0);return e}function ED(e){return e!==36||this.events[this.events.length-1][1].type==="characterEscape"}function yD(e){return{flow:{36:hD},text:{36:gD(e)}}}const vD={};function TD(e){const t=this,n=e||vD,a=t.data(),l=a.micromarkExtensions||(a.micromarkExtensions=[]),s=a.fromMarkdownExtensions||(a.fromMarkdownExtensions=[]),o=a.toMarkdownExtensions||(a.toMarkdownExtensions=[]);l.push(yD(n)),s.push(dD()),o.push(fD(n))}var _D=Object.freeze({InvalidProxyUrlErrorMessage:"The proxyUrl passed to Clerk is invalid. The expected value for proxyUrl is an absolute URL or a relative path with a leading '/'. (key={{url}})",InvalidPublishableKeyErrorMessage:"The publishableKey passed to Clerk is invalid. You can get your Publishable key at https://dashboard.clerk.com/last-active?path=api-keys. (key={{key}})",MissingPublishableKeyErrorMessage:"Missing publishableKey. You can get your key at https://dashboard.clerk.com/last-active?path=api-keys.",MissingSecretKeyErrorMessage:"Missing secretKey. You can get your key at https://dashboard.clerk.com/last-active?path=api-keys.",MissingClerkProvider:"{{source}} can only be used within the <ClerkProvider /> component. Learn more: https://clerk.com/docs/components/clerk-provider"});function L7({packageName:e,customMessages:t}){let n=e;const a={..._D,...t};function l(s,o){if(!o)return`${n}: ${s}`;let d=s;const f=s.matchAll(/{{([a-zA-Z0-9-_]+)}}/g);for(const h of f){const p=(o[h[1]]||"").toString();d=d.replace(`{{${h[1]}}}`,p)}return`${n}: ${d}`}return{setPackageName({packageName:s}){return typeof s=="string"&&(n=s),this},setMessages({customMessages:s}){return Object.assign(a,s||{}),this},throwInvalidPublishableKeyError(s){throw new Error(l(a.InvalidPublishableKeyErrorMessage,s))},throwInvalidProxyUrl(s){throw new Error(l(a.InvalidProxyUrlErrorMessage,s))},throwMissingPublishableKeyError(){throw new Error(l(a.MissingPublishableKeyErrorMessage))},throwMissingSecretKeyError(){throw new Error(l(a.MissingSecretKeyErrorMessage))},throwMissingClerkProviderError(s){throw new Error(l(a.MissingClerkProvider,s))},throw(s){throw new Error(l(s))}}}var B7=Object.defineProperty,SD=Object.getOwnPropertyDescriptor,AD=Object.getOwnPropertyNames,xD=Object.prototype.hasOwnProperty,kD=(e,t)=>{for(var n in t)B7(e,n,{get:t[n],enumerable:!0})},ND=(e,t,n,a)=>{if(t&&typeof t=="object"||typeof t=="function")for(let l of AD(t))!xD.call(e,l)&&l!==n&&B7(e,l,{get:()=>t[l],enumerable:!(a=SD(t,l))||a.enumerable});return e},wD=(e,t,n)=>(ND(e,t,"default"),n),CD={strict_mfa:{afterMinutes:10,level:"multi_factor"},strict:{afterMinutes:10,level:"second_factor"},moderate:{afterMinutes:60,level:"second_factor"},lax:{afterMinutes:1440,level:"second_factor"}},OD=new Set(["first_factor","second_factor","multi_factor"]),RD=new Set(["strict_mfa","strict","moderate","lax"]),MD=e=>typeof e=="number"&&e>0,DD=e=>OD.has(e),ID=e=>RD.has(e),n1=e=>e.replace(/^(org:)*/,"org:"),LD=(e,t)=>{const{orgId:n,orgRole:a,orgPermissions:l}=t;return!e.role&&!e.permission||!n||!a||!l?null:e.permission?l.includes(n1(e.permission)):e.role?n1(a)===n1(e.role):null},F3=(e,t)=>{const{org:n,user:a}=PD(e),[l,s]=t.split(":"),o=s||l;return l==="org"?n.includes(o):l==="user"?a.includes(o):[...n,...a].includes(o)},BD=(e,t)=>{const{features:n,plans:a}=t;return e.feature&&n?F3(n,e.feature):e.plan&&a?F3(a,e.plan):null},PD=e=>{const t=e?e.split(",").map(n=>n.trim()):[];return{org:t.filter(n=>n.split(":")[0].includes("o")).map(n=>n.split(":")[1]),user:t.filter(n=>n.split(":")[0].includes("u")).map(n=>n.split(":")[1])}},UD=e=>{if(!e)return!1;const t=l=>typeof l=="string"?CD[l]:l,n=typeof e=="string"&&ID(e),a=typeof e=="object"&&DD(e.level)&&MD(e.afterMinutes);return n||a?t.bind(null,e):!1},zD=(e,{factorVerificationAge:t})=>{if(!e.reverification||!t)return null;const n=UD(e.reverification);if(!n)return null;const{level:a,afterMinutes:l}=n(),[s,o]=t,d=s!==-1?l>s:null,f=o!==-1?l>o:null;switch(a){case"first_factor":return d;case"second_factor":return o!==-1?f:d;case"multi_factor":return o===-1?d:d&&f}},HD=e=>t=>{if(!e.userId)return!1;const n=BD(t,e),a=LD(t,e),l=zD(t,e);return[n||a,l].some(s=>s===null)?[n||a,l].some(s=>s===!0):[n||a,l].every(s=>s===!0)},FD=({authObject:{sessionId:e,sessionStatus:t,userId:n,actor:a,orgId:l,orgRole:s,orgSlug:o,signOut:d,getToken:f,has:h,sessionClaims:p},options:{treatPendingAsSignedOut:E=!0}})=>{if(e===void 0&&n===void 0)return{isLoaded:!1,isSignedIn:void 0,sessionId:e,sessionClaims:void 0,userId:n,actor:void 0,orgId:void 0,orgRole:void 0,orgSlug:void 0,has:void 0,signOut:d,getToken:f};if(e===null&&n===null)return{isLoaded:!0,isSignedIn:!1,sessionId:e,userId:n,sessionClaims:null,actor:null,orgId:null,orgRole:null,orgSlug:null,has:()=>!1,signOut:d,getToken:f};if(E&&t==="pending")return{isLoaded:!0,isSignedIn:!1,sessionId:null,userId:null,sessionClaims:null,actor:null,orgId:null,orgRole:null,orgSlug:null,has:()=>!1,signOut:d,getToken:f};if(e&&p&&n&&l&&s)return{isLoaded:!0,isSignedIn:!0,sessionId:e,sessionClaims:p,userId:n,actor:a||null,orgId:l,orgRole:s,orgSlug:o||null,has:h,signOut:d,getToken:f};if(e&&p&&n&&!l)return{isLoaded:!0,isSignedIn:!0,sessionId:e,sessionClaims:p,userId:n,actor:a||null,orgId:null,orgRole:null,orgSlug:null,has:h,signOut:d,getToken:f}},P7=e=>typeof atob<"u"&&typeof atob=="function"?atob(e):typeof global<"u"&&global.Buffer?new global.Buffer(e,"base64").toString():e,qD=[".lcl.dev",".stg.dev",".lclstage.dev",".stgstage.dev",".dev.lclclerk.com",".stg.lclclerk.com",".accounts.lclclerk.com","accountsstage.dev","accounts.dev"],U7="pk_live_",YD="pk_test_";function q3(e,t={}){if(e=e||"",!e||!K1(e)){if(t.fatal&&!e)throw new Error("Publishable key is missing. Ensure that your publishable key is correctly configured. Double-check your environment configuration for your keys, or access them here: https://dashboard.clerk.com/last-active?path=api-keys");if(t.fatal&&!K1(e))throw new Error("Publishable key not valid.");return null}const n=e.startsWith(U7)?"production":"development";let a=P7(e.split("_")[2]);return a=a.slice(0,-1),t.proxyUrl?a=t.proxyUrl:n!=="development"&&t.domain&&t.isSatellite&&(a=`clerk.${t.domain}`),{instanceType:n,frontendApi:a}}function K1(e=""){try{const t=e.startsWith(U7)||e.startsWith(YD),n=P7(e.split("_")[2]||"").endsWith("$");return t&&n}catch{return!1}}function GD(){const e=new Map;return{isDevOrStagingUrl:t=>{if(!t)return!1;const n=typeof t=="string"?t:t.hostname;let a=e.get(n);return a===void 0&&(a=qD.some(l=>n.endsWith(l)),e.set(n,a)),a}}}var VD="METHOD_CALLED";function KD(e,t){return{event:VD,payload:{method:e,...t}}}var r1={exports:{}},a1={};/**
 * @license React
 * use-sync-external-store-shim.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Y3;function jD(){if(Y3)return a1;Y3=1;var e=Hc();function t(E,T){return E===T&&(E!==0||1/E===1/T)||E!==E&&T!==T}var n=typeof Object.is=="function"?Object.is:t,a=e.useState,l=e.useEffect,s=e.useLayoutEffect,o=e.useDebugValue;function d(E,T){var v=T(),x=a({inst:{value:v,getSnapshot:T}}),N=x[0].inst,D=x[1];return s(function(){N.value=v,N.getSnapshot=T,f(N)&&D({inst:N})},[E,v,T]),l(function(){return f(N)&&D({inst:N}),E(function(){f(N)&&D({inst:N})})},[E]),o(v),v}function f(E){var T=E.getSnapshot;E=E.value;try{var v=T();return!n(E,v)}catch{return!0}}function h(E,T){return T()}var p=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?h:d;return a1.useSyncExternalStore=e.useSyncExternalStore!==void 0?e.useSyncExternalStore:p,a1}var G3;function XD(){return G3||(G3=1,r1.exports=jD()),r1.exports}var z7=XD();const H7=0,F7=1,q7=2,V3=3;var K3=Object.prototype.hasOwnProperty;function j1(e,t){var n,a;if(e===t)return!0;if(e&&t&&(n=e.constructor)===t.constructor){if(n===Date)return e.getTime()===t.getTime();if(n===RegExp)return e.toString()===t.toString();if(n===Array){if((a=e.length)===t.length)for(;a--&&j1(e[a],t[a]););return a===-1}if(!n||typeof e=="object"){a=0;for(n in e)if(K3.call(e,n)&&++a&&!K3.call(t,n)||!(n in t)||!j1(e[n],t[n]))return!1;return Object.keys(t).length===a}}return e!==e&&t!==t}const fa=new WeakMap,Wi=()=>{},Mn=Wi(),Uc=Object,mt=e=>e===Mn,Qr=e=>typeof e=="function",ui=(e,t)=>({...e,...t}),Y7=e=>Qr(e.then),i1={},dc={},Zm="undefined",Ro=typeof window!=Zm,X1=typeof document!=Zm,$D=Ro&&"Deno"in window,WD=()=>Ro&&typeof window.requestAnimationFrame!=Zm,Ki=(e,t)=>{const n=fa.get(e);return[()=>!mt(t)&&e.get(t)||i1,a=>{if(!mt(t)){const l=e.get(t);t in dc||(dc[t]=l),n[5](t,ui(l,a),l||i1)}},n[6],()=>!mt(t)&&t in dc?dc[t]:!mt(t)&&e.get(t)||i1]};let $1=!0;const QD=()=>$1,[W1,Q1]=Ro&&window.addEventListener?[window.addEventListener.bind(window),window.removeEventListener.bind(window)]:[Wi,Wi],ZD=()=>{const e=X1&&document.visibilityState;return mt(e)||e!=="hidden"},JD=e=>(X1&&document.addEventListener("visibilitychange",e),W1("focus",e),()=>{X1&&document.removeEventListener("visibilitychange",e),Q1("focus",e)}),eI=e=>{const t=()=>{$1=!0,e()},n=()=>{$1=!1};return W1("online",t),W1("offline",n),()=>{Q1("online",t),Q1("offline",n)}},tI={isOnline:QD,isVisible:ZD},nI={initFocus:JD,initReconnect:eI},j3=!he.useId,yo=!Ro||$D,rI=e=>WD()?window.requestAnimationFrame(e):setTimeout(e,1),oo=yo?Qe.useEffect:Qe.useLayoutEffect,l1=typeof navigator<"u"&&navigator.connection,X3=!yo&&l1&&(["slow-2g","2g"].includes(l1.effectiveType)||l1.saveData),fc=new WeakMap,s1=(e,t)=>Uc.prototype.toString.call(e)===`[object ${t}]`;let aI=0;const Z1=e=>{const t=typeof e,n=s1(e,"Date"),a=s1(e,"RegExp"),l=s1(e,"Object");let s,o;if(Uc(e)===e&&!n&&!a){if(s=fc.get(e),s)return s;if(s=++aI+"~",fc.set(e,s),Array.isArray(e)){for(s="@",o=0;o<e.length;o++)s+=Z1(e[o])+",";fc.set(e,s)}if(l){s="#";const d=Uc.keys(e).sort();for(;!mt(o=d.pop());)mt(e[o])||(s+=o+":"+Z1(e[o])+",");fc.set(e,s)}}else s=n?e.toJSON():t=="symbol"?e.toString():t=="string"?JSON.stringify(e):""+e;return s},Ds=e=>{if(Qr(e))try{e=e()}catch{e=""}const t=e;return e=typeof e=="string"?e:(Array.isArray(e)?e.length:e)?Z1(e):"",[e,t]};let iI=0;const J1=()=>++iI;async function G7(...e){const[t,n,a,l]=e,s=ui({populateCache:!0,throwOnError:!0},typeof l=="boolean"?{revalidate:l}:l||{});let o=s.populateCache;const d=s.rollbackOnError;let f=s.optimisticData;const h=T=>typeof d=="function"?d(T):d!==!1,p=s.throwOnError;if(Qr(n)){const T=n,v=[],x=t.keys();for(const N of x)!/^\$(inf|sub)\$/.test(N)&&T(t.get(N)._k)&&v.push(N);return Promise.all(v.map(E))}return E(n);async function E(T){const[v]=Ds(T);if(!v)return;const[x,N]=Ki(t,v),[D,C,I,F]=fa.get(t),J=()=>{const Se=D[v];return(Qr(s.revalidate)?s.revalidate(x().data,T):s.revalidate!==!1)&&(delete I[v],delete F[v],Se&&Se[0])?Se[0](q7).then(()=>x().data):x().data};if(e.length<3)return J();let K=a,U;const le=J1();C[v]=[le,0];const ae=!mt(f),se=x(),G=se.data,ge=se._c,ce=mt(ge)?G:ge;if(ae&&(f=Qr(f)?f(ce,G):f,N({data:f,_c:ce})),Qr(K))try{K=K(ce)}catch(Se){U=Se}if(K&&Y7(K))if(K=await K.catch(Se=>{U=Se}),le!==C[v][0]){if(U)throw U;return K}else U&&ae&&h(U)&&(o=!0,N({data:ce,_c:Mn}));if(o&&!U)if(Qr(o)){const Se=o(K,ce);N({data:Se,error:Mn,_c:Mn})}else N({data:K,error:Mn,_c:Mn});if(C[v][1]=J1(),Promise.resolve(J()).then(()=>{N({_c:Mn})}),U){if(p)throw U;return}return K}}const $3=(e,t)=>{for(const n in e)e[n][0]&&e[n][0](t)},V7=(e,t)=>{if(!fa.has(e)){const n=ui(nI,t),a=Object.create(null),l=G7.bind(Mn,e);let s=Wi;const o=Object.create(null),d=(p,E)=>{const T=o[p]||[];return o[p]=T,T.push(E),()=>T.splice(T.indexOf(E),1)},f=(p,E,T)=>{e.set(p,E);const v=o[p];if(v)for(const x of v)x(E,T)},h=()=>{if(!fa.has(e)&&(fa.set(e,[a,Object.create(null),Object.create(null),Object.create(null),l,f,d]),!yo)){const p=n.initFocus(setTimeout.bind(Mn,$3.bind(Mn,a,H7))),E=n.initReconnect(setTimeout.bind(Mn,$3.bind(Mn,a,F7)));s=()=>{p&&p(),E&&E(),fa.delete(e)}}};return h(),[e,l,h,s]}return[e,fa.get(e)[4]]},lI=(e,t,n,a,l)=>{const s=n.errorRetryCount,o=l.retryCount,d=~~((Math.random()+.5)*(1<<(o<8?o:8)))*n.errorRetryInterval;!mt(s)&&o>s||setTimeout(a,d,l)},sI=j1,[Mo,K7]=V7(new Map),j7=ui({onLoadingSlow:Wi,onSuccess:Wi,onError:Wi,onErrorRetry:lI,onDiscarded:Wi,revalidateOnFocus:!0,revalidateOnReconnect:!0,revalidateIfStale:!0,shouldRetryOnError:!0,errorRetryInterval:X3?1e4:5e3,focusThrottleInterval:5*1e3,dedupingInterval:2*1e3,loadingTimeout:X3?5e3:3e3,compare:sI,isPaused:()=>!1,cache:Mo,mutate:K7,fallback:{}},tI),X7=(e,t)=>{const n=ui(e,t);if(t){const{use:a,fallback:l}=e,{use:s,fallback:o}=t;a&&s&&(n.use=a.concat(s)),l&&o&&(n.fallback=ui(l,o))}return n},em=Qe.createContext({}),uI=e=>{const{value:t}=e,n=Qe.useContext(em),a=Qr(t),l=Qe.useMemo(()=>a?t(n):t,[a,n,t]),s=Qe.useMemo(()=>a?l:X7(n,l),[a,n,l]),o=l&&l.provider,d=Qe.useRef(Mn);o&&!d.current&&(d.current=V7(o(s.cache||Mo),l));const f=d.current;return f&&(s.cache=f[0],s.mutate=f[1]),oo(()=>{if(f)return f[2]&&f[2](),f[3]},[]),Qe.createElement(em.Provider,ui(e,{value:s}))},$7="$inf$",W7=Ro&&window.__SWR_DEVTOOLS_USE__,oI=W7?window.__SWR_DEVTOOLS_USE__:[],cI=()=>{W7&&(window.__SWR_DEVTOOLS_REACT__=he)},Q7=e=>Qr(e[1])?[e[0],e[1],e[2]||{}]:[e[0],null,(e[1]===null?e[2]:e[1])||{}],Z7=()=>ui(j7,Qe.useContext(em)),dI=(e,t)=>{const[n,a]=Ds(e),[,,,l]=fa.get(Mo);if(l[n])return l[n];const s=t(a);return l[n]=s,s},fI=e=>(t,n,a)=>e(t,n&&((...s)=>{const[o]=Ds(t),[,,,d]=fa.get(Mo);if(o.startsWith($7))return n(...s);const f=d[o];return mt(f)?n(...s):(delete d[o],f)}),a),hI=oI.concat(fI),mI=e=>function(...n){const a=Z7(),[l,s,o]=Q7(n),d=X7(a,o);let f=e;const{use:h}=d,p=(h||[]).concat(hI);for(let E=p.length;E--;)f=p[E](f);return f(l,s||d.fetcher||null,d)},pI=(e,t,n)=>{const a=t[e]||(t[e]=[]);return a.push(n),()=>{const l=a.indexOf(n);l>=0&&(a[l]=a[a.length-1],a.pop())}},gI=(e,t)=>(...n)=>{const[a,l,s]=Q7(n),o=(s.use||[]).concat(t);return e(a,l,{...s,use:o})};cI();const bI=()=>{},EI=bI(),tm=Object,W3=e=>e===EI,yI=e=>typeof e=="function",hc=new WeakMap,u1=(e,t)=>tm.prototype.toString.call(e)===`[object ${t}]`;let vI=0;const nm=e=>{const t=typeof e,n=u1(e,"Date"),a=u1(e,"RegExp"),l=u1(e,"Object");let s,o;if(tm(e)===e&&!n&&!a){if(s=hc.get(e),s)return s;if(s=++vI+"~",hc.set(e,s),Array.isArray(e)){for(s="@",o=0;o<e.length;o++)s+=nm(e[o])+",";hc.set(e,s)}if(l){s="#";const d=tm.keys(e).sort();for(;!W3(o=d.pop());)W3(e[o])||(s+=o+":"+nm(e[o])+",");hc.set(e,s)}}else s=n?e.toJSON():t=="symbol"?e.toString():t=="string"?JSON.stringify(e):""+e;return s},TI=e=>{if(yI(e))try{e=e()}catch{e=""}const t=e;return e=typeof e=="string"?e:(Array.isArray(e)?e.length:e)?nm(e):"",[e,t]},_I=e=>TI(e)[0],o1=he.use||(e=>{switch(e.status){case"pending":throw e;case"fulfilled":return e.value;case"rejected":throw e.reason;default:throw e.status="pending",e.then(t=>{e.status="fulfilled",e.value=t},t=>{e.status="rejected",e.reason=t}),e}}),c1={dedupe:!0},SI=(e,t,n)=>{const{cache:a,compare:l,suspense:s,fallbackData:o,revalidateOnMount:d,revalidateIfStale:f,refreshInterval:h,refreshWhenHidden:p,refreshWhenOffline:E,keepPreviousData:T}=n,[v,x,N,D]=fa.get(a),[C,I]=Ds(e),F=Qe.useRef(!1),J=Qe.useRef(!1),K=Qe.useRef(C),U=Qe.useRef(t),le=Qe.useRef(n),ae=()=>le.current,se=()=>ae().isVisible()&&ae().isOnline(),[G,ge,ce,Se]=Ki(a,C),fe=Qe.useRef({}).current,ye=mt(o)?mt(n.fallback)?Mn:n.fallback[C]:o,X=(vt,ht)=>{for(const Ut in fe){const Ve=Ut;if(Ve==="data"){if(!l(vt[Ve],ht[Ve])&&(!mt(vt[Ve])||!l(Ge,ht[Ve])))return!1}else if(ht[Ve]!==vt[Ve])return!1}return!0},oe=Qe.useMemo(()=>{const vt=!C||!t?!1:mt(d)?ae().isPaused()||s?!1:f!==!1:d,ht=Zt=>{const Ln=ui(Zt);return delete Ln._k,vt?{isValidating:!0,isLoading:!0,...Ln}:Ln},Ut=G(),Ve=Se(),At=ht(Ut),an=Ut===Ve?At:ht(Ve);let wt=At;return[()=>{const Zt=ht(G());return X(Zt,wt)?(wt.data=Zt.data,wt.isLoading=Zt.isLoading,wt.isValidating=Zt.isValidating,wt.error=Zt.error,wt):(wt=Zt,Zt)},()=>an]},[a,C]),be=z7.useSyncExternalStore(Qe.useCallback(vt=>ce(C,(ht,Ut)=>{X(Ut,ht)||vt()}),[a,C]),oe[0],oe[1]),ze=!F.current,A=v[C]&&v[C].length>0,te=be.data,ue=mt(te)?ye&&Y7(ye)?o1(ye):ye:te,R=be.error,De=Qe.useRef(ue),Ge=T?mt(te)?mt(De.current)?ue:De.current:te:ue,Le=A&&!mt(R)?!1:ze&&!mt(d)?d:ae().isPaused()?!1:s?mt(ue)?!1:f:mt(ue)||f,kt=!!(C&&t&&ze&&Le),it=mt(be.isValidating)?kt:be.isValidating,Wt=mt(be.isLoading)?kt:be.isLoading,Pt=Qe.useCallback(async vt=>{const ht=U.current;if(!C||!ht||J.current||ae().isPaused())return!1;let Ut,Ve,At=!0;const an=vt||{},wt=!N[C]||!an.dedupe,Zt=()=>j3?!J.current&&C===K.current&&F.current:C===K.current,Ln={isValidating:!1,isLoading:!1},di=()=>{ge(Ln)},pa=()=>{const Cn=N[C];Cn&&Cn[1]===Ve&&delete N[C]},cr={isValidating:!0};mt(G().data)&&(cr.isLoading=!0);try{if(wt&&(ge(cr),n.loadingTimeout&&mt(G().data)&&setTimeout(()=>{At&&Zt()&&ae().onLoadingSlow(C,n)},n.loadingTimeout),N[C]=[ht(I),J1()]),[Ut,Ve]=N[C],Ut=await Ut,wt&&setTimeout(pa,n.dedupingInterval),!N[C]||N[C][1]!==Ve)return wt&&Zt()&&ae().onDiscarded(C),!1;Ln.error=Mn;const Cn=x[C];if(!mt(Cn)&&(Ve<=Cn[0]||Ve<=Cn[1]||Cn[1]===0))return di(),wt&&Zt()&&ae().onDiscarded(C),!1;const re=G().data;Ln.data=l(re,Ut)?re:Ut,wt&&Zt()&&ae().onSuccess(Ut,C,n)}catch(Cn){pa();const re=ae(),{shouldRetryOnError:Te}=re;re.isPaused()||(Ln.error=Cn,wt&&Zt()&&(re.onError(Cn,C,re),(Te===!0||Qr(Te)&&Te(Cn))&&(!ae().revalidateOnFocus||!ae().revalidateOnReconnect||se())&&re.onErrorRetry(Cn,C,re,Ke=>{const $e=v[C];$e&&$e[0]&&$e[0](V3,Ke)},{retryCount:(an.retryCount||0)+1,dedupe:!0})))}return At=!1,di(),!0},[C,a]),In=Qe.useCallback((...vt)=>G7(a,K.current,...vt),[]);if(oo(()=>{U.current=t,le.current=n,mt(te)||(De.current=te)}),oo(()=>{if(!C)return;const vt=Pt.bind(Mn,c1);let ht=0;ae().revalidateOnFocus&&(ht=Date.now()+ae().focusThrottleInterval);const Ve=pI(C,v,(At,an={})=>{if(At==H7){const wt=Date.now();ae().revalidateOnFocus&&wt>ht&&se()&&(ht=wt+ae().focusThrottleInterval,vt())}else if(At==F7)ae().revalidateOnReconnect&&se()&&vt();else{if(At==q7)return Pt();if(At==V3)return Pt(an)}});return J.current=!1,K.current=C,F.current=!0,ge({_k:I}),Le&&(mt(ue)||yo?vt():rI(vt)),()=>{J.current=!0,Ve()}},[C]),oo(()=>{let vt;function ht(){const Ve=Qr(h)?h(G().data):h;Ve&&vt!==-1&&(vt=setTimeout(Ut,Ve))}function Ut(){!G().error&&(p||ae().isVisible())&&(E||ae().isOnline())?Pt(c1).then(ht):ht()}return ht(),()=>{vt&&(clearTimeout(vt),vt=-1)}},[h,p,E,C]),Qe.useDebugValue(Ge),s&&mt(ue)&&C){if(!j3&&yo)throw new Error("Fallback data is required when using Suspense in SSR.");U.current=t,le.current=n,J.current=!1;const vt=D[C];if(!mt(vt)){const ht=In(vt);o1(ht)}if(mt(R)){const ht=Pt(c1);mt(Ge)||(ht.status="fulfilled",ht.value=!0),o1(ht)}else throw R}return{mutate:In,get data(){return fe.data=!0,Ge},get error(){return fe.error=!0,R},get isValidating(){return fe.isValidating=!0,it},get isLoading(){return fe.isLoading=!0,Wt}}},AI=Uc.defineProperty(uI,"defaultValue",{value:j7}),Jm=mI(SI),xI=Object.freeze(Object.defineProperty({__proto__:null,SWRConfig:AI,default:Jm,mutate:K7,preload:dI,unstable_serialize:_I,useSWRConfig:Z7},Symbol.toStringTag,{value:"Module"})),kI=()=>{},NI=kI(),rm=Object,Q3=e=>e===NI,wI=e=>typeof e=="function",mc=new WeakMap,d1=(e,t)=>rm.prototype.toString.call(e)===`[object ${t}]`;let CI=0;const am=e=>{const t=typeof e,n=d1(e,"Date"),a=d1(e,"RegExp"),l=d1(e,"Object");let s,o;if(rm(e)===e&&!n&&!a){if(s=mc.get(e),s)return s;if(s=++CI+"~",mc.set(e,s),Array.isArray(e)){for(s="@",o=0;o<e.length;o++)s+=am(e[o])+",";mc.set(e,s)}if(l){s="#";const d=rm.keys(e).sort();for(;!Q3(o=d.pop());)Q3(e[o])||(s+=o+":"+am(e[o])+",");mc.set(e,s)}}else s=n?e.toJSON():t=="symbol"?e.toString():t=="string"?JSON.stringify(e):""+e;return s},OI=e=>{if(wI(e))try{e=e()}catch{e=""}const t=e;return e=typeof e=="string"?e:(Array.isArray(e)?e.length:e)?am(e):"",[e,t]},RI=e=>OI(e?e(0,null):null)[0],f1=Promise.resolve(),MI=e=>(t,n,a)=>{const l=Qe.useRef(!1),{cache:s,initialSize:o=1,revalidateAll:d=!1,persistSize:f=!1,revalidateFirstPage:h=!0,revalidateOnMount:p=!1,parallel:E=!1}=a,[,,,T]=fa.get(Mo);let v;try{v=RI(t),v&&(v=$7+v)}catch{}const[x,N,D]=Ki(s,v),C=Qe.useCallback(()=>mt(x()._l)?o:x()._l,[s,v,o]);z7.useSyncExternalStore(Qe.useCallback(ae=>v?D(v,()=>{ae()}):()=>{},[s,v]),C,C);const I=Qe.useCallback(()=>{const ae=x()._l;return mt(ae)?o:ae},[v,o]),F=Qe.useRef(I());oo(()=>{if(!l.current){l.current=!0;return}v&&N({_l:f?F.current:I()})},[v,s]);const J=p&&!l.current,K=e(v,async ae=>{const se=x()._i,G=x()._r;N({_r:Mn});const ge=[],ce=I(),[Se]=Ki(s,ae),fe=Se().data,ye=[];let X=null;for(let oe=0;oe<ce;++oe){const[be,ze]=Ds(t(oe,E?null:X));if(!be)break;const[A,te]=Ki(s,be);let ue=A().data;const R=d||se||mt(ue)||h&&!oe&&!mt(fe)||J||fe&&!mt(fe[oe])&&!a.compare(fe[oe],ue);if(n&&(typeof G=="function"?G(ue,ze):R)){const De=async()=>{if(!(be in T))ue=await n(ze);else{const Le=T[be];delete T[be],ue=await Le}te({data:ue,_k:ze}),ge[oe]=ue};E?ye.push(De):await De()}else ge[oe]=ue;E||(X=ue)}return E&&await Promise.all(ye.map(oe=>oe())),N({_i:Mn}),ge},a),U=Qe.useCallback(function(ae,se){const G=typeof se=="boolean"?{revalidate:se}:se||{},ge=G.revalidate!==!1;return v?(ge&&(mt(ae)?N({_i:!0,_r:G.revalidate}):N({_i:!1,_r:G.revalidate})),arguments.length?K.mutate(ae,{...G,revalidate:ge}):K.mutate()):f1},[v,s]),le=Qe.useCallback(ae=>{if(!v)return f1;const[,se]=Ki(s,v);let G;if(Qr(ae)?G=ae(I()):typeof ae=="number"&&(G=ae),typeof G!="number")return f1;se({_l:G}),F.current=G;const ge=[],[ce]=Ki(s,v);let Se=null;for(let fe=0;fe<G;++fe){const[ye]=Ds(t(fe,Se)),[X]=Ki(s,ye),oe=ye?X().data:Mn;if(mt(oe))return U(ce().data);ge.push(oe),Se=oe}return U(ge)},[v,s,U,I]);return{size:I(),setSize:le,mutate:U,get data(){return K.data},get error(){return K.error},get isValidating(){return K.isValidating},get isLoading(){return K.isLoading}}},DI=gI(Jm,MI);var Z3=Object.prototype.hasOwnProperty;function J3(e,t,n){for(n of e.keys())if(co(n,t))return n}function co(e,t){var n,a,l;if(e===t)return!0;if(e&&t&&(n=e.constructor)===t.constructor){if(n===Date)return e.getTime()===t.getTime();if(n===RegExp)return e.toString()===t.toString();if(n===Array){if((a=e.length)===t.length)for(;a--&&co(e[a],t[a]););return a===-1}if(n===Set){if(e.size!==t.size)return!1;for(a of e)if(l=a,l&&typeof l=="object"&&(l=J3(t,l),!l)||!t.has(l))return!1;return!0}if(n===Map){if(e.size!==t.size)return!1;for(a of e)if(l=a[0],l&&typeof l=="object"&&(l=J3(t,l),!l)||!co(a[1],t.get(l)))return!1;return!0}if(n===ArrayBuffer)e=new Uint8Array(e),t=new Uint8Array(t);else if(n===DataView){if((a=e.byteLength)===t.byteLength)for(;a--&&e.getInt8(a)===t.getInt8(a););return a===-1}if(ArrayBuffer.isView(e)){if((a=e.byteLength)===t.byteLength)for(;a--&&e[a]===t[a];);return a===-1}if(!n||typeof e=="object"){a=0;for(n in e)if(Z3.call(e,n)&&++a&&!Z3.call(t,n)||!(n in t)||!co(e[n],t[n]))return!1;return Object.keys(t).length===a}}return e!==e&&t!==t}function II(e,t){if(!e)throw typeof t=="string"?new Error(t):new Error(`${t.displayName} not found`)}var Ys=(e,t)=>{const{assertCtxFn:n=II}={},a=he.createContext(void 0);return a.displayName=e,[a,()=>{const o=he.useContext(a);return n(o,`${e} not found`),o.value},()=>{const o=he.useContext(a);return o?o.value:{}}]},ep={};kD(ep,{useSWR:()=>Jm,useSWRInfinite:()=>DI});wD(ep,xI);var[J7,LI]=Ys("ClerkInstanceContext"),[BI,EB]=Ys("UserContext"),[PI,yB]=Ys("ClientContext"),[UI,vB]=Ys("SessionContext");he.createContext({});var[zI,TB]=Ys("OrganizationContext"),HI=({children:e,organization:t,swrConfig:n})=>he.createElement(ep.SWRConfig,{value:n},he.createElement(zI.Provider,{value:{value:{organization:t}}},e));function FI(e){if(!he.useContext(J7)){if(typeof e=="function"){e();return}throw new Error(`${e} can only be used within the <ClerkProvider /> component.

Possible fixes:
1. Ensure that the <ClerkProvider /> is correctly wrapping your application where this component is used.
2. Check for multiple versions of the \`@clerk/shared\` package in your project. Use a tool like \`npm ls @clerk/shared\` to identify multiple versions, and update your dependencies to only rely on one.

Learn more: https://clerk.com/docs/components/clerk-provider`.trim())}}typeof window<"u"?he.useLayoutEffect:he.useEffect;var e6=co,qI=()=>{try{return!1}catch{}return!1},YI=()=>{try{return!1}catch{}return!1},GI=()=>{try{return!0}catch{}return!1},t6=new Set,tp=(e,t,n)=>{const a=YI()||GI(),l=e;t6.has(l)||a||(t6.add(l),console.warn(`Clerk - DEPRECATION WARNING: "${e}" is deprecated and will be removed in the next major release.
${t}`))},Ca=L7({packageName:"@clerk/clerk-react"});function VI(e){Ca.setMessages(e).setPackageName(e)}var[KI,jI]=Ys("AuthContext"),XI=J7,e8=LI,$I="You've added multiple <ClerkProvider> components in your React component tree. Wrap your components in a single <ClerkProvider>.",WI=e=>`You've passed multiple children components to <${e}/>. You can only pass a single child component or text.`,QI="Invalid state. Feel free to submit a bug or reach out to support here: https://clerk.com/support",h1="Unsupported usage of isSatellite, domain or proxyUrl. The usage of isSatellite, domain or proxyUrl as function is not supported in non-browser environments.",ZI="<UserProfile.Page /> component needs to be a direct child of `<UserProfile />` or `<UserButton />`.",JI="<UserProfile.Link /> component needs to be a direct child of `<UserProfile />` or `<UserButton />`.",eL="<OrganizationProfile.Page /> component needs to be a direct child of `<OrganizationProfile />` or `<OrganizationSwitcher />`.",tL="<OrganizationProfile.Link /> component needs to be a direct child of `<OrganizationProfile />` or `<OrganizationSwitcher />`.",nL=e=>`<${e} /> can only accept <${e}.Page /> and <${e}.Link /> as its children. Any other provided component will be ignored. Additionally, please ensure that the component is rendered in a client component.`,rL=e=>`Missing props. <${e}.Page /> component requires the following props: url, label, labelIcon, alongside with children to be rendered inside the page.`,aL=e=>`Missing props. <${e}.Link /> component requires the following props: url, label and labelIcon.`,iL="<UserButton /> can only accept <UserButton.UserProfilePage />, <UserButton.UserProfileLink /> and <UserButton.MenuItems /> as its children. Any other provided component will be ignored. Additionally, please ensure that the component is rendered in a client component.",lL="<UserButton.MenuItems /> component can only accept <UserButton.Action /> and <UserButton.Link /> as its children. Any other provided component will be ignored. Additionally, please ensure that the component is rendered in a client component.",sL="<UserButton.MenuItems /> component needs to be a direct child of `<UserButton />`.",uL="<UserButton.Action /> component needs to be a direct child of `<UserButton.MenuItems />`.",oL="<UserButton.Link /> component needs to be a direct child of `<UserButton.MenuItems />`.",cL="Missing props. <UserButton.Link /> component requires the following props: href, label and labelIcon.",dL="Missing props. <UserButton.Action /> component requires the following props: label.",ad=e=>{FI(()=>{Ca.throwMissingClerkProviderError({source:e})})},t8=e=>new Promise(t=>{const n=a=>{["ready","degraded"].includes(a)&&(t(),e.off("status",n))};e.on("status",n,{notify:!0})}),fL=e=>async t=>(await t8(e),e.session?e.session.getToken(t):null),hL=e=>async(...t)=>(await t8(e),e.signOut(...t)),n8=(e={})=>{var t,n;ad("useAuth");const{treatPendingAsSignedOut:a,...l}=e??{},s=l;let d=jI();d.sessionId===void 0&&d.userId===void 0&&(d=s??{});const f=e8(),h=Qe.useCallback(fL(f),[f]),p=Qe.useCallback(hL(f),[f]);return(t=f.telemetry)==null||t.record(KD("useAuth",{treatPendingAsSignedOut:a})),mL({...d,getToken:h,signOut:p},{treatPendingAsSignedOut:a??((n=f.__internal_getOption)==null?void 0:n.call(f,"treatPendingAsSignedOut"))})};function mL(e,{treatPendingAsSignedOut:t=!0}={}){const{userId:n,orgId:a,orgRole:l,has:s,signOut:o,getToken:d,orgPermissions:f,factorVerificationAge:h,sessionClaims:p}=e??{},E=Qe.useCallback(v=>s?s(v):HD({userId:n,orgId:a,orgRole:l,orgPermissions:f,factorVerificationAge:h,features:(p==null?void 0:p.fea)||"",plans:(p==null?void 0:p.pla)||""})(v),[s,n,a,l,f,h]),T=FD({authObject:{...e,getToken:d,signOut:o,has:E},options:{treatPendingAsSignedOut:t}});return T||Ca.throw(QI)}var gn=(e,t)=>{const a=(typeof t=="string"?t:t==null?void 0:t.component)||e.displayName||e.name||"Component";e.displayName=a;const l=typeof t=="string"?void 0:t,s=o=>{ad(a||"withClerk");const d=e8();return!d.loaded&&!(l!=null&&l.renderWhileLoading)?null:he.createElement(e,{...o,component:a,clerk:d})};return s.displayName=`withClerk(${a})`,s},pL=({children:e,treatPendingAsSignedOut:t})=>{ad("SignedIn");const{userId:n}=n8({treatPendingAsSignedOut:t});return n?e:null},gL=({children:e,treatPendingAsSignedOut:t})=>{ad("SignedOut");const{userId:n}=n8({treatPendingAsSignedOut:t});return n===null?e:null},bL=gn(({clerk:e,...t})=>{const{client:n,session:a}=e,l=n.signedInSessions?n.signedInSessions.length>0:n.activeSessions&&n.activeSessions.length>0;return he.useEffect(()=>{a===null&&l?e.redirectToAfterSignOut():e.redirectToSignIn(t)},[]),null},"RedirectToSignIn");gn(({clerk:e,...t})=>(he.useEffect(()=>{e.redirectToSignUp(t)},[]),null),"RedirectToSignUp");gn(({clerk:e})=>(he.useEffect(()=>{tp("RedirectToUserProfile","Use the `redirectToUserProfile()` method instead."),e.redirectToUserProfile()},[]),null),"RedirectToUserProfile");gn(({clerk:e})=>(he.useEffect(()=>{tp("RedirectToOrganizationProfile","Use the `redirectToOrganizationProfile()` method instead."),e.redirectToOrganizationProfile()},[]),null),"RedirectToOrganizationProfile");gn(({clerk:e})=>(he.useEffect(()=>{tp("RedirectToCreateOrganization","Use the `redirectToCreateOrganization()` method instead."),e.redirectToCreateOrganization()},[]),null),"RedirectToCreateOrganization");gn(({clerk:e,...t})=>(he.useEffect(()=>{e.handleRedirectCallback(t)},[]),null),"AuthenticateWithRedirectCallback");var r8=e=>{throw TypeError(e)},np=(e,t,n)=>t.has(e)||r8("Cannot "+n),cn=(e,t,n)=>(np(e,t,"read from private field"),n?n.call(e):t.get(e)),Cl=(e,t,n)=>t.has(e)?r8("Cannot add the same private member more than once"):t instanceof WeakSet?t.add(e):t.set(e,n),Es=(e,t,n,a)=>(np(e,t,"write to private field"),t.set(e,n),n),n6=(e,t,n)=>(np(e,t,"access private method"),n),EL=(e,t="5.69.0")=>{if(e)return e;const n=yL(t);return n?n==="snapshot"?"5.69.0":n:vL(t)},yL=e=>{var t;return(t=e.trim().replace(/^v/,"").match(/-(.+?)(\.|$)/))==null?void 0:t[1]},vL=e=>e.trim().replace(/^v/,"").split(".")[0];function TL(e){return e?_L(e)||a8(e):!0}function _L(e){return/^http(s)?:\/\//.test(e||"")}function a8(e){return e.startsWith("/")}function SL(e){return e?a8(e)?new URL(e,window.location.origin).toString():e:""}function AL(e){if(!e)return"";let t;if(e.match(/^(clerk\.)+\w*$/))t=/(clerk\.)*(?=clerk\.)/;else{if(e.match(/\.clerk.accounts/))return e;t=/^(clerk\.)*/gi}return`clerk.${e.replace(t,"")}`}var xL={initialDelay:125,maxDelayBetweenRetries:0,factor:2,shouldRetry:(e,t)=>t<5,retryImmediately:!1,jitter:!0},kL=100,i8=async e=>new Promise(t=>setTimeout(t,e)),l8=(e,t)=>t?e*(1+Math.random()):e,NL=e=>{let t=0;const n=()=>{const a=e.initialDelay,l=e.factor;let s=a*Math.pow(l,t);return s=l8(s,e.jitter),Math.min(e.maxDelayBetweenRetries||s,s)};return async()=>{await i8(n()),t++}},wL=async(e,t={})=>{let n=0;const{shouldRetry:a,initialDelay:l,maxDelayBetweenRetries:s,factor:o,retryImmediately:d,jitter:f}={...xL,...t},h=NL({initialDelay:l,maxDelayBetweenRetries:s,factor:o,jitter:f});for(;;)try{return await e()}catch(p){if(n++,!a(p,n))throw p;d&&n===1?await i8(l8(kL,f)):await h()}},CL="loadScript cannot be called when document does not exist",OL="loadScript cannot be called without a src";async function RL(e="",t){const{async:n,defer:a,beforeLoad:l,crossOrigin:s,nonce:o}=t||{};return wL(()=>new Promise((f,h)=>{e||h(new Error(OL)),(!document||!document.body)&&h(CL);const p=document.createElement("script");s&&p.setAttribute("crossorigin",s),p.async=n||!1,p.defer=a||!1,p.addEventListener("load",()=>{p.remove(),f(p)}),p.addEventListener("error",()=>{p.remove(),h()}),p.src=e,p.nonce=o,l==null||l(p),document.body.appendChild(p)}),{shouldRetry:(f,h)=>h<=5})}var r6="Clerk: Failed to load Clerk",{isDevOrStagingUrl:ML}=GD(),s8=L7({packageName:"@clerk/shared"});function DL(e){s8.setPackageName({packageName:e})}var IL=async e=>{const t=document.querySelector("script[data-clerk-js-script]");if(t)return new Promise((n,a)=>{t.addEventListener("load",()=>{n(t)}),t.addEventListener("error",()=>{a(r6)})});if(!(e!=null&&e.publishableKey)){s8.throwMissingPublishableKeyError();return}return RL(LL(e),{async:!0,crossOrigin:"anonymous",nonce:e.nonce,beforeLoad:PL(e)}).catch(()=>{throw new Error(r6)})},LL=e=>{var p,E;const{clerkJSUrl:t,clerkJSVariant:n,clerkJSVersion:a,proxyUrl:l,domain:s,publishableKey:o}=e;if(t)return t;let d="";l&&TL(l)?d=SL(l).replace(/http(s)?:\/\//,""):s&&!ML(((p=q3(o))==null?void 0:p.frontendApi)||"")?d=AL(s):d=((E=q3(o))==null?void 0:E.frontendApi)||"";const f=n?`${n.replace(/\.+$/,"")}.`:"",h=EL(a);return`https://${d}/npm/@clerk/clerk-js@${h}/dist/clerk.${f}browser.js`},BL=e=>{const t={};return e.publishableKey&&(t["data-clerk-publishable-key"]=e.publishableKey),e.proxyUrl&&(t["data-clerk-proxy-url"]=e.proxyUrl),e.domain&&(t["data-clerk-domain"]=e.domain),e.nonce&&(t.nonce=e.nonce),t},PL=e=>t=>{const n=BL(e);for(const a in n)t.setAttribute(a,n[a])},sr=e=>{qI()&&console.error(`Clerk: ${e}`)};function m1(e,t,n){if(typeof e=="function")return e(t);if(typeof e<"u")return e;if(typeof n<"u")return n}var UL=g6(),a6=(e,...t)=>{const n={...e};for(const a of t)delete n[a];return n},zL=(e,t,n)=>!e&&n?HL(n):FL(t),HL=e=>{const t=e.userId,n=e.user,a=e.sessionId,l=e.sessionStatus,s=e.sessionClaims,o=e.session,d=e.organization,f=e.orgId,h=e.orgRole,p=e.orgPermissions,E=e.orgSlug,T=e.actor,v=e.factorVerificationAge;return{userId:t,user:n,sessionId:a,session:o,sessionStatus:l,sessionClaims:s,organization:d,orgId:f,orgRole:h,orgPermissions:p,orgSlug:E,actor:T,factorVerificationAge:v}},FL=e=>{var N,D,C,I;const t=e.user?e.user.id:e.user,n=e.user,a=e.session?e.session.id:e.session,l=e.session,s=(N=e.session)==null?void 0:N.status,o=e.session?(C=(D=e.session.lastActiveToken)==null?void 0:D.jwt)==null?void 0:C.claims:null,d=e.session?e.session.factorVerificationAge:null,f=l==null?void 0:l.actor,h=e.organization,p=e.organization?e.organization.id:e.organization,E=h==null?void 0:h.slug,T=h&&((I=n==null?void 0:n.organizationMemberships)==null?void 0:I.find(F=>F.organization.id===p)),v=T&&T.permissions,x=T&&T.role;return{userId:t,user:n,sessionId:a,session:l,sessionStatus:s,sessionClaims:o,organization:h,orgId:p,orgRole:x,orgSlug:E,orgPermissions:v,actor:f,factorVerificationAge:d}};function i6(){return typeof window<"u"}var l6=(e,t,n,a,l)=>{const{notify:s}=l||{};let o=e.get(n);o||(o=[],e.set(n,o)),o.push(a),s&&t.has(n)&&a(t.get(n))},s6=(e,t,n)=>(e.get(t)||[]).map(a=>a(n)),u6=(e,t,n)=>{const a=e.get(t);a&&(n?a.splice(a.indexOf(n)>>>0,1):e.set(t,[]))},qL=()=>{const e=new Map,t=new Map,n=new Map;return{on:(...l)=>l6(e,t,...l),prioritizedOn:(...l)=>l6(n,t,...l),emit:(l,s)=>{t.set(l,s),s6(n,l,s),s6(e,l,s)},off:(...l)=>u6(e,...l),prioritizedOff:(...l)=>u6(n,...l),internal:{retrieveListeners:l=>e.get(l)||[]}}},pc={Status:"status"},YL=()=>qL();typeof window<"u"&&!window.global&&(window.global=typeof global>"u"?window:global);var id=e=>t=>{try{return he.Children.only(e)}catch{return Ca.throw(WI(t))}},ld=(e,t)=>(e||(e=t),typeof e=="string"&&(e=he.createElement("button",null,e)),e),sd=e=>(...t)=>{if(e&&typeof e=="function")return e(...t)};function GL(e){return typeof e=="function"}var gc=new Map;function VL(e,t,n=1){he.useEffect(()=>{const a=gc.get(e)||0;return a==n?Ca.throw(t):(gc.set(e,a+1),()=>{gc.set(e,(gc.get(e)||1)-1)})},[])}function KL(e,t,n){const a=e.displayName||e.name||t||"Component",l=s=>(VL(t,n),he.createElement(e,{...s}));return l.displayName=`withMaxAllowedInstancesGuard(${a})`,l}var fo=e=>{const t=Array(e.length).fill(null),[n,a]=Qe.useState(t);return e.map((l,s)=>({id:l.id,mount:o=>a(d=>d.map((f,h)=>h===s?o:f)),unmount:()=>a(o=>o.map((d,f)=>f===s?null:d)),portal:()=>he.createElement(he.Fragment,null,n[s]?UL.createPortal(l.component,n[s]):null)}))},ir=(e,t)=>!!e&&he.isValidElement(e)&&(e==null?void 0:e.type)===t,u8=(e,t)=>d8({children:e,reorderItemsLabels:["account","security"],LinkComponent:Io,PageComponent:Do,MenuItemsComponent:od,componentName:"UserProfile"},t),o8=(e,t)=>d8({children:e,reorderItemsLabels:["general","members"],LinkComponent:dd,PageComponent:cd,componentName:"OrganizationProfile"},t),c8=e=>{const t=[],n=[dd,cd,od,Do,Io];return he.Children.forEach(e,a=>{n.some(l=>ir(a,l))||t.push(a)}),t},d8=(e,t)=>{const{children:n,LinkComponent:a,PageComponent:l,MenuItemsComponent:s,reorderItemsLabels:o,componentName:d}=e,{allowForAnyChildren:f=!1}=t||{},h=[];he.Children.forEach(n,I=>{if(!ir(I,l)&&!ir(I,a)&&!ir(I,s)){I&&!f&&sr(nL(d));return}const{props:F}=I,{children:J,label:K,url:U,labelIcon:le}=F;if(ir(I,l))if(o6(F,o))h.push({label:K});else if(p1(F))h.push({label:K,labelIcon:le,children:J,url:U});else{sr(rL(d));return}if(ir(I,a))if(g1(F))h.push({label:K,labelIcon:le,url:U});else{sr(aL(d));return}});const p=[],E=[],T=[];h.forEach((I,F)=>{if(p1(I)){p.push({component:I.children,id:F}),E.push({component:I.labelIcon,id:F});return}g1(I)&&T.push({component:I.labelIcon,id:F})});const v=fo(p),x=fo(E),N=fo(T),D=[],C=[];return h.forEach((I,F)=>{if(o6(I,o)){D.push({label:I.label});return}if(p1(I)){const{portal:J,mount:K,unmount:U}=v.find(G=>G.id===F),{portal:le,mount:ae,unmount:se}=x.find(G=>G.id===F);D.push({label:I.label,url:I.url,mount:K,unmount:U,mountIcon:ae,unmountIcon:se}),C.push(J),C.push(le);return}if(g1(I)){const{portal:J,mount:K,unmount:U}=N.find(le=>le.id===F);D.push({label:I.label,url:I.url,mountIcon:K,unmountIcon:U}),C.push(J);return}}),{customPages:D,customPagesPortals:C}},o6=(e,t)=>{const{children:n,label:a,url:l,labelIcon:s}=e;return!n&&!l&&!s&&t.some(o=>o===a)},p1=e=>{const{children:t,label:n,url:a,labelIcon:l}=e;return!!t&&!!a&&!!l&&!!n},g1=e=>{const{children:t,label:n,url:a,labelIcon:l}=e;return!t&&!!a&&!!l&&!!n},jL=e=>XL({children:e,reorderItemsLabels:["manageAccount","signOut"],MenuItemsComponent:od,MenuActionComponent:h8,MenuLinkComponent:m8,UserProfileLinkComponent:Io,UserProfilePageComponent:Do}),XL=({children:e,MenuItemsComponent:t,MenuActionComponent:n,MenuLinkComponent:a,UserProfileLinkComponent:l,UserProfilePageComponent:s,reorderItemsLabels:o})=>{const d=[],f=[],h=[];he.Children.forEach(e,x=>{if(!ir(x,t)&&!ir(x,l)&&!ir(x,s)){x&&sr(iL);return}if(ir(x,l)||ir(x,s))return;const{props:N}=x;he.Children.forEach(N.children,D=>{if(!ir(D,n)&&!ir(D,a)){D&&sr(lL);return}const{props:C}=D,{label:I,labelIcon:F,href:J,onClick:K,open:U}=C;if(ir(D,n))if(c6(C,o))d.push({label:I});else if(b1(C)){const le={label:I,labelIcon:F};if(K!==void 0)d.push({...le,onClick:K});else if(U!==void 0)d.push({...le,open:U.startsWith("/")?U:`/${U}`});else{sr("Custom menu item must have either onClick or open property");return}}else{sr(dL);return}if(ir(D,a))if(E1(C))d.push({label:I,labelIcon:F,href:J});else{sr(cL);return}})});const p=[],E=[];d.forEach((x,N)=>{b1(x)&&p.push({component:x.labelIcon,id:N}),E1(x)&&E.push({component:x.labelIcon,id:N})});const T=fo(p),v=fo(E);return d.forEach((x,N)=>{if(c6(x,o)&&f.push({label:x.label}),b1(x)){const{portal:D,mount:C,unmount:I}=T.find(J=>J.id===N),F={label:x.label,mountIcon:C,unmountIcon:I};"onClick"in x?F.onClick=x.onClick:"open"in x&&(F.open=x.open),f.push(F),h.push(D)}if(E1(x)){const{portal:D,mount:C,unmount:I}=v.find(F=>F.id===N);f.push({label:x.label,href:x.href,mountIcon:C,unmountIcon:I}),h.push(D)}}),{customMenuItems:f,customMenuItemsPortals:h}},c6=(e,t)=>{const{children:n,label:a,onClick:l,labelIcon:s}=e;return!n&&!l&&!s&&t.some(o=>o===a)},b1=e=>{const{label:t,labelIcon:n,onClick:a,open:l}=e;return!!n&&!!t&&(typeof a=="function"||typeof l=="string")},E1=e=>{const{label:t,href:n,labelIcon:a}=e;return!!n&&!!a&&!!t};function $L(e){const{root:t=document==null?void 0:document.body,selector:n,timeout:a=0}=e;return new Promise((l,s)=>{if(!t){s(new Error("No root element provided"));return}let o=t;if(n&&(o=t==null?void 0:t.querySelector(n)),(o==null?void 0:o.childElementCount)&&o.childElementCount>0){l();return}const f=new MutationObserver(h=>{for(const p of h)if(p.type==="childList"&&(!o&&n&&(o=t==null?void 0:t.querySelector(n)),o!=null&&o.childElementCount&&o.childElementCount>0)){f.disconnect(),l();return}});f.observe(t,{childList:!0,subtree:!0}),a>0&&setTimeout(()=>{f.disconnect(),s(new Error("Timeout waiting for element children"))},a)})}function ra(e){const t=Qe.useRef(),[n,a]=Qe.useState("rendering");return Qe.useEffect(()=>{if(!e)throw new Error("Clerk: no component name provided, unable to detect mount.");typeof window<"u"&&!t.current&&(t.current=$L({selector:`[data-clerk-component="${e}"]`}).then(()=>{a("rendered")}).catch(()=>{a("error")}))},[e]),n}var bc=e=>"mount"in e,d6=e=>"open"in e,f6=e=>e==null?void 0:e.map(({mountIcon:t,unmountIcon:n,...a})=>a),_r=class extends he.PureComponent{constructor(){super(...arguments),this.rootRef=he.createRef()}componentDidUpdate(e){var t,n,a,l;if(!bc(e)||!bc(this.props))return;const s=a6(e.props,"customPages","customMenuItems","children"),o=a6(this.props.props,"customPages","customMenuItems","children"),d=((t=s.customPages)==null?void 0:t.length)!==((n=o.customPages)==null?void 0:n.length),f=((a=s.customMenuItems)==null?void 0:a.length)!==((l=o.customMenuItems)==null?void 0:l.length),h=f6(e.props.customMenuItems),p=f6(this.props.props.customMenuItems);(!e6(s,o)||!e6(h,p)||d||f)&&this.rootRef.current&&this.props.updateProps({node:this.rootRef.current,props:this.props.props})}componentDidMount(){this.rootRef.current&&(bc(this.props)&&this.props.mount(this.rootRef.current,this.props.props),d6(this.props)&&this.props.open(this.props.props))}componentWillUnmount(){this.rootRef.current&&(bc(this.props)&&this.props.unmount(this.rootRef.current),d6(this.props)&&this.props.close())}render(){const{hideRootHtmlElement:e=!1}=this.props,t={ref:this.rootRef,...this.props.rootProps,...this.props.component&&{"data-clerk-component":this.props.component}};return he.createElement(he.Fragment,null,!e&&he.createElement("div",{...t}),this.props.children)}},ud=e=>{var t,n;return he.createElement(he.Fragment,null,(t=e==null?void 0:e.customPagesPortals)==null?void 0:t.map((a,l)=>Qe.createElement(a,{key:l})),(n=e==null?void 0:e.customMenuItemsPortals)==null?void 0:n.map((a,l)=>Qe.createElement(a,{key:l})))};gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{component:t,mount:e.mountSignIn,unmount:e.unmountSignIn,updateProps:e.__unstable__updateProps,props:a,rootProps:o}))},{component:"SignIn",renderWhileLoading:!0});gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{component:t,mount:e.mountSignUp,unmount:e.unmountSignUp,updateProps:e.__unstable__updateProps,props:a,rootProps:o}))},{component:"SignUp",renderWhileLoading:!0});function Do({children:e}){return sr(ZI),he.createElement(he.Fragment,null,e)}function Io({children:e}){return sr(JI),he.createElement(he.Fragment,null,e)}var WL=gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}},{customPages:d,customPagesPortals:f}=u8(a.children);return he.createElement(he.Fragment,null,s&&n,he.createElement(_r,{component:t,mount:e.mountUserProfile,unmount:e.unmountUserProfile,updateProps:e.__unstable__updateProps,props:{...a,customPages:d},rootProps:o},he.createElement(ud,{customPagesPortals:f})))},{component:"UserProfile",renderWhileLoading:!0});Object.assign(WL,{Page:Do,Link:Io});var f8=Qe.createContext({mount:()=>{},unmount:()=>{},updateProps:()=>{}}),QL=gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}},{customPages:d,customPagesPortals:f}=u8(a.children,{allowForAnyChildren:!!a.__experimental_asProvider}),h=Object.assign(a.userProfileProps||{},{customPages:d}),{customMenuItems:p,customMenuItemsPortals:E}=jL(a.children),T=c8(a.children),v={mount:e.mountUserButton,unmount:e.unmountUserButton,updateProps:e.__unstable__updateProps,props:{...a,userProfileProps:h,customMenuItems:p}},x={customPagesPortals:f,customMenuItemsPortals:E};return he.createElement(f8.Provider,{value:v},s&&n,e.loaded&&he.createElement(_r,{component:t,...v,hideRootHtmlElement:!!a.__experimental_asProvider,rootProps:o},a.__experimental_asProvider?T:null,he.createElement(ud,{...x})))},{component:"UserButton",renderWhileLoading:!0});function od({children:e}){return sr(sL),he.createElement(he.Fragment,null,e)}function h8({children:e}){return sr(uL),he.createElement(he.Fragment,null,e)}function m8({children:e}){return sr(oL),he.createElement(he.Fragment,null,e)}function ZL(e){const t=Qe.useContext(f8),n={...t,props:{...t.props,...e}};return he.createElement(_r,{...n})}var JL=Object.assign(QL,{UserProfilePage:Do,UserProfileLink:Io,MenuItems:od,Action:h8,Link:m8,__experimental_Outlet:ZL});function cd({children:e}){return sr(eL),he.createElement(he.Fragment,null,e)}function dd({children:e}){return sr(tL),he.createElement(he.Fragment,null,e)}var eB=gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}},{customPages:d,customPagesPortals:f}=o8(a.children);return he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{component:t,mount:e.mountOrganizationProfile,unmount:e.unmountOrganizationProfile,updateProps:e.__unstable__updateProps,props:{...a,customPages:d},rootProps:o},he.createElement(ud,{customPagesPortals:f})))},{component:"OrganizationProfile",renderWhileLoading:!0});Object.assign(eB,{Page:cd,Link:dd});gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{component:t,mount:e.mountCreateOrganization,unmount:e.unmountCreateOrganization,updateProps:e.__unstable__updateProps,props:a,rootProps:o}))},{component:"CreateOrganization",renderWhileLoading:!0});var p8=Qe.createContext({mount:()=>{},unmount:()=>{},updateProps:()=>{}}),tB=gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}},{customPages:d,customPagesPortals:f}=o8(a.children,{allowForAnyChildren:!!a.__experimental_asProvider}),h=Object.assign(a.organizationProfileProps||{},{customPages:d}),p=c8(a.children),E={mount:e.mountOrganizationSwitcher,unmount:e.unmountOrganizationSwitcher,updateProps:e.__unstable__updateProps,props:{...a,organizationProfileProps:h},rootProps:o,component:t};return e.__experimental_prefetchOrganizationSwitcher(),he.createElement(p8.Provider,{value:E},he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{...E,hideRootHtmlElement:!!a.__experimental_asProvider},a.__experimental_asProvider?p:null,he.createElement(ud,{customPagesPortals:f}))))},{component:"OrganizationSwitcher",renderWhileLoading:!0});function nB(e){const t=Qe.useContext(p8),n={...t,props:{...t.props,...e}};return he.createElement(_r,{...n})}Object.assign(tB,{OrganizationProfilePage:cd,OrganizationProfileLink:dd,__experimental_Outlet:nB});gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{component:t,mount:e.mountOrganizationList,unmount:e.unmountOrganizationList,updateProps:e.__unstable__updateProps,props:a,rootProps:o}))},{component:"OrganizationList",renderWhileLoading:!0});gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{component:t,open:e.openGoogleOneTap,close:e.closeGoogleOneTap,updateProps:e.__unstable__updateProps,props:a,rootProps:o}))},{component:"GoogleOneTap",renderWhileLoading:!0});gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{component:t,mount:e.mountWaitlist,unmount:e.unmountWaitlist,updateProps:e.__unstable__updateProps,props:a,rootProps:o}))},{component:"Waitlist",renderWhileLoading:!0});gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{component:t,mount:e.mountPricingTable,unmount:e.unmountPricingTable,updateProps:e.__unstable__updateProps,props:a,rootProps:o}))},{component:"PricingTable",renderWhileLoading:!0});gn(({clerk:e,component:t,fallback:n,...a})=>{const s=ra(t)==="rendering"||!e.loaded,o={...s&&n&&{style:{display:"none"}}};return he.createElement(he.Fragment,null,s&&n,e.loaded&&he.createElement(_r,{component:t,mount:e.mountApiKeys,unmount:e.unmountApiKeys,updateProps:e.__unstable__updateProps,props:a,rootProps:o}))},{component:"ApiKeys",renderWhileLoading:!0});gn(({clerk:e,children:t,...n})=>{const{signUpFallbackRedirectUrl:a,forceRedirectUrl:l,fallbackRedirectUrl:s,signUpForceRedirectUrl:o,mode:d,initialValues:f,withSignUp:h,oauthFlow:p,...E}=n;t=ld(t,"Sign in");const T=id(t)("SignInButton"),v=()=>{const D={forceRedirectUrl:l,fallbackRedirectUrl:s,signUpFallbackRedirectUrl:a,signUpForceRedirectUrl:o,initialValues:f,withSignUp:h,oauthFlow:p};return d==="modal"?e.openSignIn({...D,appearance:n.appearance}):e.redirectToSignIn({...D,signInFallbackRedirectUrl:s,signInForceRedirectUrl:l})},N={...E,onClick:async D=>(T&&typeof T=="object"&&"props"in T&&await sd(T.props.onClick)(D),v())};return he.cloneElement(T,N)},{component:"SignInButton",renderWhileLoading:!0});gn(({clerk:e,children:t,...n})=>{const{fallbackRedirectUrl:a,forceRedirectUrl:l,signInFallbackRedirectUrl:s,signInForceRedirectUrl:o,mode:d,unsafeMetadata:f,initialValues:h,oauthFlow:p,...E}=n;t=ld(t,"Sign up");const T=id(t)("SignUpButton"),v=()=>{const D={fallbackRedirectUrl:a,forceRedirectUrl:l,signInFallbackRedirectUrl:s,signInForceRedirectUrl:o,unsafeMetadata:f,initialValues:h,oauthFlow:p};return d==="modal"?e.openSignUp({...D,appearance:n.appearance}):e.redirectToSignUp({...D,signUpFallbackRedirectUrl:a,signUpForceRedirectUrl:l})},N={...E,onClick:async D=>(T&&typeof T=="object"&&"props"in T&&await sd(T.props.onClick)(D),v())};return he.cloneElement(T,N)},{component:"SignUpButton",renderWhileLoading:!0});gn(({clerk:e,children:t,...n})=>{const{redirectUrl:a="/",signOutOptions:l,...s}=n;t=ld(t,"Sign out");const o=id(t)("SignOutButton"),d=()=>e.signOut({redirectUrl:a,...l}),h={...s,onClick:async p=>(await sd(o.props.onClick)(p),d())};return he.cloneElement(o,h)},{component:"SignOutButton",renderWhileLoading:!0});gn(({clerk:e,children:t,...n})=>{const{redirectUrl:a,...l}=n;t=ld(t,"Sign in with Metamask");const s=id(t)("SignInWithMetamaskButton"),o=async()=>{async function h(){await e.authenticateWithMetamask({redirectUrl:a||void 0})}h()},f={...l,onClick:async h=>(await sd(s.props.onClick)(h),o())};return he.cloneElement(s,f)},{component:"SignInWithMetamask",renderWhileLoading:!0});typeof globalThis.__BUILD_DISABLE_RHC__>"u"&&(globalThis.__BUILD_DISABLE_RHC__=!1);var rB={name:"@clerk/clerk-react",version:"5.32.0",environment:"production"},Sc,_s,Ss,Vi,ei,ji,Ac,im,g8=class b8{constructor(t){Cl(this,Ac),this.clerkjs=null,this.preopenOneTap=null,this.preopenUserVerification=null,this.preopenSignIn=null,this.preopenCheckout=null,this.preopenPlanDetails=null,this.preopenSignUp=null,this.preopenUserProfile=null,this.preopenOrganizationProfile=null,this.preopenCreateOrganization=null,this.preOpenWaitlist=null,this.premountSignInNodes=new Map,this.premountSignUpNodes=new Map,this.premountUserProfileNodes=new Map,this.premountUserButtonNodes=new Map,this.premountOrganizationProfileNodes=new Map,this.premountCreateOrganizationNodes=new Map,this.premountOrganizationSwitcherNodes=new Map,this.premountOrganizationListNodes=new Map,this.premountMethodCalls=new Map,this.premountWaitlistNodes=new Map,this.premountPricingTableNodes=new Map,this.premountApiKeysNodes=new Map,this.premountOAuthConsentNodes=new Map,this.premountAddListenerCalls=new Map,this.loadedListeners=[],Cl(this,Sc,"loading"),Cl(this,_s),Cl(this,Ss),Cl(this,Vi),Cl(this,ei,YL()),this.buildSignInUrl=l=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildSignInUrl(l))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildSignInUrl",s)},this.buildSignUpUrl=l=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildSignUpUrl(l))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildSignUpUrl",s)},this.buildAfterSignInUrl=(...l)=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildAfterSignInUrl(...l))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildAfterSignInUrl",s)},this.buildAfterSignUpUrl=(...l)=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildAfterSignUpUrl(...l))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildAfterSignUpUrl",s)},this.buildAfterSignOutUrl=()=>{const l=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildAfterSignOutUrl())||""};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("buildAfterSignOutUrl",l)},this.buildNewSubscriptionRedirectUrl=()=>{const l=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildNewSubscriptionRedirectUrl())||""};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("buildNewSubscriptionRedirectUrl",l)},this.buildAfterMultiSessionSingleSignOutUrl=()=>{const l=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildAfterMultiSessionSingleSignOutUrl())||""};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("buildAfterMultiSessionSingleSignOutUrl",l)},this.buildUserProfileUrl=()=>{const l=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildUserProfileUrl())||""};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("buildUserProfileUrl",l)},this.buildCreateOrganizationUrl=()=>{const l=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildCreateOrganizationUrl())||""};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("buildCreateOrganizationUrl",l)},this.buildOrganizationProfileUrl=()=>{const l=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildOrganizationProfileUrl())||""};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("buildOrganizationProfileUrl",l)},this.buildWaitlistUrl=()=>{const l=()=>{var s;return((s=this.clerkjs)==null?void 0:s.buildWaitlistUrl())||""};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("buildWaitlistUrl",l)},this.buildUrlWithAuth=l=>{const s=()=>{var o;return((o=this.clerkjs)==null?void 0:o.buildUrlWithAuth(l))||""};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("buildUrlWithAuth",s)},this.handleUnauthenticated=async()=>{const l=()=>{var s;return(s=this.clerkjs)==null?void 0:s.handleUnauthenticated()};this.clerkjs&&this.loaded?l():this.premountMethodCalls.set("handleUnauthenticated",l)},this.on=(...l)=>{var s;if((s=this.clerkjs)!=null&&s.on)return this.clerkjs.on(...l);cn(this,ei).on(...l)},this.off=(...l)=>{var s;if((s=this.clerkjs)!=null&&s.off)return this.clerkjs.off(...l);cn(this,ei).off(...l)},this.addOnLoaded=l=>{this.loadedListeners.push(l),this.loaded&&this.emitLoaded()},this.emitLoaded=()=>{this.loadedListeners.forEach(l=>l()),this.loadedListeners=[]},this.beforeLoad=l=>{if(!l)throw new Error("Failed to hydrate latest Clerk JS")},this.hydrateClerkJS=l=>{var s;if(!l)throw new Error("Failed to hydrate latest Clerk JS");return this.clerkjs=l,this.premountMethodCalls.forEach(o=>o()),this.premountAddListenerCalls.forEach((o,d)=>{o.nativeUnsubscribe=l.addListener(d)}),(s=cn(this,ei).internal.retrieveListeners("status"))==null||s.forEach(o=>{this.on("status",o,{notify:!0})}),this.preopenSignIn!==null&&l.openSignIn(this.preopenSignIn),this.preopenCheckout!==null&&l.__internal_openCheckout(this.preopenCheckout),this.preopenPlanDetails!==null&&l.__internal_openPlanDetails(this.preopenPlanDetails),this.preopenSignUp!==null&&l.openSignUp(this.preopenSignUp),this.preopenUserProfile!==null&&l.openUserProfile(this.preopenUserProfile),this.preopenUserVerification!==null&&l.__internal_openReverification(this.preopenUserVerification),this.preopenOneTap!==null&&l.openGoogleOneTap(this.preopenOneTap),this.preopenOrganizationProfile!==null&&l.openOrganizationProfile(this.preopenOrganizationProfile),this.preopenCreateOrganization!==null&&l.openCreateOrganization(this.preopenCreateOrganization),this.preOpenWaitlist!==null&&l.openWaitlist(this.preOpenWaitlist),this.premountSignInNodes.forEach((o,d)=>{l.mountSignIn(d,o)}),this.premountSignUpNodes.forEach((o,d)=>{l.mountSignUp(d,o)}),this.premountUserProfileNodes.forEach((o,d)=>{l.mountUserProfile(d,o)}),this.premountUserButtonNodes.forEach((o,d)=>{l.mountUserButton(d,o)}),this.premountOrganizationListNodes.forEach((o,d)=>{l.mountOrganizationList(d,o)}),this.premountWaitlistNodes.forEach((o,d)=>{l.mountWaitlist(d,o)}),this.premountPricingTableNodes.forEach((o,d)=>{l.mountPricingTable(d,o)}),this.premountApiKeysNodes.forEach((o,d)=>{l.mountApiKeys(d,o)}),this.premountOAuthConsentNodes.forEach((o,d)=>{l.__internal_mountOAuthConsent(d,o)}),typeof this.clerkjs.status>"u"&&cn(this,ei).emit(pc.Status,"ready"),this.emitLoaded(),this.clerkjs},this.__unstable__updateProps=async l=>{const s=await n6(this,Ac,im).call(this);if(s&&"__unstable__updateProps"in s)return s.__unstable__updateProps(l)},this.__experimental_navigateToTask=async l=>this.clerkjs?this.clerkjs.__experimental_navigateToTask(l):Promise.reject(),this.setActive=l=>this.clerkjs?this.clerkjs.setActive(l):Promise.reject(),this.openSignIn=l=>{this.clerkjs&&this.loaded?this.clerkjs.openSignIn(l):this.preopenSignIn=l},this.closeSignIn=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeSignIn():this.preopenSignIn=null},this.__internal_openCheckout=l=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_openCheckout(l):this.preopenCheckout=l},this.__internal_closeCheckout=()=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_closeCheckout():this.preopenCheckout=null},this.__internal_openPlanDetails=l=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_openPlanDetails(l):this.preopenPlanDetails=l},this.__internal_closePlanDetails=()=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_closePlanDetails():this.preopenPlanDetails=null},this.__internal_openReverification=l=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_openReverification(l):this.preopenUserVerification=l},this.__internal_closeReverification=()=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_closeReverification():this.preopenUserVerification=null},this.openGoogleOneTap=l=>{this.clerkjs&&this.loaded?this.clerkjs.openGoogleOneTap(l):this.preopenOneTap=l},this.closeGoogleOneTap=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeGoogleOneTap():this.preopenOneTap=null},this.openUserProfile=l=>{this.clerkjs&&this.loaded?this.clerkjs.openUserProfile(l):this.preopenUserProfile=l},this.closeUserProfile=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeUserProfile():this.preopenUserProfile=null},this.openOrganizationProfile=l=>{this.clerkjs&&this.loaded?this.clerkjs.openOrganizationProfile(l):this.preopenOrganizationProfile=l},this.closeOrganizationProfile=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeOrganizationProfile():this.preopenOrganizationProfile=null},this.openCreateOrganization=l=>{this.clerkjs&&this.loaded?this.clerkjs.openCreateOrganization(l):this.preopenCreateOrganization=l},this.closeCreateOrganization=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeCreateOrganization():this.preopenCreateOrganization=null},this.openWaitlist=l=>{this.clerkjs&&this.loaded?this.clerkjs.openWaitlist(l):this.preOpenWaitlist=l},this.closeWaitlist=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeWaitlist():this.preOpenWaitlist=null},this.openSignUp=l=>{this.clerkjs&&this.loaded?this.clerkjs.openSignUp(l):this.preopenSignUp=l},this.closeSignUp=()=>{this.clerkjs&&this.loaded?this.clerkjs.closeSignUp():this.preopenSignUp=null},this.mountSignIn=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountSignIn(l,s):this.premountSignInNodes.set(l,s)},this.unmountSignIn=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountSignIn(l):this.premountSignInNodes.delete(l)},this.mountSignUp=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountSignUp(l,s):this.premountSignUpNodes.set(l,s)},this.unmountSignUp=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountSignUp(l):this.premountSignUpNodes.delete(l)},this.mountUserProfile=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountUserProfile(l,s):this.premountUserProfileNodes.set(l,s)},this.unmountUserProfile=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountUserProfile(l):this.premountUserProfileNodes.delete(l)},this.mountOrganizationProfile=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountOrganizationProfile(l,s):this.premountOrganizationProfileNodes.set(l,s)},this.unmountOrganizationProfile=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountOrganizationProfile(l):this.premountOrganizationProfileNodes.delete(l)},this.mountCreateOrganization=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountCreateOrganization(l,s):this.premountCreateOrganizationNodes.set(l,s)},this.unmountCreateOrganization=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountCreateOrganization(l):this.premountCreateOrganizationNodes.delete(l)},this.mountOrganizationSwitcher=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountOrganizationSwitcher(l,s):this.premountOrganizationSwitcherNodes.set(l,s)},this.unmountOrganizationSwitcher=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountOrganizationSwitcher(l):this.premountOrganizationSwitcherNodes.delete(l)},this.__experimental_prefetchOrganizationSwitcher=()=>{const l=()=>{var s;return(s=this.clerkjs)==null?void 0:s.__experimental_prefetchOrganizationSwitcher()};this.clerkjs&&this.loaded?l():this.premountMethodCalls.set("__experimental_prefetchOrganizationSwitcher",l)},this.mountOrganizationList=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountOrganizationList(l,s):this.premountOrganizationListNodes.set(l,s)},this.unmountOrganizationList=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountOrganizationList(l):this.premountOrganizationListNodes.delete(l)},this.mountUserButton=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountUserButton(l,s):this.premountUserButtonNodes.set(l,s)},this.unmountUserButton=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountUserButton(l):this.premountUserButtonNodes.delete(l)},this.mountWaitlist=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountWaitlist(l,s):this.premountWaitlistNodes.set(l,s)},this.unmountWaitlist=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountWaitlist(l):this.premountWaitlistNodes.delete(l)},this.mountPricingTable=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountPricingTable(l,s):this.premountPricingTableNodes.set(l,s)},this.unmountPricingTable=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountPricingTable(l):this.premountPricingTableNodes.delete(l)},this.mountApiKeys=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.mountApiKeys(l,s):this.premountApiKeysNodes.set(l,s)},this.unmountApiKeys=l=>{this.clerkjs&&this.loaded?this.clerkjs.unmountApiKeys(l):this.premountApiKeysNodes.delete(l)},this.__internal_mountOAuthConsent=(l,s)=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_mountOAuthConsent(l,s):this.premountOAuthConsentNodes.set(l,s)},this.__internal_unmountOAuthConsent=l=>{this.clerkjs&&this.loaded?this.clerkjs.__internal_unmountOAuthConsent(l):this.premountOAuthConsentNodes.delete(l)},this.addListener=l=>{if(this.clerkjs)return this.clerkjs.addListener(l);{const s=()=>{var o;const d=this.premountAddListenerCalls.get(l);d&&((o=d.nativeUnsubscribe)==null||o.call(d),this.premountAddListenerCalls.delete(l))};return this.premountAddListenerCalls.set(l,{unsubscribe:s,nativeUnsubscribe:void 0}),s}},this.navigate=l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.navigate(l)};this.clerkjs&&this.loaded?s():this.premountMethodCalls.set("navigate",s)},this.redirectWithAuth=async(...l)=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.redirectWithAuth(...l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("redirectWithAuth",s)},this.redirectToSignIn=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.redirectToSignIn(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("redirectToSignIn",s)},this.redirectToSignUp=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.redirectToSignUp(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("redirectToSignUp",s)},this.redirectToUserProfile=async()=>{const l=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToUserProfile()};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("redirectToUserProfile",l)},this.redirectToAfterSignUp=()=>{const l=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToAfterSignUp()};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("redirectToAfterSignUp",l)},this.redirectToAfterSignIn=()=>{const l=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToAfterSignIn()};this.clerkjs&&this.loaded?l():this.premountMethodCalls.set("redirectToAfterSignIn",l)},this.redirectToAfterSignOut=()=>{const l=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToAfterSignOut()};this.clerkjs&&this.loaded?l():this.premountMethodCalls.set("redirectToAfterSignOut",l)},this.redirectToOrganizationProfile=async()=>{const l=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToOrganizationProfile()};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("redirectToOrganizationProfile",l)},this.redirectToCreateOrganization=async()=>{const l=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToCreateOrganization()};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("redirectToCreateOrganization",l)},this.redirectToWaitlist=async()=>{const l=()=>{var s;return(s=this.clerkjs)==null?void 0:s.redirectToWaitlist()};if(this.clerkjs&&this.loaded)return l();this.premountMethodCalls.set("redirectToWaitlist",l)},this.handleRedirectCallback=async l=>{var s;const o=()=>{var d;return(d=this.clerkjs)==null?void 0:d.handleRedirectCallback(l)};this.clerkjs&&this.loaded?(s=o())==null||s.catch(()=>{}):this.premountMethodCalls.set("handleRedirectCallback",o)},this.handleGoogleOneTapCallback=async(l,s)=>{var o;const d=()=>{var f;return(f=this.clerkjs)==null?void 0:f.handleGoogleOneTapCallback(l,s)};this.clerkjs&&this.loaded?(o=d())==null||o.catch(()=>{}):this.premountMethodCalls.set("handleGoogleOneTapCallback",d)},this.handleEmailLinkVerification=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.handleEmailLinkVerification(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("handleEmailLinkVerification",s)},this.authenticateWithMetamask=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithMetamask(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithMetamask",s)},this.authenticateWithCoinbaseWallet=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithCoinbaseWallet(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithCoinbaseWallet",s)},this.authenticateWithOKXWallet=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithOKXWallet(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithOKXWallet",s)},this.authenticateWithWeb3=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.authenticateWithWeb3(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("authenticateWithWeb3",s)},this.authenticateWithGoogleOneTap=async l=>(await n6(this,Ac,im).call(this)).authenticateWithGoogleOneTap(l),this.createOrganization=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.createOrganization(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("createOrganization",s)},this.getOrganization=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.getOrganization(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("getOrganization",s)},this.joinWaitlist=async l=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.joinWaitlist(l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("joinWaitlist",s)},this.signOut=async(...l)=>{const s=()=>{var o;return(o=this.clerkjs)==null?void 0:o.signOut(...l)};if(this.clerkjs&&this.loaded)return s();this.premountMethodCalls.set("signOut",s)};const{Clerk:n=null,publishableKey:a}=t||{};Es(this,Vi,a),Es(this,Ss,t==null?void 0:t.proxyUrl),Es(this,_s,t==null?void 0:t.domain),this.options=t,this.Clerk=n,this.mode=i6()?"browser":"server",this.options.sdkMetadata||(this.options.sdkMetadata=rB),cn(this,ei).emit(pc.Status,"loading"),cn(this,ei).prioritizedOn(pc.Status,l=>Es(this,Sc,l)),cn(this,Vi)&&this.loadClerkJS()}get publishableKey(){return cn(this,Vi)}get loaded(){var t;return((t=this.clerkjs)==null?void 0:t.loaded)||!1}get status(){var t;return this.clerkjs?((t=this.clerkjs)==null?void 0:t.status)||(this.clerkjs.loaded?"ready":"loading"):cn(this,Sc)}static getOrCreateInstance(t){return(!i6()||!cn(this,ji)||t.Clerk&&cn(this,ji).Clerk!==t.Clerk||cn(this,ji).publishableKey!==t.publishableKey)&&Es(this,ji,new b8(t)),cn(this,ji)}static clearInstance(){Es(this,ji,null)}get domain(){return typeof window<"u"&&window.location?m1(cn(this,_s),new URL(window.location.href),""):typeof cn(this,_s)=="function"?Ca.throw(h1):cn(this,_s)||""}get proxyUrl(){return typeof window<"u"&&window.location?m1(cn(this,Ss),new URL(window.location.href),""):typeof cn(this,Ss)=="function"?Ca.throw(h1):cn(this,Ss)||""}__internal_getOption(t){var n,a;return(n=this.clerkjs)!=null&&n.__internal_getOption?(a=this.clerkjs)==null?void 0:a.__internal_getOption(t):this.options[t]}get sdkMetadata(){var t;return((t=this.clerkjs)==null?void 0:t.sdkMetadata)||this.options.sdkMetadata||void 0}get instanceType(){var t;return(t=this.clerkjs)==null?void 0:t.instanceType}get frontendApi(){var t;return((t=this.clerkjs)==null?void 0:t.frontendApi)||""}get isStandardBrowser(){var t;return((t=this.clerkjs)==null?void 0:t.isStandardBrowser)||this.options.standardBrowser||!1}get isSatellite(){return typeof window<"u"&&window.location?m1(this.options.isSatellite,new URL(window.location.href),!1):typeof this.options.isSatellite=="function"?Ca.throw(h1):!1}async loadClerkJS(){var t;if(!(this.mode!=="browser"||this.loaded)){typeof window<"u"&&(window.__clerk_publishable_key=cn(this,Vi),window.__clerk_proxy_url=this.proxyUrl,window.__clerk_domain=this.domain);try{if(this.Clerk){let n;GL(this.Clerk)?(n=new this.Clerk(cn(this,Vi),{proxyUrl:this.proxyUrl,domain:this.domain}),this.beforeLoad(n),await n.load(this.options)):(n=this.Clerk,n.loaded||(this.beforeLoad(n),await n.load(this.options))),global.Clerk=n}else if(!__BUILD_DISABLE_RHC__){if(global.Clerk||await IL({...this.options,publishableKey:cn(this,Vi),proxyUrl:this.proxyUrl,domain:this.domain,nonce:this.options.nonce}),!global.Clerk)throw new Error("Failed to download latest ClerkJS. Contact support@clerk.com.");this.beforeLoad(global.Clerk),await global.Clerk.load(this.options)}return(t=global.Clerk)!=null&&t.loaded?this.hydrateClerkJS(global.Clerk):void 0}catch(n){const a=n;cn(this,ei).emit(pc.Status,"error"),console.error(a.stack||a.message||a);return}}}get version(){var t;return(t=this.clerkjs)==null?void 0:t.version}get client(){if(this.clerkjs)return this.clerkjs.client}get session(){if(this.clerkjs)return this.clerkjs.session}get user(){if(this.clerkjs)return this.clerkjs.user}get organization(){if(this.clerkjs)return this.clerkjs.organization}get telemetry(){if(this.clerkjs)return this.clerkjs.telemetry}get __unstable__environment(){if(this.clerkjs)return this.clerkjs.__unstable__environment}get isSignedIn(){return this.clerkjs?this.clerkjs.isSignedIn:!1}get billing(){var t;return(t=this.clerkjs)==null?void 0:t.billing}get apiKeys(){var t;return(t=this.clerkjs)==null?void 0:t.apiKeys}__unstable__setEnvironment(...t){if(this.clerkjs&&"__unstable__setEnvironment"in this.clerkjs)this.clerkjs.__unstable__setEnvironment(t);else return}};Sc=new WeakMap;_s=new WeakMap;Ss=new WeakMap;Vi=new WeakMap;ei=new WeakMap;ji=new WeakMap;Ac=new WeakSet;im=function(){return new Promise(e=>{this.addOnLoaded(()=>e(this.clerkjs))})};Cl(g8,ji);var h6=g8;function aB(e){const{isomorphicClerkOptions:t,initialState:n,children:a}=e,{isomorphicClerk:l,clerkStatus:s}=iB(t),[o,d]=he.useState({client:l.client,session:l.session,user:l.user,organization:l.organization});he.useEffect(()=>l.addListener(ce=>d({...ce})),[]);const f=zL(l.loaded,o,n),h=he.useMemo(()=>({value:l}),[s]),p=he.useMemo(()=>({value:o.client}),[o.client]),{sessionId:E,sessionStatus:T,sessionClaims:v,session:x,userId:N,user:D,orgId:C,actor:I,organization:F,orgRole:J,orgSlug:K,orgPermissions:U,factorVerificationAge:le}=f,ae=he.useMemo(()=>({value:{sessionId:E,sessionStatus:T,sessionClaims:v,userId:N,actor:I,orgId:C,orgRole:J,orgSlug:K,orgPermissions:U,factorVerificationAge:le}}),[E,T,N,I,C,J,K,le,v==null?void 0:v.__raw]),se=he.useMemo(()=>({value:x}),[E,x]),G=he.useMemo(()=>({value:D}),[N,D]),ge=he.useMemo(()=>({value:{organization:F}}),[C,F]);return he.createElement(XI.Provider,{value:h},he.createElement(PI.Provider,{value:p},he.createElement(UI.Provider,{value:se},he.createElement(HI,{...ge.value},he.createElement(KI.Provider,{value:ae},he.createElement(BI.Provider,{value:G},a))))))}var iB=e=>{const t=he.useRef(h6.getOrCreateInstance(e)),[n,a]=he.useState(t.current.status);return he.useEffect(()=>{t.current.__unstable__updateProps({appearance:e.appearance})},[e.appearance]),he.useEffect(()=>{t.current.__unstable__updateProps({options:e})},[e.localization]),he.useEffect(()=>(t.current.on("status",a),()=>{t.current&&t.current.off("status",a),h6.clearInstance()}),[]),{isomorphicClerk:t.current,clerkStatus:n}};function lB(e){const{initialState:t,children:n,__internal_bypassMissingPublishableKey:a,...l}=e,{publishableKey:s="",Clerk:o}=l;return!o&&!a&&(s?s&&!K1(s)&&Ca.throwInvalidPublishableKeyError({key:s}):Ca.throwMissingPublishableKeyError()),he.createElement(aB,{initialState:t,isomorphicClerkOptions:l},n)}var E8=KL(lB,"ClerkProvider",$I);E8.displayName="ClerkProvider";VI({packageName:"@clerk/clerk-react"});DL("@clerk/clerk-react");const sB=({children:e})=>gt.jsx("div",{className:"not-prose",children:e}),uB=({href:e,onSend:t,...n})=>{const a=Qe.useCallback(l=>{t(decodeURIComponent(e.slice(23))),l.preventDefault()},[e,t]);return e.startsWith("https://cycls.com/send/")?gt.jsx("a",{...n,className:n.className||"underline decoration-gray-500/40 decoration-2 hover:decoration-gray-500/60",href:"#",onClick:a}):gt.jsx("a",{...n,href:e,target:"_blank"})},As=he.memo(({markdown:e,onSend:t})=>{const n=Qe.useMemo(()=>({raw:sB,a:a=>gt.jsx(uB,{...a,onSend:t})}),[t]);return gt.jsx("div",{dir:"auto",children:gt.jsx(DS,{components:n,remarkPlugins:[Vx,TD],rehypePlugins:[dC,cD,[ZO,{ignoreMissing:!0}]],children:e})})}),oB=({onSend:e})=>{const[t,n]=Qe.useState(""),[a,l]=Qe.useState(!1);Qe.useEffect(()=>{const d=()=>l(window.innerWidth<=768);return d(),window.addEventListener("resize",d),()=>window.removeEventListener("resize",d)},[]);const s=()=>{e(t),n("")},o=d=>{d.key==="Enter"&&!d.shiftKey&&!a&&(d.preventDefault(),s())};return gt.jsxs("div",{className:"fixed bottom-3 inset-x-2 mx-auto flex max-w-2xl items-end rounded-3xl bg-gray-50/90 backdrop-blur p-2 border",children:[gt.jsx("button",{onClick:()=>e(":clear"),className:"mb-1 border rounded-full bg-white hover:opacity-60",children:gt.jsx("svg",{className:"h-8 w-8",width:"24",height:"24"})}),gt.jsx("textarea",{className:"flex-grow resize-none border-0 bg-transparent focus:ring-0",dir:"auto",autoFocus:!0,tabIndex:"0",rows:t.split(`
`).length,placeholder:"Message @agent",onChange:d=>n(d.target.value),onKeyPress:o,value:t}),gt.jsx("button",{onClick:s,className:"mb-1 rounded-full bg-black hover:opacity-60 flex items-center justify-center w-8 h-8",children:gt.jsx("svg",{className:"h-5 w-5",viewBox:"0 0 24 24",fill:"none",xmlns:"http://www.w3.org/2000/svg",children:gt.jsx("path",{d:"M12 4L12 20M12 4L7 9M12 4L17 9",stroke:"white",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round"})})})]})},cB=he.memo(({messages:e,onSend:t})=>{const n=Qe.useMemo(()=>e.map((a,l)=>a.type==="request"?gt.jsx("div",{className:/[\u0591-\u07FF\uFB1D-\uFDFD\uFE70-\uFEFC]/.test(a.content)?"flex justify-start":"flex justify-end",children:gt.jsx("div",{className:"bg-gray-100 p-4 m-2 rounded-3xl max-w-4/5",children:gt.jsx("div",{dir:"auto",style:{whiteSpace:"pre-wrap"},children:a.content})})},l):gt.jsx(As,{markdown:a.content,onSend:t},l)),[e,t]);return gt.jsx(gt.Fragment,{children:n})}),dB=(e,t,n)=>async a=>{var o;if(!a.trim()){n(!0);return}if(a===":clear"){t([]),window.scrollTo(0,0);return}if(a.startsWith(":echo")){t(d=>[...d,{type:"request",content:a},{type:"response",content:a}]),window.scrollTo(0,document.body.scrollHeight),n(!0);return}t(d=>[...d,{type:"request",content:a},{type:"response",content:""}]),window.scrollTo(0,document.body.scrollHeight);const s=[...e,{type:"request",content:a}].map(({type:d,content:f})=>({role:d==="request"?"user":"assistant",content:f}));try{const d={"Content-Type":"application/json"};if(AUTH){const v=await((o=Clerk.session)==null?void 0:o.getToken({template:"template"}));await Clerk.setActive({organization:ORG}),d.Authorization=`Bearer ${v}`}const f=await fetch("/",{method:"POST",headers:d,body:JSON.stringify({messages:s})});if(!f.ok)throw new Error(`HTTP error! status: ${f.status}`);const h=f.body.getReader(),p=new TextDecoder;let E=!1,T="";for(;!E;){const{value:v,done:x}=await h.read();if(E=x,v){const N=p.decode(v,{stream:!0});T+=N,t(D=>{const C=[...D];return C[C.length-1].content=T,C}),window.scrollTo(0,document.body.scrollHeight)}}n(!0)}catch(d){console.error("Fetch error:",d),n(!0)}},m6=()=>{const[e,t]=Qe.useState([]),[n,a]=Qe.useState(!1);Qe.useEffect(()=>{n&&(document.querySelector("textarea").focus(),a(!1))},[n]);const l=Qe.useCallback(dB(e,t,a),[e]);return gt.jsxs("div",{className:"prose m-2 mx-auto max-w-2xl p-2 prose-pre:p-0",children:[gt.jsx(As,{markdown:HEADER,onSend:l}),e.length===0?gt.jsx(As,{markdown:INTRO,onSend:l}):null,gt.jsx(cB,{messages:e,onSend:l}),gt.jsxs("div",{className:"opacity-0",children:[gt.jsx(As,{markdown:"."}),gt.jsx(As,{markdown:"."}),gt.jsx(As,{markdown:"."})]}),gt.jsx(oB,{onSend:l})]})},fB=PROD?{isSatellite:!0,domain:"cycls.ai",signInUrl:"https://accounts.cycls.com/sign-in"}:{},hB=document.getElementById("root"),p6=Nv.createRoot(hB);AUTH?p6.render(gt.jsxs(E8,{publishableKey:PUBLISHABLE_KEY,...fB,children:[gt.jsxs(pL,{children:[gt.jsx("div",{className:"fixed right-2 top-2 z-50",children:gt.jsx(JL,{})}),gt.jsx(m6,{})]}),gt.jsx(gL,{children:gt.jsx(bL,{})})]})):p6.render(gt.jsx(m6,{}));
